@@ -40,29 +40,6 @@
 #include "emu.h"
 
 
-//**************************************************************************
-//  ADDRESS MAP ENTRY
-//**************************************************************************
-
-//-------------------------------------------------
-//  set_tag - set the appropriate tag for a device
-//-------------------------------------------------
-
-inline void map_handler_data::set_tag(const device_t &device, const char *tag)
-{
-	if (strcmp(tag, DEVICE_SELF) == 0)
-		m_tag = device.tag();
-	else if (strcmp(tag, DEVICE_SELF_OWNER) == 0)
-	{
-		assert(device.owner() != NULL);
-		m_tag = device.owner()->tag();
-	}
-	else
-		m_tag = device.subtag(m_derived_tag, tag);
-}
-
-
-
 //**************************************************************************
 //  ADDRESS MAP ENTRY
 //**************************************************************************
@@ -132,7 +109,7 @@ void address_map_entry::set_mask(offs_t _mask)
 void address_map_entry::set_read_port(const device_t &device, const char *tag)
 {
 	m_read.m_type = AMH_PORT;
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 }
 
 
@@ -144,7 +121,7 @@ void address_map_entry::set_read_port(const device_t &device, const char *tag)
 void address_map_entry::set_write_port(const device_t &device, const char *tag)
 {
 	m_write.m_type = AMH_PORT;
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 }
 
 
@@ -156,9 +133,9 @@ void address_map_entry::set_write_port(const device_t &device, const char *tag)
 void address_map_entry::set_readwrite_port(const device_t &device, const char *tag)
 {
 	m_read.m_type = AMH_PORT;
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_write.m_type = AMH_PORT;
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 }
 
 
@@ -170,7 +147,7 @@ void address_map_entry::set_readwrite_port(const device_t &device, const char *t
 void address_map_entry::set_read_bank(const device_t &device, const char *tag)
 {
 	m_read.m_type = AMH_BANK;
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 }
 
 
@@ -182,21 +159,44 @@ void address_map_entry::set_read_bank(const device_t &device, const char *tag)
 void address_map_entry::set_write_bank(const device_t &device, const char *tag)
 {
 	m_write.m_type = AMH_BANK;
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 }
 
 
 //-------------------------------------------------
 //  set_readwrite_bank - set up a handler for
-//  writing to a memory bank
+//  reading and writing to a memory bank
 //-------------------------------------------------
 
 void address_map_entry::set_readwrite_bank(const device_t &device, const char *tag)
 {
 	m_read.m_type = AMH_BANK;
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_write.m_type = AMH_BANK;
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
+}
+
+
+//-------------------------------------------------
+//  set_submap - set up a handler for
+//  retrieve a submap from a device
+//-------------------------------------------------
+
+void address_map_entry::set_submap(const device_t &device, const char *tag, address_map_delegate func, int bits, UINT64 mask)
+{
+	if(!bits)
+		bits = m_map.m_databits;
+
+	assert(unitmask_is_appropriate(bits, mask, func.name()));
+
+	m_read.m_type = AMH_DEVICE_SUBMAP;
+	device.subtag(m_read.m_tag, tag);
+	m_read.m_mask = mask;
+	m_write.m_type = AMH_DEVICE_SUBMAP;
+	device.subtag(m_write.m_tag, tag);
+	m_write.m_mask = mask;
+	m_submap_delegate = func;
+	m_submap_bits = bits;
 }
 
 
@@ -244,7 +244,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_read.m_bits = 8;
 	m_read.m_mask = unitmask;
 	m_read.m_name = string;
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_rdevice8 = func;
 }
 
@@ -257,7 +257,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_write.m_bits = 8;
 	m_write.m_mask = unitmask;
 	m_write.m_name = string;
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 	m_wdevice8 = func;
 }
 
@@ -277,7 +277,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_read.m_bits = 8;
 	m_read.m_mask = unitmask;
 	m_read.m_name = func.name();
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_rproto8 = func;
 }
 
@@ -290,7 +290,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_write.m_bits = 8;
 	m_write.m_mask = unitmask;
 	m_write.m_name = func.name();
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 	m_wproto8 = func;
 }
 
@@ -346,7 +346,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_read.m_bits = 16;
 	m_read.m_mask = unitmask;
 	m_read.m_name = string;
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_rdevice16 = func;
 }
 
@@ -359,7 +359,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_write.m_bits = 16;
 	m_write.m_mask = unitmask;
 	m_write.m_name = string;
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 	m_wdevice16 = func;
 }
 
@@ -379,7 +379,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_read.m_bits = 16;
 	m_read.m_mask = unitmask;
 	m_read.m_name = func.name();
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_rproto16 = func;
 }
 
@@ -392,7 +392,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_write.m_bits = 16;
 	m_write.m_mask = unitmask;
 	m_write.m_name = func.name();
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 	m_wproto16 = func;
 }
 
@@ -448,7 +448,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_read.m_bits = 32;
 	m_read.m_mask = unitmask;
 	m_read.m_name = string;
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_rdevice32 = func;
 }
 
@@ -461,7 +461,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_write.m_bits = 32;
 	m_write.m_mask = unitmask;
 	m_write.m_name = string;
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 	m_wdevice32 = func;
 }
 
@@ -481,7 +481,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_read.m_bits = 32;
 	m_read.m_mask = unitmask;
 	m_read.m_name = func.name();
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_rproto32 = func;
 }
 
@@ -494,7 +494,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_write.m_bits = 32;
 	m_write.m_mask = unitmask;
 	m_write.m_name = func.name();
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 	m_wproto32 = func;
 }
 
@@ -550,7 +550,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_read.m_bits = 64;
 	m_read.m_mask = 0;
 	m_read.m_name = string;
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_rdevice64 = func;
 }
 
@@ -563,7 +563,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_write.m_bits = 64;
 	m_write.m_mask = 0;
 	m_write.m_name = string;
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 	m_wdevice64 = func;
 }
 
@@ -583,7 +583,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_read.m_bits = 64;
 	m_read.m_mask = 0;
 	m_read.m_name = func.name();
-	m_read.set_tag(device, tag);
+	device.subtag(m_read.m_tag, tag);
 	m_rproto64 = func;
 }
 
@@ -596,7 +596,7 @@ void address_map_entry::internal_set_handler(const device_t &device, const char
 	m_write.m_bits = 64;
 	m_write.m_mask = 0;
 	m_write.m_name = func.name();
-	m_write.set_tag(device, tag);
+	device.subtag(m_write.m_tag, tag);
 	m_wproto64 = func;
 }
 
@@ -724,6 +724,23 @@ address_map::address_map(const device_t &device, address_spacenum spacenum)
 }
 
 
+
+//-------------------------------------------------
+//  address_map - constructor in the submap case
+//-------------------------------------------------
+
+address_map::address_map(const device_t &device, address_map_entry *entry)
+	: m_spacenum(AS_PROGRAM),
+	  m_databits(0xff),
+	  m_unmapval(0),
+	  m_globalmask(0)
+{
+	// Retrieve the submap
+	entry->m_submap_delegate.late_bind(const_cast<device_t &>(device));
+	entry->m_submap_delegate(*this, device);
+}
+
+
 //-------------------------------------------------
 //  ~address_map - destructor
 //-------------------------------------------------
@@ -797,3 +814,139 @@ address_map_entry64 *address_map::add(offs_t start, offs_t end, address_map_entr
 	m_entrylist.append(*ptr);
 	return ptr;
 }
+
+
+//-------------------------------------------------
+//  uplift_submaps - propagate in the device submaps
+//-------------------------------------------------
+
+void address_map::uplift_submaps(running_machine &machine, device_t &device, endianness_t endian)
+{
+	address_map_entry *prev = 0;
+	address_map_entry *entry = m_entrylist.first();
+	while (entry)
+	{
+		if (entry->m_read.m_type == AMH_DEVICE_SUBMAP)
+		{
+			const char *tag = entry->m_read.m_tag;
+			device_t *mapdevice = machine.device(tag);
+			if (mapdevice == NULL)
+				throw emu_fatalerror("Attempted to submap a non-existent device '%s' in space %d of device '%s'\n", tag, m_spacenum, device.tag());
+			// Grab the submap
+			address_map submap(*mapdevice, entry);
+
+			// Recursively uplift it if needed
+			submap.uplift_submaps(machine, *mapdevice, endian);
+
+			// Compute the unit repartition characteristics
+			int entry_bits = entry->m_submap_bits;
+			if (!entry_bits)
+				entry_bits = m_databits;
+
+			if (submap.m_databits != entry_bits)
+				throw emu_fatalerror("AM_DEVICE wants a %d bits large address map and got a %d bits large one instead.\n", entry_bits, submap.m_databits);
+
+			int entry_bytes = entry_bits / 8;
+			int databytes = m_databits / 8;
+
+			offs_t mirror_address_mask = (databytes - 1) & ~(entry_bytes - 1);
+
+			UINT64 entry_mask = (2ULL << (entry_bits-1)) - 1;
+
+			int slot_offset[8];
+			int slot_count = 0;
+			int max_slot_count = m_databits / entry_bits;
+			int slot_xor_mask = endian == ENDIANNESS_LITTLE ? 0 : max_slot_count - 1;
+
+			UINT64 global_mask = entry->m_read.m_mask;
+			// zero means all
+			if (!global_mask)
+				global_mask = ~global_mask;
+
+			// mask consistency has already been checked in
+			// unitmask_is_appropriate, so one bit is enough
+			for (int slot=0; slot < max_slot_count; slot++)
+				if (global_mask & (1ULL << (slot * entry_bits)))
+					slot_offset[slot_count++] = (slot ^ slot_xor_mask) * entry_bits;
+
+			// Merge in all the map contents in order
+			while (submap.m_entrylist.count())
+			{
+				address_map_entry *subentry = submap.m_entrylist.detach_head();
+
+				// Remap start and end
+
+				int start_offset = subentry->m_addrstart / entry_bytes;
+				int start_slot = start_offset % slot_count;
+				subentry->m_addrstart = entry->m_addrstart + (start_offset / slot_count) * databytes;
+
+				// Drop the entry if it ends up outside the range
+				if (subentry->m_addrstart > entry->m_addrend)
+				{
+					global_free(subentry);
+					continue;
+				}
+
+				int end_offset = subentry->m_addrend / entry_bytes;
+				int end_slot = end_offset % slot_count;
+				subentry->m_addrend = entry->m_addrstart + (end_offset / slot_count) * databytes + databytes - 1;
+
+				// Clip the entry to the end of the range
+				if (subentry->m_addrend > entry->m_addrend)
+					subentry->m_addrend = entry->m_addrend;
+
+				// Detect special unhandled case (range straddling
+				// slots, requiring splitting in multiple entries and
+				// unimplemented offset-add subunit handler)
+				if (subentry->m_addrstart + databytes - 1 != subentry->m_addrend &&
+					(start_slot != 0 || end_slot != slot_count - 1))
+					throw emu_fatalerror("uplift_submaps unhandled case: range straddling slots.\n");
+
+				if (entry->m_addrmask || subentry->m_addrmask)
+					throw emu_fatalerror("uplift_submaps unhandled case: address masks.\n");
+
+				if (subentry->m_addrmirror & mirror_address_mask)
+					throw emu_fatalerror("uplift_submaps unhandled case: address mirror bit within subentry.\n");
+
+				subentry->m_addrmirror |= entry->m_addrmirror;
+
+				// Twiddle the unitmask on the data accessors that need it
+				for (int data_entry = 0; data_entry < 2; data_entry++)
+				{
+					map_handler_data &mdata = data_entry ? subentry->m_write : subentry->m_read;
+
+					if (mdata.m_type == AMH_NONE)
+						continue;
+
+					if (mdata.m_type != AMH_DEVICE_DELEGATE)
+						throw emu_fatalerror("Only normal read/write methods are accepted in device submaps.\n");
+
+					if (mdata.m_bits == 0 && entry_bits != m_databits)
+						mdata.m_bits = entry_bits;
+
+					UINT64 mask = 0;
+					if (entry_bits != m_databits)
+					{
+						UINT64 unitmask = mdata.m_mask ? mdata.m_mask : entry_mask;
+						for (int slot = start_slot; slot <= end_slot; slot++)
+							mask |= unitmask << slot_offset[slot];
+					}
+					mdata.m_mask = mask;
+				}
+
+				// Insert the entry in the map
+				m_entrylist.insert_after(*subentry, prev);
+				prev = subentry;
+			}
+
+			address_map_entry *to_delete = entry;
+			entry = entry->next();
+			m_entrylist.remove(*to_delete);
+		}
+		else
+		{
+			prev = entry;
+			entry = entry->next();
+		}
+	}
+}
