@@ -251,7 +251,7 @@ static CPU_INIT( esrip )
 	esrip_state *cpustate = get_safe_token(device);
 	esrip_config* _config = (esrip_config*)device->static_config();
 
-	memset(cpustate, 0, sizeof(cpustate));
+	memset(cpustate, 0, sizeof(*cpustate));
 
 	/* Register configuration structure callbacks */
 	cpustate->fdt_r = _config->fdt_r;
@@ -1618,7 +1618,7 @@ static void test(esrip_state *cpustate, UINT16 inst)
 		default:   INVALID;
 	}
 
-	cpustate->ct = res && 1;
+	cpustate->ct = res ? 1 : 0;
 }
 
 
