@@ -46,14 +46,11 @@ enum
 };
 
 #define M6502_IRQ_LINE		0
-/* use cpu_set_input_line(cpudevice, M6502_SET_OVERFLOW, level)
+/* use device_set_input_line(cpudevice, M6502_SET_OVERFLOW, level)
    to change level of the so input line
    positiv edge sets overflow flag */
 #define M6502_SET_OVERFLOW	1
 
-typedef UINT8 (*m6510_port_read_func)(device_t *device, UINT8 direction);
-typedef void (*m6510_port_write_func)(device_t *device, UINT8 direction, UINT8 data);
-
 
 /* Optional interface to set callbacks */
 typedef struct _m6502_interface m6502_interface;
@@ -61,12 +58,12 @@ struct _m6502_interface
 {
 	read8_space_func		read_indexed_func;
 	write8_space_func		write_indexed_func;
-	m6510_port_read_func	port_read_func;
-	m6510_port_write_func	port_write_func;
+	devcb_read8				in_port_func;
+	devcb_write8			out_port_func;
 };
 
 DECLARE_LEGACY_CPU_DEVICE(M6502, m6502);
-
+DECLARE_LEGACY_CPU_DEVICE(M6504, m6504);
 extern CPU_DISASSEMBLE( m6502 );
 
 /****************************************************************************
