@@ -16,6 +16,9 @@
 #define M68K_IRQ_6    6
 #define M68K_IRQ_7    7
 
+// special input lines
+#define M68K_LINE_BUSERROR 16
+
 /* CPU types for use in m68k_set_cpu_type() */
 enum
 {
@@ -30,7 +33,19 @@ enum
 	M68K_CPU_TYPE_68EC040,
 	M68K_CPU_TYPE_68LC040,
 	M68K_CPU_TYPE_68040,
-	M68K_CPU_TYPE_SCC68070
+	M68K_CPU_TYPE_SCC68070,
+	M68K_CPU_TYPE_68340,
+    M68K_CPU_TYPE_COLDFIRE
+};
+
+// function codes
+enum
+{
+	M68K_FC_USER_DATA = 1,
+	M68K_FC_USER_PROGRAM = 2,
+	M68K_FC_SUPERVISOR_DATA = 5,
+	M68K_FC_SUPERVISOR_PROGRAM = 6,
+	M68K_FC_INTERRUPT = 7
 };
 
 /* HMMU enable types for use with m68k_set_hmmu_enable() */
@@ -79,6 +94,7 @@ typedef int (*m68k_tas_func)(device_t *device);
 
 DECLARE_LEGACY_CPU_DEVICE(M68000, m68000);
 DECLARE_LEGACY_CPU_DEVICE(M68008, m68008);
+DECLARE_LEGACY_CPU_DEVICE(M68008PLCC, m68008plcc);
 DECLARE_LEGACY_CPU_DEVICE(M68010, m68010);
 DECLARE_LEGACY_CPU_DEVICE(M68EC020, m68ec020);
 DECLARE_LEGACY_CPU_DEVICE(M68020, m68020);
@@ -90,6 +106,8 @@ DECLARE_LEGACY_CPU_DEVICE(M68EC040, m68ec040);
 DECLARE_LEGACY_CPU_DEVICE(M68LC040, m68lc040);
 DECLARE_LEGACY_CPU_DEVICE(M68040, m68040);
 DECLARE_LEGACY_CPU_DEVICE(SCC68070, scc68070);
+DECLARE_LEGACY_CPU_DEVICE(M68340, m68340);
+DECLARE_LEGACY_CPU_DEVICE(MCF5206E, mcf5206e);
 
 
 void m68k_set_encrypted_opcode_range(device_t *device, offs_t start, offs_t end);
@@ -102,5 +120,6 @@ void m68k_set_reset_callback(device_t *device, m68k_reset_func callback);
 void m68k_set_cmpild_callback(device_t *device, m68k_cmpild_func callback);
 void m68k_set_rte_callback(device_t *device, m68k_rte_func callback);
 void m68k_set_tas_callback(device_t *device, m68k_tas_func callback);
+UINT16 m68k_get_fc(device_t *device);
 
 #endif /* __M68000_H__ */
