@@ -17,7 +17,7 @@ device_slot_interface::~device_slot_interface()
 }
 
 
-void device_slot_interface::static_set_slot_info(device_t &device, const slot_interface *slots_info, const char *default_card)
+void device_slot_interface::static_set_slot_info(device_t &device, const slot_interface *slots_info, const char *default_card,const input_device_default *default_input)
 {
 	device_slot_interface *slot;
 	if (!device.interface(slot))
@@ -25,13 +25,19 @@ void device_slot_interface::static_set_slot_info(device_t &device, const slot_in
 
 	slot->m_slot_interfaces = slots_info;
 	slot->m_default_card = default_card;
+	slot->m_input_defaults = default_input;
 }
 
 device_t* device_slot_interface::get_card_device()
 {
-	const char *subtag = device().machine().options().value(device().tag());
+	const char *subtag;
 	device_t *dev = NULL;
-	if (subtag) {
+	if (!device().mconfig().options().exists(device().tag()+1)) {
+		subtag = m_default_card;
+	} else {
+		subtag = device().mconfig().options().value(device().tag()+1);
+	}
+	if (subtag && strlen(subtag)>0) {
 		device_slot_card_interface *intf = NULL;
 		dev = device().subdevice(subtag);
 		if (dev!=NULL && !dev->interface(intf))
