@@ -82,7 +82,7 @@ struct _floppy_drive
 
 	device_t *controller;
 
-	floppy_image *floppy;
+	floppy_image_legacy *floppy;
 	int track;
 	void (*load_proc)(device_image_interface &image);
 	void (*unload_proc)(device_image_interface &image);
@@ -117,17 +117,17 @@ static const floppy_error_map errmap[] =
 /***************************************************************************
     IMPLEMENTATION
 ***************************************************************************/
-DECLARE_LEGACY_IMAGE_DEVICE(FLOPPY_APPLE, apple525);
-DECLARE_LEGACY_IMAGE_DEVICE(FLOPPY_SONY, sonydriv);
+//DECLARE_LEGACY_IMAGE_DEVICE(FLOPPY_APPLE, apple525);
+//DECLARE_LEGACY_IMAGE_DEVICE(FLOPPY_SONY, sonydriv);
 
 INLINE floppy_drive *get_safe_token(device_t *device)
 {
 	assert( device != NULL );
-	assert( device->type() == FLOPPY || device->type() == FLOPPY_APPLE || device->type() == FLOPPY_SONY);
+	//assert( device->type() == LEGACY_FLOPPY || device->type() == FLOPPY_APPLE || device->type() == FLOPPY_SONY);
 	return (floppy_drive *) downcast<legacy_device_base *>(device)->token();
 }
 
-floppy_image *flopimg_get_image(device_t *image)
+floppy_image_legacy *flopimg_get_image(device_t *image)
 {
 	return get_safe_token(image)->floppy;
 }
@@ -342,7 +342,7 @@ int	floppy_drive_get_flag_state(device_t *img, int flag)
 
 	drive_flags = drv->flags;
 
-	/* these flags are independant of a real drive/disk image */
+	/* these flags are independent of a real drive/disk image */
     flags |= drive_flags & (FLOPPY_DRIVE_READY | FLOPPY_DRIVE_INDEX);
 
     flags &= flag;
@@ -750,10 +750,10 @@ device_t *floppy_get_device_by_type(running_machine &machine,int ftype,int drive
 int floppy_get_drive(device_t *image)
 {
 	int drive =0;
-	if (strcmp(image->tag(), FLOPPY_0) == 0) drive = 0;
-	if (strcmp(image->tag(), FLOPPY_1) == 0) drive = 1;
-	if (strcmp(image->tag(), FLOPPY_2) == 0) drive = 2;
-	if (strcmp(image->tag(), FLOPPY_3) == 0) drive = 3;
+	if (strcmp(image->tag(), ":" FLOPPY_0) == 0) drive = 0;
+	if (strcmp(image->tag(), ":" FLOPPY_1) == 0) drive = 1;
+	if (strcmp(image->tag(), ":" FLOPPY_2) == 0) drive = 2;
+	if (strcmp(image->tag(), ":" FLOPPY_3) == 0) drive = 3;
 	return drive;
 }
 
@@ -1002,9 +1002,7 @@ DEVICE_GET_INFO(floppy)
 		case DEVINFO_FCT_IMAGE_UNLOAD:				info->f = (genf *) DEVICE_IMAGE_UNLOAD_NAME(floppy); break;
 		case DEVINFO_FCT_IMAGE_SOFTLIST_LOAD:		info->f = (genf *) DEVICE_IMAGE_SOFTLIST_LOAD_NAME(floppy);	break;
 		case DEVINFO_FCT_IMAGE_DISPLAY_INFO:
-			if (device->type() == FLOPPY_APPLE) {
-				info->f = NULL;
-			} else {
+			if (device->type() == LEGACY_FLOPPY) {
 				if ( device && downcast<const legacy_image_device_base *>(device)->static_config() && ((floppy_interface*)(device)->static_config())->device_displayinfo) {
 					info->f = (genf *) ((floppy_interface*)(device)->static_config())->device_displayinfo;
 				} else {
@@ -1068,4 +1066,4 @@ DEVICE_GET_INFO(floppy)
 	}
 }
 
-DEFINE_LEGACY_IMAGE_DEVICE(FLOPPY, floppy);
+DEFINE_LEGACY_IMAGE_DEVICE(LEGACY_FLOPPY, floppy);
