@@ -38,6 +38,7 @@
 ***************************************************************************/
 
 #include "emu.h"
+#include "emuopts.h"
 #include "machine/ram.h"
 #include "sound/samples.h"
 #include "info.h"
@@ -53,20 +54,21 @@
 
 // DTD string describing the data
 const char info_xml_creator::s_dtd_string[] =
-"<!DOCTYPE " XML_ROOT " [\n"
-"<!ELEMENT " XML_ROOT " (" XML_TOP "+)>\n"
-"\t<!ATTLIST " XML_ROOT " build CDATA #IMPLIED>\n"
-"\t<!ATTLIST " XML_ROOT " debug (yes|no) \"no\">\n"
-"\t<!ATTLIST " XML_ROOT " mameconfig CDATA #REQUIRED>\n"
-"\t<!ELEMENT " XML_TOP " (description, year?, manufacturer, biosset*, rom*, disk*, sample*, chip*, display*, sound?, input?, dipswitch*, configuration*, category*, adjuster*, driver?, device*, slot*, softwarelist*, ramoption*)>\n"
-"\t\t<!ATTLIST " XML_TOP " name CDATA #REQUIRED>\n"
-"\t\t<!ATTLIST " XML_TOP " sourcefile CDATA #IMPLIED>\n"
-"\t\t<!ATTLIST " XML_TOP " isbios (yes|no) \"no\">\n"
-"\t\t<!ATTLIST " XML_TOP " ismechanical (yes|no) \"no\">\n"
-"\t\t<!ATTLIST " XML_TOP " runnable (yes|no) \"yes\">\n"
-"\t\t<!ATTLIST " XML_TOP " cloneof CDATA #IMPLIED>\n"
-"\t\t<!ATTLIST " XML_TOP " romof CDATA #IMPLIED>\n"
-"\t\t<!ATTLIST " XML_TOP " sampleof CDATA #IMPLIED>\n"
+"<!DOCTYPE __XML_ROOT__ [\n"
+"<!ELEMENT __XML_ROOT__ (__XML_TOP__+)>\n"
+"\t<!ATTLIST __XML_ROOT__ build CDATA #IMPLIED>\n"
+"\t<!ATTLIST __XML_ROOT__ debug (yes|no) \"no\">\n"
+"\t<!ATTLIST __XML_ROOT__ mameconfig CDATA #REQUIRED>\n"
+"\t<!ELEMENT __XML_TOP__ (description, year?, manufacturer?, biosset*, rom*, disk*, device_ref*, sample*, chip*, display*, sound?, input?, dipswitch*, configuration*, adjuster*, driver?, device*, slot*, softwarelist*, ramoption*)>\n"
+"\t\t<!ATTLIST __XML_TOP__ name CDATA #REQUIRED>\n"
+"\t\t<!ATTLIST __XML_TOP__ sourcefile CDATA #IMPLIED>\n"
+"\t\t<!ATTLIST __XML_TOP__ isbios (yes|no) \"no\">\n"
+"\t\t<!ATTLIST __XML_TOP__ isdevice (yes|no) \"no\">\n"
+"\t\t<!ATTLIST __XML_TOP__ ismechanical (yes|no) \"no\">\n"
+"\t\t<!ATTLIST __XML_TOP__ runnable (yes|no) \"yes\">\n"
+"\t\t<!ATTLIST __XML_TOP__ cloneof CDATA #IMPLIED>\n"
+"\t\t<!ATTLIST __XML_TOP__ romof CDATA #IMPLIED>\n"
+"\t\t<!ATTLIST __XML_TOP__ sampleof CDATA #IMPLIED>\n"
 "\t\t<!ELEMENT description (#PCDATA)>\n"
 "\t\t<!ELEMENT year (#PCDATA)>\n"
 "\t\t<!ELEMENT manufacturer (#PCDATA)>\n"
@@ -79,7 +81,6 @@ const char info_xml_creator::s_dtd_string[] =
 "\t\t\t<!ATTLIST rom bios CDATA #IMPLIED>\n"
 "\t\t\t<!ATTLIST rom size CDATA #REQUIRED>\n"
 "\t\t\t<!ATTLIST rom crc CDATA #IMPLIED>\n"
-"\t\t\t<!ATTLIST rom md5 CDATA #IMPLIED>\n"
 "\t\t\t<!ATTLIST rom sha1 CDATA #IMPLIED>\n"
 "\t\t\t<!ATTLIST rom merge CDATA #IMPLIED>\n"
 "\t\t\t<!ATTLIST rom region CDATA #IMPLIED>\n"
@@ -88,7 +89,6 @@ const char info_xml_creator::s_dtd_string[] =
 "\t\t\t<!ATTLIST rom optional (yes|no) \"no\">\n"
 "\t\t<!ELEMENT disk EMPTY>\n"
 "\t\t\t<!ATTLIST disk name CDATA #REQUIRED>\n"
-"\t\t\t<!ATTLIST disk md5 CDATA #IMPLIED>\n"
 "\t\t\t<!ATTLIST disk sha1 CDATA #IMPLIED>\n"
 "\t\t\t<!ATTLIST disk merge CDATA #IMPLIED>\n"
 "\t\t\t<!ATTLIST disk region CDATA #IMPLIED>\n"
@@ -96,6 +96,8 @@ const char info_xml_creator::s_dtd_string[] =
 "\t\t\t<!ATTLIST disk writable (yes|no) \"no\">\n"
 "\t\t\t<!ATTLIST disk status (baddump|nodump|good) \"good\">\n"
 "\t\t\t<!ATTLIST disk optional (yes|no) \"no\">\n"
+"\t\t<!ELEMENT device_ref EMPTY>\n"
+"\t\t\t<!ATTLIST device_ref name CDATA #REQUIRED>\n"
 "\t\t<!ELEMENT sample EMPTY>\n"
 "\t\t\t<!ATTLIST sample name CDATA #REQUIRED>\n"
 "\t\t<!ELEMENT chip EMPTY>\n"
@@ -132,6 +134,9 @@ const char info_xml_creator::s_dtd_string[] =
 "\t\t\t\t<!ATTLIST control sensitivity CDATA #IMPLIED>\n"
 "\t\t\t\t<!ATTLIST control keydelta CDATA #IMPLIED>\n"
 "\t\t\t\t<!ATTLIST control reverse (yes|no) \"no\">\n"
+"\t\t\t\t<!ATTLIST control ways CDATA #IMPLIED>\n"
+"\t\t\t\t<!ATTLIST control ways2 CDATA #IMPLIED>\n"
+"\t\t\t\t<!ATTLIST control ways3 CDATA #IMPLIED>\n"
 "\t\t<!ELEMENT dipswitch (dipvalue*)>\n"
 "\t\t\t<!ATTLIST dipswitch name CDATA #REQUIRED>\n"
 "\t\t\t<!ATTLIST dipswitch tag CDATA #REQUIRED>\n"
@@ -148,11 +153,6 @@ const char info_xml_creator::s_dtd_string[] =
 "\t\t\t\t<!ATTLIST confsetting name CDATA #REQUIRED>\n"
 "\t\t\t\t<!ATTLIST confsetting value CDATA #REQUIRED>\n"
 "\t\t\t\t<!ATTLIST confsetting default (yes|no) \"no\">\n"
-"\t\t<!ELEMENT category (item*)>\n"
-"\t\t\t<!ATTLIST category name CDATA #REQUIRED>\n"
-"\t\t\t<!ELEMENT item EMPTY>\n"
-"\t\t\t\t<!ATTLIST item name CDATA #REQUIRED>\n"
-"\t\t\t\t<!ATTLIST item default (yes|no) \"no\">\n"
 "\t\t<!ELEMENT adjuster EMPTY>\n"
 "\t\t\t<!ATTLIST adjuster name CDATA #REQUIRED>\n"
 "\t\t\t<!ATTLIST adjuster default CDATA #REQUIRED>\n"
@@ -184,11 +184,14 @@ const char info_xml_creator::s_dtd_string[] =
 "\t\t<!ELEMENT softwarelist EMPTY>\n"
 "\t\t\t<!ATTLIST softwarelist name CDATA #REQUIRED>\n"
 "\t\t\t<!ATTLIST softwarelist status (original|compatible) #REQUIRED>\n"
+"\t\t\t<!ATTLIST softwarelist filter CDATA #IMPLIED>\n"
 "\t\t<!ELEMENT ramoption (#PCDATA)>\n"
 "\t\t\t<!ATTLIST ramoption default CDATA #IMPLIED>\n"
 "]>";
 
 
+extern const device_type *s_devices_sorted[];
+extern int m_device_count;
 
 //**************************************************************************
 //  INFO XML CREATOR
@@ -200,8 +203,10 @@ const char info_xml_creator::s_dtd_string[] =
 
 info_xml_creator::info_xml_creator(driver_enumerator &drivlist)
 	: m_output(NULL),
-	  m_drivlist(drivlist)
+	  m_drivlist(drivlist),
+	  m_lookup_options(m_drivlist.options())
 {
+	m_lookup_options.remove_device_options();
 }
 
 
@@ -216,29 +221,80 @@ void info_xml_creator::output(FILE *out)
 
 	// output the DTD
 	fprintf(m_output, "<?xml version=\"1.0\"?>\n");
-	fprintf(m_output, "%s\n\n", s_dtd_string);
+	astring dtd(s_dtd_string);
+	dtd.replace(0,"__XML_ROOT__", emulator_info::get_xml_root());
+	dtd.replace(0,"__XML_TOP__", emulator_info::get_xml_top());
+
+	fprintf(m_output, "%s\n\n", dtd.cstr());
 
 	// top-level tag
-	fprintf(m_output, "<" XML_ROOT " build=\"%s\" debug=\""
+	fprintf(m_output, "<%s build=\"%s\" debug=\""
 #ifdef MAME_DEBUG
 		"yes"
 #else
 		"no"
 #endif
 		"\" mameconfig=\"%d\">\n",
+		emulator_info::get_xml_root(),
 		xml_normalize_string(build_version),
 		CONFIG_VERSION
 	);
 
+	m_device_used = global_alloc_array_clear(UINT8, m_device_count);
+
 	// iterate through the drivers, outputting one at a time
 	while (m_drivlist.next())
 		output_one();
 
+	// iterate through the devices, and output their roms
+	output_devices();
+
+	global_free(m_device_used);
+
 	// close the top level tag
-	fprintf(m_output, "</" XML_ROOT ">\n");
+	fprintf(m_output, "</%s>\n",emulator_info::get_xml_root());
 }
 
 
+//-------------------------------------------------
+//  output_devices - print the XML information
+//  for one particular game driver
+//-------------------------------------------------
+
+void info_xml_creator::output_devices()
+{
+	m_drivlist.reset();
+	m_drivlist.next();
+	machine_config &config = m_drivlist.config();
+	device_t &owner = config.root_device();
+	// check if all are listed, note that empty one is included
+	bool display_all = driver_list::total() == (m_drivlist.count()+1);
+	for(int i=0;i<m_device_count;i++) {
+		if (display_all || (m_device_used[i]!=0)) {
+			device_type type = *s_devices_sorted[i];
+			device_t *dev = (*type)(config, "dummy", &owner, 0);
+			dev->config_complete();
+
+			// print the header and the game name
+			fprintf(m_output, "\t<%s",emulator_info::get_xml_top());
+			fprintf(m_output, " name=\"%s\"", xml_normalize_string(dev->shortname()));
+			fprintf(m_output, " isdevice=\"yes\"");
+			fprintf(m_output, " runnable=\"no\"");
+			fprintf(m_output, ">\n");
+
+			// output device description
+			if (dev->name() != NULL)
+				fprintf(m_output, "\t\t<description>%s</description>\n", xml_normalize_string(dev->name()));
+
+			output_rom(dev);
+
+			// close the topmost tag
+			fprintf(m_output, "\t</%s>\n",emulator_info::get_xml_top());
+			global_free(dev);
+		}
+	}
+}
+
 //-------------------------------------------------
 //  output_one - print the XML information
 //  for one particular game driver
@@ -255,11 +311,12 @@ void info_xml_creator::output_one()
 	machine_config &config = m_drivlist.config();
 	ioport_list portlist;
 	astring errors;
-	for (device_t *device = config.devicelist().first(); device != NULL; device = device->next())
+	device_iterator iter(config.root_device());
+	for (device_t *device = iter.first(); device != NULL; device = iter.next())
 		input_port_list_init(*device, portlist, errors);
 
 	// print the header and the game name
-	fprintf(m_output, "\t<" XML_TOP);
+	fprintf(m_output, "\t<%s",emulator_info::get_xml_top());
 	fprintf(m_output, " name=\"%s\"", xml_normalize_string(driver.name));
 
 	// strip away any path information from the source_file and output it
@@ -303,7 +360,8 @@ void info_xml_creator::output_one()
 
 	// now print various additional information
 	output_bios();
-	output_rom();
+	output_rom(rom_first_source(m_drivlist.config()));
+	output_device_roms();
 	output_sample();
 	output_chips();
 	output_display();
@@ -311,7 +369,6 @@ void info_xml_creator::output_one()
 	output_input(portlist);
 	output_switches(portlist, IPT_DIPSWITCH, "dipswitch", "dipvalue");
 	output_switches(portlist, IPT_CONFIG, "configuration", "confsetting");
-	output_categories(portlist);
 	output_adjusters(portlist);
 	output_driver();
 	output_images();
@@ -320,9 +377,28 @@ void info_xml_creator::output_one()
 	output_ramoptions();
 
 	// close the topmost tag
-	fprintf(m_output, "\t</" XML_TOP ">\n");
+	fprintf(m_output, "\t</%s>\n",emulator_info::get_xml_top());
 }
 
+//------------------------------------------------
+//  output_device_roms - print the device
+//  with roms, if appropriate
+//-------------------------------------------------
+
+void info_xml_creator::output_device_roms()
+{
+	int cnt=0;
+	for (const rom_source *source = rom_first_source(m_drivlist.config()); source != NULL; source = rom_next_source(*source))
+	{
+		if (cnt!=0) {
+			fprintf(m_output, "\t\t<device_ref name=\"%s\"/>\n", xml_normalize_string(source->shortname()));
+			for(int i=0;i<m_device_count;i++) {
+				if (source->type() == *s_devices_sorted[i]) m_device_used[i] = 1;
+			}
+		}
+		cnt++;
+	}
+}
 
 //------------------------------------------------
 //  output_sampleof - print the 'sampleof'
@@ -332,7 +408,8 @@ void info_xml_creator::output_one()
 void info_xml_creator::output_sampleof()
 {
 	// iterate over sample devices
-	for (const device_t *device = m_drivlist.config().devicelist().first(SAMPLES); device != NULL; device = device->typenext())
+	samples_device_iterator iter(m_drivlist.config().root_device());
+	for (samples_device *device = iter.first(); device != NULL; device = iter.next())
 	{
 		const char *const *samplenames = ((const samples_interface *)device->static_config())->samplenames;
 		if (samplenames != NULL)
@@ -383,13 +460,11 @@ void info_xml_creator::output_bios()
 //  the XML output
 //-------------------------------------------------
 
-void info_xml_creator::output_rom()
+void info_xml_creator::output_rom(const rom_source *source)
 {
 	// iterate over 3 different ROM "types": BIOS, ROMs, DISKs
 	for (int rom_type = 0; rom_type < 3; rom_type++)
 	{
-		// iterate over ROM sources: first the game, then any devices
-		for (const rom_source *source = rom_first_source(m_drivlist.config()); source != NULL; source = rom_next_source(*source))
 			for (const rom_entry *region = rom_first_region(*source); region != NULL; region = rom_next_region(region))
 			{
 				bool is_disk = ROMREGION_ISDISKDATA(region);
@@ -471,7 +546,7 @@ void info_xml_creator::output_rom()
 					else
 					{
 						fprintf(m_output, " index=\"%x\"", DISK_GETINDEX(rom));
-						fprintf(m_output, " writeable=\"%s\"", DISK_ISREADONLY(rom) ? "no" : "yes");
+						fprintf(m_output, " writable=\"%s\"", DISK_ISREADONLY(rom) ? "no" : "yes");
 					}
 
 					// add optional flag
@@ -493,7 +568,8 @@ void info_xml_creator::output_rom()
 void info_xml_creator::output_sample()
 {
 	// iterate over sample devices
-	for (const device_t *device = m_drivlist.config().devicelist().first(SAMPLES); device != NULL; device = device->typenext())
+	samples_device_iterator iter(m_drivlist.config().root_device());
+	for (const device_t *device = iter.first(); device != NULL; device = iter.next())
 	{
 		const char *const *samplenames = ((const samples_interface *)device->static_config())->samplenames;
 		if (samplenames != NULL)
@@ -529,8 +605,8 @@ void info_xml_creator::output_sample()
 void info_xml_creator::output_chips()
 {
 	// iterate over executable devices
-	device_execute_interface *exec = NULL;
-	for (bool gotone = m_drivlist.config().devicelist().first(exec); gotone; gotone = exec->next(exec))
+	execute_interface_iterator execiter(m_drivlist.config().root_device());
+	for (device_execute_interface *exec = execiter.first(); exec != NULL; exec = execiter.next())
 	{
 		fprintf(m_output, "\t\t<chip");
 		fprintf(m_output, " type=\"cpu\"");
@@ -541,8 +617,8 @@ void info_xml_creator::output_chips()
 	}
 
 	// iterate over sound devices
-	device_sound_interface *sound = NULL;
-	for (bool gotone = m_drivlist.config().devicelist().first(sound); gotone; gotone = sound->next(sound))
+	sound_interface_iterator sounditer(m_drivlist.config().root_device());
+	for (device_sound_interface *sound = sounditer.first(); sound != NULL; sound = sounditer.next())
 	{
 		fprintf(m_output, "\t\t<chip");
 		fprintf(m_output, " type=\"audio\"");
@@ -563,7 +639,8 @@ void info_xml_creator::output_chips()
 void info_xml_creator::output_display()
 {
 	// iterate over screens
-	for (const screen_device *device = m_drivlist.config().first_screen(); device != NULL; device = device->next_screen())
+	screen_device_iterator iter(m_drivlist.config().root_device());
+	for (const screen_device *device = iter.first(); device != NULL; device = iter.next())
 	{
 		fprintf(m_output, "\t\t<display");
 
@@ -608,8 +685,8 @@ void info_xml_creator::output_display()
 		if (device->screen_type() != SCREEN_TYPE_VECTOR)
 		{
 			const rectangle &visarea = device->visible_area();
-			fprintf(m_output, " width=\"%d\"", visarea.max_x - visarea.min_x + 1);
-			fprintf(m_output, " height=\"%d\"", visarea.max_y - visarea.min_y + 1);
+			fprintf(m_output, " width=\"%d\"", visarea.width());
+			fprintf(m_output, " height=\"%d\"", visarea.height());
 		}
 
 		// output refresh rate
@@ -641,11 +718,12 @@ void info_xml_creator::output_display()
 
 void info_xml_creator::output_sound()
 {
-	int speakers = m_drivlist.config().devicelist().count(SPEAKER);
+	speaker_device_iterator spkiter(m_drivlist.config().root_device());
+	int speakers = spkiter.count();
 
 	// if we have no sound, zero m_output the speaker count
-	const device_sound_interface *sound = NULL;
-	if (!m_drivlist.config().devicelist().first(sound))
+	sound_interface_iterator snditer(m_drivlist.config().root_device());
+	if (snditer.first() == NULL)
 		speakers = 0;
 
 	fprintf(m_output, "\t\t<sound channels=\"%d\"/>\n", speakers);
@@ -662,20 +740,23 @@ void info_xml_creator::output_input(const ioport_list &portlist)
 	// enumerated list of control types
 	enum
 	{
+		ANALOG_TYPE_PADDLE,
+		ANALOG_TYPE_PEDAL,
 		ANALOG_TYPE_JOYSTICK,
+		ANALOG_TYPE_POSITIONAL,
+		ANALOG_TYPE_LIGHTGUN,
 		ANALOG_TYPE_DIAL,
 		ANALOG_TYPE_TRACKBALL,
-		ANALOG_TYPE_PADDLE,
-		ANALOG_TYPE_LIGHTGUN,
-		ANALOG_TYPE_PEDAL,
+		ANALOG_TYPE_MOUSE,
 		ANALOG_TYPE_COUNT
 	};
 
 	// directions
-	const UINT8 DIR_LEFTRIGHT = 0x01;
-	const UINT8 DIR_UPDOWN = 0x02;
-	const UINT8 DIR_4WAY = 0x04;
-	const UINT8 DIR_DUAL = 0x08;
+	const UINT8 DIR_UP = 0x01;
+	const UINT8 DIR_DOWN = 0x02;
+	const UINT8 DIR_LEFT = 0x04;
+	const UINT8 DIR_RIGHT = 0x08;
+	const UINT8 DIR_4WAY = 0x10;
 
 	// initialize the list of control types
 	struct
@@ -696,11 +777,14 @@ void info_xml_creator::output_input(const ioport_list &portlist)
 	int nplayer = 0;
 	int nbutton = 0;
 	int ncoin = 0;
-	UINT8 joytype = 0;
+	UINT8 joytype[3] = { 0,0,0 };
 	bool service = false;
 	bool tilt = false;
 	bool keypad = false;
 	bool keyboard = false;
+	bool mahjong = false;
+	bool hanafuda = false;
+	bool gambling = false;
 
 	// iterate over the ports
 	for (input_port_config *port = portlist.first(); port != NULL; port = port->next())
@@ -716,49 +800,37 @@ void info_xml_creator::output_input(const ioport_list &portlist)
 			switch (field->type)
 			{
 				// map which joystick directions are present
-				case IPT_JOYSTICKRIGHT_LEFT:
-				case IPT_JOYSTICKRIGHT_RIGHT:
-				case IPT_JOYSTICKLEFT_LEFT:
-				case IPT_JOYSTICKLEFT_RIGHT:
-					joytype |= DIR_DUAL;
-					// fall through...
+				case IPT_JOYSTICK_UP:			joytype[0] |= DIR_UP | ((field->way == 4) ? DIR_4WAY : 0);		break;
+				case IPT_JOYSTICK_DOWN:			joytype[0] |= DIR_DOWN | ((field->way == 4) ? DIR_4WAY : 0);	break;
+				case IPT_JOYSTICK_LEFT:			joytype[0] |= DIR_LEFT | ((field->way == 4) ? DIR_4WAY : 0);	break;
+				case IPT_JOYSTICK_RIGHT:		joytype[0] |= DIR_RIGHT | ((field->way == 4) ? DIR_4WAY : 0);	break;
 
-				case IPT_JOYSTICK_LEFT:
-				case IPT_JOYSTICK_RIGHT:
-					joytype |= DIR_LEFTRIGHT | ((field->way == 4) ? DIR_4WAY : 0);
-					break;
+				case IPT_JOYSTICKLEFT_UP:		joytype[1] |= DIR_UP | ((field->way == 4) ? DIR_4WAY : 0);		break;
+				case IPT_JOYSTICKLEFT_DOWN:		joytype[1] |= DIR_DOWN | ((field->way == 4) ? DIR_4WAY : 0);	break;
+				case IPT_JOYSTICKLEFT_LEFT:		joytype[1] |= DIR_LEFT | ((field->way == 4) ? DIR_4WAY : 0);	break;
+				case IPT_JOYSTICKLEFT_RIGHT:	joytype[1] |= DIR_RIGHT | ((field->way == 4) ? DIR_4WAY : 0);	break;
 
-				case IPT_JOYSTICKRIGHT_UP:
-				case IPT_JOYSTICKRIGHT_DOWN:
-				case IPT_JOYSTICKLEFT_UP:
-				case IPT_JOYSTICKLEFT_DOWN:
-					joytype |= DIR_DUAL;
-					// fall through...
-
-				case IPT_JOYSTICK_UP:
-				case IPT_JOYSTICK_DOWN:
-					joytype |= DIR_UPDOWN | ((field->way == 4) ? DIR_4WAY : 0);
-					break;
+				case IPT_JOYSTICKRIGHT_UP:		joytype[2] |= DIR_UP | ((field->way == 4) ? DIR_4WAY : 0);		break;
+				case IPT_JOYSTICKRIGHT_DOWN:	joytype[2] |= DIR_DOWN | ((field->way == 4) ? DIR_4WAY : 0);	break;
+				case IPT_JOYSTICKRIGHT_LEFT:	joytype[2] |= DIR_LEFT | ((field->way == 4) ? DIR_4WAY : 0);	break;
+				case IPT_JOYSTICKRIGHT_RIGHT:	joytype[2] |= DIR_RIGHT | ((field->way == 4) ? DIR_4WAY : 0);	break;
 
 				// mark as an analog input, and get analog stats after switch
+				case IPT_AD_STICK_X:
+				case IPT_AD_STICK_Y:
+				case IPT_AD_STICK_Z:
+					control_info[analogtype = ANALOG_TYPE_JOYSTICK].type = "stick";
+					break;
+
 				case IPT_PADDLE:
+				case IPT_PADDLE_V:
 					control_info[analogtype = ANALOG_TYPE_PADDLE].type = "paddle";
 					break;
 
-				case IPT_DIAL:
-					control_info[analogtype = ANALOG_TYPE_DIAL].type = "dial";
-					analogtype = ANALOG_TYPE_DIAL;
-					break;
-
-				case IPT_TRACKBALL_X:
-				case IPT_TRACKBALL_Y:
-					control_info[analogtype = ANALOG_TYPE_TRACKBALL].type = "trackball";
-					analogtype = ANALOG_TYPE_TRACKBALL;
-					break;
-
-				case IPT_AD_STICK_X:
-				case IPT_AD_STICK_Y:
-					control_info[analogtype = ANALOG_TYPE_JOYSTICK].type = "stick";
+				case IPT_PEDAL:
+				case IPT_PEDAL2:
+				case IPT_PEDAL3:
+					control_info[analogtype = ANALOG_TYPE_PEDAL].type = "pedal";
 					break;
 
 				case IPT_LIGHTGUN_X:
@@ -766,10 +838,24 @@ void info_xml_creator::output_input(const ioport_list &portlist)
 					control_info[analogtype = ANALOG_TYPE_LIGHTGUN].type = "lightgun";
 					break;
 
-				case IPT_PEDAL:
-				case IPT_PEDAL2:
-				case IPT_PEDAL3:
-					control_info[analogtype = ANALOG_TYPE_PEDAL].type = "pedal";
+				case IPT_POSITIONAL:
+				case IPT_POSITIONAL_V:
+					control_info[analogtype = ANALOG_TYPE_POSITIONAL].type = "positional";
+					break;
+
+				case IPT_DIAL:
+				case IPT_DIAL_V:
+					control_info[analogtype = ANALOG_TYPE_DIAL].type = "dial";
+					break;
+
+				case IPT_TRACKBALL_X:
+				case IPT_TRACKBALL_Y:
+					control_info[analogtype = ANALOG_TYPE_TRACKBALL].type = "trackball";
+					break;
+
+				case IPT_MOUSE_X:
+				case IPT_MOUSE_Y:
+					control_info[analogtype = ANALOG_TYPE_MOUSE].type = "mouse";
 					break;
 
 				// track maximum button index
@@ -821,6 +907,15 @@ void info_xml_creator::output_input(const ioport_list &portlist)
 				case IPT_TILT:
 					tilt = true;
 					break;
+
+				default:
+					if (field->type >= __ipt_mahjong_start && field->type <= __ipt_mahjong_end)
+						mahjong = true;
+					else if (field->type >= __ipt_hanafuda_start && field->type <= __ipt_hanafuda_end)
+						hanafuda = true;
+					else if (field->type >= __ipt_gambling_start && field->type <= __ipt_gambling_end)
+						gambling = true;
+					break;
 			}
 
 			// get the analog stats
@@ -853,12 +948,47 @@ void info_xml_creator::output_input(const ioport_list &portlist)
 	fprintf(m_output, ">\n");
 
 	// output the joystick types
-	if (joytype != 0)
+	if (joytype[1]==0 && joytype[2]!=0) { joytype[1] = joytype[2]; joytype[2] = 0; }
+	if (joytype[0]==0 && joytype[1]!=0) { joytype[0] = joytype[1]; joytype[1] = 0; }
+	if (joytype[1]==0 && joytype[2]!=0) { joytype[1] = joytype[2]; joytype[2] = 0; }
+	if (joytype[0] != 0)
 	{
-		const char *vertical = ((joytype & DIR_LEFTRIGHT) == 0) ? "v" : "";
-		const char *doubletype = ((joytype & DIR_DUAL) != 0) ? "doublejoy" : "joy";
-		const char *way = ((joytype & DIR_LEFTRIGHT) == 0 || (joytype & DIR_UPDOWN) == 0) ? "2way" : ((joytype & DIR_4WAY) != 0) ? "4way" : "8way";
-		fprintf(m_output, "\t\t\t<control type=\"%s%s%s\"/>\n", vertical, doubletype, way);
+		const char *joys = (joytype[2]!=0) ? "triple" : (joytype[1]!=0) ? "double" : "";
+		fprintf(m_output, "\t\t\t<control type=\"%sjoy\"", joys);
+		for (int lp=0; lp<3 && joytype[lp]!=0; lp++)
+		{
+			const char *plural = (lp==2) ? "3" : (lp==1) ? "2" : "";
+			const char *ways;
+			switch (joytype[lp] & (DIR_UP | DIR_DOWN | DIR_LEFT | DIR_RIGHT))
+			{
+				case DIR_UP | DIR_DOWN | DIR_LEFT | DIR_RIGHT:
+					ways = ((joytype[lp] & DIR_4WAY) != 0) ? "4" : "8";
+					break;
+				case DIR_LEFT | DIR_RIGHT:
+					ways = "2";
+					break;
+				case DIR_UP | DIR_DOWN:
+					ways = "vertical2";
+					break;
+				case DIR_UP:
+				case DIR_DOWN:
+				case DIR_LEFT:
+				case DIR_RIGHT:
+					ways = "1";
+					break;
+				case DIR_UP | DIR_DOWN | DIR_LEFT:
+				case DIR_UP | DIR_DOWN | DIR_RIGHT:
+				case DIR_UP | DIR_LEFT | DIR_RIGHT:
+				case DIR_DOWN | DIR_LEFT | DIR_RIGHT:
+					ways = ((joytype[lp] & DIR_4WAY) != 0) ? "3 (half4)" : "5 (half8)";
+					break;
+				default:
+					ways = "strange2";
+					break;
+			}
+			fprintf(m_output, " ways%s=\"%s\"", plural,ways);
+		}
+		fprintf(m_output, "/>\n");
 	}
 
 	// output analog types
@@ -887,6 +1017,14 @@ void info_xml_creator::output_input(const ioport_list &portlist)
 	if (keyboard)
 		fprintf(m_output, "\t\t\t<control type=\"keyboard\"/>\n");
 
+	// misc
+	if (mahjong)
+		fprintf(m_output, "\t\t\t<control type=\"mahjong\"/>\n");
+	if (hanafuda)
+		fprintf(m_output, "\t\t\t<control type=\"hanafuda\"/>\n");
+	if (gambling)
+		fprintf(m_output, "\t\t\t<control type=\"gambling\"/>\n");
+
 	fprintf(m_output, "\t\t</input>\n");
 }
 
@@ -956,7 +1094,7 @@ void info_xml_creator::output_driver()
 	/* some minor issues, games marked as status=preliminary */
 	/* don't work or have major emulation problems. */
 
-	if (m_drivlist.driver().flags & (GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_NO_SOUND | GAME_WRONG_COLORS))
+	if (m_drivlist.driver().flags & (GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_NO_SOUND | GAME_WRONG_COLORS | GAME_MECHANICAL))
 		fprintf(m_output, " status=\"preliminary\"");
 	else if (m_drivlist.driver().flags & (GAME_IMPERFECT_COLORS | GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS))
 		fprintf(m_output, " status=\"imperfect\"");
@@ -1004,36 +1142,6 @@ void info_xml_creator::output_driver()
 }
 
 
-//-------------------------------------------------
-//  output_categories - print the Categories
-//  settings for a system
-//-------------------------------------------------
-
-void info_xml_creator::output_categories(const ioport_list &portlist)
-{
-	// iterate looking for Categories
-	for (input_port_config *port = portlist.first(); port != NULL; port = port->next())
-		for (input_field_config *field = port->fieldlist().first(); field != NULL; field = field->next())
-			if (field->type == IPT_CATEGORY)
-			{
-				// output the category name information
-				fprintf(m_output, "\t\t<category name=\"%s\">\n", xml_normalize_string(input_field_name(field)));
-
-				// loop over item settings
-				for (input_setting_config *setting = field->settinglist().first(); setting != NULL; setting = setting->next())
-				{
-					fprintf(m_output, "\t\t\t<item name=\"%s\"", xml_normalize_string(setting->name));
-					if (setting->value == field->defvalue)
-						fprintf(m_output, " default=\"yes\"");
-					fprintf(m_output, "/>\n");
-				}
-
-				// terminate the category entry
-				fprintf(m_output, "\t\t</category>\n");
-			}
-}
-
-
 //-------------------------------------------------
 //  output_images - prints m_output all info on
 //  image devices
@@ -1041,8 +1149,8 @@ void info_xml_creator::output_categories(const ioport_list &portlist)
 
 void info_xml_creator::output_images()
 {
-	const device_image_interface *dev = NULL;
-	for (bool gotone = m_drivlist.config().devicelist().first(dev); gotone; gotone = dev->next(dev))
+	image_interface_iterator iter(m_drivlist.config().root_device());
+	for (const device_image_interface *dev = iter.first(); dev != NULL; dev = iter.next())
 	{
 		// print m_output device type
 		fprintf(m_output, "\t\t<device type=\"%s\"", xml_normalize_string(dev->image_type_name()));
@@ -1091,11 +1199,11 @@ void info_xml_creator::output_images()
 
 void info_xml_creator::output_slots()
 {
-	const device_slot_interface *slot = NULL;
-	for (bool gotone = m_drivlist.config().devicelist().first(slot); gotone; gotone = slot->next(slot))
+	slot_interface_iterator iter(m_drivlist.config().root_device());
+	for (const device_slot_interface *slot = iter.first(); slot != NULL; slot = iter.next())
 	{
 		// print m_output device type
-		fprintf(m_output, "\t\t<slot name=\"%s\">\n", xml_normalize_string(slot->device().tag()));
+		fprintf(m_output, "\t\t<slot name=\"%s\">\n", xml_normalize_string(slot->device().tag()+1));
 
 		/*
         if (slot->slot_interface()[0])
@@ -1107,9 +1215,9 @@ void info_xml_creator::output_slots()
 		{
 			fprintf(m_output, "\t\t\t<slotoption");
 			fprintf(m_output, " name=\"%s\"", xml_normalize_string(intf[i].name));
-			if (slot->get_default_card())
+			if (slot->get_default_card(m_drivlist.config(), m_drivlist.options()))
 			{
-				if (slot->get_default_card() == intf[i].name)
+				if (slot->get_default_card(m_drivlist.config(), m_drivlist.options()) == intf[i].name)
 					fprintf(m_output, " default=\"yes\"");
 			}
 			fprintf(m_output, "/>\n");
@@ -1127,16 +1235,15 @@ void info_xml_creator::output_slots()
 
 void info_xml_creator::output_software_list()
 {
-	for (const device_t *dev = m_drivlist.config().devicelist().first(SOFTWARE_LIST); dev != NULL; dev = dev->typenext())
+	software_list_device_iterator iter(m_drivlist.config().root_device());
+	for (const software_list_device *swlist = iter.first(); swlist != NULL; swlist = iter.next())
 	{
-		software_list_config *swlist = (software_list_config *)downcast<const legacy_device_base *>(dev)->inline_config();
-
-		for (int i = 0; i < DEVINFO_STR_SWLIST_MAX - DEVINFO_STR_SWLIST_0; i++)
-			if (swlist->list_name[i])
-			{
-				fprintf(m_output, "\t\t<softwarelist name=\"%s\" ", swlist->list_name[i]);
-				fprintf(m_output, "status=\"%s\" />\n", (swlist->list_type == SOFTWARE_LIST_ORIGINAL_SYSTEM) ? "original" : "compatible");
-			}
+		fprintf(m_output, "\t\t<softwarelist name=\"%s\" ", swlist->list_name());
+		fprintf(m_output, "status=\"%s\" ", (swlist->list_type() == SOFTWARE_LIST_ORIGINAL_SYSTEM) ? "original" : "compatible");
+		if (swlist->filter()) {
+			fprintf(m_output, "filter=\"%s\" ", swlist->filter());
+		}
+		fprintf(m_output, "/>\n");
 	}
 }
 
@@ -1149,19 +1256,19 @@ void info_xml_creator::output_software_list()
 
 void info_xml_creator::output_ramoptions()
 {
-	for (const device_t *device = m_drivlist.config().devicelist().first(RAM); device != NULL; device = device->typenext())
+	ram_device_iterator iter(m_drivlist.config().root_device());
+	for (const ram_device *ram = iter.first(); ram != NULL; ram = iter.next())
 	{
-		ram_config *ram = (ram_config *)downcast<const legacy_device_base *>(device)->inline_config();
-		fprintf(m_output, "\t\t<ramoption default=\"1\">%u</ramoption>\n", ram_parse_string(ram->default_size));
+		fprintf(m_output, "\t\t<ramoption default=\"1\">%u</ramoption>\n", ram->default_size());
 
-		if (ram->extra_options != NULL)
+		if (ram->extra_options() != NULL)
 		{
-			astring options(ram->extra_options);
+			astring options(ram->extra_options());
 			for (int start = 0, end = options.chr(0, ','); ; start = end + 1, end = options.chr(start, ','))
 			{
 				astring option;
 				option.cpysubstr(options, start, (end == -1) ? -1 : end - start);
-				fprintf(m_output, "\t\t<ramoption>%u</ramoption>\n", ram_parse_string(option));
+				fprintf(m_output, "\t\t<ramoption>%u</ramoption>\n", ram_device::parse_string(option));
 				if (end == -1)
 					break;
 			}
@@ -1178,12 +1285,11 @@ void info_xml_creator::output_ramoptions()
 const char *info_xml_creator::get_merge_name(const hash_collection &romhashes)
 {
 	const char *merge_name = NULL;
-
 	// walk the parent chain
 	for (int clone_of = m_drivlist.find(m_drivlist.driver().parent); clone_of != -1; clone_of = m_drivlist.find(m_drivlist.driver(clone_of).parent))
 
 		// look in the parent's ROMs
-		for (const rom_source *psource = rom_first_source(m_drivlist.config(clone_of)); psource != NULL; psource = rom_next_source(*psource))
+		for (const rom_source *psource = rom_first_source(m_drivlist.config(clone_of,m_lookup_options)); psource != NULL; psource = rom_next_source(*psource))
 			for (const rom_entry *pregion = rom_first_region(*psource); pregion != NULL; pregion = rom_next_region(pregion))
 				for (const rom_entry *prom = rom_first_file(pregion); prom != NULL; prom = rom_next_file(prom))
 				{
