@@ -6,7 +6,7 @@
     AMD/Fujitsu 29F016 (byte-wide)
     Sharp LH28F400 (word-wide)
 
-    Flash ROMs use a standardized command set accross manufacturers,
+    Flash ROMs use a standardized command set across manufacturers,
     so this emulation should work even for non-Intel and non-Sharp chips
     as long as the game doesn't query the maker ID.
 */
@@ -35,98 +35,86 @@ enum
 	FM_ERASEAMD3,	// part 3 of AMD erase sequence
 	FM_ERASEAMD4,	// part 4 of AMD erase sequence
 	FM_BYTEPROGRAM,
+	FM_BANKSELECT,
 };
 
 
 
-//**************************************************************************
-//  DEVICE DEFINITIONS
-//**************************************************************************
-
-// 8-bit variants
-DEFINE_TRIVIAL_DERIVED_DEVICE(intel_28f016s5_device_config, intelfsh8_device_config, intel_28f016s5_device, intelfsh8_device, "Sharp LH28F400 Flash", intelfsh_device_config::FLASH_SHARP_LH28F400)
-DEFINE_TRIVIAL_DERIVED_DEVICE(fujitsu_29f016a_device_config, intelfsh8_device_config, fujitsu_29f016a_device, intelfsh8_device, "Fujitsu 29F016A Flash", intelfsh_device_config::FLASH_FUJITSU_29F016A)
-DEFINE_TRIVIAL_DERIVED_DEVICE(sharp_lh28f016s_device_config, intelfsh8_device_config, sharp_lh28f016s_device, intelfsh8_device, "Sharp LH28F016S Flash", intelfsh_device_config::FLASH_SHARP_LH28F016S)
-DEFINE_TRIVIAL_DERIVED_DEVICE(intel_e28f008sa_device_config, intelfsh8_device_config, intel_e28f008sa_device, intelfsh8_device, "Intel E28F008SA Flash", intelfsh_device_config::FLASH_INTEL_E28F008SA)
-DEFINE_TRIVIAL_DERIVED_DEVICE(macronix_29l001mc_device_config, intelfsh8_device_config, macronix_29l001mc_device, intelfsh8_device, "Macronix 29L001MC Flash", intelfsh_device_config::FLASH_MACRONIX_29L001MC)
-DEFINE_TRIVIAL_DERIVED_DEVICE(panasonic_mn63f805mnp_device_config, intelfsh8_device_config, panasonic_mn63f805mnp_device, intelfsh8_device, "Panasonic MN63F805MNP Flash", intelfsh_device_config::FLASH_PANASONIC_MN63F805MNP)
-DEFINE_TRIVIAL_DERIVED_DEVICE(sanyo_le26fv10n1ts_device_config, intelfsh8_device_config, sanyo_le26fv10n1ts_device, intelfsh8_device, "Sanyo LE26FV10N1TS Flash", intelfsh_device_config::FLASH_SANYO_LE26FV10N1TS)
-
-const device_type INTEL_28F016S5 = intel_28f016s5_device_config::static_alloc_device_config;
-const device_type SHARP_LH28F016S = sharp_lh28f016s_device_config::static_alloc_device_config;
-const device_type FUJITSU_29F016A = fujitsu_29f016a_device_config::static_alloc_device_config;
-const device_type INTEL_E28F008SA = intel_e28f008sa_device_config::static_alloc_device_config;
-const device_type MACRONIX_29L001MC = macronix_29l001mc_device_config::static_alloc_device_config;
-const device_type PANASONIC_MN63F805MNP = panasonic_mn63f805mnp_device_config::static_alloc_device_config;
-const device_type SANYO_LE26FV10N1TS = sanyo_le26fv10n1ts_device_config::static_alloc_device_config;
-
-
-// 16-bit variants
-DEFINE_TRIVIAL_DERIVED_DEVICE(sharp_lh28f400_device_config, intelfsh16_device_config, sharp_lh28f400_device, intelfsh16_device, "Sharp LH28F400 Flash", intelfsh_device_config::FLASH_SHARP_LH28F400)
-DEFINE_TRIVIAL_DERIVED_DEVICE(intel_te28f160_device_config, intelfsh16_device_config, intel_te28f160_device, intelfsh16_device, "Intel TE28F160 Flash", intelfsh_device_config::FLASH_INTEL_TE28F160)
-DEFINE_TRIVIAL_DERIVED_DEVICE(intel_e28f400_device_config, intelfsh16_device_config, intel_e28f400_device, intelfsh16_device, "Intel E28F400 Flash", intelfsh_device_config::FLASH_INTEL_E28F400)
-DEFINE_TRIVIAL_DERIVED_DEVICE(sharp_unk128mbit_device_config, intelfsh16_device_config, sharp_unk128mbit_device, intelfsh16_device, "Sharp Unknown 128Mb Flash", intelfsh_device_config::FLASH_SHARP_UNK128MBIT)
-
-const device_type SHARP_LH28F400 = sharp_lh28f400_device_config::static_alloc_device_config;
-const device_type INTEL_TE28F160 = intel_te28f160_device_config::static_alloc_device_config;
-const device_type INTEL_E28F400 = intel_e28f400_device_config::static_alloc_device_config;
-const device_type SHARP_UNK128MBIT = sharp_unk128mbit_device_config::static_alloc_device_config;
-
-
-
 //**************************************************************************
 //  GLOBAL VARIABLES
 //**************************************************************************
 
-static ADDRESS_MAP_START( memory_map8_512Kb, ADDRESS_SPACE_PROGRAM, 8 )
+// device type definition
+const device_type INTEL_28F016S5 = &device_creator<intel_28f016s5_device>;
+const device_type SHARP_LH28F016S = &device_creator<sharp_lh28f016s_device>;
+const device_type AMD_29F080 = &device_creator<amd_29f080_device>;
+const device_type FUJITSU_29F016A = &device_creator<fujitsu_29f016a_device>;
+const device_type FUJITSU_29DL16X = &device_creator<fujitsu_29dl16x_device>;
+const device_type INTEL_E28F400 = &device_creator<intel_e28f400_device>;
+const device_type MACRONIX_29L001MC = &device_creator<macronix_29l001mc_device>;
+const device_type PANASONIC_MN63F805MNP = &device_creator<panasonic_mn63f805mnp_device>;
+const device_type SANYO_LE26FV10N1TS = &device_creator<sanyo_le26fv10n1ts_device>;
+
+const device_type SHARP_LH28F400 = &device_creator<sharp_lh28f400_device>;
+const device_type INTEL_E28F008SA = &device_creator<intel_e28f008sa_device>;
+const device_type INTEL_TE28F160 = &device_creator<intel_te28f160_device>;
+const device_type SHARP_UNK128MBIT = &device_creator<sharp_unk128mbit_device>;
+
+static ADDRESS_MAP_START( memory_map8_512Kb, AS_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x00ffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( memory_map8_1Mb, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( memory_map8_1Mb, AS_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x01ffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( memory_map8_8Mb, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( memory_map8_8Mb, AS_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x0fffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( memory_map8_16Mb, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( memory_map8_16Mb, AS_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x1fffff) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( memory_map16_4Mb, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( memory_map16_4Mb, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000, 0x03ffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( memory_map16_16Mb, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( memory_map16_16Mb, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000, 0x0fffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( memory_map16_64Mb, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( memory_map16_64Mb, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000, 0x3fffff) AM_RAM
 ADDRESS_MAP_END
 
 
 
 //**************************************************************************
-//  DEVICE CONFIGURATION
+//  LIVE DEVICE
 //**************************************************************************
 
 //-------------------------------------------------
-//  intelfsh_device_config - constructor
+//  intelfsh_device - constructor
 //-------------------------------------------------
 
-intelfsh_device_config::intelfsh_device_config(const machine_config &mconfig, device_type type, const char *name, const char *tag, const device_config *owner, UINT32 clock, UINT32 variant)
-	: device_config(mconfig, type, name, tag, owner, clock),
-	  device_config_memory_interface(mconfig, *this),
-	  device_config_nvram_interface(mconfig, *this),
+intelfsh_device::intelfsh_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, UINT32 variant)
+	: device_t(mconfig, type, name, tag, owner, clock),
+	  device_memory_interface(mconfig, *this),
+	  device_nvram_interface(mconfig, *this),
 	  m_type(variant),
 	  m_size(0),
 	  m_bits(8),
 	  m_device_id(0),
 	  m_maker_id(0),
-	  m_sector_is_4k(false)
+	  m_sector_is_4k(false),
+	  m_status(0x80),
+	  m_erase_sector(0),
+	  m_flash_mode(FM_NORMAL),
+	  m_flash_master_lock(false),
+	  m_timer(NULL),
+	  m_bank(0)
 {
 	address_map_constructor map = NULL;
 
@@ -140,6 +128,13 @@ intelfsh_device_config::intelfsh_device_config(const machine_config &mconfig, de
 		m_device_id = 0xaa;
 		map = ADDRESS_MAP_NAME( memory_map8_16Mb );
 		break;
+	case FLASH_AMD_29F080:
+		m_bits = 8;
+		m_size = 0x100000;
+		m_maker_id = 0x01;
+		m_device_id = 0xd5;
+		map = ADDRESS_MAP_NAME( memory_map8_8Mb );
+		break;
 	case FLASH_SHARP_LH28F400:
 	case FLASH_INTEL_E28F400:
 		m_bits = 16;
@@ -155,6 +150,13 @@ intelfsh_device_config::intelfsh_device_config(const machine_config &mconfig, de
 		m_device_id = 0xad;
 		map = ADDRESS_MAP_NAME( memory_map8_16Mb );
 		break;
+	case FLASH_FUJITSU_29DL16X:
+		m_bits = 8;
+		m_size = 0x200000;
+		m_maker_id = 0x04;
+		m_device_id = 0x35;
+		map = ADDRESS_MAP_NAME( memory_map8_16Mb );
+		break;
 	case FLASH_INTEL_E28F008SA:
 		m_bits = 8;
 		m_size = 0x100000;
@@ -209,55 +211,51 @@ intelfsh_device_config::intelfsh_device_config(const machine_config &mconfig, de
 	m_space_config = address_space_config("flash", ENDIANNESS_BIG, m_bits, addrbits, (m_bits == 8) ? 0 : -1, map);
 }
 
-intelfsh8_device_config::intelfsh8_device_config(const machine_config &mconfig, device_type type, const char *name, const char *tag, const device_config *owner, UINT32 clock, UINT32 variant)
-	: intelfsh_device_config(mconfig, type, name, tag, owner, clock, variant)
-{
-}
+intelfsh8_device::intelfsh8_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, UINT32 variant)
+	: intelfsh_device(mconfig, type, name, tag, owner, clock, variant) { }
 
-intelfsh16_device_config::intelfsh16_device_config(const machine_config &mconfig, device_type type, const char *name, const char *tag, const device_config *owner, UINT32 clock, UINT32 variant)
-	: intelfsh_device_config(mconfig, type, name, tag, owner, clock, variant)
-{
-}
+intelfsh16_device::intelfsh16_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, UINT32 variant)
+	: intelfsh_device(mconfig, type, name, tag, owner, clock, variant) { }
 
 
-//-------------------------------------------------
-//  memory_space_config - return a description of
-//  any address spaces owned by this device
-//-------------------------------------------------
+intel_28f016s5_device::intel_28f016s5_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, INTEL_28F016S5, "Intel 28F016S5 Flash", tag, owner, clock, FLASH_INTEL_28F016S5) { }
 
-const address_space_config *intelfsh_device_config::memory_space_config(int spacenum) const
-{
-	return (spacenum == 0) ? &m_space_config : NULL;
-}
+fujitsu_29f016a_device::fujitsu_29f016a_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, FUJITSU_29F016A, "Fujitsu 29F016A Flash", tag, owner, clock, FLASH_FUJITSU_29F016A) { }
 
+fujitsu_29dl16x_device::fujitsu_29dl16x_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, FUJITSU_29DL16X, "Fujitsu 29DL16X Flash", tag, owner, clock, FLASH_FUJITSU_29DL16X) { }
 
+sharp_lh28f016s_device::sharp_lh28f016s_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, SHARP_LH28F016S, "Sharp LH28F016S Flash", tag, owner, clock, FLASH_SHARP_LH28F016S) { }
 
-//**************************************************************************
-//  LIVE DEVICE
-//**************************************************************************
+amd_29f080_device::amd_29f080_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, AMD_29F080, "AMD 29F080 Flash", tag, owner, clock, FLASH_AMD_29F080) { }
 
-//-------------------------------------------------
-//  intelfsh_device - constructor
-//-------------------------------------------------
+intel_e28f008sa_device::intel_e28f008sa_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, INTEL_E28F008SA, "Intel E28F008SA Flash", tag, owner, clock, FLASH_INTEL_E28F008SA) { }
 
-intelfsh_device::intelfsh_device(running_machine &_machine, const intelfsh_device_config &config)
-	: device_t(_machine, config),
-	  device_memory_interface(_machine, config, *this),
-	  device_nvram_interface(_machine, config, *this),
-	  m_config(config),
-	  m_status(0x80),
-	  m_erase_sector(0),
-	  m_flash_mode(FM_NORMAL),
-	  m_flash_master_lock(false),
-	  m_timer(NULL)
-{
-}
+macronix_29l001mc_device::macronix_29l001mc_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, MACRONIX_29L001MC, "Macronix 29L001MC Flash", tag, owner, clock, FLASH_MACRONIX_29L001MC) { }
 
-intelfsh8_device::intelfsh8_device(running_machine &_machine, const intelfsh_device_config &config)
-	: intelfsh_device(_machine, config) { }
+panasonic_mn63f805mnp_device::panasonic_mn63f805mnp_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, PANASONIC_MN63F805MNP, "Panasonic MN63F805MNP Flash", tag, owner, clock, FLASH_PANASONIC_MN63F805MNP) { }
 
-intelfsh16_device::intelfsh16_device(running_machine &_machine, const intelfsh_device_config &config)
-	: intelfsh_device(_machine, config) { }
+sanyo_le26fv10n1ts_device::sanyo_le26fv10n1ts_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, SANYO_LE26FV10N1TS, "Sanyo LE26FV10N1TS Flash", tag, owner, clock, FLASH_SANYO_LE26FV10N1TS) { }
+
+sharp_lh28f400_device::sharp_lh28f400_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh16_device(mconfig, SHARP_LH28F400, "Sharp LH28F400 Flash", tag, owner, clock, FLASH_SHARP_LH28F400) { }
+
+intel_te28f160_device::intel_te28f160_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh16_device(mconfig, INTEL_TE28F160, "Intel TE28F160 Flash", tag, owner, clock, FLASH_INTEL_TE28F160) { }
+
+intel_e28f400_device::intel_e28f400_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh16_device(mconfig, INTEL_E28F400, "Intel E28F400 Flash", tag, owner, clock, FLASH_INTEL_E28F400) { }
+
+sharp_unk128mbit_device::sharp_unk128mbit_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh16_device(mconfig, SHARP_UNK128MBIT, "Sharp Unknown 128Mbit Flash", tag, owner, clock, FLASH_SHARP_UNK128MBIT) { }
 
 
 //-------------------------------------------------
@@ -266,11 +264,11 @@ intelfsh16_device::intelfsh16_device(running_machine &_machine, const intelfsh_d
 
 void intelfsh_device::device_start()
 {
-	m_timer = device_timer_alloc(*this);
+	m_timer = timer_alloc();
 
-	state_save_register_device_item( this, 0, m_status );
-	state_save_register_device_item( this, 0, m_flash_mode );
-	state_save_register_device_item( this, 0, m_flash_master_lock );
+	save_item( NAME(m_status) );
+	save_item( NAME(m_flash_mode) );
+	save_item( NAME(m_flash_master_lock) );
 }
 
 
@@ -293,6 +291,17 @@ void intelfsh_device::device_timer(emu_timer &timer, device_timer_id id, int par
 }
 
 
+//-------------------------------------------------
+//  memory_space_config - return a description of
+//  any address spaces owned by this device
+//-------------------------------------------------
+
+const address_space_config *intelfsh_device::memory_space_config(address_spacenum spacenum) const
+{
+	return (spacenum == 0) ? &m_space_config : NULL;
+}
+
+
 //-------------------------------------------------
 //  nvram_default - called to initialize NVRAM to
 //  its default state
@@ -304,10 +313,10 @@ void intelfsh_device::nvram_default()
 	if (m_region != NULL)
 	{
 		UINT32 bytes = m_region->bytes();
-		if (bytes > m_config.m_size)
-			bytes = m_config.m_size;
+		if (bytes > m_size)
+			bytes = m_size;
 
-		if (m_config.m_bits == 8)
+		if (m_bits == 8)
 		{
 			for (offs_t offs = 0; offs < bytes; offs++)
 				m_addrspace[0]->write_byte(offs, m_region->u8(offs));
@@ -321,7 +330,7 @@ void intelfsh_device::nvram_default()
 	}
 
 	// otherwise, default to 0xff
-	for (offs_t offs = 0; offs < m_config.m_size; offs++)
+	for (offs_t offs = 0; offs < m_size; offs++)
 		m_addrspace[0]->write_byte(offs, 0xff);
 }
 
@@ -331,11 +340,11 @@ void intelfsh_device::nvram_default()
 //  .nv file
 //-------------------------------------------------
 
-void intelfsh_device::nvram_read(mame_file &file)
+void intelfsh_device::nvram_read(emu_file &file)
 {
-	UINT8 *buffer = global_alloc_array(UINT8, m_config.m_size);
-	mame_fread(&file, buffer, m_config.m_size);
-	for (int byte = 0; byte < m_config.m_size; byte++)
+	UINT8 *buffer = global_alloc_array(UINT8, m_size);
+	file.read(buffer, m_size);
+	for (int byte = 0; byte < m_size; byte++)
 		m_addrspace[0]->write_byte(byte, buffer[byte]);
 	global_free(buffer);
 }
@@ -346,12 +355,12 @@ void intelfsh_device::nvram_read(mame_file &file)
 //  .nv file
 //-------------------------------------------------
 
-void intelfsh_device::nvram_write(mame_file &file)
+void intelfsh_device::nvram_write(emu_file &file)
 {
-	UINT8 *buffer = global_alloc_array(UINT8, m_config.m_size);
-	for (int byte = 0; byte < m_config.m_size; byte++)
+	UINT8 *buffer = global_alloc_array(UINT8, m_size);
+	for (int byte = 0; byte < m_size; byte++)
 		buffer[byte] = m_addrspace[0]->read_byte(byte);
-	mame_fwrite(&file, buffer, m_config.m_size);
+	file.write(buffer, m_size);
 	global_free(buffer);
 }
 
@@ -364,11 +373,12 @@ void intelfsh_device::nvram_write(mame_file &file)
 UINT32 intelfsh_device::read_full(UINT32 address)
 {
 	UINT32 data = 0;
+	address += m_bank << 16;
 	switch( m_flash_mode )
 	{
 	default:
 	case FM_NORMAL:
-		switch( m_config.m_bits )
+		switch( m_bits )
 		{
 		case 8:
 			{
@@ -386,21 +396,34 @@ UINT32 intelfsh_device::read_full(UINT32 address)
 		data = m_status;
 		break;
 	case FM_READAMDID3:
-		switch (address)
+		if (m_maker_id == 0x04 && m_device_id == 0x35)
 		{
-			case 0:	data = m_config.m_maker_id; break;
-			case 1: data = m_config.m_device_id; break;
-			case 2: data = 0; break;
+			//used in Fujitsu 29DL16X 8bits mode
+			switch (address)
+			{
+				case 0:	data = m_maker_id; break;
+				case 2: data = m_device_id; break;
+				case 4: data = 0; break;
+			}
+		}
+		else
+		{
+			switch (address)
+			{
+				case 0:	data = m_maker_id; break;
+				case 1: data = m_device_id; break;
+				case 2: data = 0; break;
+			}
 		}
 		break;
 	case FM_READID:
 		switch (address)
 		{
 		case 0:	// maker ID
-			data = m_config.m_maker_id;
+			data = m_maker_id;
 			break;
 		case 1:	// chip ID
-			data = m_config.m_device_id;
+			data = m_device_id;
 			break;
 		case 2:	// block lock config
 			data = 0; // we don't support this yet
@@ -421,7 +444,7 @@ UINT32 intelfsh_device::read_full(UINT32 address)
 		// reads outside of the erasing sector return normal data
 		if ((address < m_erase_sector) || (address >= m_erase_sector+(64*1024)))
 		{
-			switch( m_config.m_bits )
+			switch( m_bits )
 			{
 			case 8:
 				{
@@ -458,6 +481,8 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 {
 //  logerror( "intelflash_write( %d, %08x, %08x )\n", chip, address, data );
 
+	address += m_bank << 16;
+
 	switch( m_flash_mode )
 	{
 	case FM_NORMAL:
@@ -495,6 +520,10 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 			{
 				m_flash_mode = FM_READAMDID1;
 			}
+			else if( ( address & 0xfff ) == 0xaaa )
+			{
+				m_flash_mode = FM_READAMDID1;
+			}
 			break;
 		default:
 			logerror( "Unknown flash mode byte %x\n", data & 0xff );
@@ -510,6 +539,14 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		{
 			m_flash_mode = FM_READAMDID2;
 		}
+		else if( ( address & 0xfff ) == 0x555 && ( data & 0xff ) == 0x55 )
+		{
+			m_flash_mode = FM_READAMDID2;
+		}
+		else if( ( address & 0x7ff ) == 0x2aa && ( data & 0xff ) == 0x55 && m_type == FLASH_AMD_29F080 )
+		{
+			m_flash_mode = FM_READAMDID2;
+		}
 		else
 		{
 			logerror( "unexpected %08x=%02x in FM_READAMDID1\n", address, data & 0xff );
@@ -525,6 +562,10 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		{
 			m_flash_mode = FM_READAMDID3;
 		}
+		else if( ( address & 0xfff ) == 0xaaa && ( data & 0xff ) == 0x90 )
+		{
+			m_flash_mode = FM_READAMDID3;
+		}
 		else if( ( address & 0xffff ) == 0x555 && ( data & 0xff ) == 0x80 )
 		{
 			m_flash_mode = FM_ERASEAMD1;
@@ -533,6 +574,10 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		{
 			m_flash_mode = FM_ERASEAMD1;
 		}
+		else if( ( address & 0xfff ) == 0xaaa && ( data & 0xff ) == 0x80 )
+		{
+			m_flash_mode = FM_ERASEAMD1;
+		}
 		else if( ( address & 0xffff ) == 0x555 && ( data & 0xff ) == 0xa0 )
 		{
 			m_flash_mode = FM_BYTEPROGRAM;
@@ -541,6 +586,10 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		{
 			m_flash_mode = FM_BYTEPROGRAM;
 		}
+		else if( ( address & 0xfff ) == 0xaaa && ( data & 0xff ) == 0xa0 )
+		{
+			m_flash_mode = FM_BYTEPROGRAM;
+		}
 		else if( ( address & 0xffff ) == 0x555 && ( data & 0xff ) == 0xf0 )
 		{
 			m_flash_mode = FM_NORMAL;
@@ -549,6 +598,32 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		{
 			m_flash_mode = FM_NORMAL;
 		}
+		else if( ( address & 0xfff ) == 0xaaa && ( data & 0xff ) == 0xf0 )
+		{
+			m_flash_mode = FM_NORMAL;
+		}
+		else if( ( address & 0xffff ) == 0x5555 && ( data & 0xff ) == 0xb0 && m_maker_id == 0x62 && m_device_id == 0x13 )
+		{
+			m_flash_mode = FM_BANKSELECT;
+		}
+
+		// for AMD 29F080 address bits A11-A19 don't care
+		else if(( address & 0x7ff ) == 0x555 && ( data & 0xff ) == 0x80 && m_type == FLASH_AMD_29F080 )
+		{
+			m_flash_mode = FM_ERASEAMD1;
+		}
+		else if(( address & 0x7ff ) == 0x555 && ( data & 0xff ) == 0x90 && m_type == FLASH_AMD_29F080 )
+		{
+			m_flash_mode = FM_READAMDID3;
+		}
+		else if(( address & 0x7ff ) == 0x555 && ( data & 0xff ) == 0xa0 && m_type == FLASH_AMD_29F080 )
+		{
+			m_flash_mode = FM_BYTEPROGRAM;
+		}
+		else if(( address & 0x7ff ) == 0x555 && ( data & 0xff ) == 0xf0 && m_type == FLASH_AMD_29F080 )
+		{
+			m_flash_mode = FM_NORMAL;
+		}
 		else
 		{
 			logerror( "unexpected %08x=%02x in FM_READAMDID2\n", address, data & 0xff );
@@ -560,6 +635,10 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		{
 			m_flash_mode = FM_ERASEAMD2;
 		}
+		else if( ( address & 0xfff ) == 0xaaa && ( data & 0xff ) == 0xaa )
+		{
+			m_flash_mode = FM_ERASEAMD2;
+		}
 		else
 		{
 			logerror( "unexpected %08x=%02x in FM_ERASEAMD1\n", address, data & 0xff );
@@ -574,48 +653,53 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		{
 			m_flash_mode = FM_ERASEAMD3;
 		}
+		else if( ( address & 0xfff ) == 0x555 && ( data & 0xff ) == 0x55 )
+		{
+			m_flash_mode = FM_ERASEAMD3;
+		}
 		else
 		{
 			logerror( "unexpected %08x=%02x in FM_ERASEAMD2\n", address, data & 0xff );
 		}
 		break;
 	case FM_ERASEAMD3:
-		if( ( address & 0xfff ) == 0x555 && ( data & 0xff ) == 0x10 )
+		if( (( address & 0xfff ) == 0x555 && ( data & 0xff ) == 0x10 ) ||
+		    (( address & 0xfff ) == 0xaaa && ( data & 0xff ) == 0x10 ) )
 		{
 			// chip erase
-			for (offs_t offs = 0; offs < m_config.m_size; offs++)
+			for (offs_t offs = 0; offs < m_size; offs++)
 				m_addrspace[0]->write_byte(offs, 0xff);
 
 			m_status = 1 << 3;
 			m_flash_mode = FM_ERASEAMD4;
 
-			if (m_config.m_sector_is_4k)
+			if (m_sector_is_4k)
 			{
-				timer_adjust_oneshot( m_timer, ATTOTIME_IN_SEC( 1 ), 0 );
+				m_timer->adjust( attotime::from_seconds( 1 ) );
 			}
 			else
 			{
-				timer_adjust_oneshot( m_timer, ATTOTIME_IN_SEC( 16 ), 0 );
+				m_timer->adjust( attotime::from_seconds( 16 ) );
 			}
 		}
 		else if( ( data & 0xff ) == 0x30 )
 		{
 			// sector erase
 			// clear the 4k/64k block containing the current address to all 0xffs
-			UINT32 base = address * ((m_config.m_bits == 16) ? 2 : 1);
-			if (m_config.m_sector_is_4k)
+			UINT32 base = address * ((m_bits == 16) ? 2 : 1);
+			if (m_sector_is_4k)
 			{
 				for (offs_t offs = 0; offs < 4 * 1024; offs++)
 					m_addrspace[0]->write_byte((base & ~0xfff) + offs, 0xff);
-				m_erase_sector = address & ((m_config.m_bits == 16) ? ~0x7ff : ~0xfff);
-				timer_adjust_oneshot( m_timer, ATTOTIME_IN_MSEC( 125 ), 0 );
+				m_erase_sector = address & ((m_bits == 16) ? ~0x7ff : ~0xfff);
+				m_timer->adjust( attotime::from_msec( 125 ) );
 			}
 			else
 			{
 				for (offs_t offs = 0; offs < 64 * 1024; offs++)
 					m_addrspace[0]->write_byte((base & ~0xffff) + offs, 0xff);
-				m_erase_sector = address & ((m_config.m_bits == 16) ? ~0x7fff : ~0xffff);
-				timer_adjust_oneshot( m_timer, ATTOTIME_IN_SEC( 1 ), 0 );
+				m_erase_sector = address & ((m_bits == 16) ? ~0x7fff : ~0xffff);
+				m_timer->adjust( attotime::from_seconds( 1 ) );
 			}
 
 			m_status = 1 << 3;
@@ -627,7 +711,7 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		}
 		break;
 	case FM_BYTEPROGRAM:
-		switch( m_config.m_bits )
+		switch( m_bits )
 		{
 		case 8:
 			{
@@ -635,13 +719,13 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 			}
 			break;
 		default:
-			logerror( "FM_BYTEPROGRAM not supported when m_bits == %d\n", m_config.m_bits );
+			logerror( "FM_BYTEPROGRAM not supported when m_bits == %d\n", m_bits );
 			break;
 		}
 		m_flash_mode = FM_NORMAL;
 		break;
 	case FM_WRITEPART1:
-		switch( m_config.m_bits )
+		switch( m_bits )
 		{
 		case 8:
 			{
@@ -654,7 +738,7 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 			}
 			break;
 		default:
-			logerror( "FM_WRITEPART1 not supported when m_bits == %d\n", m_config.m_bits );
+			logerror( "FM_WRITEPART1 not supported when m_bits == %d\n", m_bits );
 			break;
 		}
 		m_status = 0x80;
@@ -664,14 +748,14 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		if( ( data & 0xff ) == 0xd0 )
 		{
 			// clear the 64k block containing the current address to all 0xffs
-			UINT32 base = address * ((m_config.m_bits == 16) ? 2 : 1);
+			UINT32 base = address * ((m_bits == 16) ? 2 : 1);
 			for (offs_t offs = 0; offs < 64 * 1024; offs++)
 				m_addrspace[0]->write_byte((base & ~0xffff) + offs, 0xff);
 
 			m_status = 0x00;
 			m_flash_mode = FM_READSTATUS;
 
-			timer_adjust_oneshot( m_timer, ATTOTIME_IN_SEC( 1 ), 0 );
+			m_timer->adjust( attotime::from_seconds( 1 ) );
 			break;
 		}
 		else
@@ -694,5 +778,9 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 		}
 		m_flash_mode = FM_NORMAL;
 		break;
+	case FM_BANKSELECT:
+		m_bank = data & 0xff;
+		m_flash_mode = FM_NORMAL;
+		break;
 	}
 }
