@@ -84,7 +84,6 @@
 #include "ui.h"
 #include "uimenu.h"
 #include "uiinput.h"
-#include "streams.h"
 #include "crsshair.h"
 #include "validity.h"
 #include "debug/debugcon.h"
@@ -97,36 +96,27 @@
     GLOBAL VARIABLES
 ***************************************************************************/
 
-/* the current options */
-static core_options *mame_opts;
-
 /* started empty? */
 static bool started_empty;
 
+static bool print_verbose = false;
+
 static running_machine *global_machine;
 
 /* output channels */
-static output_callback_func output_cb[OUTPUT_CHANNEL_COUNT];
-static void *output_cb_param[OUTPUT_CHANNEL_COUNT];
-
-/* the "disclaimer" that should be printed when run with no parameters */
-const char mame_disclaimer[] =
-	"MAME is an emulator: it reproduces, more or less faithfully, the behaviour of\n"
-	"several arcade machines. But hardware is useless without software, so an image\n"
-	"of the ROMs which run on that hardware is required. Such ROMs, like any other\n"
-	"commercial software, are copyrighted material and it is therefore illegal to\n"
-	"use them if you don't own the original arcade machine. Needless to say, ROMs\n"
-	"are not distributed together with MAME. Distribution of MAME together with ROM\n"
-	"images is a violation of copyright law and should be promptly reported to the\n"
-	"authors so that appropriate legal action can be taken.\n";
-
-
-
-/***************************************************************************
-    FUNCTION PROTOTYPES
-***************************************************************************/
-
-static int parse_ini_file(core_options *options, const char *name, int priority);
+static output_delegate output_cb[OUTPUT_CHANNEL_COUNT] =
+{
+	output_delegate(FUNC(mame_file_output_callback), stderr),	// OUTPUT_CHANNEL_ERROR
+	output_delegate(FUNC(mame_file_output_callback), stderr),	// OUTPUT_CHANNEL_WARNING
+	output_delegate(FUNC(mame_file_output_callback), stdout),	// OUTPUT_CHANNEL_INFO
+#ifdef MAME_DEBUG
+	output_delegate(FUNC(mame_file_output_callback), stdout),	// OUTPUT_CHANNEL_DEBUG
+#else
+	output_delegate(FUNC(mame_null_output_callback), stdout),	// OUTPUT_CHANNEL_DEBUG
+#endif
+	output_delegate(FUNC(mame_file_output_callback), stdout),	// OUTPUT_CHANNEL_VERBOSE
+	output_delegate(FUNC(mame_file_output_callback), stdout)	// OUTPUT_CHANNEL_LOG
+};
 
 
 
@@ -139,9 +129,9 @@ static int parse_ini_file(core_options *options, const char *name, int priority)
     given machine is valid
 -------------------------------------------------*/
 
-int mame_is_valid_machine(running_machine *machine)
+int mame_is_valid_machine(running_machine &machine)
 {
-	return (machine != NULL && machine == global_machine);
+	return (&machine == global_machine);
 }
 
 
@@ -149,74 +139,70 @@ int mame_is_valid_machine(running_machine *machine)
     mame_execute - run the core emulation
 -------------------------------------------------*/
 
-int mame_execute(osd_interface &osd, core_options *options)
+int mame_execute(emu_options &options, osd_interface &osd)
 {
 	bool firstgame = true;
 	bool firstrun = true;
 
+	// extract the verbose printing option
+	if (options.verbose())
+		print_verbose = true;
+
 	// loop across multiple hard resets
 	bool exit_pending = false;
 	int error = MAMERR_NONE;
 	while (error == MAMERR_NONE && !exit_pending)
 	{
-		// specify the global mame_options
-		mame_opts = options;
-
-		// convert the specified gamename to a driver
-		astring gamename;
-		core_filename_extract_base(&gamename, options_get_string(options, OPTION_GAMENAME), true);
-		const game_driver *driver = driver_get_name(gamename);
-
 		// if no driver, use the internal empty driver
-		if (driver == NULL)
+		const game_driver *system = options.system();
+		if (system == NULL)
 		{
-			driver = &GAME_NAME(empty);
+			system = &GAME_NAME(___empty);
 			if (firstgame)
 				started_empty = true;
 		}
 
 		// otherwise, perform validity checks before anything else
-		else if (mame_validitychecks(driver) != 0)
-			return MAMERR_FAILED_VALIDITY;
+		else
+		{
+			validity_checker valid(options);
+			valid.check_shared_source(*system);
+		}
 
 		firstgame = false;
 
 		// parse any INI files as the first thing
-		if (options_get_bool(options, OPTION_READCONFIG))
+		if (options.read_config())
 		{
-			options_revert(options, OPTION_PRIORITY_INI);
-			mame_parse_ini_files(options, driver);
+			options.revert(OPTION_PRIORITY_INI);
+			astring errors;
+			options.parse_standard_inis(errors);
 		}
 
 		// create the machine configuration
-		const machine_config *config = global_alloc(machine_config(*driver));
+		machine_config config(*system, options);
 
 		// create the machine structure and driver
-		running_machine *machine = global_alloc(running_machine(*config, osd, *options, started_empty));
+		running_machine machine(config, osd, started_empty);
 
 		// looooong term: remove this
-		global_machine = machine;
+		global_machine = &machine;
 
 		// run the machine
-		error = machine->run(firstrun);
+		error = machine.run(firstrun);
 		firstrun = false;
 
 		// check the state of the machine
-		if (machine->new_driver_pending())
+		if (machine.new_driver_pending())
 		{
-			options_set_string(options, OPTION_GAMENAME, machine->new_driver_name(), OPTION_PRIORITY_CMDLINE);
+			options.set_system_name(machine.new_driver_name());
 			firstrun = true;
 		}
-		if (machine->exit_pending())
+		if (machine.exit_pending())
 			exit_pending = true;
 
-		// destroy the machine and the config
-		global_free(machine);
-		global_free(config);
+		// machine will go away when we exit scope
 		global_machine = NULL;
-
-		// reset the options
-		mame_opts = NULL;
 	}
 
 	// return an error
@@ -224,30 +210,6 @@ int mame_execute(osd_interface &osd, core_options *options)
 }
 
 
-/*-------------------------------------------------
-    mame_options - accesses the options for the
-    currently running emulation
--------------------------------------------------*/
-
-core_options *mame_options(void)
-{
-	assert(mame_opts != NULL);
-	return mame_opts;
-}
-
-
-
-/*-------------------------------------------------
-    set_mame_options - set mame options, used by
-    validate option
--------------------------------------------------*/
-
-void set_mame_options(core_options *options)
-{
-	mame_opts = options;
-}
-
-
 /***************************************************************************
     OUTPUT MANAGEMENT
 ***************************************************************************/
@@ -257,20 +219,17 @@ void set_mame_options(core_options *options)
     channel
 -------------------------------------------------*/
 
-void mame_set_output_channel(output_channel channel, output_callback_func callback, void *param, output_callback_func *prevcb, void **prevparam)
+output_delegate mame_set_output_channel(output_channel channel, output_delegate callback)
 {
 	assert(channel < OUTPUT_CHANNEL_COUNT);
-	assert(callback != NULL);
+	assert(!callback.isnull());
 
 	/* return the originals if requested */
-	if (prevcb != NULL)
-		*prevcb = output_cb[channel];
-	if (prevparam != NULL)
-		*prevparam = output_cb_param[channel];
+	output_delegate prevcb = output_cb[channel];
 
 	/* set the new ones */
 	output_cb[channel] = callback;
-	output_cb_param[channel] = param;
+	return prevcb;
 }
 
 
@@ -279,9 +238,9 @@ void mame_set_output_channel(output_channel channel, output_callback_func callba
     for file output
 -------------------------------------------------*/
 
-void mame_file_output_callback(void *param, const char *format, va_list argptr)
+void mame_file_output_callback(FILE *param, const char *format, va_list argptr)
 {
-	vfprintf((FILE *)param, format, argptr);
+	vfprintf(param, format, argptr);
 }
 
 
@@ -290,7 +249,7 @@ void mame_file_output_callback(void *param, const char *format, va_list argptr)
     for no output
 -------------------------------------------------*/
 
-void mame_null_output_callback(void *param, const char *format, va_list argptr)
+void mame_null_output_callback(FILE *param, const char *format, va_list argptr)
 {
 }
 
@@ -304,16 +263,9 @@ void mame_printf_error(const char *format, ...)
 {
 	va_list argptr;
 
-	/* by default, we go to stderr */
-	if (output_cb[OUTPUT_CHANNEL_ERROR] == NULL)
-	{
-		output_cb[OUTPUT_CHANNEL_ERROR] = mame_file_output_callback;
-		output_cb_param[OUTPUT_CHANNEL_ERROR] = stderr;
-	}
-
 	/* do the output */
 	va_start(argptr, format);
-	(*output_cb[OUTPUT_CHANNEL_ERROR])(output_cb_param[OUTPUT_CHANNEL_ERROR], format, argptr);
+	output_cb[OUTPUT_CHANNEL_ERROR](format, argptr);
 	va_end(argptr);
 }
 
@@ -327,16 +279,9 @@ void mame_printf_warning(const char *format, ...)
 {
 	va_list argptr;
 
-	/* by default, we go to stderr */
-	if (output_cb[OUTPUT_CHANNEL_WARNING] == NULL)
-	{
-		output_cb[OUTPUT_CHANNEL_WARNING] = mame_file_output_callback;
-		output_cb_param[OUTPUT_CHANNEL_WARNING] = stderr;
-	}
-
 	/* do the output */
 	va_start(argptr, format);
-	(*output_cb[OUTPUT_CHANNEL_WARNING])(output_cb_param[OUTPUT_CHANNEL_WARNING], format, argptr);
+	output_cb[OUTPUT_CHANNEL_WARNING](format, argptr);
 	va_end(argptr);
 }
 
@@ -350,16 +295,9 @@ void mame_printf_info(const char *format, ...)
 {
 	va_list argptr;
 
-	/* by default, we go to stdout */
-	if (output_cb[OUTPUT_CHANNEL_INFO] == NULL)
-	{
-		output_cb[OUTPUT_CHANNEL_INFO] = mame_file_output_callback;
-		output_cb_param[OUTPUT_CHANNEL_INFO] = stdout;
-	}
-
 	/* do the output */
 	va_start(argptr, format);
-	(*output_cb[OUTPUT_CHANNEL_INFO])(output_cb_param[OUTPUT_CHANNEL_INFO], format, argptr);
+	output_cb[OUTPUT_CHANNEL_INFO](format, argptr);
 	va_end(argptr);
 }
 
@@ -374,19 +312,12 @@ void mame_printf_verbose(const char *format, ...)
 	va_list argptr;
 
 	/* if we're not verbose, skip it */
-	if (mame_opts == NULL || !options_get_bool(mame_options(), OPTION_VERBOSE))
+	if (!print_verbose)
 		return;
 
-	/* by default, we go to stdout */
-	if (output_cb[OUTPUT_CHANNEL_VERBOSE] == NULL)
-	{
-		output_cb[OUTPUT_CHANNEL_VERBOSE] = mame_file_output_callback;
-		output_cb_param[OUTPUT_CHANNEL_VERBOSE] = stdout;
-	}
-
 	/* do the output */
 	va_start(argptr, format);
-	(*output_cb[OUTPUT_CHANNEL_VERBOSE])(output_cb_param[OUTPUT_CHANNEL_VERBOSE], format, argptr);
+	output_cb[OUTPUT_CHANNEL_VERBOSE](format, argptr);
 	va_end(argptr);
 }
 
@@ -400,21 +331,9 @@ void mame_printf_debug(const char *format, ...)
 {
 	va_list argptr;
 
-	/* by default, we go to stderr */
-	if (output_cb[OUTPUT_CHANNEL_DEBUG] == NULL)
-	{
-#ifdef MAME_DEBUG
-		output_cb[OUTPUT_CHANNEL_DEBUG] = mame_file_output_callback;
-		output_cb_param[OUTPUT_CHANNEL_DEBUG] = stdout;
-#else
-		output_cb[OUTPUT_CHANNEL_DEBUG] = mame_null_output_callback;
-		output_cb_param[OUTPUT_CHANNEL_DEBUG] = NULL;
-#endif
-	}
-
 	/* do the output */
 	va_start(argptr, format);
-	(*output_cb[OUTPUT_CHANNEL_DEBUG])(output_cb_param[OUTPUT_CHANNEL_DEBUG], format, argptr);
+	output_cb[OUTPUT_CHANNEL_DEBUG](format, argptr);
 	va_end(argptr);
 }
 
@@ -429,16 +348,9 @@ void mame_printf_log(const char *format, ...)
 {
 	va_list argptr;
 
-	/* by default, we go to stderr */
-	if (output_cb[OUTPUT_CHANNEL_LOG] == NULL)
-	{
-		output_cb[OUTPUT_CHANNEL_LOG] = mame_file_output_callback;
-		output_cb_param[OUTPUT_CHANNEL_LOG] = stderr;
-	}
-
 	/* do the output */
 	va_start(argptr, format);
-	(*output_cb[OUTPUT_CHANNEL_LOG])(output_cb_param[OUTPUT_CHANNEL_LOG], format, argptr);
+	output_cb[OUTPUT_CHANNEL_LOG])(format, argptr);
 	va_end(argptr);
 }
 #endif
@@ -481,109 +393,22 @@ void CLIB_DECL popmessage(const char *format, ...)
 -------------------------------------------------*/
 
 void CLIB_DECL logerror(const char *format, ...)
+{
+	va_list arg;
+	va_start(arg, format);
+	vlogerror(format, arg);
+	va_end(arg);
+}
+
+
+/*-------------------------------------------------
+    vlogerror - log to the debugger and any other
+    OSD-defined output streams
+-------------------------------------------------*/
+
+void CLIB_DECL vlogerror(const char *format, va_list arg)
 {
 	if (global_machine != NULL)
-	{
-		va_list arg;
-		va_start(arg, format);
 		global_machine->vlogerror(format, arg);
-		va_end(arg);
-	}
 }
 
-
-
-/***************************************************************************
-    INTERNAL INITIALIZATION LOGIC
-***************************************************************************/
-
-/*-------------------------------------------------
-    mame_parse_ini_files - parse the relevant INI
-    files and apply their options
--------------------------------------------------*/
-
-void mame_parse_ini_files(core_options *options, const game_driver *driver)
-{
-	/* parse the INI file defined by the platform (e.g., "mame.ini") */
-	/* we do this twice so that the first file can change the INI path */
-	parse_ini_file(options, CONFIGNAME, OPTION_PRIORITY_MAME_INI);
-	parse_ini_file(options, CONFIGNAME, OPTION_PRIORITY_MAME_INI);
-
-	/* debug mode: parse "debug.ini" as well */
-	if (options_get_bool(options, OPTION_DEBUG))
-		parse_ini_file(options, "debug", OPTION_PRIORITY_DEBUG_INI);
-
-	/* if we have a valid game driver, parse game-specific INI files */
-	if (driver != NULL && driver != &GAME_NAME(empty))
-	{
-#ifndef MESS
-		const game_driver *parent = driver_get_clone(driver);
-		const game_driver *gparent = (parent != NULL) ? driver_get_clone(parent) : NULL;
-
-		/* parse "vertical.ini" or "horizont.ini" */
-		if (driver->flags & ORIENTATION_SWAP_XY)
-			parse_ini_file(options, "vertical", OPTION_PRIORITY_ORIENTATION_INI);
-		else
-			parse_ini_file(options, "horizont", OPTION_PRIORITY_ORIENTATION_INI);
-
-		/* parse "vector.ini" for vector games */
-		{
-			machine_config config(*driver);
-			for (const screen_device_config *devconfig = config.first_screen(); devconfig != NULL; devconfig = devconfig->next_screen())
-				if (devconfig->screen_type() == SCREEN_TYPE_VECTOR)
-				{
-					parse_ini_file(options, "vector", OPTION_PRIORITY_VECTOR_INI);
-					break;
-				}
-		}
-
-		/* next parse "source/<sourcefile>.ini"; if that doesn't exist, try <sourcefile>.ini */
-		astring sourcename;
-		core_filename_extract_base(&sourcename, driver->source_file, TRUE)->ins(0, "source" PATH_SEPARATOR);
-		if (!parse_ini_file(options, sourcename, OPTION_PRIORITY_SOURCE_INI))
-		{
-			core_filename_extract_base(&sourcename, driver->source_file, TRUE);
-			parse_ini_file(options, sourcename, OPTION_PRIORITY_SOURCE_INI);
-		}
-
-		/* then parent the grandparent, parent, and game-specific INIs */
-		if (gparent != NULL)
-			parse_ini_file(options, gparent->name, OPTION_PRIORITY_GPARENT_INI);
-		if (parent != NULL)
-			parse_ini_file(options, parent->name, OPTION_PRIORITY_PARENT_INI);
-#endif	/* MESS */
-		parse_ini_file(options, driver->name, OPTION_PRIORITY_DRIVER_INI);
-	}
-}
-
-
-/*-------------------------------------------------
-    parse_ini_file - parse a single INI file
--------------------------------------------------*/
-
-static int parse_ini_file(core_options *options, const char *name, int priority)
-{
-	file_error filerr;
-	mame_file *file;
-
-	/* update game name so depending callback options could be added */
-	if (priority==OPTION_PRIORITY_DRIVER_INI) {
-		options_force_option_callback(options, OPTION_GAMENAME, name, priority);
-	}
-
-	/* don't parse if it has been disabled */
-	if (!options_get_bool(options, OPTION_READCONFIG))
-		return FALSE;
-
-	/* open the file; if we fail, that's ok */
-	astring fname(name, ".ini");
-	filerr = mame_fopen_options(options, SEARCHPATH_INI, fname, OPEN_FLAG_READ, &file);
-	if (filerr != FILERR_NONE)
-		return FALSE;
-
-	/* parse the file and close it */
-	mame_printf_verbose("Parsing %s.ini\n", name);
-	options_parse_ini_file(options, mame_core_file(file), priority);
-	mame_fclose(file);
-	return TRUE;
-}
