@@ -78,23 +78,18 @@ screen_device::screen_device(const machine_config &mconfig, const char *tag, dev
 	  m_oldstyle_vblank_supplied(false),
 	  m_refresh(0),
 	  m_vblank(0),
-	  m_format(BITMAP_FORMAT_INVALID),
 	  m_xoffset(0.0f),
 	  m_yoffset(0.0f),
 	  m_xscale(1.0f),
 	  m_yscale(1.0f),
-	  m_screen_update(NULL),
-	  m_screen_eof(NULL),
 	  m_container(NULL),
 	  m_width(100),
 	  m_height(100),
-	  m_burnin(NULL),
+	  m_visarea(0, 99, 0, 99),
 	  m_curbitmap(0),
 	  m_curtexture(0),
-	  m_texture_format(0),
 	  m_changed(true),
 	  m_last_partial_scan(0),
-	  m_screen_overlay_bitmap(NULL),
 	  m_frame_period(DEFAULT_FRAME_PERIOD.as_attoseconds()),
 	  m_scantime(1),
 	  m_pixeltime(1),
@@ -108,11 +103,7 @@ screen_device::screen_device(const machine_config &mconfig, const char *tag, dev
 	  m_frame_number(0),
 	  m_partial_updates_this_frame(0)
 {
-	m_visarea.min_x = m_visarea.min_y = 0;
-	m_visarea.max_x = m_width - 1;
-	m_visarea.max_y = m_height - 1;
 	memset(m_texture, 0, sizeof(m_texture));
-	memset(m_bitmap, 0, sizeof(m_bitmap));
 }
 
 
@@ -125,18 +116,6 @@ screen_device::~screen_device()
 }
 
 
-//-------------------------------------------------
-//  static_set_format - configuration helper
-//  to set the bitmap format
-//-------------------------------------------------
-
-void screen_device::static_set_format(device_t &device, bitmap_format format)
-{
-	screen_device &screen = downcast<screen_device &>(device);
-	screen.m_format = format;
-}
-
-
 //-------------------------------------------------
 //  static_set_type - configuration helper
 //  to set the screen type
@@ -144,8 +123,7 @@ void screen_device::static_set_format(device_t &device, bitmap_format format)
 
 void screen_device::static_set_type(device_t &device, screen_type_enum type)
 {
-	screen_device &screen = downcast<screen_device &>(device);
-	screen.m_type = type;
+	downcast<screen_device &>(device).m_type = type;
 }
 
 
@@ -161,10 +139,7 @@ void screen_device::static_set_raw(device_t &device, UINT32 pixclock, UINT16 hto
 	screen.m_vblank = screen.m_refresh / vtotal * (vtotal - (vbstart - vbend));
 	screen.m_width = htotal;
 	screen.m_height = vtotal;
-	screen.m_visarea.min_x = hbend;
-	screen.m_visarea.max_x = hbstart - 1;
-	screen.m_visarea.min_y = vbend;
-	screen.m_visarea.max_y = vbstart - 1;
+	screen.m_visarea.set(hbend, hbstart - 1, vbend, vbstart - 1);
 }
 
 
@@ -175,8 +150,7 @@ void screen_device::static_set_raw(device_t &device, UINT32 pixclock, UINT16 hto
 
 void screen_device::static_set_refresh(device_t &device, attoseconds_t rate)
 {
-	screen_device &screen = downcast<screen_device &>(device);
-	screen.m_refresh = rate;
+	downcast<screen_device &>(device).m_refresh = rate;
 }
 
 
@@ -213,11 +187,7 @@ void screen_device::static_set_size(device_t &device, UINT16 width, UINT16 heigh
 
 void screen_device::static_set_visarea(device_t &device, INT16 minx, INT16 maxx, INT16 miny, INT16 maxy)
 {
-	screen_device &screen = downcast<screen_device &>(device);
-	screen.m_visarea.min_x = minx;
-	screen.m_visarea.max_x = maxx;
-	screen.m_visarea.min_y = miny;
-	screen.m_visarea.max_y = maxy;
+	downcast<screen_device &>(device).m_visarea.set(minx, maxx, miny, maxy);
 }
 
 
@@ -243,21 +213,29 @@ void screen_device::static_set_default_position(device_t &device, double xscale,
 //  configuration
 //-------------------------------------------------
 
-void screen_device::static_set_screen_update(device_t &device, screen_update_func callback)
+void screen_device::static_set_screen_update(device_t &device, screen_update_ind16_delegate callback)
 {
-	downcast<screen_device &>(device).m_screen_update = callback;
+	screen_device &screen = downcast<screen_device &>(device);
+	screen.m_screen_update_ind16 = callback;
+	screen.m_screen_update_rgb32 = screen_update_rgb32_delegate();
+}
+
+void screen_device::static_set_screen_update(device_t &device, screen_update_rgb32_delegate callback)
+{
+	screen_device &screen = downcast<screen_device &>(device);
+	screen.m_screen_update_ind16 = screen_update_ind16_delegate();
+	screen.m_screen_update_rgb32 = callback;
 }
 
 
 //-------------------------------------------------
-//  static_set_screen_eof - set the legacy
-//  screen eof callback in the device
-//  configuration
+//  static_set_screen_vblank - set the screen
+//  VBLANK callback in the device configuration
 //-------------------------------------------------
 
-void screen_device::static_set_screen_eof(device_t &device, screen_eof_func callback)
+void screen_device::static_set_screen_vblank(device_t &device, screen_vblank_delegate callback)
 {
-	downcast<screen_device &>(device).m_screen_eof = callback;
+	downcast<screen_device &>(device).m_screen_vblank = callback;
 }
 
 
@@ -266,46 +244,26 @@ void screen_device::static_set_screen_eof(device_t &device, screen_eof_func call
 //  configuration
 //-------------------------------------------------
 
-bool screen_device::device_validity_check(emu_options &options, const game_driver &driver) const
+void screen_device::device_validity_check(validity_checker &valid) const
 {
-	bool error = false;
-
 	// sanity check dimensions
 	if (m_width <= 0 || m_height <= 0)
-	{
-		mame_printf_error("%s: %s screen '%s' has invalid display dimensions\n", driver.source_file, driver.name, tag());
-		error = true;
-	}
+		mame_printf_error("Invalid display dimensions\n");
 
 	// sanity check display area
 	if (m_type != SCREEN_TYPE_VECTOR)
 	{
-		if ((m_visarea.max_x < m_visarea.min_x) ||
-			(m_visarea.max_y < m_visarea.min_y) ||
-			(m_visarea.max_x >= m_width) ||
-			(m_visarea.max_y >= m_height))
-		{
-			mame_printf_error("%s: %s screen '%s' has an invalid display area\n", driver.source_file, driver.name, tag());
-			error = true;
-		}
+		if (m_visarea.empty() || m_visarea.max_x >= m_width || m_visarea.max_y >= m_height)
+			mame_printf_error("Invalid display area\n");
 
 		// sanity check screen formats
-		if (m_format != BITMAP_FORMAT_INDEXED16 &&
-			m_format != BITMAP_FORMAT_RGB15 &&
-			m_format != BITMAP_FORMAT_RGB32)
-		{
-			mame_printf_error("%s: %s screen '%s' has unsupported format\n", driver.source_file, driver.name, tag());
-			error = true;
-		}
+		if (m_screen_update_ind16.isnull() && m_screen_update_rgb32.isnull())
+			mame_printf_error("Missing SCREEN_UPDATE function\n");
 	}
 
 	// check for zero frame rate
 	if (m_refresh == 0)
-	{
-		mame_printf_error("%s: %s screen '%s' has a zero refresh rate\n", driver.source_file, driver.name, tag());
-		error = true;
-	}
-	return error;
+		mame_printf_error("Invalid (zero) refresh rate\n");
 }
 
 
@@ -315,6 +273,23 @@ bool screen_device::device_validity_check(emu_options &options, const game_drive
 
 void screen_device::device_start()
 {
+	// bind our handlers
+	m_screen_update_ind16.bind_relative_to(*owner());
+	m_screen_update_rgb32.bind_relative_to(*owner());
+	m_screen_vblank.bind_relative_to(*owner());
+
+	// configure bitmap formats and allocate screen bitmaps
+	texture_format texformat = !m_screen_update_ind16.isnull() ? TEXFORMAT_PALETTE16 : TEXFORMAT_RGB32;
+	for (int index = 0; index < ARRAY_LENGTH(m_bitmap); index++)
+	{
+		m_bitmap[index].set_format(format(), texformat);
+		register_screen_bitmap(m_bitmap[index]);
+	}
+
+	// allocate raw textures
+	m_texture[0] = machine().render().texture_alloc();
+	m_texture[1] = machine().render().texture_alloc();
+
 	// configure the default cliparea
 	render_container::user_settings settings;
 	m_container->get_user_settings(settings);
@@ -325,15 +300,15 @@ void screen_device::device_start()
 	m_container->set_user_settings(settings);
 
 	// allocate the VBLANK timers
-	m_vblank_begin_timer = machine().scheduler().timer_alloc(FUNC(static_vblank_begin_callback), (void *)this);
-	m_vblank_end_timer = machine().scheduler().timer_alloc(FUNC(static_vblank_end_callback), (void *)this);
+	m_vblank_begin_timer = timer_alloc(TID_VBLANK_START);
+	m_vblank_end_timer = timer_alloc(TID_VBLANK_END);
 
 	// allocate a timer to reset partial updates
-	m_scanline0_timer = machine().scheduler().timer_alloc(FUNC(static_scanline0_callback), (void *)this);
+	m_scanline0_timer = timer_alloc(TID_SCANLINE0);
 
 	// allocate a timer to generate per-scanline updates
 	if ((machine().config().m_video_attributes & VIDEO_UPDATE_SCANLINE) != 0)
-		m_scanline_timer = machine().scheduler().timer_alloc(FUNC(static_scanline_update_callback), (void *)this);
+		m_scanline_timer = timer_alloc(TID_SCANLINE);
 
 	// configure the screen with the default parameters
 	configure(m_width, m_height, m_visarea, m_refresh);
@@ -352,10 +327,8 @@ void screen_device::device_start()
 		int width, height;
 		if (sscanf(machine().options().snap_size(), "%dx%d", &width, &height) != 2 || width == 0 || height == 0)
 			width = height = 300;
-		m_burnin = auto_alloc(machine(), bitmap_t(width, height, BITMAP_FORMAT_INDEXED64));
-		if (m_burnin == NULL)
-			fatalerror("Error allocating burn-in bitmap for screen at (%dx%d)\n", width, height);
-		bitmap_fill(m_burnin, NULL, 0);
+		m_burnin.allocate(width, height);
+		m_burnin.fill(0);
 	}
 
 	// load the effect overlay
@@ -390,9 +363,8 @@ void screen_device::device_stop()
 {
 	machine().render().texture_free(m_texture[0]);
 	machine().render().texture_free(m_texture[1]);
-	if (m_burnin != NULL)
+	if (m_burnin.valid())
 		finalize_burnin();
-	global_free(m_screen_overlay_bitmap);
 }
 
 
@@ -407,6 +379,46 @@ void screen_device::device_post_load()
 }
 
 
+//-------------------------------------------------
+//  device_timer - called whenever a device timer
+//  fires
+//-------------------------------------------------
+
+void screen_device::device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr)
+{
+	switch (id)
+	{
+		// signal VBLANK start
+		case TID_VBLANK_START:
+			vblank_begin();
+			break;
+
+		// signal VBLANK end
+		case TID_VBLANK_END:
+			vblank_end();
+			break;
+
+		// first visible scanline
+		case TID_SCANLINE0:
+			reset_partial_updates();
+			break;
+
+		// subsequent scanlines when scanline updates are enabled
+		case TID_SCANLINE:
+
+			// force a partial update to the current scanline
+			update_partial(param);
+
+			// compute the next visible scanline
+			param++;
+			if (param > m_visarea.max_y)
+				param = m_visarea.min_y;
+			m_scanline_timer->adjust(time_until_pos(param), param);
+			break;
+	}
+}
+
+
 //-------------------------------------------------
 //  configure - configure screen parameters
 //-------------------------------------------------
@@ -418,6 +430,8 @@ void screen_device::configure(int width, int height, const rectangle &visarea, a
 	assert(height > 0);
 	assert(visarea.min_x >= 0);
 	assert(visarea.min_y >= 0);
+//  assert(visarea.max_x < width);
+//  assert(visarea.max_y < height);
 	assert(m_type == SCREEN_TYPE_VECTOR || visarea.min_x < width);
 	assert(m_type == SCREEN_TYPE_VECTOR || visarea.min_y < height);
 	assert(frame_period > 0);
@@ -438,7 +452,7 @@ void screen_device::configure(int width, int height, const rectangle &visarea, a
 	// if there has been no VBLANK time specified in the MACHINE_DRIVER, compute it now
     // from the visible area, otherwise just used the supplied value
 	if (m_vblank == 0 && !m_oldstyle_vblank_supplied)
-		m_vblank_period = m_scantime * (height - (visarea.max_y + 1 - visarea.min_y));
+		m_vblank_period = m_scantime * (height - visarea.height());
 	else
 		m_vblank_period = m_vblank;
 
@@ -472,14 +486,14 @@ void screen_device::reset_origin(int beamy, int beamx)
 	// if we are resetting relative to (0,0) == VBLANK end, call the
 	// scanline 0 timer by hand now; otherwise, adjust it for the future
 	if (beamy == 0 && beamx == 0)
-		scanline0_callback();
+		reset_partial_updates();
 	else
 		m_scanline0_timer->adjust(time_until_pos(0));
 
 	// if we are resetting relative to (visarea.max_y + 1, 0) == VBLANK start,
 	// call the VBLANK start timer now; otherwise, adjust it for the future
 	if (beamy == m_visarea.max_y + 1 && beamx == 0)
-		vblank_begin_callback();
+		vblank_begin();
 	else
 		m_vblank_begin_timer->adjust(time_until_vblank_start());
 }
@@ -492,53 +506,21 @@ void screen_device::reset_origin(int beamy, int beamx)
 
 void screen_device::realloc_screen_bitmaps()
 {
+	// doesn't apply for vector games
 	if (m_type == SCREEN_TYPE_VECTOR)
 		return;
 
-	int curwidth = 0, curheight = 0;
+	// determine effective size to allocate
+	INT32 effwidth = MAX(m_width, m_visarea.max_x + 1);
+	INT32 effheight = MAX(m_height, m_visarea.max_y + 1);
 
-	// extract the current width/height from the bitmap
-	if (m_bitmap[0] != NULL)
-	{
-		curwidth = m_bitmap[0]->width;
-		curheight = m_bitmap[0]->height;
-	}
+	// reize all registered screen bitmaps
+	for (auto_bitmap_item *item = m_auto_bitmap_list.first(); item != NULL; item = item->next())
+		item->m_bitmap.resize(effwidth, effheight);
 
-	// if we're too small to contain this width/height, reallocate our bitmaps and textures
-	if (m_width > curwidth || m_height > curheight)
-	{
-		// free what we have currently
-		machine().render().texture_free(m_texture[0]);
-		machine().render().texture_free(m_texture[1]);
-		auto_free(machine(), m_bitmap[0]);
-		auto_free(machine(), m_bitmap[1]);
-
-		// compute new width/height
-		curwidth = MAX(m_width, curwidth);
-		curheight = MAX(m_height, curheight);
-
-		// choose the texture format - convert the screen format to a texture format
-		palette_t *palette = NULL;
-		switch (m_format)
-		{
-			case BITMAP_FORMAT_INDEXED16:	m_texture_format = TEXFORMAT_PALETTE16;	palette = machine().palette;	break;
-			case BITMAP_FORMAT_RGB15:		m_texture_format = TEXFORMAT_RGB15;		palette = NULL;				break;
-			case BITMAP_FORMAT_RGB32:		m_texture_format = TEXFORMAT_RGB32;		palette = NULL;				break;
-			default:						fatalerror("Invalid bitmap format!");												break;
-		}
-
-		// allocate bitmaps
-		m_bitmap[0] = auto_alloc(machine(), bitmap_t(curwidth, curheight, m_format));
-		bitmap_set_palette(m_bitmap[0], machine().palette);
-		m_bitmap[1] = auto_alloc(machine(), bitmap_t(curwidth, curheight, m_format));
-		bitmap_set_palette(m_bitmap[1], machine().palette);
-
-		// allocate textures
-		m_texture[0] = machine().render().texture_alloc();
-		m_texture[0]->set_bitmap(m_bitmap[0], &m_visarea, m_texture_format, palette);
-		m_texture[1] = machine().render().texture_alloc();
-		m_texture[1]->set_bitmap(m_bitmap[1], &m_visarea, m_texture_format, palette);
-	}
+	// re-set up textures
+	m_texture[0]->set_bitmap(m_bitmap[0], m_visarea, m_bitmap[0].texformat());
+	m_texture[1]->set_bitmap(m_bitmap[1], m_visarea, m_bitmap[1].texformat());
 }
 
 
@@ -548,18 +530,8 @@ void screen_device::realloc_screen_bitmaps()
 
 void screen_device::set_visible_area(int min_x, int max_x, int min_y, int max_y)
 {
-	// validate arguments
-	assert(min_x >= 0);
-	assert(min_y >= 0);
-	assert(min_x < max_x);
-	assert(min_y < max_y);
-
-	rectangle visarea;
-	visarea.min_x = min_x;
-	visarea.max_x = max_x;
-	visarea.min_y = min_y;
-	visarea.max_y = max_y;
-
+	rectangle visarea(min_x, max_x, min_y, max_y);
+	assert(!visarea.empty());
 	configure(m_width, m_height, visarea, m_frame_period);
 }
 
@@ -618,7 +590,15 @@ bool screen_device::update_partial(int scanline)
 		g_profiler.start(PROFILER_VIDEO);
 		LOG_PARTIAL_UPDATES(("updating %d-%d\n", clip.min_y, clip.max_y));
 
-		flags = screen_update(*m_bitmap[m_curbitmap], clip);
+		flags = 0;
+		screen_bitmap &curbitmap = m_bitmap[m_curbitmap];
+		switch (curbitmap.format())
+		{
+			default:
+			case BITMAP_FORMAT_IND16:	flags = m_screen_update_ind16(*this, curbitmap.as_ind16(), clip);	break;
+			case BITMAP_FORMAT_RGB32:	flags = m_screen_update_rgb32(*this, curbitmap.as_rgb32(), clip);	break;
+		}
+
 		m_partial_updates_this_frame++;
 		g_profiler.stop();
 
@@ -658,6 +638,19 @@ void screen_device::update_now()
 }
 
 
+//-------------------------------------------------
+//  reset_partial_updates - reset the partial
+//  updating state
+//-------------------------------------------------
+
+void screen_device::reset_partial_updates()
+{
+	m_last_partial_scan = 0;
+	m_partial_updates_this_frame = 0;
+	m_scanline0_timer->adjust(time_until_pos(0));
+}
+
+
 //-------------------------------------------------
 //  vpos - returns the current vertical position
 //  of the beam
@@ -773,45 +766,65 @@ void screen_device::register_vblank_callback(vblank_state_delegate vblank_callba
 
 
 //-------------------------------------------------
-//  vblank_begin_callback - call any external
-//  callbacks to signal the VBLANK period has begun
+//  register_screen_bitmap - registers a bitmap
+//  that should track the screen size
 //-------------------------------------------------
 
-void screen_device::vblank_begin_callback()
+void screen_device::register_screen_bitmap(bitmap_t &bitmap)
+{
+	// append to the list
+	m_auto_bitmap_list.append(*global_alloc(auto_bitmap_item(bitmap)));
+
+	// if allocating now, just do it
+	bitmap.allocate(width(), height());
+	bitmap.set_palette(machine().palette);
+}
+
+
+//-------------------------------------------------
+//  vblank_begin - call any external callbacks to
+//  signal the VBLANK period has begun
+//-------------------------------------------------
+
+void screen_device::vblank_begin()
 {
 	// reset the starting VBLANK time
 	m_vblank_start_time = machine().time();
 	m_vblank_end_time = m_vblank_start_time + attotime(0, m_vblank_period);
 
-	// call the screen specific callbacks
-	for (callback_item *item = m_callback_list.first(); item != NULL; item = item->next())
-		item->m_callback(*this, true);
-
 	// if this is the primary screen and we need to update now
 	if (this == machine().primary_screen && !(machine().config().m_video_attributes & VIDEO_UPDATE_AFTER_VBLANK))
 		machine().video().frame_update();
 
+	// call the screen specific callbacks
+	for (callback_item *item = m_callback_list.first(); item != NULL; item = item->next())
+		item->m_callback(*this, true);
+	if (!m_screen_vblank.isnull())
+		m_screen_vblank(*this, true);
+
 	// reset the VBLANK start timer for the next frame
 	m_vblank_begin_timer->adjust(time_until_vblank_start());
 
 	// if no VBLANK period, call the VBLANK end callback immedietely, otherwise reset the timer
 	if (m_vblank_period == 0)
-		vblank_end_callback();
+		vblank_end();
 	else
 		m_vblank_end_timer->adjust(time_until_vblank_end());
 }
 
 
 //-------------------------------------------------
-//  vblank_end_callback - call any external
-//  callbacks to signal the VBLANK period has ended
+//  vblank_end - call any external callbacks to
+//  signal the VBLANK period has ended
 //-------------------------------------------------
 
-void screen_device::vblank_end_callback()
+void screen_device::vblank_end()
 {
 	// call the screen specific callbacks
 	for (callback_item *item = m_callback_list.first(); item != NULL; item = item->next())
 		item->m_callback(*this, false);
+	if (!m_screen_vblank.isnull())
+		m_screen_vblank(*this, false);
 
 	// if this is the primary screen and we need to update now
 	if (this == machine().primary_screen && (machine().config().m_video_attributes & VIDEO_UPDATE_AFTER_VBLANK))
@@ -822,39 +835,6 @@ void screen_device::vblank_end_callback()
 }
 
 
-//-------------------------------------------------
-//  scanline0_callback - reset partial updates
-//  for a screen
-//-------------------------------------------------
-
-void screen_device::scanline0_callback()
-{
-	// reset partial updates
-	m_last_partial_scan = 0;
-	m_partial_updates_this_frame = 0;
-
-	m_scanline0_timer->adjust(time_until_pos(0));
-}
-
-
-//-------------------------------------------------
-//  scanline_update_callback - perform partial
-//  updates on each scanline
-//-------------------------------------------------
-
-void screen_device::scanline_update_callback(int scanline)
-{
-	// force a partial update to the current scanline
-	update_partial(scanline);
-
-	// compute the next visible scanline
-	scanline++;
-	if (scanline > m_visarea.max_y)
-		scanline = m_visarea.min_y;
-	m_scanline_timer->adjust(time_until_pos(scanline), scanline);
-}
-
-
 //-------------------------------------------------
 //  update_quads - set up the quads for this
 //  screen
@@ -871,13 +851,7 @@ bool screen_device::update_quads()
 			// if we're not skipping the frame and if the screen actually changed, then update the texture
 			if (!machine().video().skip_this_frame() && m_changed)
 			{
-				rectangle fixedvis = m_visarea;
-				fixedvis.max_x++;
-				fixedvis.max_y++;
-
-				palette_t *palette = (m_texture_format == TEXFORMAT_PALETTE16) ? machine().palette : NULL;
-				m_texture[m_curbitmap]->set_bitmap(m_bitmap[m_curbitmap], &fixedvis, m_texture_format, palette);
-
+				m_texture[m_curbitmap]->set_bitmap(m_bitmap[m_curbitmap], m_visarea, m_bitmap[m_curbitmap].texformat());
 				m_curtexture = m_curbitmap;
 				m_curbitmap = 1 - m_curbitmap;
 			}
@@ -902,17 +876,17 @@ bool screen_device::update_quads()
 void screen_device::update_burnin()
 {
 #undef rand
-	if (m_burnin == NULL)
+	if (!m_burnin.valid())
 		return;
 
-	bitmap_t *srcbitmap = m_bitmap[m_curtexture];
-	if (srcbitmap == NULL)
+	screen_bitmap &curbitmap = m_bitmap[m_curtexture];
+	if (!curbitmap.valid())
 		return;
 
-	int srcwidth = srcbitmap->width;
-	int srcheight = srcbitmap->height;
-	int dstwidth = m_burnin->width;
-	int dstheight = m_burnin->height;
+	int srcwidth = curbitmap.width();
+	int srcheight = curbitmap.height();
+	int dstwidth = m_burnin.width();
+	int dstheight = m_burnin.height();
 	int xstep = (srcwidth << 16) / dstwidth;
 	int ystep = (srcheight << 16) / dstheight;
 	int xstart = ((UINT32)rand() % 32767) * xstep / 32767;
@@ -920,43 +894,42 @@ void screen_device::update_burnin()
 	int srcx, srcy;
 	int x, y;
 
-	// iterate over rows in the destination
-	for (y = 0, srcy = ystart; y < dstheight; y++, srcy += ystep)
+	switch (curbitmap.format())
 	{
-		UINT64 *dst = BITMAP_ADDR64(m_burnin, y, 0);
-
-		// handle the 16-bit palettized case
-		if (srcbitmap->format == BITMAP_FORMAT_INDEXED16)
+		default:
+		case BITMAP_FORMAT_IND16:
 		{
-			const UINT16 *src = BITMAP_ADDR16(srcbitmap, srcy >> 16, 0);
-			const rgb_t *palette = palette_entry_list_adjusted(machine().palette);
-			for (x = 0, srcx = xstart; x < dstwidth; x++, srcx += xstep)
+			// iterate over rows in the destination
+			bitmap_ind16 &srcbitmap = curbitmap.as_ind16();
+			for (y = 0, srcy = ystart; y < dstheight; y++, srcy += ystep)
 			{
-				rgb_t pixel = palette[src[srcx >> 16]];
-				dst[x] += RGB_GREEN(pixel) + RGB_RED(pixel) + RGB_BLUE(pixel);
+				UINT64 *dst = &m_burnin.pix64(y);
+				const UINT16 *src = &srcbitmap.pix16(srcy >> 16);
+				const rgb_t *palette = palette_entry_list_adjusted(machine().palette);
+				for (x = 0, srcx = xstart; x < dstwidth; x++, srcx += xstep)
+				{
+					rgb_t pixel = palette[src[srcx >> 16]];
+					dst[x] += RGB_GREEN(pixel) + RGB_RED(pixel) + RGB_BLUE(pixel);
+				}
 			}
+			break;
 		}
 
-		// handle the 15-bit RGB case
-		else if (srcbitmap->format == BITMAP_FORMAT_RGB15)
+		case BITMAP_FORMAT_RGB32:
 		{
-			const UINT16 *src = BITMAP_ADDR16(srcbitmap, srcy >> 16, 0);
-			for (x = 0, srcx = xstart; x < dstwidth; x++, srcx += xstep)
+			// iterate over rows in the destination
+			bitmap_rgb32 &srcbitmap = curbitmap.as_rgb32();
+			for (y = 0, srcy = ystart; y < dstheight; y++, srcy += ystep)
 			{
-				rgb15_t pixel = src[srcx >> 16];
-				dst[x] += ((pixel >> 10) & 0x1f) + ((pixel >> 5) & 0x1f) + ((pixel >> 0) & 0x1f);
-			}
-		}
-
-		// handle the 32-bit RGB case
-		else if (srcbitmap->format == BITMAP_FORMAT_RGB32)
-		{
-			const UINT32 *src = BITMAP_ADDR32(srcbitmap, srcy >> 16, 0);
-			for (x = 0, srcx = xstart; x < dstwidth; x++, srcx += xstep)
-			{
-				rgb_t pixel = src[srcx >> 16];
-				dst[x] += RGB_GREEN(pixel) + RGB_RED(pixel) + RGB_BLUE(pixel);
+				UINT64 *dst = &m_burnin.pix64(y);
+				const UINT32 *src = &srcbitmap.pix32(srcy >> 16);
+				for (x = 0, srcx = xstart; x < dstwidth; x++, srcx += xstep)
+				{
+					rgb_t pixel = src[srcx >> 16];
+					dst[x] += RGB_GREEN(pixel) + RGB_RED(pixel) + RGB_BLUE(pixel);
+				}
 			}
+			break;
 		}
 	}
 }
@@ -968,25 +941,22 @@ void screen_device::update_burnin()
 
 void screen_device::finalize_burnin()
 {
-	if (m_burnin == NULL)
+	if (!m_burnin.valid())
 		return;
 
 	// compute the scaled visible region
 	rectangle scaledvis;
-	scaledvis.min_x = m_visarea.min_x * m_burnin->width / m_width;
-	scaledvis.max_x = m_visarea.max_x * m_burnin->width / m_width;
-	scaledvis.min_y = m_visarea.min_y * m_burnin->height / m_height;
-	scaledvis.max_y = m_visarea.max_y * m_burnin->height / m_height;
+	scaledvis.min_x = m_visarea.min_x * m_burnin.width() / m_width;
+	scaledvis.max_x = m_visarea.max_x * m_burnin.width() / m_width;
+	scaledvis.min_y = m_visarea.min_y * m_burnin.height() / m_height;
+	scaledvis.max_y = m_visarea.max_y * m_burnin.height() / m_height;
 
 	// wrap a bitmap around the subregion we care about
-	bitmap_t *finalmap = auto_alloc(machine(), bitmap_t(scaledvis.max_x + 1 - scaledvis.min_x,
-				                        scaledvis.max_y + 1 - scaledvis.min_y,
-				                        BITMAP_FORMAT_ARGB32));
-
-	int srcwidth = m_burnin->width;
-	int srcheight = m_burnin->height;
-	int dstwidth = finalmap->width;
-	int dstheight = finalmap->height;
+	bitmap_argb32 finalmap(scaledvis.width(), scaledvis.height());
+	int srcwidth = m_burnin.width();
+	int srcheight = m_burnin.height();
+	int dstwidth = finalmap.width();
+	int dstheight = finalmap.height();
 	int xstep = (srcwidth << 16) / dstwidth;
 	int ystep = (srcheight << 16) / dstheight;
 
@@ -995,7 +965,7 @@ void screen_device::finalize_burnin()
 	UINT64 maxval = 0;
 	for (int y = 0; y < srcheight; y++)
 	{
-		UINT64 *src = BITMAP_ADDR64(m_burnin, y, 0);
+		UINT64 *src = &m_burnin.pix64(y);
 		for (int x = 0; x < srcwidth; x++)
 		{
 			minval = MIN(minval, src[x]);
@@ -1009,8 +979,8 @@ void screen_device::finalize_burnin()
 	// now normalize and convert to RGB
 	for (int y = 0, srcy = 0; y < dstheight; y++, srcy += ystep)
 	{
-		UINT64 *src = BITMAP_ADDR64(m_burnin, srcy >> 16, 0);
-		UINT32 *dst = BITMAP_ADDR32(finalmap, y, 0);
+		UINT64 *src = &m_burnin.pix64(srcy >> 16);
+		UINT32 *dst = &finalmap.pix32(y);
 		for (int x = 0, srcx = 0; x < dstwidth; x++, srcx += xstep)
 		{
 			int brightness = (UINT64)(maxval - src[srcx >> 16]) * 255 / (maxval - minval);
@@ -1030,7 +1000,7 @@ void screen_device::finalize_burnin()
 		char text[256];
 
 		// add two text entries describing the image
-		sprintf(text, APPNAME " %s", build_version);
+		sprintf(text,"%s %s", emulator_info::get_appname(), build_version);
 		png_add_text(&pnginfo, "Software", text);
 		sprintf(text, "%s %s", machine().system().manufacturer, machine().system().description);
 		png_add_text(&pnginfo, "System", text);
@@ -1059,38 +1029,9 @@ void screen_device::load_effect_overlay(const char *filename)
 
 	// load the file
 	emu_file file(machine().options().art_path(), OPEN_FLAG_READ);
-	m_screen_overlay_bitmap = render_load_png(file, NULL, fullname, NULL, NULL);
-	if (m_screen_overlay_bitmap != NULL)
-		m_container->set_overlay(m_screen_overlay_bitmap);
+	render_load_png(m_screen_overlay_bitmap, file, NULL, fullname);
+	if (m_screen_overlay_bitmap.valid())
+		m_container->set_overlay(&m_screen_overlay_bitmap);
 	else
 		mame_printf_warning("Unable to load effect PNG file '%s'\n", fullname.cstr());
 }
-
-//-------------------------------------------------
-//  screen_update - default implementation which
-//  calls to the legacy screen_update function
-//-------------------------------------------------
-
-bool screen_device::screen_update(bitmap_t &bitmap, const rectangle &cliprect)
-{
-	if (m_screen_update != NULL) {
-		return (*m_screen_update)(this, &bitmap, &cliprect);
-	} else {
-		machine().driver_data<driver_device>()->screen_update(*this, bitmap, cliprect);
-	}
-	return 0;
-}
-
-//-------------------------------------------------
-//  screen_eof - default implementation which
-//  calls to the legacy screen_update function
-//-------------------------------------------------
-
-void screen_device::screen_eof()
-{
-	if (m_screen_eof != NULL) {
-		return (*m_screen_eof)(this, machine());
-	} else {
-		machine().driver_data<driver_device>()->screen_eof();
-	}
-}
