@@ -17,7 +17,6 @@
 *
 ******************************************************************************/
 #include "emu.h"
-#include "streams.h"
 #include "3526intf.h"
 #include "fm.h"
 #include "sound/fmopl.h"
@@ -63,13 +62,13 @@ static TIMER_CALLBACK( timer_callback_1 )
 static void TimerHandler(void *param,int c,attotime period)
 {
 	ym3526_state *info = (ym3526_state *)param;
-	if( attotime_compare(period, attotime_zero) == 0 )
+	if( period == attotime::zero )
 	{	/* Reset FM Timer */
-		timer_enable(info->timer[c], 0);
+		info->timer[c]->enable(false);
 	}
 	else
 	{	/* Start FM Timer */
-		timer_adjust_oneshot(info->timer[c], period, 0);
+		info->timer[c]->adjust(period);
 	}
 }
 
@@ -83,7 +82,7 @@ static STREAM_UPDATE( ym3526_stream_update )
 static void _stream_update(void *param, int interval)
 {
 	ym3526_state *info = (ym3526_state *)param;
-	stream_update(info->stream);
+	info->stream->update();
 }
 
 
@@ -93,21 +92,21 @@ static DEVICE_START( ym3526 )
 	ym3526_state *info = get_safe_token(device);
 	int rate = device->clock()/72;
 
-	info->intf = device->baseconfig().static_config() ? (const ym3526_interface *)device->baseconfig().static_config() : &dummy;
+	info->intf = device->static_config() ? (const ym3526_interface *)device->static_config() : &dummy;
 	info->device = device;
 
 	/* stream system initialize */
 	info->chip = ym3526_init(device,device->clock(),rate);
 	assert_always(info->chip != NULL, "Error creating YM3526 chip");
 
-	info->stream = stream_create(device,0,1,rate,info,ym3526_stream_update);
+	info->stream = device->machine().sound().stream_alloc(*device,0,1,rate,info,ym3526_stream_update);
 	/* YM3526 setup */
 	ym3526_set_timer_handler (info->chip, TimerHandler, info);
 	ym3526_set_irq_handler   (info->chip, IRQHandler, info);
 	ym3526_set_update_handler(info->chip, _stream_update, info);
 
-	info->timer[0] = timer_alloc(device->machine, timer_callback_0, info);
-	info->timer[1] = timer_alloc(device->machine, timer_callback_1, info);
+	info->timer[0] = device->machine().scheduler().timer_alloc(FUNC(timer_callback_0), info);
+	info->timer[1] = device->machine().scheduler().timer_alloc(FUNC(timer_callback_1), info);
 }
 
 static DEVICE_STOP( ym3526 )
