@@ -7,7 +7,6 @@
 ***************************************************************************/
 
 #include "emu.h"
-#include "streams.h"
 #include "snkwave.h"
 
 
@@ -111,7 +110,7 @@ static DEVICE_START( snkwave )
 {
 	snkwave_state *chip = get_safe_token(device);
 
-	assert(device->baseconfig().static_config() == 0);
+	assert(device->static_config() == 0);
 
 	/* adjust internal clock */
 	chip->external_clock = device->clock();
@@ -120,7 +119,7 @@ static DEVICE_START( snkwave )
 	chip->sample_rate = chip->external_clock >> CLOCK_SHIFT;
 
 	/* get stream channels */
-	chip->stream = stream_create(device, 0, 1, chip->sample_rate, chip, snkwave_update);
+	chip->stream = device->machine().sound().stream_alloc(*device, 0, 1, chip->sample_rate, chip, snkwave_update);
 
 	/* reset all the voices */
 	chip->frequency = 0;
@@ -128,10 +127,10 @@ static DEVICE_START( snkwave )
 	chip->waveform_position = 0;
 
 	/* register with the save state system */
-	state_save_register_device_item(device, 0, chip->frequency);
-	state_save_register_device_item(device, 0, chip->counter);
-	state_save_register_device_item(device, 0, chip->waveform_position);
-	state_save_register_device_item_pointer(device, 0, chip->waveform, WAVEFORM_LENGTH);
+	device->save_item(NAME(chip->frequency));
+	device->save_item(NAME(chip->counter));
+	device->save_item(NAME(chip->waveform_position));
+	device->save_pointer(NAME(chip->waveform), WAVEFORM_LENGTH);
 }
 
 
@@ -147,7 +146,7 @@ WRITE8_DEVICE_HANDLER( snkwave_w )
 {
 	snkwave_state *chip = get_safe_token(device);
 
-	stream_update(chip->stream);
+	chip->stream->update();
 
 	// all registers are 6-bit
 	data &= 0x3f;
