@@ -55,7 +55,7 @@
 const int FRAMESKIP_LEVELS = 12;
 const int MAX_FRAMESKIP = FRAMESKIP_LEVELS - 2;
 
-
+#define LCD_FRAMES_PER_SECOND	30
 
 //**************************************************************************
 //  TYPE DEFINITIONS
@@ -86,6 +86,7 @@ public:
 	video_manager(running_machine &machine);
 
 	// getters
+	running_machine &machine() const { return m_machine; }
 	bool skip_this_frame() const { return m_skipping_this_frame; }
 	int speed_factor() const { return m_speed; }
 	int frameskip() const { return m_auto_frameskip ? -1 : m_frameskip_level; }
@@ -107,7 +108,7 @@ public:
 	double speed_percent() const { return m_speed_percent; }
 
 	// snapshots
-	void save_snapshot(screen_device *screen, mame_file &file);
+	void save_snapshot(screen_device *screen, emu_file &file);
 	void save_active_screen_snapshots();
 
 	// movies
@@ -117,9 +118,8 @@ public:
 
 private:
 	// internal helpers
-	static void exit_static(running_machine &machine);
 	void exit();
-	static TIMER_CALLBACK( screenless_update_callback );
+	void screenless_update_callback(void *ptr, int param);
 	void postload();
 
 	// effective value helpers
@@ -137,8 +137,8 @@ private:
 	void recompute_speed(attotime emutime);
 
 	// snapshot/movie helpers
-	void create_snapshot_bitmap(device_t *screen);
-	file_error mame_fopen_next(const char *pathoption, const char *extension, mame_file *&file);
+	void create_snapshot_bitmap(screen_device *screen);
+	file_error open_next(emu_file &file, const char *extension);
 	void record_frame();
 
 	// internal state
@@ -169,7 +169,7 @@ private:
 	bool				m_fastforward;				// flag: TRUE if we're currently fast-forwarding
 	UINT32				m_seconds_to_run;			// number of seconds to run before quitting
 	bool				m_auto_frameskip;			// flag: TRUE if we're automatically frameskipping
-	UINT32				m_speed;					// overall speed (*100)
+	UINT32				m_speed;					// overall speed (*1000)
 
 	// frameskipping
 	UINT8				m_empty_skip_count;			// number of empty frames we have skipped
@@ -181,13 +181,13 @@ private:
 
 	// snapshot stuff
 	render_target *		m_snap_target;				// screen shapshot target
-	bitmap_t *			m_snap_bitmap;				// screen snapshot bitmap
+	bitmap_rgb32		m_snap_bitmap;				// screen snapshot bitmap
 	bool				m_snap_native;				// are we using native per-screen layouts?
 	INT32				m_snap_width;				// width of snapshots (0 == auto)
 	INT32				m_snap_height;				// height of snapshots (0 == auto)
 
 	// movie recording
-	mame_file *			m_mngfile;					// handle to the open movie file
+	emu_file *			m_mngfile;					// handle to the open movie file
 	avi_file *			m_avifile;					// handle to the open movie file
 	attotime			m_movie_frame_period;		// period of a single movie frame
 	attotime			m_movie_next_frame_time;	// time of next frame
@@ -195,7 +195,7 @@ private:
 
 	static const UINT8		s_skiptable[FRAMESKIP_LEVELS][FRAMESKIP_LEVELS];
 
-	static const attoseconds_t SUBSECONDS_PER_SPEED_UPDATE = ATTOSECONDS_PER_SECOND / 4;
+	static const attoseconds_t ATTOSECONDS_PER_SPEED_UPDATE = ATTOSECONDS_PER_SECOND / 4;
 	static const int PAUSED_REFRESH_RATE = 30;
 };
 
@@ -204,7 +204,7 @@ private:
 // ----- debugging helpers -----
 
 // assert if any pixels in the given bitmap contain an invalid palette index
-void video_assert_out_of_range_pixels(running_machine *machine, bitmap_t *bitmap);
+bool video_assert_out_of_range_pixels(running_machine &machine, bitmap_ind16 &bitmap);
 
 
 #endif	/* __VIDEO_H__ */
