@@ -13,6 +13,6 @@
 
 /**************************************************************************/
 
-FLOPPY_OPTIONS_EXTERN(specimx);
+LEGACY_FLOPPY_OPTIONS_EXTERN(specimx);
 
 #endif /* SVI_DSK_H */
