@@ -44,7 +44,7 @@ static FLOPPY_CONSTRUCT(trd_dsk_construct)
 
 /* ----------------------------------------------------------------------- */
 
-FLOPPY_OPTIONS_START( trd )
-	FLOPPY_OPTION( trd_dsk, "trd",		"TRD floppy disk image",	trd_dsk_identify, trd_dsk_construct, NULL, NULL)
-FLOPPY_OPTIONS_END
+LEGACY_FLOPPY_OPTIONS_START( trd )
+	LEGACY_FLOPPY_OPTION( trd_dsk, "trd",		"TRD floppy disk image",	trd_dsk_identify, trd_dsk_construct, NULL, NULL)
+LEGACY_FLOPPY_OPTIONS_END
 
