@@ -56,7 +56,7 @@
 #define CD_MAX_SUBCODE_DATA		(96)
 
 #define CD_FRAME_SIZE			(CD_MAX_SECTOR_DATA + CD_MAX_SUBCODE_DATA)
-#define CD_FRAMES_PER_HUNK		(4)
+#define CD_FRAMES_PER_HUNK		(4) // should be 8 for v5 CDs, with a 4-frame pad at the end to maintain SHA1 compatibility
 
 #define CD_METADATA_WORDS		(1+(CD_MAX_TRACKS * 6))
 
@@ -130,6 +130,8 @@ struct _cdrom_toc
 cdrom_file *cdrom_open(chd_file *chd);
 void cdrom_close(cdrom_file *file);
 
+cdrom_file *cdrom_open(const char *inputfile);
+
 /* core read access */
 UINT32 cdrom_read_data(cdrom_file *file, UINT32 lbasector, void *buffer, UINT32 datatype);
 UINT32 cdrom_read_subcode(cdrom_file *file, UINT32 lbasector, void *buffer);
