@@ -8,7 +8,6 @@
 ***************************************************************************/
 
 #include "emu.h"
-#include "streams.h"
 #include "cpu/mcs48/mcs48.h"
 #include "includes/segag80r.h"
 #include "machine/8255ppi.h"
@@ -35,28 +34,6 @@ DEFINE_LEGACY_SOUND_DEVICE(SEGA005, sega005_sound);
 
 
 
-/*************************************
- *
- *  Local sound states
- *
- *************************************/
-
-static UINT8 sound_state[2];
-static UINT8 sound_rate;
-static UINT16 sound_addr;
-static UINT8 sound_data;
-
-static UINT8 square_state;
-static UINT8 square_count;
-
-static emu_timer *sega005_sound_timer;
-static sound_stream *sega005_stream;
-
-static UINT8 n7751_command;
-static UINT8 n7751_busy;
-
-
-
 /*************************************
  *
  *  Astro Blaster sound hardware
@@ -106,7 +83,7 @@ static SOUND_START( astrob );
         about 12V - 0.5V (diode drop in low current circuit) =
         11.5V.
 
-        Now you need to calculate the refrence voltage on the
+        Now you need to calculate the reference voltage on the
         + input (pin 5).  Depending on the state of WARP...
 
         If the warp data is 0, then U31 inverts it to an Open
@@ -181,22 +158,22 @@ static SOUND_START( astrob );
 static const char *const astrob_sample_names[] =
 {
 	"*astrob",
-	"invadr1.wav",		/* 0 */
-	"winvadr1.wav",		/* 1 */
-	"invadr2.wav",		/* 2 */
-	"winvadr2.wav",		/* 3 */
-	"invadr3.wav",		/* 4 */
-	"winvadr3.wav",		/* 5 */
-	"invadr4.wav",		/* 6 */
-	"winvadr4.wav",		/* 7 */
-	"asteroid.wav",		/* 8 */
-	"refuel.wav",		/* 9 */
-	"pbullet.wav",		/* 10 */
-	"ebullet.wav",		/* 11 */
-	"eexplode.wav",		/* 12 */
-	"pexplode.wav",		/* 13 */
-	"deedle.wav",		/* 14 */
-	"sonar.wav",		/* 15 */
+	"invadr1",		/* 0 */
+	"winvadr1",		/* 1 */
+	"invadr2",		/* 2 */
+	"winvadr2",		/* 3 */
+	"invadr3",		/* 4 */
+	"winvadr3",		/* 5 */
+	"invadr4",		/* 6 */
+	"winvadr4",		/* 7 */
+	"asteroid",		/* 8 */
+	"refuel",		/* 9 */
+	"pbullet",		/* 10 */
+	"ebullet",		/* 11 */
+	"eexplode",		/* 12 */
+	"pexplode",		/* 13 */
+	"deedle",		/* 14 */
+	"sonar",		/* 15 */
 	0
 };
 
@@ -228,8 +205,9 @@ MACHINE_CONFIG_END
 
 static SOUND_START( astrob )
 {
-	state_save_register_global_array(machine, sound_state);
-	state_save_register_global(machine, sound_rate);
+	segag80r_state *state = machine.driver_data<segag80r_state>();
+	state_save_register_global_array(machine, state->m_sound_state);
+	state_save_register_global(machine, state->m_sound_rate);
 }
 
 
@@ -242,15 +220,16 @@ static SOUND_START( astrob )
 
 WRITE8_HANDLER( astrob_sound_w )
 {
+	segag80r_state *state = space->machine().driver_data<segag80r_state>();
 	static const float attack_resistor[10] =
 	{
 		120.0f, 82.0f, 62.0f, 56.0f, 47.0f, 39.0f, 33.0f, 27.0f, 24.0f, 22.0f
 	};
-	device_t *samples = space->machine->device("samples");
+	device_t *samples = space->machine().device("samples");
 	float freq_factor;
 
-	UINT8 diff = data ^ sound_state[offset];
-	sound_state[offset] = data;
+	UINT8 diff = data ^ state->m_sound_state[offset];
+	state->m_sound_state[offset] = data;
 
 	switch (offset)
 	{
@@ -276,7 +255,7 @@ WRITE8_HANDLER( astrob_sound_w )
 			if ((data & 0x10) && sample_playing(samples, 4)) sample_stop(samples, 4);
 
 			/* MUTE */
-			sound_global_enable(space->machine, !(data & 0x20));
+			space->machine().sound().system_mute(data & 0x20);
 
 			/* REFILL: channel 5 */
 			if (!(data & 0x40) && !sample_playing(samples, 5)) sample_start(samples, 5, 9, FALSE);
@@ -306,10 +285,10 @@ WRITE8_HANDLER( astrob_sound_w )
 			if ((diff & 0x08) && !(data & 0x08)) sample_start(samples, 8, 13, FALSE);
 
 			/* ATTACK RATE */
-			if ((diff & 0x10) && !(data & 0x10)) sound_rate = (sound_rate + 1) % 10;
+			if ((diff & 0x10) && !(data & 0x10)) state->m_sound_rate = (state->m_sound_rate + 1) % 10;
 
 			/* RATE RESET */
-			if (!(data & 0x20)) sound_rate = 0;
+			if (!(data & 0x20)) state->m_sound_rate = 0;
 
 			/* BONUS: channel 9 */
 			if ((diff & 0x40) && !(data & 0x40)) sample_start(samples, 9, 14, FALSE);
@@ -325,7 +304,7 @@ WRITE8_HANDLER( astrob_sound_w )
 	/* account for the fact that frequency goes up as CV goes down */
 	/* WARP is already taken into account by the differing samples above */
 	freq_factor  = (11.5f - 8.163f) * (-22.0f / attack_resistor[0]) + 8.163f;
-	freq_factor /= (11.5f - 8.163f) * (-22.0f / attack_resistor[sound_rate]) + 8.163f;
+	freq_factor /= (11.5f - 8.163f) * (-22.0f / attack_resistor[state->m_sound_rate]) + 8.163f;
 
 	/* adjust the sample rate of invader sounds based the sound_rate */
 	/* this is an approximation */
@@ -407,13 +386,13 @@ static WRITE8_DEVICE_HANDLER( sega005_sound_b_w );
 static const char *const sega005_sample_names[] =
 {
 	"*005",
-	"lexplode.wav",		/* 0 */
-	"sexplode.wav",		/* 1 */
-	"dropbomb.wav",		/* 2 */
-	"shoot.wav",		/* 3 */
-	"missile.wav",		/* 4 */
-	"heilcopt.wav",		/* 5 */
-	"whistle.wav",		/* 6 */
+	"lexplode",		/* 0 */
+	"sexplode",		/* 1 */
+	"dropbomb",		/* 2 */
+	"shoot",		/* 3 */
+	"missile",		/* 4 */
+	"helicopt",		/* 5 */
+	"whistle",		/* 6 */
 	0
 };
 
@@ -461,11 +440,12 @@ MACHINE_CONFIG_END
 
 static SOUND_START( sega005 )
 {
-	state_save_register_global_array(machine, sound_state);
-	state_save_register_global(machine, sound_addr);
-	state_save_register_global(machine, sound_data);
-	state_save_register_global(machine, square_state);
-	state_save_register_global(machine, square_count);
+	segag80r_state *state = machine.driver_data<segag80r_state>();
+	state_save_register_global_array(machine, state->m_sound_state);
+	state_save_register_global(machine, state->m_sound_addr);
+	state_save_register_global(machine, state->m_sound_data);
+	state_save_register_global(machine, state->m_square_state);
+	state_save_register_global(machine, state->m_square_count);
 }
 
 
@@ -478,9 +458,10 @@ static SOUND_START( sega005 )
 
 static WRITE8_DEVICE_HANDLER( sega005_sound_a_w )
 {
-	device_t *samples = device->machine->device("samples");
-	UINT8 diff = data ^ sound_state[0];
-	sound_state[0] = data;
+	segag80r_state *state = device->machine().driver_data<segag80r_state>();
+	device_t *samples = device->machine().device("samples");
+	UINT8 diff = data ^ state->m_sound_state[0];
+	state->m_sound_state[0] = data;
 
 	/* LARGE EXPL: channel 0 */
 	if ((diff & 0x01) && !(data & 0x01)) sample_start(samples, 0, 0, FALSE);
@@ -507,64 +488,66 @@ static WRITE8_DEVICE_HANDLER( sega005_sound_a_w )
 }
 
 
-INLINE void sega005_update_sound_data(running_machine *machine)
+INLINE void sega005_update_sound_data(running_machine &machine)
 {
-	UINT8 newval = machine->region("005")->base()[sound_addr];
-	UINT8 diff = newval ^ sound_data;
+	segag80r_state *state = machine.driver_data<segag80r_state>();
+	UINT8 newval = machine.region("005")->base()[state->m_sound_addr];
+	UINT8 diff = newval ^ state->m_sound_data;
 
-	//mame_printf_debug("  [%03X] = %02X\n", sound_addr, newval);
+	//mame_printf_debug("  [%03X] = %02X\n", state->m_sound_addr, newval);
 
 	/* latch the new value */
-	sound_data = newval;
+	state->m_sound_data = newval;
 
 	/* if bit 5 goes high, we reset the timer */
 	if ((diff & 0x20) && !(newval & 0x20))
 	{
 		//mame_printf_debug("Stopping timer\n");
-		timer_adjust_oneshot(sega005_sound_timer, attotime_never, 0);
+		state->m_sega005_sound_timer->adjust(attotime::never);
 	}
 
 	/* if bit 5 goes low, we start the timer again */
 	if ((diff & 0x20) && (newval & 0x20))
 	{
 		//mame_printf_debug("Starting timer\n");
-		timer_adjust_periodic(sega005_sound_timer, ATTOTIME_IN_HZ(SEGA005_555_TIMER_FREQ), 0, ATTOTIME_IN_HZ(SEGA005_555_TIMER_FREQ));
+		state->m_sega005_sound_timer->adjust(attotime::from_hz(SEGA005_555_TIMER_FREQ), 0, attotime::from_hz(SEGA005_555_TIMER_FREQ));
 	}
 }
 
 
 static WRITE8_DEVICE_HANDLER( sega005_sound_b_w )
 {
+	segag80r_state *state = device->machine().driver_data<segag80r_state>();
 	/*
            D6: manual timer clock (0->1)
            D5: 0 = manual timer, 1 = auto timer
            D4: 1 = hold/reset address counter to 0
         D3-D0: upper 4 bits of ROM address
     */
-	UINT8 diff = data ^ sound_state[1];
-	sound_state[1] = data;
+	UINT8 diff = data ^ state->m_sound_state[1];
+	state->m_sound_state[1] = data;
 
 	//mame_printf_debug("sound[%d] = %02X\n", 1, data);
 
 	/* force a stream update */
-	stream_update(sega005_stream);
+	state->m_sega005_stream->update();
 
 	/* ROM address */
-	sound_addr = ((data & 0x0f) << 7) | (sound_addr & 0x7f);
+	state->m_sound_addr = ((data & 0x0f) << 7) | (state->m_sound_addr & 0x7f);
 
 	/* reset both sound address and square wave counters */
 	if (data & 0x10)
 	{
-		sound_addr &= 0x780;
-		square_state = 0;
+		state->m_sound_addr &= 0x780;
+		state->m_square_state = 0;
 	}
 
 	/* manual clock */
 	if ((diff & 0x40) && (data & 0x40) && !(data & 0x20) && !(data & 0x10))
-		sound_addr = (sound_addr & 0x780) | ((sound_addr + 1) & 0x07f);
+		state->m_sound_addr = (state->m_sound_addr & 0x780) | ((state->m_sound_addr + 1) & 0x07f);
 
 	/* update the sound data */
-	sega005_update_sound_data(device->machine);
+	sega005_update_sound_data(device->machine());
 }
 
 
@@ -577,16 +560,17 @@ static WRITE8_DEVICE_HANDLER( sega005_sound_b_w )
 
 static DEVICE_START( sega005_sound )
 {
-	running_machine *machine = device->machine;
+	segag80r_state *state = device->machine().driver_data<segag80r_state>();
+	running_machine &machine = device->machine();
 
 	/* create the stream */
-	sega005_stream = stream_create(device, 0, 1, SEGA005_COUNTER_FREQ, NULL, sega005_stream_update);
+	state->m_sega005_stream = device->machine().sound().stream_alloc(*device, 0, 1, SEGA005_COUNTER_FREQ, NULL, sega005_stream_update);
 
 	/* create a timer for the 555 */
-	sega005_sound_timer = timer_alloc(machine, sega005_auto_timer, NULL);
+	state->m_sega005_sound_timer = machine.scheduler().timer_alloc(FUNC(sega005_auto_timer));
 
 	/* set the initial sound data */
-	sound_data = 0x00;
+	state->m_sound_data = 0x00;
 	sega005_update_sound_data(machine);
 }
 
@@ -607,33 +591,35 @@ DEVICE_GET_INFO( sega005_sound )
 
 static STREAM_UPDATE( sega005_stream_update )
 {
-	const UINT8 *sound_prom = device->machine->region("proms")->base();
+	segag80r_state *state = device->machine().driver_data<segag80r_state>();
+	const UINT8 *sound_prom = device->machine().region("proms")->base();
 	int i;
 
 	/* no implementation yet */
 	for (i = 0; i < samples; i++)
 	{
-		if (!(sound_state[1] & 0x10) && (++square_count & 0xff) == 0)
+		if (!(state->m_sound_state[1] & 0x10) && (++state->m_square_count & 0xff) == 0)
 		{
-			square_count = sound_prom[sound_data & 0x1f];
+			state->m_square_count = sound_prom[state->m_sound_data & 0x1f];
 
 			/* hack - the RC should filter this out */
-			if (square_count != 0xff)
-				square_state += 2;
+			if (state->m_square_count != 0xff)
+				state->m_square_state += 2;
 		}
 
-		outputs[0][i] = (square_state & 2) ? 0x7fff : 0x0000;
+		outputs[0][i] = (state->m_square_state & 2) ? 0x7fff : 0x0000;
 	}
 }
 
 
 static TIMER_CALLBACK( sega005_auto_timer )
 {
+	segag80r_state *state = machine.driver_data<segag80r_state>();
 	/* force an update then clock the sound address if not held in reset */
-	stream_update(sega005_stream);
-	if ((sound_state[1] & 0x20) && !(sound_state[1] & 0x10))
+	state->m_sega005_stream->update();
+	if ((state->m_sound_state[1] & 0x20) && !(state->m_sound_state[1] & 0x10))
 	{
-		sound_addr = (sound_addr & 0x780) | ((sound_addr + 1) & 0x07f);
+		state->m_sound_addr = (state->m_sound_addr & 0x780) | ((state->m_sound_addr + 1) & 0x07f);
 		sega005_update_sound_data(machine);
 	}
 }
@@ -651,17 +637,17 @@ static SOUND_START( spaceod );
 static const char *const spaceod_sample_names[] =
 {
 	"*spaceod",
-	"fire.wav",			/* 0 */
-	"bomb.wav",			/* 1 */
-	"eexplode.wav", 	/* 2 */
-	"pexplode.wav",		/* 3 */
-	"warp.wav", 		/* 4 */
-	"birth.wav",		/* 5 */
-	"scoreup.wav",		/* 6 */
-	"ssound.wav",		/* 7 */
-	"accel.wav",		/* 8 */
-	"damaged.wav",		/* 9 */
-	"erocket.wav",		/* 10 */
+	"fire",			/* 0 */
+	"bomb",			/* 1 */
+	"eexplode", 	/* 2 */
+	"pexplode",		/* 3 */
+	"warp", 		/* 4 */
+	"birth",		/* 5 */
+	"scoreup",		/* 6 */
+	"ssound",		/* 7 */
+	"accel",		/* 8 */
+	"damaged",		/* 9 */
+	"erocket",		/* 10 */
 	0
 };
 
@@ -693,7 +679,8 @@ MACHINE_CONFIG_END
 
 static SOUND_START( spaceod )
 {
-	state_save_register_global_array(machine, sound_state);
+	segag80r_state *state = machine.driver_data<segag80r_state>();
+	state_save_register_global_array(machine, state->m_sound_state);
 }
 
 
@@ -706,9 +693,10 @@ static SOUND_START( spaceod )
 
 WRITE8_HANDLER( spaceod_sound_w )
 {
-	device_t *samples = space->machine->device("samples");
-	UINT8 diff = data ^ sound_state[offset];
-	sound_state[offset] = data;
+	segag80r_state *state = space->machine().driver_data<segag80r_state>();
+	device_t *samples = space->machine().device("samples");
+	UINT8 diff = data ^ state->m_sound_state[offset];
+	state->m_sound_state[offset] = data;
 
 	switch (offset)
 	{
@@ -785,8 +773,8 @@ static READ8_HANDLER( n7751_t1_r );
 static const char *const monsterb_sample_names[] =
 {
 	"*monsterb",
-	"zap.wav",
-	"jumpdown.wav",
+	"zap",
+	"jumpdown",
 	0
 };
 
@@ -812,7 +800,7 @@ static const tms36xx_interface monsterb_tms3617_interface =
  *
  *************************************/
 
-static ADDRESS_MAP_START( monsterb_7751_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( monsterb_7751_portmap, AS_IO, 8 )
 	AM_RANGE(MCS48_PORT_T1,   MCS48_PORT_T1) AM_READ(n7751_t1_r)
 	AM_RANGE(MCS48_PORT_P2,   MCS48_PORT_P2) AM_READ(n7751_command_r)
 	AM_RANGE(MCS48_PORT_BUS,  MCS48_PORT_BUS) AM_READ(n7751_rom_r)
@@ -875,10 +863,11 @@ MACHINE_CONFIG_END
 
 static SOUND_START( monsterb )
 {
-	state_save_register_global_array(machine, sound_state);
-	state_save_register_global(machine, sound_addr);
-	state_save_register_global(machine, n7751_command);
-	state_save_register_global(machine, n7751_busy);
+	segag80r_state *state = machine.driver_data<segag80r_state>();
+	state_save_register_global_array(machine, state->m_sound_state);
+	state_save_register_global(machine, state->m_sound_addr);
+	state_save_register_global(machine, state->m_n7751_command);
+	state_save_register_global(machine, state->m_n7751_busy);
 }
 
 
@@ -891,14 +880,14 @@ static SOUND_START( monsterb )
 
 static WRITE8_DEVICE_HANDLER( monsterb_sound_a_w )
 {
-	device_t *tms = device->machine->device("music");
+	device_t *tms = device->machine().device("music");
 	int enable_val;
 
 	/* Lower four data lines get decoded into 13 control lines */
 	tms36xx_note_w(tms, 0, data & 15);
 
 	/* Top four data lines address an 82S123 ROM that enables/disables voices */
-	enable_val = device->machine->region("prom")->base()[(data & 0xF0) >> 4];
+	enable_val = device->machine().region("prom")->base()[(data & 0xF0) >> 4];
 	tms3617_enable_w(tms, enable_val >> 2);
 }
 
@@ -912,9 +901,10 @@ static WRITE8_DEVICE_HANDLER( monsterb_sound_a_w )
 
 static WRITE8_DEVICE_HANDLER( monsterb_sound_b_w )
 {
-	device_t *samples = device->machine->device("samples");
-	UINT8 diff = data ^ sound_state[1];
-	sound_state[1] = data;
+	segag80r_state *state = device->machine().driver_data<segag80r_state>();
+	device_t *samples = device->machine().device("samples");
+	UINT8 diff = data ^ state->m_sound_state[1];
+	state->m_sound_state[1] = data;
 
 	/* SHOT: channel 0 */
 	if ((diff & 0x01) && !(data & 0x01)) sample_start(samples, 0, 0, FALSE);
@@ -935,26 +925,29 @@ static WRITE8_DEVICE_HANDLER( monsterb_sound_b_w )
 
 static READ8_DEVICE_HANDLER( n7751_status_r )
 {
-	return n7751_busy << 4;
+	segag80r_state *state = device->machine().driver_data<segag80r_state>();
+	return state->m_n7751_busy << 4;
 }
 
 
 static WRITE8_DEVICE_HANDLER( n7751_command_w )
 {
+	segag80r_state *state = device->machine().driver_data<segag80r_state>();
 	/*
         Z80 7751 control port
 
         D0-D2 = connected to 7751 port C
         D3    = /INT line
     */
-	n7751_command = data & 0x07;
-	cputag_set_input_line(device->machine, "audiocpu", 0, ((data & 0x08) == 0) ? ASSERT_LINE : CLEAR_LINE);
-	cpuexec_boost_interleave(device->machine, attotime_zero, ATTOTIME_IN_USEC(100));
+	state->m_n7751_command = data & 0x07;
+	cputag_set_input_line(device->machine(), "audiocpu", 0, ((data & 0x08) == 0) ? ASSERT_LINE : CLEAR_LINE);
+	device->machine().scheduler().boost_interleave(attotime::zero, attotime::from_usec(100));
 }
 
 
 static WRITE8_DEVICE_HANDLER( n7751_rom_control_w )
 {
+	segag80r_state *state = device->machine().driver_data<segag80r_state>();
 	/* P4 - address lines 0-3 */
 	/* P5 - address lines 4-7 */
 	/* P6 - address lines 8-11 */
@@ -962,25 +955,25 @@ static WRITE8_DEVICE_HANDLER( n7751_rom_control_w )
 	switch (offset)
 	{
 		case 0:
-			sound_addr = (sound_addr & ~0x00f) | ((data & 0x0f) << 0);
+			state->m_sound_addr = (state->m_sound_addr & ~0x00f) | ((data & 0x0f) << 0);
 			break;
 
 		case 1:
-			sound_addr = (sound_addr & ~0x0f0) | ((data & 0x0f) << 4);
+			state->m_sound_addr = (state->m_sound_addr & ~0x0f0) | ((data & 0x0f) << 4);
 			break;
 
 		case 2:
-			sound_addr = (sound_addr & ~0xf00) | ((data & 0x0f) << 8);
+			state->m_sound_addr = (state->m_sound_addr & ~0xf00) | ((data & 0x0f) << 8);
 			break;
 
 		case 3:
-			sound_addr &= 0xfff;
+			state->m_sound_addr &= 0xfff;
 			{
-				int numroms = device->machine->region("n7751")->bytes() / 0x1000;
-				if (!(data & 0x01) && numroms >= 1) sound_addr |= 0x0000;
-				if (!(data & 0x02) && numroms >= 2) sound_addr |= 0x1000;
-				if (!(data & 0x04) && numroms >= 3) sound_addr |= 0x2000;
-				if (!(data & 0x08) && numroms >= 4) sound_addr |= 0x3000;
+				int numroms = device->machine().region("n7751")->bytes() / 0x1000;
+				if (!(data & 0x01) && numroms >= 1) state->m_sound_addr |= 0x0000;
+				if (!(data & 0x02) && numroms >= 2) state->m_sound_addr |= 0x1000;
+				if (!(data & 0x04) && numroms >= 3) state->m_sound_addr |= 0x2000;
+				if (!(data & 0x08) && numroms >= 4) state->m_sound_addr |= 0x3000;
 			}
 			break;
 	}
@@ -989,27 +982,30 @@ static WRITE8_DEVICE_HANDLER( n7751_rom_control_w )
 
 static READ8_HANDLER( n7751_rom_r )
 {
+	segag80r_state *state = space->machine().driver_data<segag80r_state>();
 	/* read from BUS */
-	return space->machine->region("n7751")->base()[sound_addr];
+	return space->machine().region("n7751")->base()[state->m_sound_addr];
 }
 
 
 static READ8_HANDLER( n7751_command_r )
 {
+	segag80r_state *state = space->machine().driver_data<segag80r_state>();
 	/* read from P2 - 8255's PC0-2 connects to 7751's S0-2 (P24-P26 on an 8048) */
 	/* bit 0x80 is an alternate way to control the sample on/off; doesn't appear to be used */
-	return 0x80 | ((n7751_command & 0x07) << 4);
+	return 0x80 | ((state->m_n7751_command & 0x07) << 4);
 }
 
 
 static WRITE8_DEVICE_HANDLER( n7751_p2_w )
 {
+	segag80r_state *state = device->machine().driver_data<segag80r_state>();
 	/* write to P2; low 4 bits go to 8243 */
 	i8243_p2_w(device, offset, data & 0x0f);
 
 	/* output of bit $80 indicates we are ready (1) or busy (0) */
 	/* no other outputs are used */
-	n7751_busy = data >> 7;
+	state->m_n7751_busy = data >> 7;
 }
 
 
