@@ -10,7 +10,6 @@
 ***************************************************************************/
 
 #include "emu.h"
-#include "streams.h"
 #include "cpu/mcs48/mcs48.h"
 #include "sound/sp0250.h"
 #include "segasnd.h"
@@ -81,6 +80,7 @@ struct _usb_state
 {
 	sound_stream *		stream;				/* output stream */
 	device_t *cpu;				/* CPU index of the 8035 */
+	device_t *maincpu;
 	UINT8				in_latch;			/* input latch */
 	UINT8				out_latch;			/* output latch */
 	UINT8				last_p2_value;		/* current P2 output value */
@@ -100,17 +100,13 @@ struct _usb_state
 	filter_state		noise_filters[5];
 };
 
-
-
-/***************************************************************************
-    GLOBAL VARIABLES
-***************************************************************************/
-
 /* SP0250-based speech board */
-static UINT8 speech_latch, speech_t0, speech_p2, speech_drq;
-
-/* Universal sound board */
-static usb_state usb;
+typedef struct _speech_state speech_state;
+struct _speech_state
+{
+	UINT8 latch, t0, p2, drq;
+	UINT8 *speech;
+};
 
 
 
@@ -145,6 +141,43 @@ INLINE double step_cr_filter(filter_state *state, double input)
     SPEECH BOARD
 ***************************************************************************/
 
+DECLARE_LEGACY_SOUND_DEVICE(SEGASPEECH, speech_sound);
+
+INLINE speech_state *get_safe_speech(device_t *device)
+{
+	assert(device != NULL);
+	assert(device->type() == SEGASPEECH);
+
+	return (speech_state *)downcast<legacy_device_base *>(device)->token();
+}
+
+static DEVICE_START( speech_sound )
+{
+	speech_state *state = get_safe_speech(device);
+
+	state->speech = device->machine().region("speech")->base();
+}
+
+
+DEVICE_GET_INFO( speech_sound )
+{
+	switch (state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TOKEN_BYTES:					info->i = sizeof(speech_state);			break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME(speech_sound);		break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_NAME:							strcpy(info->s, "Sega Speech Sound Board");	break;
+		case DEVINFO_STR_SOURCE_FILE:						strcpy(info->s, __FILE__);						break;
+	}
+}
+
+DEFINE_LEGACY_SOUND_DEVICE(SEGASPEECH, speech_sound);
+
+
 
 /*************************************
  *
@@ -152,35 +185,49 @@ INLINE double step_cr_filter(filter_state *state, double input)
  *
  *************************************/
 
-static READ8_HANDLER( speech_t0_r )
+
+
+static READ8_DEVICE_HANDLER( speech_t0_r )
 {
-	return speech_t0;
+	speech_state *state = get_safe_speech(device);
+
+	return state->t0;
 }
 
-static READ8_HANDLER( speech_t1_r )
+static READ8_DEVICE_HANDLER( speech_t1_r )
 {
-	return speech_drq;
+	speech_state *state = get_safe_speech(device);
+
+	return state->drq;
 }
 
-static READ8_HANDLER( speech_p1_r )
+static READ8_DEVICE_HANDLER( speech_p1_r )
 {
-	return speech_latch & 0x7f;
+	speech_state *state = get_safe_speech(device);
+
+	return state->latch & 0x7f;
 }
 
-static READ8_HANDLER( speech_rom_r )
+static READ8_DEVICE_HANDLER( speech_rom_r )
 {
-	return space->machine->region("speech")->base()[0x100 * (speech_p2 & 0x3f) + offset];
+	speech_state *state = get_safe_speech(device);
+
+	return state->speech[0x100 * (state->p2 & 0x3f) + offset];
 }
 
-static WRITE8_HANDLER( speech_p1_w )
+static WRITE8_DEVICE_HANDLER( speech_p1_w )
 {
+	speech_state *state = get_safe_speech(device);
+
 	if (!(data & 0x80))
-		speech_t0 = 0;
+		state->t0 = 0;
 }
 
-static WRITE8_HANDLER( speech_p2_w )
+static WRITE8_DEVICE_HANDLER( speech_p2_w )
 {
-	speech_p2 = data;
+	speech_state *state = get_safe_speech(device);
+
+	state->p2 = data;
 }
 
 
@@ -193,7 +240,10 @@ static WRITE8_HANDLER( speech_p2_w )
 
 static void speech_drq_w(device_t *device, int level)
 {
-	speech_drq = (level == ASSERT_LINE);
+	device_t *speech = device->machine().device("segaspeech");
+	speech_state *state = get_safe_speech(speech);
+
+	state->drq = (level == ASSERT_LINE);
 }
 
 
@@ -207,27 +257,30 @@ static void speech_drq_w(device_t *device, int level)
 static TIMER_CALLBACK( delayed_speech_w )
 {
 	int data = param;
-	UINT8 old = speech_latch;
+	speech_state *state = (speech_state *)ptr;
+	UINT8 old = state->latch;
 
 	/* all 8 bits are latched */
-	speech_latch = data;
+	state->latch = data;
 
 	/* the high bit goes directly to the INT line */
 	cputag_set_input_line(machine, "audiocpu", 0, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
 
 	/* a clock on the high bit clocks a 1 into T0 */
 	if (!(old & 0x80) && (data & 0x80))
-		speech_t0 = 1;
+		state->t0 = 1;
 }
 
 
-WRITE8_HANDLER( sega_speech_data_w )
+WRITE8_DEVICE_HANDLER( sega_speech_data_w )
 {
-	timer_call_after_resynch(space->machine, NULL, data, delayed_speech_w);
+	speech_state *state = get_safe_speech(device);
+
+	device->machine().scheduler().synchronize(FUNC(delayed_speech_w), data, state);
 }
 
 
-WRITE8_HANDLER( sega_speech_control_w )
+WRITE8_DEVICE_HANDLER( sega_speech_control_w )
 {
 	LOG(("Speech control = %X\n", data));
 }
@@ -240,18 +293,18 @@ WRITE8_HANDLER( sega_speech_control_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( speech_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( speech_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_MIRROR(0x0800) AM_ROM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( speech_portmap, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x00, 0xff) AM_READ(speech_rom_r)
+static ADDRESS_MAP_START( speech_portmap, AS_IO, 8 )
+	AM_RANGE(0x00, 0xff) AM_DEVREAD("segaspeech", speech_rom_r)
 	AM_RANGE(0x00, 0xff) AM_DEVWRITE("speech", sp0250_w)
-	AM_RANGE(MCS48_PORT_P1, MCS48_PORT_P1) AM_READWRITE(speech_p1_r, speech_p1_w)
-	AM_RANGE(MCS48_PORT_P2, MCS48_PORT_P2) AM_WRITE(speech_p2_w)
-	AM_RANGE(MCS48_PORT_T0, MCS48_PORT_T0) AM_READ(speech_t0_r)
-	AM_RANGE(MCS48_PORT_T1, MCS48_PORT_T1) AM_READ(speech_t1_r)
+	AM_RANGE(MCS48_PORT_P1, MCS48_PORT_P1) AM_DEVREADWRITE("segaspeech", speech_p1_r, speech_p1_w)
+	AM_RANGE(MCS48_PORT_P2, MCS48_PORT_P2) AM_DEVWRITE("segaspeech", speech_p2_w)
+	AM_RANGE(MCS48_PORT_T0, MCS48_PORT_T0) AM_DEVREAD("segaspeech", speech_t0_r)
+	AM_RANGE(MCS48_PORT_T1, MCS48_PORT_T1) AM_DEVREAD("segaspeech", speech_t1_r)
 ADDRESS_MAP_END
 
 
@@ -283,6 +336,7 @@ MACHINE_CONFIG_FRAGMENT( sega_speech_board )
 	MCFG_CPU_IO_MAP(speech_portmap)
 
 	/* sound hardware */
+	MCFG_SOUND_ADD("segaspeech", SEGASPEECH, 0)
 	MCFG_SOUND_ADD("speech", SP0250, SPEECH_MASTER_CLOCK)
 	MCFG_SOUND_CONFIG(sp0250_interface)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
@@ -294,6 +348,15 @@ MACHINE_CONFIG_END
     UNIVERSAL SOUND BOARD
 ***************************************************************************/
 
+static DECLARE_LEGACY_SOUND_DEVICE(SEGAUSB, usb_sound);
+
+INLINE usb_state *get_safe_token(device_t *device)
+{
+	assert(device != NULL);
+	assert(device->type() == SEGAUSB);
+
+	return (usb_state *)downcast<legacy_device_base *>(device)->token();
+}
 
 /*************************************
  *
@@ -303,19 +366,24 @@ MACHINE_CONFIG_END
 
 static TIMER_DEVICE_CALLBACK( increment_t1_clock )
 {
+	device_t *usbsnd = timer.machine().device("usbsnd");
+	usb_state *usb = get_safe_token(usbsnd);
+
 	/* only increment if it is not being forced clear */
-	if (!(usb.last_p2_value & 0x80))
-		usb.t1_clock++;
+	if (!(usb->last_p2_value & 0x80))
+		usb->t1_clock++;
 }
 
 
-void sega_usb_reset(running_machine *machine, UINT8 t1_clock_mask)
+static DEVICE_RESET( usb_sound )
 {
+	usb_state *usb = get_safe_token(device);
+
 	/* halt the USB CPU at reset time */
-	cpu_set_input_line(usb.cpu, INPUT_LINE_RESET, ASSERT_LINE);
+	device_set_input_line(usb->cpu, INPUT_LINE_RESET, ASSERT_LINE);
 
 	/* start the clock timer */
-	usb.t1_clock_mask = t1_clock_mask;
+	usb->t1_clock_mask = 0x10;
 }
 
 
@@ -326,56 +394,65 @@ void sega_usb_reset(running_machine *machine, UINT8 t1_clock_mask)
  *
  *************************************/
 
-READ8_HANDLER( sega_usb_status_r )
+READ8_DEVICE_HANDLER( sega_usb_status_r )
 {
-	LOG(("%04X:usb_data_r = %02X\n", cpu_get_pc(space->cpu), (usb.out_latch & 0x81) | (usb.in_latch & 0x7e)));
+	usb_state *usb = get_safe_token(device);
 
-	cpu_adjust_icount(space->cpu, -200);
+	LOG(("%04X:usb_data_r = %02X\n", cpu_get_pc(usb->maincpu), (usb->out_latch & 0x81) | (usb->in_latch & 0x7e)));
+
+	device_adjust_icount(usb->maincpu, -200);
 
 	/* only bits 0 and 7 are controlled by the I8035; the remaining */
 	/* bits 1-6 reflect the current input latch values */
-	return (usb.out_latch & 0x81) | (usb.in_latch & 0x7e);
+	return (usb->out_latch & 0x81) | (usb->in_latch & 0x7e);
 }
 
 
 static TIMER_CALLBACK( delayed_usb_data_w )
 {
+	usb_state *usb = (usb_state *)ptr;
 	int data = param;
 
 	/* look for rising/falling edges of bit 7 to control the RESET line */
-	cpu_set_input_line(usb.cpu, INPUT_LINE_RESET, (data & 0x80) ? ASSERT_LINE : CLEAR_LINE);
+	device_set_input_line(usb->cpu, INPUT_LINE_RESET, (data & 0x80) ? ASSERT_LINE : CLEAR_LINE);
 
 	/* if the CLEAR line is set, the low 7 bits of the input are ignored */
-	if ((usb.last_p2_value & 0x40) == 0)
+	if ((usb->last_p2_value & 0x40) == 0)
 		data &= ~0x7f;
 
 	/* update the effective input latch */
-	usb.in_latch = data;
+	usb->in_latch = data;
 }
 
 
-WRITE8_HANDLER( sega_usb_data_w )
+WRITE8_DEVICE_HANDLER( sega_usb_data_w )
 {
-	LOG(("%04X:usb_data_w = %02X\n", cpu_get_pc(space->cpu), data));
-	timer_call_after_resynch(space->machine, NULL, data, delayed_usb_data_w);
+	usb_state *usb = get_safe_token(device);
+
+	LOG(("%04X:usb_data_w = %02X\n", cpu_get_pc(usb->maincpu), data));
+	device->machine().scheduler().synchronize(FUNC(delayed_usb_data_w), data, usb);
 
 	/* boost the interleave so that sequences can be sent */
-	cpuexec_boost_interleave(space->machine, attotime_zero, ATTOTIME_IN_USEC(250));
+	device->machine().scheduler().boost_interleave(attotime::zero, attotime::from_usec(250));
 }
 
 
-READ8_HANDLER( sega_usb_ram_r )
+READ8_DEVICE_HANDLER( sega_usb_ram_r )
 {
-	return usb.program_ram[offset];
+	usb_state *usb = get_safe_token(device);
+
+	return usb->program_ram[offset];
 }
 
 
-WRITE8_HANDLER( sega_usb_ram_w )
+WRITE8_DEVICE_HANDLER( sega_usb_ram_w )
 {
-	if (usb.in_latch & 0x80)
-		usb.program_ram[offset] = data;
+	usb_state *usb = get_safe_token(device);
+
+	if (usb->in_latch & 0x80)
+		usb->program_ram[offset] = data;
 	else
-		LOG(("%04X:sega_usb_ram_w(%03X) = %02X while /LOAD disabled\n", cpu_get_pc(space->cpu), offset, data));
+		LOG(("%04X:sega_usb_ram_w(%03X) = %02X while /LOAD disabled\n", cpu_get_pc(usb->maincpu), offset, data));
 }
 
 
@@ -386,50 +463,57 @@ WRITE8_HANDLER( sega_usb_ram_w )
  *
  *************************************/
 
-static READ8_HANDLER( usb_p1_r )
+static READ8_DEVICE_HANDLER( usb_p1_r )
 {
+	usb_state *usb = get_safe_token(device);
+
 	/* bits 0-6 are inputs and map to bits 0-6 of the input latch */
-	if ((usb.in_latch & 0x7f) != 0)
-		LOG(("%03X: P1 read = %02X\n", cpu_get_pc(space->cpu), usb.in_latch & 0x7f));
-	return usb.in_latch & 0x7f;
+	if ((usb->in_latch & 0x7f) != 0)
+		LOG(("%03X: P1 read = %02X\n", cpu_get_pc(usb->maincpu), usb->in_latch & 0x7f));
+	return usb->in_latch & 0x7f;
 }
 
 
-static WRITE8_HANDLER( usb_p1_w )
+static WRITE8_DEVICE_HANDLER( usb_p1_w )
 {
+	usb_state *usb = get_safe_token(device);
+
 	/* bit 7 maps to bit 0 on the output latch */
-	usb.out_latch = (usb.out_latch & 0xfe) | (data >> 7);
-	LOG(("%03X: P1 write = %02X\n", cpu_get_pc(space->cpu), data));
+	usb->out_latch = (usb->out_latch & 0xfe) | (data >> 7);
+	LOG(("%03X: P1 write = %02X\n", cpu_get_pc(usb->maincpu), data));
 }
 
 
-static WRITE8_HANDLER( usb_p2_w )
+static WRITE8_DEVICE_HANDLER( usb_p2_w )
 {
-	UINT8 old = usb.last_p2_value;
-	usb.last_p2_value = data;
+	usb_state *usb = get_safe_token(device);
+	UINT8 old = usb->last_p2_value;
+	usb->last_p2_value = data;
 
 	/* low 2 bits control the bank of work RAM we are addressing */
-	usb.work_ram_bank = data & 3;
+	usb->work_ram_bank = data & 3;
 
 	/* bit 6 controls the "ready" bit output to the host */
 	/* it also clears the input latch from the host (active low) */
-	usb.out_latch = ((data & 0x40) << 1) | (usb.out_latch & 0x7f);
+	usb->out_latch = ((data & 0x40) << 1) | (usb->out_latch & 0x7f);
 	if ((data & 0x40) == 0)
-		usb.in_latch = 0;
+		usb->in_latch = 0;
 
 	/* bit 7 controls the reset on the upper counter at U33 */
 	if ((old & 0x80) && !(data & 0x80))
-		usb.t1_clock = 0;
+		usb->t1_clock = 0;
 
-	LOG(("%03X: P2 write -> bank=%d ready=%d clock=%d\n", cpu_get_pc(space->cpu), data & 3, (data >> 6) & 1, (data >> 7) & 1));
+	LOG(("%03X: P2 write -> bank=%d ready=%d clock=%d\n", cpu_get_pc(usb->maincpu), data & 3, (data >> 6) & 1, (data >> 7) & 1));
 }
 
 
-static READ8_HANDLER( usb_t1_r )
+static READ8_DEVICE_HANDLER( usb_t1_r )
 {
+	usb_state *usb = get_safe_token(device);
+
 	/* T1 returns 1 based on the value of the T1 clock; the exact */
 	/* pattern is determined by one or more jumpers on the board. */
-	return (usb.t1_clock & usb.t1_clock_mask) != 0;
+	return (usb->t1_clock & usb->t1_clock_mask) != 0;
 }
 
 
@@ -483,6 +567,7 @@ INLINE void clock_channel(timer8253_channel *ch)
 
 static STREAM_UPDATE( usb_stream_update )
 {
+	usb_state *usb = get_safe_token(device);
 	stream_sample_t *dest = outputs[0];
 
 	/* iterate over samples */
@@ -504,30 +589,30 @@ static STREAM_UPDATE( usb_stream_update )
        */
 
 		/* update the noise source */
-		for (step = USB_2MHZ_CLOCK / SAMPLE_RATE; step >= usb.noise_subcount; step -= usb.noise_subcount)
+		for (step = USB_2MHZ_CLOCK / SAMPLE_RATE; step >= usb->noise_subcount; step -= usb->noise_subcount)
 		{
-			usb.noise_shift = (usb.noise_shift << 1) | (((usb.noise_shift >> 13) ^ (usb.noise_shift >> 16)) & 1);
-			usb.noise_state = (usb.noise_shift >> 16) & 1;
-			usb.noise_subcount = USB_2MHZ_CLOCK / MM5837_CLOCK;
+			usb->noise_shift = (usb->noise_shift << 1) | (((usb->noise_shift >> 13) ^ (usb->noise_shift >> 16)) & 1);
+			usb->noise_state = (usb->noise_shift >> 16) & 1;
+			usb->noise_subcount = USB_2MHZ_CLOCK / MM5837_CLOCK;
 		}
-		usb.noise_subcount -= step;
+		usb->noise_subcount -= step;
 
 		/* update the filtered noise value -- this is just an approximation to the pink noise filter */
 		/* being applied on the PCB, but it sounds pretty close */
-		usb.noise_filters[0].capval = 0.99765 * usb.noise_filters[0].capval + usb.noise_state * 0.0990460;
-		usb.noise_filters[1].capval = 0.96300 * usb.noise_filters[1].capval + usb.noise_state * 0.2965164;
-		usb.noise_filters[2].capval = 0.57000 * usb.noise_filters[2].capval + usb.noise_state * 1.0526913;
-		noiseval = usb.noise_filters[0].capval + usb.noise_filters[1].capval + usb.noise_filters[2].capval + usb.noise_state * 0.1848;
+		usb->noise_filters[0].capval = 0.99765 * usb->noise_filters[0].capval + usb->noise_state * 0.0990460;
+		usb->noise_filters[1].capval = 0.96300 * usb->noise_filters[1].capval + usb->noise_state * 0.2965164;
+		usb->noise_filters[2].capval = 0.57000 * usb->noise_filters[2].capval + usb->noise_state * 1.0526913;
+		noiseval = usb->noise_filters[0].capval + usb->noise_filters[1].capval + usb->noise_filters[2].capval + usb->noise_state * 0.1848;
 
 		/* final output goes through a CR filter; the scaling factor is arbitrary to get the noise to the */
 		/* correct relative volume */
-		noiseval = step_cr_filter(&usb.noise_filters[4], noiseval);
+		noiseval = step_cr_filter(&usb->noise_filters[4], noiseval);
 		noiseval *= 0.075;
 
 		/* there are 3 identical groups of circuits, each with its own 8253 */
 		for (group = 0; group < 3; group++)
 		{
-			timer8253 *g = &usb.timer_group[group];
+			timer8253 *g = &usb->timer_group[group];
 			double chan0, chan1, chan2, mix;
 
 
@@ -602,8 +687,8 @@ static STREAM_UPDATE( usb_stream_update )
 			}
 
 			/* the exponents for the gate filters are determined by channel 2's output */
-			g->gate1.exponent = usb.gate_rc1_exp[g->chan[2].output];
-			g->gate2.exponent = usb.gate_rc2_exp[g->chan[2].output];
+			g->gate1.exponent = usb->gate_rc1_exp[g->chan[2].output];
+			g->gate2.exponent = usb->gate_rc2_exp[g->chan[2].output];
 
 			/* based on the envelope mode, we do one of two things with source 2 */
 			if (g->config == 0)
@@ -632,33 +717,37 @@ static STREAM_UPDATE( usb_stream_update )
           WEIGHT
 
        */
-       *dest++ = 4000 * step_cr_filter(&usb.final_filter, sample);
+       *dest++ = 4000 * step_cr_filter(&usb->final_filter, sample);
 	}
 }
 
 
 static DEVICE_START( usb_sound )
 {
-	running_machine *machine = device->machine;
+	usb_state *usb = get_safe_token(device);
+	running_machine &machine = device->machine();
 	filter_state temp;
 	int tchan, tgroup;
 
 	/* find the CPU we are associated with */
-	usb.cpu = machine->device("usbcpu");
-	assert(usb.cpu != NULL);
+	usb->maincpu = machine.device("maincpu");
+	assert(usb->maincpu != NULL);
+	usb->cpu = machine.device("usbcpu");
+	assert(usb->cpu != NULL);
 
-	/* allocate work RAM */
-	usb.work_ram = auto_alloc_array(machine, UINT8, 0x400);
+	/* allocate RAM */
+	usb->program_ram = (UINT8 *)memory_get_shared(device->machine(), "pgmram");
+	usb->work_ram = auto_alloc_array(machine, UINT8, 0x400);
 
 	/* create a sound stream */
-	usb.stream = stream_create(device, 0, 1, SAMPLE_RATE, NULL, usb_stream_update);
+	usb->stream = device->machine().sound().stream_alloc(*device, 0, 1, SAMPLE_RATE, NULL, usb_stream_update);
 
 	/* initialize state */
-	usb.noise_shift = 0x15555;
+	usb->noise_shift = 0x15555;
 
 	for (tgroup = 0; tgroup < 3; tgroup++)
 	{
-		timer8253 *g = &usb.timer_group[tgroup];
+		timer8253 *g = &usb->timer_group[tgroup];
 		configure_filter(&g->chan_filter[0], 10e3, 1e-6);
 		configure_filter(&g->chan_filter[1], 10e3, 1e-6);
 		configure_filter(&g->gate1, 100e3, 0.01e-6);
@@ -666,32 +755,32 @@ static DEVICE_START( usb_sound )
 	}
 
 	configure_filter(&temp, 100e3, 0.01e-6);
-	usb.gate_rc1_exp[0] = temp.exponent;
+	usb->gate_rc1_exp[0] = temp.exponent;
 	configure_filter(&temp, 1e3, 0.01e-6);
-	usb.gate_rc1_exp[1] = temp.exponent;
+	usb->gate_rc1_exp[1] = temp.exponent;
 	configure_filter(&temp, 2 * 100e3, 0.01e-6);
-	usb.gate_rc2_exp[0] = temp.exponent;
+	usb->gate_rc2_exp[0] = temp.exponent;
 	configure_filter(&temp, 2 * 1e3, 0.01e-6);
-	usb.gate_rc2_exp[1] = temp.exponent;
+	usb->gate_rc2_exp[1] = temp.exponent;
 
-	configure_filter(&usb.noise_filters[0], 2.7e3 + 2.7e3, 1.0e-6);
-	configure_filter(&usb.noise_filters[1], 2.7e3 + 1e3, 0.30e-6);
-	configure_filter(&usb.noise_filters[2], 2.7e3 + 270, 0.15e-6);
-	configure_filter(&usb.noise_filters[3], 2.7e3 + 0, 0.082e-6);
-	configure_filter(&usb.noise_filters[4], 33e3, 0.1e-6);
+	configure_filter(&usb->noise_filters[0], 2.7e3 + 2.7e3, 1.0e-6);
+	configure_filter(&usb->noise_filters[1], 2.7e3 + 1e3, 0.30e-6);
+	configure_filter(&usb->noise_filters[2], 2.7e3 + 270, 0.15e-6);
+	configure_filter(&usb->noise_filters[3], 2.7e3 + 0, 0.082e-6);
+	configure_filter(&usb->noise_filters[4], 33e3, 0.1e-6);
 
-	configure_filter(&usb.final_filter, 100e3, 4.7e-6);
+	configure_filter(&usb->final_filter, 100e3, 4.7e-6);
 
 	/* register for save states */
-	state_save_register_item(machine, "usb", NULL, 0, usb.in_latch);
-	state_save_register_item(machine, "usb", NULL, 0, usb.out_latch);
-	state_save_register_item(machine, "usb", NULL, 0, usb.last_p2_value);
-	state_save_register_item(machine, "usb", NULL, 0, usb.work_ram_bank);
-	state_save_register_item(machine, "usb", NULL, 0, usb.t1_clock);
+	state_save_register_item(machine, "usb", NULL, 0, usb->in_latch);
+	state_save_register_item(machine, "usb", NULL, 0, usb->out_latch);
+	state_save_register_item(machine, "usb", NULL, 0, usb->last_p2_value);
+	state_save_register_item(machine, "usb", NULL, 0, usb->work_ram_bank);
+	state_save_register_item(machine, "usb", NULL, 0, usb->t1_clock);
 
 	for (tgroup = 0; tgroup < 3; tgroup++)
 	{
-		timer8253 *group = &usb.timer_group[tgroup];
+		timer8253 *group = &usb->timer_group[tgroup];
 		for (tchan = 0; tchan < 3; tchan++)
 		{
 			timer8253_channel *channel = &group->chan[tchan];
@@ -715,25 +804,29 @@ static DEVICE_START( usb_sound )
 		state_save_register_item(machine, "usb", NULL, tgroup, group->config);
 	}
 
-	state_save_register_item_array(machine, "usb", NULL, 0, usb.timer_mode);
-	state_save_register_item(machine, "usb", NULL, 0, usb.noise_shift);
-	state_save_register_item(machine, "usb", NULL, 0, usb.noise_state);
-	state_save_register_item(machine, "usb", NULL, 0, usb.noise_subcount);
-	state_save_register_item(machine, "usb", NULL, 0, usb.final_filter.capval);
-	state_save_register_item(machine, "usb", NULL, 0, usb.noise_filters[0].capval);
-	state_save_register_item(machine, "usb", NULL, 0, usb.noise_filters[1].capval);
-	state_save_register_item(machine, "usb", NULL, 0, usb.noise_filters[2].capval);
-	state_save_register_item(machine, "usb", NULL, 0, usb.noise_filters[3].capval);
-	state_save_register_item(machine, "usb", NULL, 0, usb.noise_filters[4].capval);
+	state_save_register_item_array(machine, "usb", NULL, 0, usb->timer_mode);
+	state_save_register_item(machine, "usb", NULL, 0, usb->noise_shift);
+	state_save_register_item(machine, "usb", NULL, 0, usb->noise_state);
+	state_save_register_item(machine, "usb", NULL, 0, usb->noise_subcount);
+	state_save_register_item(machine, "usb", NULL, 0, usb->final_filter.capval);
+	state_save_register_item(machine, "usb", NULL, 0, usb->noise_filters[0].capval);
+	state_save_register_item(machine, "usb", NULL, 0, usb->noise_filters[1].capval);
+	state_save_register_item(machine, "usb", NULL, 0, usb->noise_filters[2].capval);
+	state_save_register_item(machine, "usb", NULL, 0, usb->noise_filters[3].capval);
+	state_save_register_item(machine, "usb", NULL, 0, usb->noise_filters[4].capval);
 }
 
 
-DEVICE_GET_INFO( usb_sound )
+static DEVICE_GET_INFO( usb_sound )
 {
 	switch (state)
 	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TOKEN_BYTES:					info->i = sizeof(usb_state);			break;
+
 		/* --- the following bits of info are returned as pointers to data or functions --- */
 		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME(usb_sound);		break;
+		case DEVINFO_FCT_RESET:							info->start = DEVICE_RESET_NAME(usb_sound);		break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
 		case DEVINFO_STR_NAME:							strcpy(info->s, "Sega Universal Sound Board");	break;
@@ -741,8 +834,7 @@ DEVICE_GET_INFO( usb_sound )
 	}
 }
 
-DECLARE_LEGACY_SOUND_DEVICE(USB, usb_sound);
-DEFINE_LEGACY_SOUND_DEVICE(USB, usb_sound);
+DEFINE_LEGACY_SOUND_DEVICE(SEGAUSB, usb_sound);
 
 
 
@@ -752,13 +844,13 @@ DEFINE_LEGACY_SOUND_DEVICE(USB, usb_sound);
  *
  *************************************/
 
-static void timer_w(int which, UINT8 offset, UINT8 data)
+static void timer_w(usb_state *usb, int which, UINT8 offset, UINT8 data)
 {
-	timer8253 *g = &usb.timer_group[which];
+	timer8253 *g = &usb->timer_group[which];
 	timer8253_channel *ch;
 	int was_holding;
 
-	stream_update(usb.stream);
+	usb->stream->update();
 
 	/* switch off the offset */
 	switch (offset)
@@ -821,11 +913,11 @@ static void timer_w(int which, UINT8 offset, UINT8 data)
 }
 
 
-static void env_w(int which, UINT8 offset, UINT8 data)
+static void env_w(usb_state *usb, int which, UINT8 offset, UINT8 data)
 {
-	timer8253 *g = &usb.timer_group[which];
+	timer8253 *g = &usb->timer_group[which];
 
-	stream_update(usb.stream);
+	usb->stream->update();
 
 	if (offset < 3)
 		g->env[offset] = (double)data;
@@ -841,43 +933,47 @@ static void env_w(int which, UINT8 offset, UINT8 data)
  *
  *************************************/
 
-static READ8_HANDLER( usb_workram_r )
+static READ8_DEVICE_HANDLER( usb_workram_r )
 {
-	offset += 256 * usb.work_ram_bank;
-	return usb.work_ram[offset];
+	usb_state *usb = get_safe_token(device);
+
+	offset += 256 * usb->work_ram_bank;
+	return usb->work_ram[offset];
 }
 
 
-static WRITE8_HANDLER( usb_workram_w )
+static WRITE8_DEVICE_HANDLER( usb_workram_w )
 {
-	offset += 256 * usb.work_ram_bank;
-	usb.work_ram[offset] = data;
+	usb_state *usb = get_safe_token(device);
+
+	offset += 256 * usb->work_ram_bank;
+	usb->work_ram[offset] = data;
 
 	/* writes to the low 32 bytes go to various controls */
 	switch (offset & ~3)
 	{
 		case 0x00:	/* CTC0 */
-			timer_w(0, offset & 3, data);
+			timer_w(usb, 0, offset & 3, data);
 			break;
 
 		case 0x04:	/* ENV0 */
-			env_w(0, offset & 3, data);
+			env_w(usb, 0, offset & 3, data);
 			break;
 
 		case 0x08:	/* CTC1 */
-			timer_w(1, offset & 3, data);
+			timer_w(usb, 1, offset & 3, data);
 			break;
 
 		case 0x0c:	/* ENV1 */
-			env_w(1, offset & 3, data);
+			env_w(usb, 1, offset & 3, data);
 			break;
 
 		case 0x10:	/* CTC2 */
-			timer_w(2, offset & 3, data);
+			timer_w(usb, 2, offset & 3, data);
 			break;
 
 		case 0x14:	/* ENV2 */
-			env_w(2, offset & 3, data);
+			env_w(usb, 2, offset & 3, data);
 			break;
 	}
 }
@@ -890,21 +986,21 @@ static WRITE8_HANDLER( usb_workram_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( usb_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0fff) AM_RAM AM_BASE(&usb.program_ram)
+static ADDRESS_MAP_START( usb_map, AS_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x0fff) AM_RAM AM_SHARE("pgmram")
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( usb_map_rom, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( usb_map_rom, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_ROM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( usb_portmap, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x00, 0xff) AM_READWRITE(usb_workram_r, usb_workram_w)
-	AM_RANGE(MCS48_PORT_P1, MCS48_PORT_P1) AM_READWRITE(usb_p1_r, usb_p1_w)
-	AM_RANGE(MCS48_PORT_P2, MCS48_PORT_P2) AM_WRITE(usb_p2_w)
-	AM_RANGE(MCS48_PORT_T1, MCS48_PORT_T1) AM_READ(usb_t1_r)
+static ADDRESS_MAP_START( usb_portmap, AS_IO, 8 )
+	AM_RANGE(0x00, 0xff) AM_DEVREADWRITE("usbsnd", usb_workram_r, usb_workram_w)
+	AM_RANGE(MCS48_PORT_P1, MCS48_PORT_P1) AM_DEVREADWRITE("usbsnd", usb_p1_r, usb_p1_w)
+	AM_RANGE(MCS48_PORT_P2, MCS48_PORT_P2) AM_DEVWRITE("usbsnd", usb_p2_w)
+	AM_RANGE(MCS48_PORT_T1, MCS48_PORT_T1) AM_DEVREAD("usbsnd", usb_t1_r)
 ADDRESS_MAP_END
 
 
@@ -922,10 +1018,10 @@ MACHINE_CONFIG_FRAGMENT( sega_universal_sound_board )
 	MCFG_CPU_PROGRAM_MAP(usb_map)
 	MCFG_CPU_IO_MAP(usb_portmap)
 
-	MCFG_TIMER_ADD_PERIODIC("usb_timer", increment_t1_clock, HZ(USB_2MHZ_CLOCK / 256))
+	MCFG_TIMER_ADD_PERIODIC("usb_timer", increment_t1_clock, attotime::from_hz(USB_2MHZ_CLOCK / 256))
 
 	/* sound hardware */
-	MCFG_SOUND_ADD("usbsnd", USB, 0)
+	MCFG_SOUND_ADD("usbsnd", SEGAUSB, 0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_CONFIG_END
 
