@@ -47,21 +47,25 @@
     STATIC GLOBALS
 ****************************************************************************/
 
-static UINT8 williams_sound_int_state;
+typedef struct _williams_audio_state williams_audio_state;
+struct _williams_audio_state
+{
+	UINT8 sound_int_state;
 
-static UINT8 audio_talkback;
-static UINT8 audio_sync;
-
-static device_t *sound_cpu;
-static device_t *soundalt_cpu;
+	UINT8 audio_talkback;
+	UINT8 audio_sync;
 
+	device_t *sound_cpu;
+	device_t *soundalt_cpu;
+};
 
+static williams_audio_state audio;
 
 /***************************************************************************
     FUNCTION PROTOTYPES
 ****************************************************************************/
 
-static void init_audio_state(running_machine *machine);
+static void init_audio_state(running_machine &machine);
 
 static void cvsd_ym2151_irq(device_t *device, int state);
 static void adpcm_ym2151_irq(device_t *device, int state);
@@ -95,10 +99,10 @@ static WRITE8_HANDLER( narc_slave_sync_w );
 ****************************************************************************/
 
 /* CVSD readmem/writemem structures */
-static ADDRESS_MAP_START( williams_cvsd_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( williams_cvsd_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_MIRROR(0x1800) AM_RAM
 	AM_RANGE(0x2000, 0x2001) AM_MIRROR(0x1ffe) AM_DEVREADWRITE("ymsnd", ym2151_r, ym2151_w)
-	AM_RANGE(0x4000, 0x4003) AM_MIRROR(0x1ffc) AM_DEVREADWRITE("cvsdpia", pia6821_r, pia6821_w)
+	AM_RANGE(0x4000, 0x4003) AM_MIRROR(0x1ffc) AM_DEVREADWRITE_MODERN("cvsdpia", pia6821_device, read, write)
 	AM_RANGE(0x6000, 0x6000) AM_MIRROR(0x07ff) AM_DEVWRITE("cvsd", cvsd_digit_clock_clear_w)
 	AM_RANGE(0x6800, 0x6800) AM_MIRROR(0x07ff) AM_DEVWRITE("cvsd", cvsd_clock_set_w)
 	AM_RANGE(0x7800, 0x7800) AM_MIRROR(0x07ff) AM_WRITE(cvsd_bank_select_w)
@@ -107,7 +111,7 @@ ADDRESS_MAP_END
 
 
 /* NARC master readmem/writemem structures */
-static ADDRESS_MAP_START( williams_narc_master_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( williams_narc_master_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM
 	AM_RANGE(0x2000, 0x2001) AM_MIRROR(0x03fe) AM_DEVREADWRITE("ymsnd", ym2151_r, ym2151_w)
 	AM_RANGE(0x2800, 0x2800) AM_MIRROR(0x03ff) AM_WRITE(narc_master_talkback_w)
@@ -121,7 +125,7 @@ static ADDRESS_MAP_START( williams_narc_master_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 /* NARC slave readmem/writemem structures */
-static ADDRESS_MAP_START( williams_narc_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( williams_narc_slave_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM
 	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x03ff) AM_DEVWRITE("cvsd", cvsd_clock_set_w)
 	AM_RANGE(0x2400, 0x2400) AM_MIRROR(0x03ff) AM_DEVWRITE("cvsd", cvsd_digit_clock_clear_w)
@@ -136,7 +140,7 @@ ADDRESS_MAP_END
 
 
 /* ADPCM readmem/writemem structures */
-static ADDRESS_MAP_START( williams_adpcm_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( williams_adpcm_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM
 	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x03ff) AM_WRITE(adpcm_bank_select_w)
 	AM_RANGE(0x2400, 0x2401) AM_MIRROR(0x03fe) AM_DEVREADWRITE("ymsnd", ym2151_r, ym2151_w)
@@ -264,17 +268,18 @@ MACHINE_CONFIG_END
     INITIALIZATION
 ****************************************************************************/
 
-void williams_cvsd_init(running_machine *machine)
+void williams_cvsd_init(running_machine &machine)
 {
+	williams_audio_state *state = &audio;
 	UINT8 *ROM;
 	int bank;
 
 	/* configure the CPU */
-	sound_cpu = machine->device("cvsdcpu");
-	soundalt_cpu = NULL;
+	state->sound_cpu = machine.device("cvsdcpu");
+	state->soundalt_cpu = NULL;
 
 	/* configure master CPU banks */
-	ROM = machine->region("cvsdcpu")->base();
+	ROM = machine.region("cvsdcpu")->base();
 	for (bank = 0; bank < 16; bank++)
 	{
 		/*
@@ -288,25 +293,26 @@ void williams_cvsd_init(running_machine *machine)
 	memory_set_bank(machine, "bank5", 0);
 
 	/* reset the IRQ state */
-	pia6821_ca1_w(machine->device("cvsdpia"), 1);
+	machine.device<pia6821_device>("cvsdpia")->ca1_w(1);
 
 	/* register for save states */
-	state_save_register_global(machine, williams_sound_int_state);
-	state_save_register_global(machine, audio_talkback);
+	state_save_register_global(machine, state->sound_int_state);
+	state_save_register_global(machine, state->audio_talkback);
 }
 
 
-void williams_narc_init(running_machine *machine)
+void williams_narc_init(running_machine &machine)
 {
+	williams_audio_state *state = &audio;
 	UINT8 *ROM;
 	int bank;
 
 	/* configure the CPU */
-	sound_cpu = machine->device("narc1cpu");
-	soundalt_cpu = machine->device("narc2cpu");
+	state->sound_cpu = machine.device("narc1cpu");
+	state->soundalt_cpu = machine.device("narc2cpu");
 
 	/* configure master CPU banks */
-	ROM = machine->region("narc1cpu")->base();
+	ROM = machine.region("narc1cpu")->base();
 	for (bank = 0; bank < 16; bank++)
 	{
 		/*
@@ -320,7 +326,7 @@ void williams_narc_init(running_machine *machine)
 	memory_set_bankptr(machine, "bank6", &ROM[0x10000 + 0x4000 + 0x8000 + 0x10000 + 0x20000 * 3]);
 
 	/* configure slave CPU banks */
-	ROM = machine->region("narc2cpu")->base();
+	ROM = machine.region("narc2cpu")->base();
 	for (bank = 0; bank < 16; bank++)
 	{
 		/*
@@ -334,28 +340,29 @@ void williams_narc_init(running_machine *machine)
 	memory_set_bankptr(machine, "bank8", &ROM[0x10000 + 0x4000 + 0x8000 + 0x10000 + 0x20000 * 3]);
 
 	/* register for save states */
-	state_save_register_global(machine, williams_sound_int_state);
-	state_save_register_global(machine, audio_talkback);
-	state_save_register_global(machine, audio_sync);
+	state_save_register_global(machine, state->sound_int_state);
+	state_save_register_global(machine, state->audio_talkback);
+	state_save_register_global(machine, state->audio_sync);
 }
 
 
-void williams_adpcm_init(running_machine *machine)
+void williams_adpcm_init(running_machine &machine)
 {
+	williams_audio_state *state = &audio;
 	UINT8 *ROM;
 
 	/* configure the CPU */
-	sound_cpu = machine->device("adpcm");
-	soundalt_cpu = NULL;
+	state->sound_cpu = machine.device("adpcm");
+	state->soundalt_cpu = NULL;
 
 	/* configure banks */
-	ROM = machine->region("adpcm")->base();
+	ROM = machine.region("adpcm")->base();
 	memory_configure_bank(machine, "bank5", 0, 8, &ROM[0x10000], 0x8000);
 	memory_set_bankptr(machine, "bank6", &ROM[0x10000 + 0x4000 + 7 * 0x8000]);
 
 	/* expand ADPCM data */
 	/* it is assumed that U12 is loaded @ 0x00000 and U13 is loaded @ 0x40000 */
-	ROM = machine->region("oki")->base();
+	ROM = machine.region("oki")->base();
 	memcpy(ROM + 0x1c0000, ROM + 0x080000, 0x20000);	/* expand individual banks */
 	memcpy(ROM + 0x180000, ROM + 0x0a0000, 0x20000);
 	memcpy(ROM + 0x140000, ROM + 0x0c0000, 0x20000);
@@ -373,29 +380,33 @@ void williams_adpcm_init(running_machine *machine)
 	memcpy(ROM + 0x020000, ROM + 0x060000, 0x20000);
 
 	/* register for save states */
-	state_save_register_global(machine, williams_sound_int_state);
-	state_save_register_global(machine, audio_talkback);
+	state_save_register_global(machine, state->sound_int_state);
+	state_save_register_global(machine, state->audio_talkback);
 }
 
 
-static void init_audio_state(running_machine *machine)
+static void init_audio_state(running_machine &machine)
 {
+	williams_audio_state *state = &audio;
+	device_t *sound_cpu = state->sound_cpu;
+	device_t *soundalt_cpu = state->soundalt_cpu;
+
 	/* reset the YM2151 state */
 	devtag_reset(machine, "ymsnd");
 
 	/* clear all the interrupts */
-	williams_sound_int_state = 0;
+	state->sound_int_state = 0;
 	if (sound_cpu != NULL)
 	{
-		cpu_set_input_line(sound_cpu, M6809_FIRQ_LINE, CLEAR_LINE);
-		cpu_set_input_line(sound_cpu, M6809_IRQ_LINE, CLEAR_LINE);
-		cpu_set_input_line(sound_cpu, INPUT_LINE_NMI, CLEAR_LINE);
+		device_set_input_line(sound_cpu, M6809_FIRQ_LINE, CLEAR_LINE);
+		device_set_input_line(sound_cpu, M6809_IRQ_LINE, CLEAR_LINE);
+		device_set_input_line(sound_cpu, INPUT_LINE_NMI, CLEAR_LINE);
 	}
 	if (soundalt_cpu != NULL)
 	{
-		cpu_set_input_line(soundalt_cpu, M6809_FIRQ_LINE, CLEAR_LINE);
-		cpu_set_input_line(soundalt_cpu, M6809_IRQ_LINE, CLEAR_LINE);
-		cpu_set_input_line(soundalt_cpu, INPUT_LINE_NMI, CLEAR_LINE);
+		device_set_input_line(soundalt_cpu, M6809_FIRQ_LINE, CLEAR_LINE);
+		device_set_input_line(soundalt_cpu, M6809_IRQ_LINE, CLEAR_LINE);
+		device_set_input_line(soundalt_cpu, INPUT_LINE_NMI, CLEAR_LINE);
 	}
 }
 
@@ -407,19 +418,23 @@ static void init_audio_state(running_machine *machine)
 
 static void cvsd_ym2151_irq(device_t *device, int state)
 {
-	pia6821_ca1_w(device->machine->device("cvsdpia"), !state);
+	device->machine().device<pia6821_device>("cvsdpia")->ca1_w(!state);
 }
 
 
 static WRITE_LINE_DEVICE_HANDLER( cvsd_irqa )
 {
-	cpu_set_input_line(sound_cpu, M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	williams_audio_state *sndstate = &audio;
+
+	device_set_input_line(sndstate->sound_cpu, M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static WRITE_LINE_DEVICE_HANDLER( cvsd_irqb )
 {
-	cpu_set_input_line(sound_cpu, INPUT_LINE_NMI, state ? ASSERT_LINE : CLEAR_LINE);
+	williams_audio_state *sndstate = &audio;
+
+	device_set_input_line(sndstate->sound_cpu, INPUT_LINE_NMI, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -430,7 +445,9 @@ static WRITE_LINE_DEVICE_HANDLER( cvsd_irqb )
 
 static void adpcm_ym2151_irq(device_t *device, int state)
 {
-	cpu_set_input_line(sound_cpu, M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	williams_audio_state *sndstate = &audio;
+
+	device_set_input_line(sndstate->sound_cpu, M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -441,13 +458,15 @@ static void adpcm_ym2151_irq(device_t *device, int state)
 
 static WRITE8_HANDLER( cvsd_bank_select_w )
 {
-	memory_set_bank(space->machine, "bank5", data & 0x0f);
+	memory_set_bank(space->machine(), "bank5", data & 0x0f);
 }
 
 
 static WRITE8_DEVICE_HANDLER( cvsd_talkback_w )
 {
-	audio_talkback = data;
+	williams_audio_state *state = &audio;
+
+	state->audio_talkback = data;
 	logerror("CVSD Talkback = %02X\n", data);
 }
 
@@ -471,33 +490,34 @@ static WRITE8_DEVICE_HANDLER( cvsd_clock_set_w )
 
 static TIMER_CALLBACK( williams_cvsd_delayed_data_w )
 {
-	device_t *pia = machine->device("cvsdpia");
-	pia6821_portb_w(pia, 0, param & 0xff);
-	pia6821_cb1_w(pia, (param >> 8) & 1);
-	pia6821_cb2_w(pia, (param >> 9) & 1);
+	pia6821_device *pia = machine.device<pia6821_device>("cvsdpia");
+	pia->portb_w(param & 0xff);
+	pia->cb1_w((param >> 8) & 1);
+	pia->cb2_w((param >> 9) & 1);
 }
 
 
-void williams_cvsd_data_w(running_machine *machine, int data)
+void williams_cvsd_data_w(running_machine &machine, int data)
 {
-	timer_call_after_resynch(machine, NULL, data, williams_cvsd_delayed_data_w);
+	machine.scheduler().synchronize(FUNC(williams_cvsd_delayed_data_w), data);
 }
 
 
-void williams_cvsd_reset_w(int state)
+void williams_cvsd_reset_w(running_machine &machine, int state)
 {
-	address_space *space = cpu_get_address_space(sound_cpu, ADDRESS_SPACE_PROGRAM);
+	williams_audio_state *sndstate = &audio;
+	address_space *space = sndstate->sound_cpu->memory().space(AS_PROGRAM);
 
 	/* going high halts the CPU */
 	if (state)
 	{
 		cvsd_bank_select_w(space, 0, 0);
-		init_audio_state(space->machine);
-		cpu_set_input_line(space->cpu, INPUT_LINE_RESET, ASSERT_LINE);
+		init_audio_state(space->machine());
+		device_set_input_line(&space->device(), INPUT_LINE_RESET, ASSERT_LINE);
 	}
 	/* going low resets and reactivates the CPU */
 	else
-		cpu_set_input_line(space->cpu, INPUT_LINE_RESET, CLEAR_LINE);
+		device_set_input_line(&space->device(), INPUT_LINE_RESET, CLEAR_LINE);
 }
 
 
@@ -508,54 +528,66 @@ void williams_cvsd_reset_w(int state)
 
 static WRITE8_HANDLER( narc_master_bank_select_w )
 {
-	memory_set_bank(space->machine, "bank5", data & 0x0f);
+	memory_set_bank(space->machine(), "bank5", data & 0x0f);
 }
 
 
 static WRITE8_HANDLER( narc_slave_bank_select_w )
 {
-	memory_set_bank(space->machine, "bank7", data & 0x0f);
+	memory_set_bank(space->machine(), "bank7", data & 0x0f);
 }
 
 
 static READ8_HANDLER( narc_command_r )
 {
-	cpu_set_input_line(sound_cpu, M6809_IRQ_LINE, CLEAR_LINE);
-	williams_sound_int_state = 0;
+	williams_audio_state *state = &audio;
+
+	device_set_input_line(state->sound_cpu, M6809_IRQ_LINE, CLEAR_LINE);
+	state->sound_int_state = 0;
 	return soundlatch_r(space, 0);
 }
 
 
 static WRITE8_HANDLER( narc_command2_w )
 {
+	williams_audio_state *state = &audio;
+
 	soundlatch2_w(space, 0, data & 0xff);
-	cpu_set_input_line(soundalt_cpu, M6809_FIRQ_LINE, ASSERT_LINE);
+	device_set_input_line(state->soundalt_cpu, M6809_FIRQ_LINE, ASSERT_LINE);
 }
 
 
 static READ8_HANDLER( narc_command2_r )
 {
-	cpu_set_input_line(soundalt_cpu, M6809_FIRQ_LINE, CLEAR_LINE);
+	williams_audio_state *state = &audio;
+
+	device_set_input_line(state->soundalt_cpu, M6809_FIRQ_LINE, CLEAR_LINE);
 	return soundlatch2_r(space, 0);
 }
 
 
 static WRITE8_HANDLER( narc_master_talkback_w )
 {
-	audio_talkback = data;
+	williams_audio_state *state = &audio;
+
+	state->audio_talkback = data;
 	logerror("Master Talkback = %02X\n", data);
 }
 
 
 static TIMER_CALLBACK( narc_sync_clear )
 {
-	audio_sync &= ~param;
+	williams_audio_state *state = &audio;
+
+	state->audio_sync &= ~param;
 }
 
 static WRITE8_HANDLER( narc_master_sync_w )
 {
-	timer_set(space->machine, double_to_attotime(TIME_OF_74LS123(180000, 0.000001)), NULL, 0x01, narc_sync_clear);
-	audio_sync |= 0x01;
+	williams_audio_state *state = &audio;
+
+	space->machine().scheduler().timer_set(attotime::from_double(TIME_OF_74LS123(180000, 0.000001)), FUNC(narc_sync_clear), 0x01);
+	state->audio_sync |= 0x01;
 	logerror("Master sync = %02X\n", data);
 }
 
@@ -568,8 +600,10 @@ static WRITE8_HANDLER( narc_slave_talkback_w )
 
 static WRITE8_HANDLER( narc_slave_sync_w )
 {
-	timer_set(space->machine, double_to_attotime(TIME_OF_74LS123(180000, 0.000001)), NULL, 0x02, narc_sync_clear);
-	audio_sync |= 0x02;
+	williams_audio_state *state = &audio;
+
+	space->machine().scheduler().timer_set(attotime::from_double(TIME_OF_74LS123(180000, 0.000001)), FUNC(narc_sync_clear), 0x02);
+	state->audio_sync |= 0x02;
 	logerror("Slave sync = %02X\n", data);
 }
 
@@ -579,44 +613,52 @@ static WRITE8_HANDLER( narc_slave_sync_w )
     NARC COMMUNICATIONS
 ****************************************************************************/
 
-void williams_narc_data_w(int data)
+void williams_narc_data_w(running_machine &machine, int data)
 {
-	address_space *space = cpu_get_address_space(sound_cpu, ADDRESS_SPACE_PROGRAM);
+	williams_audio_state *state = &audio;
+	device_t *sound_cpu = state->sound_cpu;
+	address_space *space = sound_cpu->memory().space(AS_PROGRAM);
 
 	soundlatch_w(space, 0, data & 0xff);
-	cpu_set_input_line(sound_cpu, INPUT_LINE_NMI, (data & 0x100) ? CLEAR_LINE : ASSERT_LINE);
+	device_set_input_line(sound_cpu, INPUT_LINE_NMI, (data & 0x100) ? CLEAR_LINE : ASSERT_LINE);
 	if (!(data & 0x200))
 	{
-		cpu_set_input_line(sound_cpu, M6809_IRQ_LINE, ASSERT_LINE);
-		williams_sound_int_state = 1;
+		device_set_input_line(sound_cpu, M6809_IRQ_LINE, ASSERT_LINE);
+		state->sound_int_state = 1;
 	}
 }
 
 
-void williams_narc_reset_w(int state)
+void williams_narc_reset_w(running_machine &machine, int state)
 {
+	williams_audio_state *sndstate = &audio;
+	device_t *sound_cpu = sndstate->sound_cpu;
+	device_t *soundalt_cpu = sndstate->soundalt_cpu;
+
 	/* going high halts the CPU */
 	if (state)
 	{
-		address_space *space = cpu_get_address_space(sound_cpu, ADDRESS_SPACE_PROGRAM);
+		address_space *space = sound_cpu->memory().space(AS_PROGRAM);
 		narc_master_bank_select_w(space, 0, 0);
 		narc_slave_bank_select_w(space, 0, 0);
-		init_audio_state(space->machine);
-		cpu_set_input_line(sound_cpu, INPUT_LINE_RESET, ASSERT_LINE);
-		cpu_set_input_line(soundalt_cpu, INPUT_LINE_RESET, ASSERT_LINE);
+		init_audio_state(space->machine());
+		device_set_input_line(sound_cpu, INPUT_LINE_RESET, ASSERT_LINE);
+		device_set_input_line(soundalt_cpu, INPUT_LINE_RESET, ASSERT_LINE);
 	}
 	/* going low resets and reactivates the CPU */
 	else
 	{
-		cpu_set_input_line(sound_cpu, INPUT_LINE_RESET, CLEAR_LINE);
-		cpu_set_input_line(soundalt_cpu, INPUT_LINE_RESET, CLEAR_LINE);
+		device_set_input_line(sound_cpu, INPUT_LINE_RESET, CLEAR_LINE);
+		device_set_input_line(soundalt_cpu, INPUT_LINE_RESET, CLEAR_LINE);
 	}
 }
 
 
-int williams_narc_talkback_r(void)
+int williams_narc_talkback_r(running_machine &machine)
 {
-	return audio_talkback | (audio_sync << 8);
+	williams_audio_state *state = &audio;
+
+	return state->audio_talkback | (state->audio_sync << 8);
 }
 
 
@@ -627,7 +669,7 @@ int williams_narc_talkback_r(void)
 
 static WRITE8_HANDLER( adpcm_bank_select_w )
 {
-	memory_set_bank(space->machine, "bank5", data & 0x07);
+	memory_set_bank(space->machine(), "bank5", data & 0x07);
 }
 
 
@@ -639,24 +681,29 @@ static WRITE8_DEVICE_HANDLER( adpcm_6295_bank_select_w )
 
 static TIMER_CALLBACK( clear_irq_state )
 {
-	williams_sound_int_state = 0;
+	williams_audio_state *state = &audio;
+
+	state->sound_int_state = 0;
 }
 
 
 static READ8_HANDLER( adpcm_command_r )
 {
-	cpu_set_input_line(sound_cpu, M6809_IRQ_LINE, CLEAR_LINE);
+	williams_audio_state *state = &audio;
+	device_t *sound_cpu = state->sound_cpu;
+	device_set_input_line(sound_cpu, M6809_IRQ_LINE, CLEAR_LINE);
 
 	/* don't clear the external IRQ state for a short while; this allows the
        self-tests to pass */
-	timer_set(space->machine, ATTOTIME_IN_USEC(10), NULL, 0, clear_irq_state);
+	space->machine().scheduler().timer_set(attotime::from_usec(10), FUNC(clear_irq_state));
 	return soundlatch_r(space, 0);
 }
 
 
 static WRITE8_HANDLER( adpcm_talkback_w )
 {
-	audio_talkback = data;
+	williams_audio_state *state = &audio;
+	state->audio_talkback = data;
 	logerror("ADPCM Talkback = %02X\n", data);
 }
 
@@ -666,36 +713,42 @@ static WRITE8_HANDLER( adpcm_talkback_w )
     ADPCM COMMUNICATIONS
 ****************************************************************************/
 
-void williams_adpcm_data_w(int data)
+void williams_adpcm_data_w(running_machine &machine, int data)
 {
-	address_space *space = cpu_get_address_space(sound_cpu, ADDRESS_SPACE_PROGRAM);
+	williams_audio_state *state = &audio;
+	device_t *sound_cpu = state->sound_cpu;
+	address_space *space = sound_cpu->memory().space(AS_PROGRAM);
 	soundlatch_w(space, 0, data & 0xff);
 	if (!(data & 0x200))
 	{
-		cpu_set_input_line(sound_cpu, M6809_IRQ_LINE, ASSERT_LINE);
-		williams_sound_int_state = 1;
-		cpuexec_boost_interleave(space->machine, attotime_zero, ATTOTIME_IN_USEC(100));
+		device_set_input_line(sound_cpu, M6809_IRQ_LINE, ASSERT_LINE);
+		state->sound_int_state = 1;
+		space->machine().scheduler().boost_interleave(attotime::zero, attotime::from_usec(100));
 	}
 }
 
 
-void williams_adpcm_reset_w(int state)
+void williams_adpcm_reset_w(running_machine &machine, int state)
 {
+	williams_audio_state *sndstate = &audio;
+	device_t *sound_cpu = sndstate->sound_cpu;
+
 	/* going high halts the CPU */
 	if (state)
 	{
-		address_space *space = cpu_get_address_space(sound_cpu, ADDRESS_SPACE_PROGRAM);
+		address_space *space = sound_cpu->memory().space(AS_PROGRAM);
 		adpcm_bank_select_w(space, 0, 0);
-		init_audio_state(space->machine);
-		cpu_set_input_line(sound_cpu, INPUT_LINE_RESET, ASSERT_LINE);
+		init_audio_state(space->machine());
+		device_set_input_line(sound_cpu, INPUT_LINE_RESET, ASSERT_LINE);
 	}
 	/* going low resets and reactivates the CPU */
 	else
-		cpu_set_input_line(sound_cpu, INPUT_LINE_RESET, CLEAR_LINE);
+		device_set_input_line(sound_cpu, INPUT_LINE_RESET, CLEAR_LINE);
 }
 
 
-int williams_adpcm_sound_irq_r(void)
+int williams_adpcm_sound_irq_r(running_machine &machine)
 {
-	return williams_sound_int_state;
+	williams_audio_state *state = &audio;
+	return state->sound_int_state;
 }
