@@ -448,11 +448,10 @@ static MACHINE_CONFIG_START( drill, _2mindril_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500)) /* inaccurate, same as Taito F3? (needs screen raw params anyway) */
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(40*8+48*2, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(46, 40*8-1 + 46, 24, 24+224-1)
-	MCFG_SCREEN_UPDATE(f3)
-	MCFG_SCREEN_EOF(f3)
+	MCFG_SCREEN_UPDATE_STATIC(f3)
+	MCFG_SCREEN_VBLANK_STATIC(f3)
 
 	MCFG_PALETTE_LENGTH(0x2000)
 
