@@ -481,14 +481,14 @@ static WRITE8_HANDLER( fclown_videoram_w )
 {
 	_5clown_state *state = space->machine().driver_data<_5clown_state>();
 	state->m_videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
+	state->m_bg_tilemap->mark_tile_dirty(offset);
 }
 
 static WRITE8_HANDLER( fclown_colorram_w )
 {
 	_5clown_state *state = space->machine().driver_data<_5clown_state>();
 	state->m_colorram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
+	state->m_bg_tilemap->mark_tile_dirty(offset);
 }
 
 
@@ -521,10 +521,10 @@ static VIDEO_START(fclown)
 }
 
 
-static SCREEN_UPDATE( fclown )
+static SCREEN_UPDATE_IND16( fclown )
 {
-	_5clown_state *state = screen->machine().driver_data<_5clown_state>();
-	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
+	_5clown_state *state = screen.machine().driver_data<_5clown_state>();
+	state->m_bg_tilemap->draw(bitmap, cliprect, 0, 0);
 	return 0;
 }
 
@@ -1068,10 +1068,9 @@ static MACHINE_CONFIG_START( fclown, _5clown_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE((39+1)*8, (31+1)*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(fclown)
+	MCFG_SCREEN_UPDATE_STATIC(fclown)
 
 	MCFG_GFXDECODE(fclown)
 	MCFG_PALETTE_LENGTH(256)
