@@ -24,22 +24,24 @@
 #include "cpu/m68000/m68000.h"
 #include "render.h"
 #include "includes/amiga.h"
-#include "machine/laserdsc.h"
+#include "machine/ldstub.h"
 #include "machine/6526cia.h"
 #include "machine/nvram.h"
+#include "machine/amigafdc.h"
 
 
 class alg_state : public amiga_state
 {
 public:
-	alg_state(running_machine &machine, const driver_device_config_base &config)
-		: amiga_state(machine, config) { }
+	alg_state(const machine_config &mconfig, device_type type, const char *tag)
+		: amiga_state(mconfig, type, tag),
+		  m_laserdisc(*this, "laserdisc") { }
 
 
-	device_t *laserdisc;
-	emu_timer *serial_timer;
-	UINT8 serial_timer_active;
-	UINT16 input_select;
+	required_device<sony_ldp1450_device> m_laserdisc;
+	emu_timer *m_serial_timer;
+	UINT8 m_serial_timer_active;
+	UINT16 m_input_select;
 };
 
 static TIMER_CALLBACK( response_timer );
@@ -56,14 +58,14 @@ static int get_lightgun_pos(screen_device &screen, int player, int *x, int *y)
 {
 	const rectangle &visarea = screen.visible_area();
 
-	int xpos = input_port_read_safe(screen.machine, (player == 0) ? "GUN1X" : "GUN2X", 0xffffffff);
-	int ypos = input_port_read_safe(screen.machine, (player == 0) ? "GUN1Y" : "GUN2Y", 0xffffffff);
+	int xpos = input_port_read_safe(screen.machine(), (player == 0) ? "GUN1X" : "GUN2X", 0xffffffff);
+	int ypos = input_port_read_safe(screen.machine(), (player == 0) ? "GUN1Y" : "GUN2Y", 0xffffffff);
 
 	if (xpos == -1 || ypos == -1)
 		return FALSE;
 
-	*x = visarea.min_x + xpos * (visarea.max_x - visarea.min_x + 1) / 255;
-	*y = visarea.min_y + ypos * (visarea.max_y - visarea.min_y + 1) / 255;
+	*x = visarea.min_x + xpos * visarea.width() / 255;
+	*y = visarea.min_y + ypos * visarea.height() / 255;
 	return TRUE;
 }
 
@@ -95,11 +97,10 @@ static VIDEO_START( alg )
 
 static MACHINE_START( alg )
 {
-	alg_state *state = machine->driver_data<alg_state>();
-	state->laserdisc = machine->device("laserdisc");
+	alg_state *state = machine.driver_data<alg_state>();
 
-	state->serial_timer = timer_alloc(machine, response_timer, NULL);
-	state->serial_timer_active = FALSE;
+	state->m_serial_timer = machine.scheduler().timer_alloc(FUNC(response_timer));
+	state->m_serial_timer_active = FALSE;
 }
 
 
@@ -118,50 +119,50 @@ static MACHINE_RESET( alg )
 
 static TIMER_CALLBACK( response_timer )
 {
-	alg_state *state = machine->driver_data<alg_state>();
+	alg_state *state = machine.driver_data<alg_state>();
 
 	/* if we still have data to send, do it now */
-	if (laserdisc_line_r(state->laserdisc, LASERDISC_LINE_DATA_AVAIL) == ASSERT_LINE)
+	if (state->m_laserdisc->data_available_r() == ASSERT_LINE)
 	{
-		UINT8 data = laserdisc_data_r(state->laserdisc);
+		UINT8 data = state->m_laserdisc->data_r();
 		if (data != 0x0a)
 			mame_printf_debug("Sending serial data = %02X\n", data);
 		amiga_serial_in_w(machine, data);
 	}
 
 	/* if there's more to come, set another timer */
-	if (laserdisc_line_r(state->laserdisc, LASERDISC_LINE_DATA_AVAIL) == ASSERT_LINE)
-		timer_adjust_oneshot(state->serial_timer, amiga_get_serial_char_period(machine), 0);
+	if (state->m_laserdisc->data_available_r() == ASSERT_LINE)
+		state->m_serial_timer->adjust(amiga_get_serial_char_period(machine));
 	else
-		state->serial_timer_active = FALSE;
+		state->m_serial_timer_active = FALSE;
 }
 
 
-static void vsync_callback(running_machine *machine)
+static void vsync_callback(running_machine &machine)
 {
-	alg_state *state = machine->driver_data<alg_state>();
+	alg_state *state = machine.driver_data<alg_state>();
 
 	/* if we have data available, set a timer to read it */
-	if (!state->serial_timer_active && laserdisc_line_r(state->laserdisc, LASERDISC_LINE_DATA_AVAIL) == ASSERT_LINE)
+	if (!state->m_serial_timer_active && state->m_laserdisc->data_available_r() == ASSERT_LINE)
 	{
-		timer_adjust_oneshot(state->serial_timer, amiga_get_serial_char_period(machine), 0);
-		state->serial_timer_active = TRUE;
+		state->m_serial_timer->adjust(amiga_get_serial_char_period(machine));
+		state->m_serial_timer_active = TRUE;
 	}
 }
 
 
-static void serial_w(running_machine *machine, UINT16 data)
+static void serial_w(running_machine &machine, UINT16 data)
 {
-	alg_state *state = machine->driver_data<alg_state>();
+	alg_state *state = machine.driver_data<alg_state>();
 
 	/* write to the laserdisc player */
-	laserdisc_data_w(state->laserdisc, data & 0xff);
+	state->m_laserdisc->data_w(data & 0xff);
 
 	/* if we have data available, set a timer to read it */
-	if (!state->serial_timer_active && laserdisc_line_r(state->laserdisc, LASERDISC_LINE_DATA_AVAIL) == ASSERT_LINE)
+	if (!state->m_serial_timer_active && state->m_laserdisc->data_available_r() == ASSERT_LINE)
 	{
-		timer_adjust_oneshot(state->serial_timer, amiga_get_serial_char_period(machine), 0);
-		state->serial_timer_active = TRUE;
+		state->m_serial_timer->adjust(amiga_get_serial_char_period(machine));
+		state->m_serial_timer_active = TRUE;
 	}
 }
 
@@ -173,42 +174,42 @@ static void serial_w(running_machine *machine, UINT16 data)
  *
  *************************************/
 
-static void alg_potgo_w(running_machine *machine, UINT16 data)
+static void alg_potgo_w(running_machine &machine, UINT16 data)
 {
-	alg_state *state = machine->driver_data<alg_state>();
+	alg_state *state = machine.driver_data<alg_state>();
 
 	/* bit 15 controls whether pin 9 is input/output */
 	/* bit 14 controls the value, which selects which player's controls to read */
-	state->input_select = (data & 0x8000) ? ((data >> 14) & 1) : 0;
+	state->m_input_select = (data & 0x8000) ? ((data >> 14) & 1) : 0;
 }
 
 
 static CUSTOM_INPUT( lightgun_pos_r )
 {
-	alg_state *state = field->port->machine->driver_data<alg_state>();
+	alg_state *state = field.machine().driver_data<alg_state>();
 	int x = 0, y = 0;
 
 	/* get the position based on the input select */
-	get_lightgun_pos(*field->port->machine->primary_screen, state->input_select, &x, &y);
+	get_lightgun_pos(*field.machine().primary_screen, state->m_input_select, &x, &y);
 	return (y << 8) | (x >> 2);
 }
 
 
 static CUSTOM_INPUT( lightgun_trigger_r )
 {
-	alg_state *state = field->port->machine->driver_data<alg_state>();
+	alg_state *state = field.machine().driver_data<alg_state>();
 
 	/* read the trigger control based on the input select */
-	return (input_port_read(field->port->machine, "TRIGGERS") >> state->input_select) & 1;
+	return (input_port_read(field.machine(), "TRIGGERS") >> state->m_input_select) & 1;
 }
 
 
 static CUSTOM_INPUT( lightgun_holster_r )
 {
-	alg_state *state = field->port->machine->driver_data<alg_state>();
+	alg_state *state = field.machine().driver_data<alg_state>();
 
 	/* read the holster control based on the input select */
-	return (input_port_read(field->port->machine, "TRIGGERS") >> (2 + state->input_select)) & 1;
+	return (input_port_read(field.machine(), "TRIGGERS") >> (2 + state->m_input_select)) & 1;
 }
 
 
@@ -221,31 +222,31 @@ static CUSTOM_INPUT( lightgun_holster_r )
 
 static WRITE8_DEVICE_HANDLER( alg_cia_0_porta_w )
 {
-	address_space *space = cputag_get_address_space(device->machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = device->machine().device("maincpu")->memory().space(AS_PROGRAM);
 
 	/* switch banks as appropriate */
-	memory_set_bank(device->machine, "bank1", data & 1);
+	memory_set_bank(device->machine(), "bank1", data & 1);
 
 	/* swap the write handlers between ROM and bank 1 based on the bit */
 	if ((data & 1) == 0)
 		/* overlay disabled, map RAM on 0x000000 */
-		memory_install_write_bank(space, 0x000000, 0x07ffff, 0, 0, "bank1");
+		space->install_write_bank(0x000000, 0x07ffff, "bank1");
 
 	else
 		/* overlay enabled, map Amiga system ROM on 0x000000 */
-		memory_unmap_write(space, 0x000000, 0x07ffff, 0, 0);
+		space->unmap_write(0x000000, 0x07ffff);
 }
 
 
 static READ8_DEVICE_HANDLER( alg_cia_0_porta_r )
 {
-	return input_port_read(device->machine, "FIRE") | 0x3f;
+	return input_port_read(device->machine(), "FIRE") | 0x3f;
 }
 
 
 static READ8_DEVICE_HANDLER( alg_cia_0_portb_r )
 {
-	logerror("%s:alg_cia_0_portb_r\n", cpuexec_describe_context(device->machine));
+	logerror("%s:alg_cia_0_portb_r\n", device->machine().describe_context());
 	return 0xff;
 }
 
@@ -253,20 +254,20 @@ static READ8_DEVICE_HANDLER( alg_cia_0_portb_r )
 static WRITE8_DEVICE_HANDLER( alg_cia_0_portb_w )
 {
 	/* parallel port */
-	logerror("%s:alg_cia_0_portb_w(%02x)\n", cpuexec_describe_context(device->machine), data);
+	logerror("%s:alg_cia_0_portb_w(%02x)\n", device->machine().describe_context(), data);
 }
 
 
 static READ8_DEVICE_HANDLER( alg_cia_1_porta_r )
 {
-	logerror("%s:alg_cia_1_porta_r\n", cpuexec_describe_context(device->machine));
+	logerror("%s:alg_cia_1_porta_r\n", device->machine().describe_context());
 	return 0xff;
 }
 
 
 static WRITE8_DEVICE_HANDLER( alg_cia_1_porta_w )
 {
-	logerror("%s:alg_cia_1_porta_w(%02x)\n", cpuexec_describe_context(device->machine), data);
+	logerror("%s:alg_cia_1_porta_w(%02x)\n", device->machine().describe_context(), data);
 }
 
 
@@ -277,11 +278,11 @@ static WRITE8_DEVICE_HANDLER( alg_cia_1_porta_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_map_r1, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( main_map_r1, AS_PROGRAM, 16 )
 	ADDRESS_MAP_UNMAP_HIGH
-	AM_RANGE(0x000000, 0x07ffff) AM_RAMBANK("bank1") AM_BASE_SIZE_MEMBER(alg_state, chip_ram, chip_ram_size)
+	AM_RANGE(0x000000, 0x07ffff) AM_RAMBANK("bank1") AM_BASE_SIZE_MEMBER(alg_state, m_chip_ram, m_chip_ram_size)
 	AM_RANGE(0xbfd000, 0xbfefff) AM_READWRITE(amiga_cia_r, amiga_cia_w)
-	AM_RANGE(0xc00000, 0xdfffff) AM_READWRITE(amiga_custom_r, amiga_custom_w) AM_BASE_MEMBER(alg_state, custom_regs)
+	AM_RANGE(0xc00000, 0xdfffff) AM_READWRITE(amiga_custom_r, amiga_custom_w) AM_BASE_MEMBER(alg_state, m_custom_regs)
 	AM_RANGE(0xe80000, 0xe8ffff) AM_READWRITE(amiga_autoconfig_r, amiga_autoconfig_w)
 	AM_RANGE(0xfc0000, 0xffffff) AM_ROM AM_REGION("user1", 0)			/* System ROM */
 
@@ -290,11 +291,11 @@ static ADDRESS_MAP_START( main_map_r1, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( main_map_r2, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( main_map_r2, AS_PROGRAM, 16 )
 	ADDRESS_MAP_UNMAP_HIGH
-	AM_RANGE(0x000000, 0x07ffff) AM_RAMBANK("bank1") AM_BASE_SIZE_MEMBER(alg_state, chip_ram, chip_ram_size)
+	AM_RANGE(0x000000, 0x07ffff) AM_RAMBANK("bank1") AM_BASE_SIZE_MEMBER(alg_state, m_chip_ram, m_chip_ram_size)
 	AM_RANGE(0xbfd000, 0xbfefff) AM_READWRITE(amiga_cia_r, amiga_cia_w)
-	AM_RANGE(0xc00000, 0xdfffff) AM_READWRITE(amiga_custom_r, amiga_custom_w) AM_BASE_MEMBER(alg_state, custom_regs)
+	AM_RANGE(0xc00000, 0xdfffff) AM_READWRITE(amiga_custom_r, amiga_custom_w) AM_BASE_MEMBER(alg_state, m_custom_regs)
 	AM_RANGE(0xe80000, 0xe8ffff) AM_READWRITE(amiga_autoconfig_r, amiga_autoconfig_w)
 	AM_RANGE(0xfc0000, 0xffffff) AM_ROM AM_REGION("user1", 0)			/* System ROM */
 
@@ -303,11 +304,11 @@ static ADDRESS_MAP_START( main_map_r2, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( main_map_picmatic, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( main_map_picmatic, AS_PROGRAM, 16 )
 	ADDRESS_MAP_UNMAP_HIGH
-	AM_RANGE(0x000000, 0x07ffff) AM_RAMBANK("bank1") AM_BASE_SIZE_MEMBER(alg_state, chip_ram, chip_ram_size)
+	AM_RANGE(0x000000, 0x07ffff) AM_RAMBANK("bank1") AM_BASE_SIZE_MEMBER(alg_state, m_chip_ram, m_chip_ram_size)
 	AM_RANGE(0xbfd000, 0xbfefff) AM_READWRITE(amiga_cia_r, amiga_cia_w)
-	AM_RANGE(0xc00000, 0xdfffff) AM_READWRITE(amiga_custom_r, amiga_custom_w) AM_BASE_MEMBER(alg_state, custom_regs)
+	AM_RANGE(0xc00000, 0xdfffff) AM_READWRITE(amiga_custom_r, amiga_custom_w) AM_BASE_MEMBER(alg_state, m_custom_regs)
 	AM_RANGE(0xe80000, 0xe8ffff) AM_READWRITE(amiga_autoconfig_r, amiga_autoconfig_w)
 	AM_RANGE(0xfc0000, 0xffffff) AM_ROM AM_REGION("user1", 0)			/* System ROM */
 
@@ -436,12 +437,12 @@ static MACHINE_CONFIG_START( alg_r1, alg_state )
 	MCFG_MACHINE_RESET(alg)
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MCFG_LASERDISC_ADD("laserdisc", SONY_LDP1450, "screen", "ldsound")
-	MCFG_LASERDISC_OVERLAY(amiga, 512*2, 262, BITMAP_FORMAT_INDEXED16)
+	MCFG_LASERDISC_LDP1450_ADD("laserdisc")
+	MCFG_LASERDISC_OVERLAY_STATIC(512*2, 262, amiga)
 	MCFG_LASERDISC_OVERLAY_CLIP((129-8)*2, (449+8-1)*2, 44-8, 244+8-1)
 
 	/* video hardware */
-	MCFG_LASERDISC_SCREEN_ADD_NTSC("screen", BITMAP_FORMAT_INDEXED16)
+	MCFG_LASERDISC_SCREEN_ADD_NTSC("screen", "laserdisc")
 	MCFG_SCREEN_REFRESH_RATE(59.997)
 	MCFG_SCREEN_SIZE(512*2, 262)
 	MCFG_SCREEN_VISIBLE_AREA((129-8)*2, (449+8-1)*2, 44-8, 244+8-1)
@@ -460,13 +461,16 @@ static MACHINE_CONFIG_START( alg_r1, alg_state )
 	MCFG_SOUND_ROUTE(2, "rspeaker", 0.25)
 	MCFG_SOUND_ROUTE(3, "lspeaker", 0.25)
 
-	MCFG_SOUND_ADD("ldsound", LASERDISC_SOUND, 0)
+	MCFG_SOUND_MODIFY("laserdisc")
 	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
 	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
 
 	/* cia */
 	MCFG_MOS8520_ADD("cia_0", AMIGA_68000_NTSC_CLOCK / 10, cia_0_intf)
 	MCFG_MOS8520_ADD("cia_1", AMIGA_68000_NTSC_CLOCK / 10, cia_1_intf)
+
+	/* fdc */
+	MCFG_AMIGA_FDC_ADD("fdc", AMIGA_68000_NTSC_CLOCK)
 MACHINE_CONFIG_END
 
 
@@ -678,14 +682,14 @@ ROM_END
  *
  *************************************/
 
-static void alg_init(running_machine *machine)
+static void alg_init(running_machine &machine)
 {
-	alg_state *state = machine->driver_data<alg_state>();
+	alg_state *state = machine.driver_data<alg_state>();
 	static const amiga_machine_interface alg_intf =
 	{
 		ANGUS_CHIP_RAM_MASK,
 		NULL, NULL, alg_potgo_w,
-		NULL, NULL, serial_w,
+		serial_w,
 
 		vsync_callback,
 		NULL,
@@ -695,8 +699,8 @@ static void alg_init(running_machine *machine)
 	amiga_machine_config(machine, &alg_intf);
 
 	/* set up memory */
-	memory_configure_bank(machine, "bank1", 0, 1, state->chip_ram, 0);
-	memory_configure_bank(machine, "bank1", 1, 1, machine->region("user1")->base(), 0);
+	memory_configure_bank(machine, "bank1", 0, 1, state->m_chip_ram, 0);
+	memory_configure_bank(machine, "bank1", 1, 1, machine.region("user1")->base(), 0);
 }
 
 
@@ -709,8 +713,8 @@ static void alg_init(running_machine *machine)
 
 static DRIVER_INIT( palr1 )
 {
-	UINT32 length = machine->region("user2")->bytes();
-	UINT8 *rom = machine->region("user2")->base();
+	UINT32 length = machine.region("user2")->bytes();
+	UINT8 *rom = machine.region("user2")->base();
 	UINT8 *original = auto_alloc_array(machine, UINT8, length);
 	UINT32 srcaddr;
 
@@ -729,8 +733,8 @@ static DRIVER_INIT( palr1 )
 
 static DRIVER_INIT( palr3 )
 {
-	UINT32 length = machine->region("user2")->bytes();
-	UINT8 *rom = machine->region("user2")->base();
+	UINT32 length = machine.region("user2")->bytes();
+	UINT8 *rom = machine.region("user2")->base();
 	UINT8 *original = auto_alloc_array(machine, UINT8, length);
 	UINT32 srcaddr;
 
@@ -748,8 +752,8 @@ static DRIVER_INIT( palr3 )
 
 static DRIVER_INIT( palr6 )
 {
-	UINT32 length = machine->region("user2")->bytes();
-	UINT8 *rom = machine->region("user2")->base();
+	UINT32 length = machine.region("user2")->bytes();
+	UINT8 *rom = machine.region("user2")->base();
 	UINT8 *original = auto_alloc_array(machine, UINT8, length);
 	UINT32 srcaddr;
 
@@ -770,7 +774,7 @@ static DRIVER_INIT( palr6 )
 static DRIVER_INIT( aplatoon )
 {
 	/* NOT DONE TODO FIGURE OUT THE RIGHT ORDER!!!! */
-	UINT8 *rom = machine->region("user2")->base();
+	UINT8 *rom = machine.region("user2")->base();
 	UINT8 *decrypted = auto_alloc_array(machine, UINT8, 0x40000);
 	int i;
 
