@@ -725,7 +725,7 @@ static WRITE8_HANDLER( blitter_txram_w )
 	armedf_state *state = space->machine().driver_data<armedf_state>();
 
 	state->m_text_videoram[offset] = (data & 0xff) | (state->m_text_videoram[offset] & 0xff00);
-	tilemap_mark_tile_dirty(state->m_tx_tilemap, offset);
+	state->m_tx_tilemap->mark_tile_dirty(offset);
 }
 
 static WRITE8_HANDLER( fg_scrollx_w )
@@ -1209,13 +1209,12 @@ static MACHINE_CONFIG_START( terraf, armedf_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(57)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
 
 	MCFG_VIDEO_START(terraf)
-	MCFG_SCREEN_UPDATE(armedf)
-	MCFG_SCREEN_EOF(armedf)
+	MCFG_SCREEN_UPDATE_STATIC(armedf)
+	MCFG_SCREEN_VBLANK_STATIC(armedf)
 
 	MCFG_GFXDECODE(armedf)
 
@@ -1259,13 +1258,12 @@ static MACHINE_CONFIG_START( terrafb, armedf_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(57)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
 
 	MCFG_VIDEO_START(terraf)
-	MCFG_SCREEN_UPDATE(armedf)
-	MCFG_SCREEN_EOF(armedf)
+	MCFG_SCREEN_UPDATE_STATIC(armedf)
+	MCFG_SCREEN_VBLANK_STATIC(armedf)
 
 	MCFG_GFXDECODE(armedf)
 	MCFG_PALETTE_LENGTH(2048)
@@ -1304,13 +1302,12 @@ static MACHINE_CONFIG_START( kozure, armedf_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 ) // 320 x 240, trusted
 
 	MCFG_VIDEO_START(terraf)
-	MCFG_SCREEN_UPDATE(armedf)
-	MCFG_SCREEN_EOF(armedf)
+	MCFG_SCREEN_UPDATE_STATIC(armedf)
+	MCFG_SCREEN_VBLANK_STATIC(armedf)
 
 	MCFG_GFXDECODE(armedf)
 	MCFG_PALETTE_LENGTH(2048)
@@ -1349,13 +1346,12 @@ static MACHINE_CONFIG_START( armedf, armedf_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(57)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
 
 	MCFG_VIDEO_START(armedf)
-	MCFG_SCREEN_UPDATE(armedf)
-	MCFG_SCREEN_EOF(armedf)
+	MCFG_SCREEN_UPDATE_STATIC(armedf)
+	MCFG_SCREEN_VBLANK_STATIC(armedf)
 
 	MCFG_GFXDECODE(armedf)
 	MCFG_PALETTE_LENGTH(2048)
@@ -1394,13 +1390,12 @@ static MACHINE_CONFIG_START( cclimbr2, armedf_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
 
 	MCFG_VIDEO_START(terraf)
-	MCFG_SCREEN_UPDATE(armedf)
-	MCFG_SCREEN_EOF(armedf)
+	MCFG_SCREEN_UPDATE_STATIC(armedf)
+	MCFG_SCREEN_VBLANK_STATIC(armedf)
 
 	MCFG_GFXDECODE(armedf)
 	MCFG_PALETTE_LENGTH(2048)
@@ -1439,13 +1434,12 @@ static MACHINE_CONFIG_START( legion, armedf_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
 
 	MCFG_VIDEO_START(terraf)
-	MCFG_SCREEN_UPDATE(armedf)
-	MCFG_SCREEN_EOF(armedf)
+	MCFG_SCREEN_UPDATE_STATIC(armedf)
+	MCFG_SCREEN_VBLANK_STATIC(armedf)
 
 	MCFG_GFXDECODE(armedf)
 	MCFG_PALETTE_LENGTH(2048)
@@ -1484,13 +1478,12 @@ static MACHINE_CONFIG_START( legiono, armedf_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
 
 	MCFG_VIDEO_START(terraf)
-	MCFG_SCREEN_UPDATE(armedf)
-	MCFG_SCREEN_EOF(armedf)
+	MCFG_SCREEN_UPDATE_STATIC(armedf)
+	MCFG_SCREEN_VBLANK_STATIC(armedf)
 
 	MCFG_GFXDECODE(armedf)
 	MCFG_PALETTE_LENGTH(2048)
@@ -1544,13 +1537,12 @@ static MACHINE_CONFIG_START( bigfghtr, bigfghtr_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(57)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
 
 	MCFG_VIDEO_START(armedf)
-	MCFG_SCREEN_UPDATE(armedf)
-	MCFG_SCREEN_EOF(armedf)
+	MCFG_SCREEN_UPDATE_STATIC(armedf)
+	MCFG_SCREEN_VBLANK_STATIC(armedf)
 
 	MCFG_GFXDECODE(armedf)
 	MCFG_PALETTE_LENGTH(2048)
@@ -1691,7 +1683,7 @@ ROM_START( terrafu ) /* Bootleg of the USA version?, uses some roms common to bo
 	ROM_LOAD( "tf-002.9d", 0x10000, 0x10000, CRC(148aa0c5) SHA1(8d8a565540e91b384a9c154522501921b7da4d4e) )
 
 	ROM_REGION( 0x4000, "blit_data", 0 )	/* data for mcu/blitter */
-	ROM_LOAD( "tf-10.11c", 0x0000, 0x4000, CRC(ac705812) SHA1(65be46ee959d8478cb6dffb25e61f7742276997b) )
+	ROM_LOAD( "10.11c", 0x0000, 0x4000, CRC(ac705812) SHA1(65be46ee959d8478cb6dffb25e61f7742276997b) )
 
 	ROM_REGION( 0x0100, "proms", 0 )	/* Unknown use */
 	ROM_LOAD( "n82s129an.11j", 0x0000, 0x0100, CRC(81244757) SHA1(6324f63e571f0f7a0bb9eb97f9994809db79493f) ) /* N82S129AN or compatible labled "TF" */
@@ -1721,8 +1713,8 @@ ROM_START( terrafj )
 	ROM_LOAD( "14.6a", 0x10000, 0x10000, CRC(744f5c9e) SHA1(696223a087bb575c7cfaba11e682b221ada461e4) )
 
 	ROM_REGION( 0x20000, "gfx4", 0 )
-	ROM_LOAD( "12.7d", 0x00000, 0x10000, CRC(2d1f2ceb) SHA1(77544e1c4bda06feac135a96bb76af7c79278dc0) ) /* sprites */
-	ROM_LOAD( "13.9d", 0x10000, 0x10000, CRC(1d2f92d6) SHA1(e842c6bf95a5958a6ca2c85e68b9bc3cc15211a4) )
+	ROM_LOAD( "tfj-12.7d", 0x00000, 0x10000, CRC(d74085a1) SHA1(3f6ba85dbd6e48a502c115b2d322a586fc4f56c9) ) /* sprites */
+	ROM_LOAD( "tfj-13.9d", 0x10000, 0x10000, CRC(148aa0c5) SHA1(8d8a565540e91b384a9c154522501921b7da4d4e) )
 
 	ROM_REGION( 0x4000, "blit_data", 0 )	/* data for mcu/blitter */
 	ROM_LOAD( "10.11c", 0x0000, 0x4000, CRC(ac705812) SHA1(65be46ee959d8478cb6dffb25e61f7742276997b) )
@@ -1788,9 +1780,8 @@ ROM_START( terrafjb )
 	ROM_LOAD( "14.6a", 0x10000, 0x10000, CRC(744f5c9e) SHA1(696223a087bb575c7cfaba11e682b221ada461e4) )
 
 	ROM_REGION( 0x20000, "gfx4", 0 )
-	ROM_LOAD( "tf-003.7d", 0x00000, 0x10000, CRC(d74085a1) SHA1(3f6ba85dbd6e48a502c115b2d322a586fc4f56c9) ) /* sprites */
-	ROM_LOAD( "tf-002.9d", 0x10000, 0x10000, CRC(148aa0c5) SHA1(8d8a565540e91b384a9c154522501921b7da4d4e) )
-
+	ROM_LOAD( "tfj-12.7d", 0x00000, 0x10000, CRC(d74085a1) SHA1(3f6ba85dbd6e48a502c115b2d322a586fc4f56c9) ) /* sprites */
+	ROM_LOAD( "tfj-13.9d", 0x10000, 0x10000, CRC(148aa0c5) SHA1(8d8a565540e91b384a9c154522501921b7da4d4e) )
 
 	ROM_REGION( 0x0100, "proms", 0 )	/* Unknown use */
 	ROM_LOAD( "n82s129an.11j", 0x0000, 0x0100, CRC(81244757) SHA1(6324f63e571f0f7a0bb9eb97f9994809db79493f) ) /* N82S129AN or compatible labled "TF" */
@@ -1820,8 +1811,8 @@ ROM_START( terrafb ) /* Seems to be a bootleg of the Japanese version with the r
 	ROM_LOAD( "14.6a", 0x10000, 0x10000, CRC(744f5c9e) SHA1(696223a087bb575c7cfaba11e682b221ada461e4) )
 
 	ROM_REGION( 0x20000, "gfx4", 0 )
-	ROM_LOAD( "tf-003.7d", 0x00000, 0x10000, CRC(d74085a1) SHA1(3f6ba85dbd6e48a502c115b2d322a586fc4f56c9) ) /* sprites */
-	ROM_LOAD( "tf-002.9d", 0x10000, 0x10000, CRC(148aa0c5) SHA1(8d8a565540e91b384a9c154522501921b7da4d4e) )
+	ROM_LOAD( "tfj-12.7d", 0x00000, 0x10000, CRC(d74085a1) SHA1(3f6ba85dbd6e48a502c115b2d322a586fc4f56c9) ) /* sprites */
+	ROM_LOAD( "tfj-13.9d", 0x10000, 0x10000, CRC(148aa0c5) SHA1(8d8a565540e91b384a9c154522501921b7da4d4e) )
 
 	ROM_REGION( 0x4000, "blit_data", 0 )	/* data for mcu/blitter, shouldn't be loaded? */
 	ROM_LOAD( "tf-10.11c", 0x0000, 0x4000, CRC(ac705812) SHA1(65be46ee959d8478cb6dffb25e61f7742276997b) )
