@@ -44,24 +44,24 @@ enum
 class astinvad_state : public driver_device
 {
 public:
-	astinvad_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	astinvad_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT8 *    colorram;
-	UINT8 *    videoram;
-	size_t     videoram_size;
+	UINT8 *    m_colorram;
+	UINT8 *    m_videoram;
+	size_t     m_videoram_size;
 
-	emu_timer  *int_timer;
-	UINT8      sound_state[2];
-	UINT8      screen_flip;
-	UINT8      screen_red;
-	UINT8      flip_yoffs;
-	UINT8      color_latch;
+	emu_timer  *m_int_timer;
+	UINT8      m_sound_state[2];
+	UINT8      m_screen_flip;
+	UINT8      m_screen_red;
+	UINT8      m_flip_yoffs;
+	UINT8      m_color_latch;
 
-	device_t *maincpu;
-	device_t *ppi8255_0;
-	device_t *ppi8255_1;
-	device_t *samples;
+	device_t *m_maincpu;
+	device_t *m_ppi8255_0;
+	device_t *m_ppi8255_1;
+	device_t *m_samples;
 };
 
 
@@ -104,26 +104,26 @@ static const ppi8255_interface ppi8255_intf[2] =
 
 static VIDEO_START( spaceint )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
-	state->colorram = auto_alloc_array(machine, UINT8, state->videoram_size);
+	astinvad_state *state = machine.driver_data<astinvad_state>();
+	state->m_colorram = auto_alloc_array(machine, UINT8, state->m_videoram_size);
 
-	state_save_register_global(machine, state->color_latch);
-	state_save_register_global_pointer(machine, state->colorram, state->videoram_size);
+	state->save_item(NAME(state->m_color_latch));
+	state->save_pointer(NAME(state->m_colorram), state->m_videoram_size);
 }
 
 
 static WRITE8_HANDLER( color_latch_w )
 {
-	astinvad_state *state = space->machine->driver_data<astinvad_state>();
-	state->color_latch = data & 0x0f;
+	astinvad_state *state = space->machine().driver_data<astinvad_state>();
+	state->m_color_latch = data & 0x0f;
 }
 
 
 static WRITE8_HANDLER( spaceint_videoram_w )
 {
-	astinvad_state *state = space->machine->driver_data<astinvad_state>();
-	state->videoram[offset] = data;
-	state->colorram[offset] = state->color_latch;
+	astinvad_state *state = space->machine().driver_data<astinvad_state>();
+	state->m_videoram[offset] = data;
+	state->m_colorram[offset] = state->m_color_latch;
 }
 
 
@@ -134,53 +134,53 @@ static WRITE8_HANDLER( spaceint_videoram_w )
  *
  *************************************/
 
-static void plot_byte( running_machine *machine, bitmap_t *bitmap, UINT8 y, UINT8 x, UINT8 data, UINT8 color )
+static void plot_byte( running_machine &machine, bitmap_rgb32 &bitmap, UINT8 y, UINT8 x, UINT8 data, UINT8 color )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
+	astinvad_state *state = machine.driver_data<astinvad_state>();
 	pen_t fore_pen = MAKE_RGB(pal1bit(color >> 0), pal1bit(color >> 2), pal1bit(color >> 1));
-	UINT8 flip_xor = state->screen_flip & 7;
+	UINT8 flip_xor = state->m_screen_flip & 7;
 
-	*BITMAP_ADDR32(bitmap, y, x + (0 ^ flip_xor)) = (data & 0x01) ? fore_pen : RGB_BLACK;
-	*BITMAP_ADDR32(bitmap, y, x + (1 ^ flip_xor)) = (data & 0x02) ? fore_pen : RGB_BLACK;
-	*BITMAP_ADDR32(bitmap, y, x + (2 ^ flip_xor)) = (data & 0x04) ? fore_pen : RGB_BLACK;
-	*BITMAP_ADDR32(bitmap, y, x + (3 ^ flip_xor)) = (data & 0x08) ? fore_pen : RGB_BLACK;
-	*BITMAP_ADDR32(bitmap, y, x + (4 ^ flip_xor)) = (data & 0x10) ? fore_pen : RGB_BLACK;
-	*BITMAP_ADDR32(bitmap, y, x + (5 ^ flip_xor)) = (data & 0x20) ? fore_pen : RGB_BLACK;
-	*BITMAP_ADDR32(bitmap, y, x + (6 ^ flip_xor)) = (data & 0x40) ? fore_pen : RGB_BLACK;
-	*BITMAP_ADDR32(bitmap, y, x + (7 ^ flip_xor)) = (data & 0x80) ? fore_pen : RGB_BLACK;
+	bitmap.pix32(y, x + (0 ^ flip_xor)) = (data & 0x01) ? fore_pen : RGB_BLACK;
+	bitmap.pix32(y, x + (1 ^ flip_xor)) = (data & 0x02) ? fore_pen : RGB_BLACK;
+	bitmap.pix32(y, x + (2 ^ flip_xor)) = (data & 0x04) ? fore_pen : RGB_BLACK;
+	bitmap.pix32(y, x + (3 ^ flip_xor)) = (data & 0x08) ? fore_pen : RGB_BLACK;
+	bitmap.pix32(y, x + (4 ^ flip_xor)) = (data & 0x10) ? fore_pen : RGB_BLACK;
+	bitmap.pix32(y, x + (5 ^ flip_xor)) = (data & 0x20) ? fore_pen : RGB_BLACK;
+	bitmap.pix32(y, x + (6 ^ flip_xor)) = (data & 0x40) ? fore_pen : RGB_BLACK;
+	bitmap.pix32(y, x + (7 ^ flip_xor)) = (data & 0x80) ? fore_pen : RGB_BLACK;
 }
 
 
-static VIDEO_UPDATE( astinvad )
+static SCREEN_UPDATE_RGB32( astinvad )
 {
-	astinvad_state *state = screen->machine->driver_data<astinvad_state>();
-	const UINT8 *color_prom = screen->machine->region("proms")->base();
-	UINT8 yoffs = state->flip_yoffs & state->screen_flip;
+	astinvad_state *state = screen.machine().driver_data<astinvad_state>();
+	const UINT8 *color_prom = screen.machine().region("proms")->base();
+	UINT8 yoffs = state->m_flip_yoffs & state->m_screen_flip;
 	int x, y;
 
 	/* render the visible pixels */
-	for (y = cliprect->min_y; y <= cliprect->max_y; y++)
-		for (x = cliprect->min_x & ~7; x <= cliprect->max_x; x += 8)
+	for (y = cliprect.min_y; y <= cliprect.max_y; y++)
+		for (x = cliprect.min_x & ~7; x <= cliprect.max_x; x += 8)
 		{
-			UINT8 color = color_prom[((y & 0xf8) << 2) | (x >> 3)] >> (state->screen_flip ? 0 : 4);
-			UINT8 data = state->videoram[(((y ^ state->screen_flip) + yoffs) << 5) | ((x ^ state->screen_flip) >> 3)];
-			plot_byte(screen->machine, bitmap, y, x, data, state->screen_red ? 1 : color);
+			UINT8 color = color_prom[((y & 0xf8) << 2) | (x >> 3)] >> (state->m_screen_flip ? 0 : 4);
+			UINT8 data = state->m_videoram[(((y ^ state->m_screen_flip) + yoffs) << 5) | ((x ^ state->m_screen_flip) >> 3)];
+			plot_byte(screen.machine(), bitmap, y, x, data, state->m_screen_red ? 1 : color);
 		}
 
 	return 0;
 }
 
 
-static VIDEO_UPDATE( spaceint )
+static SCREEN_UPDATE_RGB32( spaceint )
 {
-	astinvad_state *state = screen->machine->driver_data<astinvad_state>();
-	const UINT8 *color_prom = screen->machine->region("proms")->base();
+	astinvad_state *state = screen.machine().driver_data<astinvad_state>();
+	const UINT8 *color_prom = screen.machine().region("proms")->base();
 	int offs;
 
-	for (offs = 0; offs < state->videoram_size; offs++)
+	for (offs = 0; offs < state->m_videoram_size; offs++)
 	{
-		UINT8 data = state->videoram[offs];
-		UINT8 color = state->colorram[offs];
+		UINT8 data = state->m_videoram[offs];
+		UINT8 color = state->m_colorram[offs];
 
 		UINT8 y = ~offs;
 		UINT8 x = offs >> 8 << 3;
@@ -189,7 +189,7 @@ static VIDEO_UPDATE( spaceint )
 		offs_t n = ((offs >> 5) & 0xf0) | color;
 		color = color_prom[n] & 0x07;
 
-		plot_byte(screen->machine, bitmap, y, x, data, color);
+		plot_byte(screen.machine(), bitmap, y, x, data, color);
 	}
 
 	return 0;
@@ -205,79 +205,79 @@ static VIDEO_UPDATE( spaceint )
 
 static TIMER_CALLBACK( kamikaze_int_off )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
-	cpu_set_input_line(state->maincpu, 0, CLEAR_LINE);
+	astinvad_state *state = machine.driver_data<astinvad_state>();
+	device_set_input_line(state->m_maincpu, 0, CLEAR_LINE);
 }
 
 
 static TIMER_CALLBACK( kamizake_int_gen )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
+	astinvad_state *state = machine.driver_data<astinvad_state>();
 	/* interrupts are asserted on every state change of the 128V line */
-	cpu_set_input_line(state->maincpu, 0, ASSERT_LINE);
+	device_set_input_line(state->m_maincpu, 0, ASSERT_LINE);
 	param ^= 128;
-	timer_adjust_oneshot(state->int_timer, machine->primary_screen->time_until_pos(param), param);
+	state->m_int_timer->adjust(machine.primary_screen->time_until_pos(param), param);
 
 	/* an RC circuit turns the interrupt off after a short amount of time */
-	timer_set(machine, double_to_attotime(300 * 0.1e-6), NULL, 0, kamikaze_int_off);
+	machine.scheduler().timer_set(attotime::from_double(300 * 0.1e-6), FUNC(kamikaze_int_off));
 }
 
 
 static MACHINE_START( kamikaze )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
+	astinvad_state *state = machine.driver_data<astinvad_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->ppi8255_0 = machine->device("ppi8255_0");
-	state->ppi8255_1 = machine->device("ppi8255_1");
-	state->samples = machine->device("samples");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_ppi8255_0 = machine.device("ppi8255_0");
+	state->m_ppi8255_1 = machine.device("ppi8255_1");
+	state->m_samples = machine.device("samples");
 
-	state->int_timer = timer_alloc(machine, kamizake_int_gen, NULL);
-	timer_adjust_oneshot(state->int_timer, machine->primary_screen->time_until_pos(128), 128);
+	state->m_int_timer = machine.scheduler().timer_alloc(FUNC(kamizake_int_gen));
+	state->m_int_timer->adjust(machine.primary_screen->time_until_pos(128), 128);
 
-	state_save_register_global(machine, state->screen_flip);
-	state_save_register_global(machine, state->screen_red);
-	state_save_register_global_array(machine, state->sound_state);
+	state->save_item(NAME(state->m_screen_flip));
+	state->save_item(NAME(state->m_screen_red));
+	state->save_item(NAME(state->m_sound_state));
 }
 
 static MACHINE_RESET( kamikaze )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
+	astinvad_state *state = machine.driver_data<astinvad_state>();
 
-	state->screen_flip = 0;
-	state->screen_red = 0;
-	state->sound_state[0] = 0;
-	state->sound_state[1] = 0;
+	state->m_screen_flip = 0;
+	state->m_screen_red = 0;
+	state->m_sound_state[0] = 0;
+	state->m_sound_state[1] = 0;
 }
 
 
 static MACHINE_START( spaceint )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
+	astinvad_state *state = machine.driver_data<astinvad_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->samples = machine->device("samples");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_samples = machine.device("samples");
 
-	state_save_register_global(machine, state->screen_flip);
-	state_save_register_global_array(machine, state->sound_state);
+	state->save_item(NAME(state->m_screen_flip));
+	state->save_item(NAME(state->m_sound_state));
 }
 
 static MACHINE_RESET( spaceint )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
+	astinvad_state *state = machine.driver_data<astinvad_state>();
 
-	state->screen_flip = 0;
-	state->sound_state[0] = 0;
-	state->sound_state[1] = 0;
-	state->color_latch = 0;
+	state->m_screen_flip = 0;
+	state->m_sound_state[0] = 0;
+	state->m_sound_state[1] = 0;
+	state->m_color_latch = 0;
 }
 
 
 static INPUT_CHANGED( spaceint_coin_inserted )
 {
-	astinvad_state *state = field->port->machine->driver_data<astinvad_state>();
+	astinvad_state *state = field.machine().driver_data<astinvad_state>();
 	/* coin insertion causes an NMI */
-	cpu_set_input_line(state->maincpu, INPUT_LINE_NMI, newval ? ASSERT_LINE : CLEAR_LINE);
+	device_set_input_line(state->m_maincpu, INPUT_LINE_NMI, newval ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -290,27 +290,27 @@ static INPUT_CHANGED( spaceint_coin_inserted )
 
 static READ8_HANDLER( kamikaze_ppi_r )
 {
-	astinvad_state *state = space->machine->driver_data<astinvad_state>();
+	astinvad_state *state = space->machine().driver_data<astinvad_state>();
 	UINT8 result = 0xff;
 
 	/* the address lines are used for /CS; yes, they can overlap! */
 	if (!(offset & 4))
-		result &= ppi8255_r(state->ppi8255_0, offset);
+		result &= ppi8255_r(state->m_ppi8255_0, offset);
 	if (!(offset & 8))
-		result &= ppi8255_r(state->ppi8255_1, offset);
+		result &= ppi8255_r(state->m_ppi8255_1, offset);
 	return result;
 }
 
 
 static WRITE8_HANDLER( kamikaze_ppi_w )
 {
-	astinvad_state *state = space->machine->driver_data<astinvad_state>();
+	astinvad_state *state = space->machine().driver_data<astinvad_state>();
 
 	/* the address lines are used for /CS; yes, they can overlap! */
 	if (!(offset & 4))
-		ppi8255_w(state->ppi8255_0, offset, data);
+		ppi8255_w(state->m_ppi8255_0, offset, data);
 	if (!(offset & 8))
-		ppi8255_w(state->ppi8255_1, offset, data);
+		ppi8255_w(state->m_ppi8255_1, offset, data);
 }
 
 
@@ -323,67 +323,67 @@ static WRITE8_HANDLER( kamikaze_ppi_w )
 
 static WRITE8_DEVICE_HANDLER( astinvad_sound1_w )
 {
-	astinvad_state *state = device->machine->driver_data<astinvad_state>();
-	int bits_gone_hi = data & ~state->sound_state[0];
-	state->sound_state[0] = data;
+	astinvad_state *state = device->machine().driver_data<astinvad_state>();
+	int bits_gone_hi = data & ~state->m_sound_state[0];
+	state->m_sound_state[0] = data;
 
-	if (bits_gone_hi & 0x01) sample_start(state->samples, 0, SND_UFO, 1);
-	if (!(data & 0x01))      sample_stop(state->samples, 0);
-	if (bits_gone_hi & 0x02) sample_start(state->samples, 1, SND_SHOT, 0);
-	if (bits_gone_hi & 0x04) sample_start(state->samples, 2, SND_BASEHIT, 0);
-	if (bits_gone_hi & 0x08) sample_start(state->samples, 3, SND_INVADERHIT, 0);
+	if (bits_gone_hi & 0x01) sample_start(state->m_samples, 0, SND_UFO, 1);
+	if (!(data & 0x01))      sample_stop(state->m_samples, 0);
+	if (bits_gone_hi & 0x02) sample_start(state->m_samples, 1, SND_SHOT, 0);
+	if (bits_gone_hi & 0x04) sample_start(state->m_samples, 2, SND_BASEHIT, 0);
+	if (bits_gone_hi & 0x08) sample_start(state->m_samples, 3, SND_INVADERHIT, 0);
 
-	sound_global_enable(device->machine, data & 0x20);
-	state->screen_red = data & 0x04;
+	device->machine().sound().system_enable(data & 0x20);
+	state->m_screen_red = data & 0x04;
 }
 
 
 static WRITE8_DEVICE_HANDLER( astinvad_sound2_w )
 {
-	astinvad_state *state = device->machine->driver_data<astinvad_state>();
-	int bits_gone_hi = data & ~state->sound_state[1];
-	state->sound_state[1] = data;
+	astinvad_state *state = device->machine().driver_data<astinvad_state>();
+	int bits_gone_hi = data & ~state->m_sound_state[1];
+	state->m_sound_state[1] = data;
 
-	if (bits_gone_hi & 0x01) sample_start(state->samples, 5, SND_FLEET1, 0);
-	if (bits_gone_hi & 0x02) sample_start(state->samples, 5, SND_FLEET2, 0);
-	if (bits_gone_hi & 0x04) sample_start(state->samples, 5, SND_FLEET3, 0);
-	if (bits_gone_hi & 0x08) sample_start(state->samples, 5, SND_FLEET4, 0);
-	if (bits_gone_hi & 0x10) sample_start(state->samples, 4, SND_UFOHIT, 0);
+	if (bits_gone_hi & 0x01) sample_start(state->m_samples, 5, SND_FLEET1, 0);
+	if (bits_gone_hi & 0x02) sample_start(state->m_samples, 5, SND_FLEET2, 0);
+	if (bits_gone_hi & 0x04) sample_start(state->m_samples, 5, SND_FLEET3, 0);
+	if (bits_gone_hi & 0x08) sample_start(state->m_samples, 5, SND_FLEET4, 0);
+	if (bits_gone_hi & 0x10) sample_start(state->m_samples, 4, SND_UFOHIT, 0);
 
-	state->screen_flip = (input_port_read(device->machine, "CABINET") & data & 0x20) ? 0xff : 0x00;
+	state->m_screen_flip = (input_port_read(device->machine(), "CABINET") & data & 0x20) ? 0xff : 0x00;
 }
 
 
 static WRITE8_HANDLER( spaceint_sound1_w )
 {
-	astinvad_state *state = space->machine->driver_data<astinvad_state>();
-	int bits_gone_hi = data & ~state->sound_state[0];
-	state->sound_state[0] = data;
+	astinvad_state *state = space->machine().driver_data<astinvad_state>();
+	int bits_gone_hi = data & ~state->m_sound_state[0];
+	state->m_sound_state[0] = data;
 
-	if (bits_gone_hi & 0x01) sample_start(state->samples, 1, SND_SHOT, 0);
-	if (bits_gone_hi & 0x02) sample_start(state->samples, 2, SND_BASEHIT, 0);
-	if (bits_gone_hi & 0x04) sample_start(state->samples, 4, SND_UFOHIT, 0);
-	if (bits_gone_hi & 0x08) sample_start(state->samples, 0, SND_UFO, 1);
-	if (!(data & 0x08))      sample_stop(state->samples, 0);
+	if (bits_gone_hi & 0x01) sample_start(state->m_samples, 1, SND_SHOT, 0);
+	if (bits_gone_hi & 0x02) sample_start(state->m_samples, 2, SND_BASEHIT, 0);
+	if (bits_gone_hi & 0x04) sample_start(state->m_samples, 4, SND_UFOHIT, 0);
+	if (bits_gone_hi & 0x08) sample_start(state->m_samples, 0, SND_UFO, 1);
+	if (!(data & 0x08))      sample_stop(state->m_samples, 0);
 
-	if (bits_gone_hi & 0x10) sample_start(state->samples, 5, SND_FLEET1, 0);
-	if (bits_gone_hi & 0x20) sample_start(state->samples, 5, SND_FLEET2, 0);
-	if (bits_gone_hi & 0x40) sample_start(state->samples, 5, SND_FLEET3, 0);
-	if (bits_gone_hi & 0x80) sample_start(state->samples, 5, SND_FLEET4, 0);
+	if (bits_gone_hi & 0x10) sample_start(state->m_samples, 5, SND_FLEET1, 0);
+	if (bits_gone_hi & 0x20) sample_start(state->m_samples, 5, SND_FLEET2, 0);
+	if (bits_gone_hi & 0x40) sample_start(state->m_samples, 5, SND_FLEET3, 0);
+	if (bits_gone_hi & 0x80) sample_start(state->m_samples, 5, SND_FLEET4, 0);
 }
 
 
 static WRITE8_HANDLER( spaceint_sound2_w )
 {
-	astinvad_state *state = space->machine->driver_data<astinvad_state>();
-	int bits_gone_hi = data & ~state->sound_state[1];
-	state->sound_state[1] = data;
+	astinvad_state *state = space->machine().driver_data<astinvad_state>();
+	int bits_gone_hi = data & ~state->m_sound_state[1];
+	state->m_sound_state[1] = data;
 
-	sound_global_enable(space->machine, data & 0x02);
+	space->machine().sound().system_enable(data & 0x02);
 
-	if (bits_gone_hi & 0x04) sample_start(state->samples, 3, SND_INVADERHIT, 0);
+	if (bits_gone_hi & 0x04) sample_start(state->m_samples, 3, SND_INVADERHIT, 0);
 
-	state->screen_flip = (input_port_read(space->machine, "CABINET") & data & 0x80) ? 0xff : 0x00;
+	state->m_screen_flip = (input_port_read(space->machine(), "CABINET") & data & 0x80) ? 0xff : 0x00;
 }
 
 
@@ -394,28 +394,28 @@ static WRITE8_HANDLER( spaceint_sound2_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( kamikaze_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( kamikaze_map, AS_PROGRAM, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x3fff)
 	AM_RANGE(0x0000, 0x1bff) AM_ROM
 	AM_RANGE(0x1c00, 0x1fff) AM_RAM
-	AM_RANGE(0x2000, 0x3fff) AM_RAM AM_BASE_SIZE_MEMBER(astinvad_state, videoram, videoram_size)
+	AM_RANGE(0x2000, 0x3fff) AM_RAM AM_BASE_SIZE_MEMBER(astinvad_state, m_videoram, m_videoram_size)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( spaceint_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( spaceint_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x23ff) AM_RAM
-	AM_RANGE(0x4000, 0x5fff) AM_RAM_WRITE(spaceint_videoram_w) AM_BASE_SIZE_MEMBER(astinvad_state, videoram, videoram_size)
+	AM_RANGE(0x4000, 0x5fff) AM_RAM_WRITE(spaceint_videoram_w) AM_BASE_SIZE_MEMBER(astinvad_state, m_videoram, m_videoram_size)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( kamikaze_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( kamikaze_portmap, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0xff) AM_READWRITE(kamikaze_ppi_r, kamikaze_ppi_w)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( spaceint_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( spaceint_portmap, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ_PORT("IN0")
 	AM_RANGE(0x01, 0x01) AM_READ_PORT("IN1")
@@ -558,15 +558,15 @@ INPUT_PORTS_END
 static const char *const astinvad_sample_names[] =
 {
 	"*invaders",
-	"0.wav",
-	"1.wav",
-	"2.wav",
-	"3.wav",
-	"4.wav",
-	"5.wav",
-	"6.wav",
-	"7.wav",
-	"8.wav",
+	"0",
+	"1",
+	"2",
+	"3",
+	"4",
+	"5",
+	"6",
+	"7",
+	"8",
 	0
 };
 
@@ -598,11 +598,9 @@ static MACHINE_CONFIG_START( kamikaze, astinvad_state )
 	MCFG_PPI8255_ADD( "ppi8255_1", ppi8255_intf[1] )
 
 	/* video hardware */
-	MCFG_VIDEO_UPDATE(astinvad)
-
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_RAW_PARAMS(VIDEO_CLOCK, 320, 0, 256, 256, 32, 256)
+	MCFG_SCREEN_UPDATE_STATIC(astinvad)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -634,13 +632,12 @@ static MACHINE_CONFIG_START( spaceint, astinvad_state )
 
 	/* video hardware */
 	MCFG_VIDEO_START(spaceint)
-	MCFG_VIDEO_UPDATE(spaceint)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_UPDATE_STATIC(spaceint)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -744,19 +741,19 @@ ROM_END
 
 static DRIVER_INIT( kamikaze )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
+	astinvad_state *state = machine.driver_data<astinvad_state>();
 
 	/* the flip screen logic adds 32 to the Y after flipping */
-	state->flip_yoffs = 32;
+	state->m_flip_yoffs = 32;
 }
 
 
 static DRIVER_INIT( spcking2 )
 {
-	astinvad_state *state = machine->driver_data<astinvad_state>();
+	astinvad_state *state = machine.driver_data<astinvad_state>();
 
 	/* don't have the schematics, but the blanking must center the screen here */
-	state->flip_yoffs = 0;
+	state->m_flip_yoffs = 0;
 }
 
 
