@@ -578,12 +578,11 @@ static MACHINE_CONFIG_START( atarig42, atarig42_state )
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses an SOS chip to generate video signals */
 	MCFG_SCREEN_RAW_PARAMS(ATARI_CLOCK_14MHz/2, 456, 0, 336, 262, 0, 240)
-	MCFG_SCREEN_UPDATE(atarig42)
-	MCFG_SCREEN_EOF(atarig42)
+	MCFG_SCREEN_UPDATE_STATIC(atarig42)
+	MCFG_SCREEN_VBLANK_STATIC(atarig42)
 
 	MCFG_VIDEO_START(atarig42)
 
