@@ -125,6 +125,26 @@ static ADDRESS_MAP_START( main_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x280200, 0x2805ff) AM_RAM_WRITE(blockout_paletteram_w) AM_BASE_MEMBER(blockout_state, m_paletteram)
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( agress_map, AS_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x03ffff) AM_ROM
+	AM_RANGE(0x100000, 0x100001) AM_READ_PORT("P1")
+	AM_RANGE(0x100002, 0x100003) AM_READ_PORT("P2")
+	AM_RANGE(0x100004, 0x100005) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x100006, 0x100007) AM_READ_PORT("DSW1")
+	AM_RANGE(0x100008, 0x100009) AM_READ_PORT("DSW2")
+	AM_RANGE(0x100010, 0x100011) AM_WRITE(blockout_irq6_ack_w)
+	AM_RANGE(0x100012, 0x100013) AM_WRITE(blockout_irq5_ack_w)
+	AM_RANGE(0x100014, 0x100015) AM_WRITE(blockout_sound_command_w)
+	AM_RANGE(0x100016, 0x100017) AM_WRITENOP	/* don't know, maybe reset sound CPU */
+	AM_RANGE(0x180000, 0x1bffff) AM_RAM_WRITE(blockout_videoram_w) AM_BASE_MEMBER(blockout_state, m_videoram)
+	AM_RANGE(0x1d4000, 0x1dffff) AM_RAM	/* work RAM */
+	AM_RANGE(0x1f4000, 0x1fffff) AM_RAM	/* work RAM */
+	AM_RANGE(0x200000, 0x203fff) AM_RAM AM_BASE_MEMBER(blockout_state, m_frontvideoram) AM_MIRROR(0x004000) // agress checks at F3A that this is mirrored, blockout glitches if you do it to it
+	AM_RANGE(0x208000, 0x21ffff) AM_RAM	/* ??? */
+	AM_RANGE(0x280002, 0x280003) AM_WRITE(blockout_frontcolor_w)
+	AM_RANGE(0x280200, 0x2805ff) AM_RAM_WRITE(blockout_paletteram_w) AM_BASE_MEMBER(blockout_state, m_paletteram)
+ADDRESS_MAP_END
+
 static ADDRESS_MAP_START( audio_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x87ff) AM_RAM
@@ -307,10 +327,9 @@ static MACHINE_CONFIG_START( blockout, blockout_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(58)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 319, 8, 247)
-	MCFG_SCREEN_UPDATE(blockout)
+	MCFG_SCREEN_UPDATE_STATIC(blockout)
 
 	MCFG_PALETTE_LENGTH(513)
 
@@ -329,7 +348,10 @@ static MACHINE_CONFIG_START( blockout, blockout_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.50)
 MACHINE_CONFIG_END
 
-
+static MACHINE_CONFIG_DERIVED( agress, blockout )
+	MCFG_CPU_MODIFY( "maincpu" )
+	MCFG_CPU_PROGRAM_MAP(agress_map)
+MACHINE_CONFIG_END
 
 /*************************************
  *
@@ -423,5 +445,5 @@ ROM_END
 GAME( 1989, blockout, 0,        blockout, blockout, 0, ROT0, "Technos Japan / California Dreams", "Block Out (set 1)", GAME_SUPPORTS_SAVE )
 GAME( 1989, blockout2,blockout, blockout, blockout, 0, ROT0, "Technos Japan / California Dreams", "Block Out (set 2)", GAME_SUPPORTS_SAVE )
 GAME( 1989, blockoutj,blockout, blockout, blockoutj,0, ROT0, "Technos Japan / California Dreams", "Block Out (Japan)", GAME_SUPPORTS_SAVE )
-GAME( 1991, agress,   0,        blockout, agress,   0, ROT0, "Palco", "Agress", GAME_SUPPORTS_SAVE )
-GAME( 2003, agressb,  agress,   blockout, agress,   0, ROT0, "bootleg", "Agress (English bootleg)", GAME_SUPPORTS_SAVE )
+GAME( 1991, agress,   0,        agress,   agress,   0, ROT0, "Palco", "Agress", GAME_SUPPORTS_SAVE )
+GAME( 2003, agressb,  agress,   agress,   agress,   0, ROT0, "bootleg", "Agress (English bootleg)", GAME_SUPPORTS_SAVE )
