@@ -296,10 +296,10 @@ static INPUT_PORTS_START( common )
 	PORT_DIPSETTING(      0x0100, "5" )
 	PORT_DIPSETTING(      0x0000, "121 (Cheat)")
 	PORT_DIPNAME( 0x0c00, 0x0c00, DEF_STR( Bonus_Life ) ) PORT_DIPLOCATION("SW2:3,4")
-	PORT_DIPSETTING(      0x0c00, "20k 50k" )
-	PORT_DIPSETTING(      0x0800, "30k 100k" )
-	PORT_DIPSETTING(      0x0400, "50k 150k" )
-	PORT_DIPSETTING(      0x0000, "70K" )
+	PORT_DIPSETTING(      0x0c00, "150k 650k 500k+" )
+	PORT_DIPSETTING(      0x0800, "200k 800k 600k+" )
+	PORT_DIPSETTING(      0x0400, "300k 1000k 700k+" )
+	PORT_DIPSETTING(      0x0000, "300k Only" )
 	PORT_DIPNAME( 0x3000, 0x2000, DEF_STR( Difficulty ) ) PORT_DIPLOCATION("SW2:5,6")
 	PORT_DIPSETTING(      0x3000, DEF_STR( Easy ) )
 	PORT_DIPSETTING(      0x2000, DEF_STR( Normal ) )
@@ -500,10 +500,9 @@ static MACHINE_CONFIG_START( cabal, cabal_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(59.60)   /* verified on pcb */
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(cabal)
+	MCFG_SCREEN_UPDATE_STATIC(cabal)
 
 	MCFG_GFXDECODE(cabal)
 	MCFG_PALETTE_LENGTH(1024)
@@ -557,10 +556,9 @@ static MACHINE_CONFIG_START( cabalbl, cabal_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(cabal)
+	MCFG_SCREEN_UPDATE_STATIC(cabal)
 
 	MCFG_GFXDECODE(cabal)
 	MCFG_PALETTE_LENGTH(1024)
