@@ -374,7 +374,7 @@ static MACHINE_CONFIG_START( capbowl, capbowl_state )
 
 	MCFG_MACHINE_START(capbowl)
 	MCFG_MACHINE_RESET(capbowl)
-	MCFG_NVRAM_ADD_CUSTOM("nvram", capbowl_state, init_nvram)
+	MCFG_NVRAM_ADD_CUSTOM_DRIVER("nvram", capbowl_state, init_nvram)
 
 	MCFG_TICKET_DISPENSER_ADD("ticket", 100, TICKET_MOTOR_ACTIVE_HIGH, TICKET_STATUS_ACTIVE_LOW)
 
@@ -382,11 +382,10 @@ static MACHINE_CONFIG_START( capbowl, capbowl_state )
 	MCFG_VIDEO_START(capbowl)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(360, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 359, 0, 244)
 	MCFG_SCREEN_REFRESH_RATE(57)
-	MCFG_SCREEN_UPDATE(capbowl)
+	MCFG_SCREEN_UPDATE_STATIC(capbowl)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
