@@ -44,11 +44,11 @@ public:
 					x<<3, y<<3,\
 					transparency?transparency:(UINT32)-1);
 
-static SCREEN_UPDATE( cardline )
+static SCREEN_UPDATE_IND16( cardline )
 {
-	cardline_state *state = screen->machine().driver_data<cardline_state>();
+	cardline_state *state = screen.machine().driver_data<cardline_state>();
 	int x,y;
-	bitmap_fill(bitmap,cliprect,0);
+	bitmap.fill(0, cliprect);
 	for(y=0;y<32;y++)
 	{
 		for(x=0;x<64;x++)
@@ -56,14 +56,14 @@ static SCREEN_UPDATE( cardline )
 			int index=y*64+x;
 			if(state->m_video&1)
 			{
-				DRAW_TILE(screen->machine(),0,0);
-				DRAW_TILE(screen->machine(),0x800,1);
+				DRAW_TILE(screen.machine(),0,0);
+				DRAW_TILE(screen.machine(),0x800,1);
 			}
 
 			if(state->m_video&2)
 			{
-				DRAW_TILE(screen->machine(),0x1000,0);
-				DRAW_TILE(screen->machine(),0x1800,1);
+				DRAW_TILE(screen.machine(),0x1000,0);
+				DRAW_TILE(screen.machine(),0x1800,1);
 			}
 		}
 	}
@@ -219,10 +219,9 @@ static MACHINE_CONFIG_START( cardline, cardline_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 35*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(cardline)
+	MCFG_SCREEN_UPDATE_STATIC(cardline)
 
 	MCFG_GFXDECODE(cardline)
 	MCFG_PALETTE_LENGTH(512)
