@@ -244,9 +244,9 @@ static GFXDECODE_START( carrera )
 	GFXDECODE_ENTRY( "gfx1", 0, tiles8x8_layout, 0, 1 )
 GFXDECODE_END
 
-static SCREEN_UPDATE(carrera)
+static SCREEN_UPDATE_IND16(carrera)
 {
-	carrera_state *state = screen->machine().driver_data<carrera_state>();
+	carrera_state *state = screen.machine().driver_data<carrera_state>();
 
 	int x,y;
 	int count = 0;
@@ -257,7 +257,7 @@ static SCREEN_UPDATE(carrera)
 		{
 			int tile = state->m_tileram[count&0x7ff] | state->m_tileram[(count&0x7ff)+0x800]<<8;
 
-			drawgfx_opaque(bitmap,cliprect,screen->machine().gfx[0],tile,0,0,0,x*8,y*8);
+			drawgfx_opaque(bitmap,cliprect,screen.machine().gfx[0],tile,0,0,0,x*8,y*8);
 			count++;
 		}
 	}
@@ -285,7 +285,7 @@ static PALETTE_INIT(carrera)
 	int br_bit0, br_bit1, bit0, bit1, r, g, b;
 	int	i;
 
-	for (i = 0; i < 0x40; ++i)
+	for (i = 0; i < 0x20; ++i)
 	{
 		br_bit0 = (color_prom[0] >> 6) & 0x01;
 		br_bit1 = (color_prom[0] >> 7) & 0x01;
@@ -332,10 +332,9 @@ static MACHINE_CONFIG_START( carrera, carrera_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(512, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 512-1, 0, 256-1)
-	MCFG_SCREEN_UPDATE(carrera)
+	MCFG_SCREEN_UPDATE_STATIC(carrera)
 
 	MCFG_MC6845_ADD("crtc", MC6845, MASTER_CLOCK / 16, mc6845_intf)
 
