@@ -699,9 +699,9 @@ static ADDRESS_MAP_START( centiped_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0c03, 0x0c03) AM_READ_PORT("IN3")		/* IN3 */
 	AM_RANGE(0x1000, 0x100f) AM_DEVREADWRITE("pokey", pokey_r, pokey_w)
 	AM_RANGE(0x1400, 0x140f) AM_WRITE(centiped_paletteram_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x1600, 0x163f) AM_DEVWRITE("earom", atari_vg_earom_w)
-	AM_RANGE(0x1680, 0x1680) AM_DEVWRITE("earom", atari_vg_earom_ctrl_w)
-	AM_RANGE(0x1700, 0x173f) AM_DEVREAD("earom", atari_vg_earom_r)
+	AM_RANGE(0x1600, 0x163f) AM_DEVWRITE_MODERN("earom",atari_vg_earom_device, write)
+	AM_RANGE(0x1680, 0x1680) AM_DEVWRITE_MODERN("earom", atari_vg_earom_device, ctrl_w)
+	AM_RANGE(0x1700, 0x173f) AM_DEVREAD_MODERN("earom", atari_vg_earom_device, read)
 	AM_RANGE(0x1800, 0x1800) AM_WRITE(irq_ack_w)
 	AM_RANGE(0x1c00, 0x1c02) AM_WRITE(coin_count_w)
 	AM_RANGE(0x1c03, 0x1c04) AM_WRITE(led_w)
@@ -725,9 +725,9 @@ static ADDRESS_MAP_START( centipdb_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x1000, 0x1001) AM_MIRROR(0x4000) AM_DEVWRITE("pokey", ay8910_data_address_w)
 	AM_RANGE(0x1001, 0x1001) AM_MIRROR(0x4000) AM_DEVREAD("pokey", ay8910_r)
 	AM_RANGE(0x1400, 0x140f) AM_MIRROR(0x4000) AM_WRITE(centiped_paletteram_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x1600, 0x163f) AM_MIRROR(0x4000) AM_DEVWRITE("earom", atari_vg_earom_w)
-	AM_RANGE(0x1680, 0x1680) AM_MIRROR(0x4000) AM_DEVWRITE("earom", atari_vg_earom_ctrl_w)
-	AM_RANGE(0x1700, 0x173f) AM_MIRROR(0x4000) AM_DEVREAD("earom", atari_vg_earom_r)
+	AM_RANGE(0x1600, 0x163f) AM_MIRROR(0x4000) AM_DEVWRITE_MODERN("earom", atari_vg_earom_device, write)
+	AM_RANGE(0x1680, 0x1680) AM_MIRROR(0x4000) AM_DEVWRITE_MODERN("earom", atari_vg_earom_device, ctrl_w)
+	AM_RANGE(0x1700, 0x173f) AM_MIRROR(0x4000) AM_DEVREAD_MODERN("earom", atari_vg_earom_device, read)
 	AM_RANGE(0x1800, 0x1800) AM_MIRROR(0x4000) AM_WRITE(irq_ack_w)
 	AM_RANGE(0x1c00, 0x1c02) AM_MIRROR(0x4000) AM_WRITE(coin_count_w)
 	AM_RANGE(0x1c03, 0x1c04) AM_MIRROR(0x4000) AM_WRITE(led_w)
@@ -756,7 +756,7 @@ static ADDRESS_MAP_START( milliped_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x2001, 0x2001) AM_READ(milliped_IN1_r)
 	AM_RANGE(0x2010, 0x2010) AM_READ(milliped_IN2_r)
 	AM_RANGE(0x2011, 0x2011) AM_READ_PORT("IN3")
-	AM_RANGE(0x2030, 0x2030) AM_DEVREAD("earom", atari_vg_earom_r)
+	AM_RANGE(0x2030, 0x2030) AM_DEVREAD_MODERN("earom", atari_vg_earom_device, read)
 	AM_RANGE(0x2480, 0x249f) AM_WRITE(milliped_paletteram_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x2500, 0x2502) AM_WRITE(coin_count_w)
 	AM_RANGE(0x2503, 0x2504) AM_WRITE(led_w)
@@ -765,8 +765,8 @@ static ADDRESS_MAP_START( milliped_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x2507, 0x2507) AM_WRITE(control_select_w) /* CNTRLSEL */
 	AM_RANGE(0x2600, 0x2600) AM_WRITE(irq_ack_w)
 	AM_RANGE(0x2680, 0x2680) AM_WRITE(watchdog_reset_w)
-	AM_RANGE(0x2700, 0x2700) AM_DEVWRITE("earom", atari_vg_earom_ctrl_w)
-	AM_RANGE(0x2780, 0x27bf) AM_DEVWRITE("earom", atari_vg_earom_w)
+	AM_RANGE(0x2700, 0x2700) AM_DEVWRITE_MODERN("earom", atari_vg_earom_device, ctrl_w)
+	AM_RANGE(0x2780, 0x27bf) AM_DEVWRITE_MODERN("earom", atari_vg_earom_device, write)
 	AM_RANGE(0x4000, 0x7fff) AM_ROM
 ADDRESS_MAP_END
 
@@ -815,7 +815,7 @@ static ADDRESS_MAP_START( mazeinv_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x2010, 0x2010) AM_READ_PORT("IN2")
 	AM_RANGE(0x2011, 0x2011) AM_READ_PORT("IN3")
 	AM_RANGE(0x2020, 0x2020) AM_READ(mazeinv_input_r)
-	AM_RANGE(0x2030, 0x2030) AM_DEVREAD("earom", atari_vg_earom_r)
+	AM_RANGE(0x2030, 0x2030) AM_DEVREAD_MODERN("earom", atari_vg_earom_device, read)
 	AM_RANGE(0x2480, 0x249f) AM_WRITE(mazeinv_paletteram_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x2500, 0x2502) AM_WRITE(coin_count_w)
 	AM_RANGE(0x2503, 0x2504) AM_WRITE(led_w)
@@ -824,8 +824,8 @@ static ADDRESS_MAP_START( mazeinv_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x2580, 0x2583) AM_WRITE(mazeinv_input_select_w)
 	AM_RANGE(0x2600, 0x2600) AM_WRITE(irq_ack_w)
 	AM_RANGE(0x2680, 0x2680) AM_WRITE(watchdog_reset_w)
-	AM_RANGE(0x2700, 0x2700) AM_DEVWRITE("earom", atari_vg_earom_ctrl_w)
-	AM_RANGE(0x2780, 0x27bf) AM_DEVWRITE("earom", atari_vg_earom_w)
+	AM_RANGE(0x2700, 0x2700) AM_DEVWRITE_MODERN("earom", atari_vg_earom_device, ctrl_w)
+	AM_RANGE(0x2780, 0x27bf) AM_DEVWRITE_MODERN("earom", atari_vg_earom_device, write)
 	AM_RANGE(0x3000, 0x7fff) AM_ROM
 ADDRESS_MAP_END
 
@@ -843,8 +843,8 @@ static ADDRESS_MAP_START( bullsdrt_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x1080, 0x1080) AM_MIRROR(0x6000) AM_READ(centiped_IN0_r)
 	AM_RANGE(0x1081, 0x1081) AM_MIRROR(0x6000) AM_READ_PORT("IN1")
 	AM_RANGE(0x1082, 0x1082) AM_MIRROR(0x6000) AM_READ(centiped_IN2_r)
-	AM_RANGE(0x1200, 0x123f) AM_MIRROR(0x6000) AM_DEVREADWRITE("earom", atari_vg_earom_r, atari_vg_earom_w)
-	AM_RANGE(0x1280, 0x1280) AM_MIRROR(0x6000) AM_DEVWRITE("earom", atari_vg_earom_ctrl_w)
+	AM_RANGE(0x1200, 0x123f) AM_MIRROR(0x6000) AM_DEVREADWRITE_MODERN("earom",atari_vg_earom_device, read, write)
+	AM_RANGE(0x1280, 0x1280) AM_MIRROR(0x6000) AM_DEVWRITE_MODERN("earom", atari_vg_earom_device, ctrl_w)
 	AM_RANGE(0x1300, 0x1300) AM_MIRROR(0x6000) AM_READ_PORT("DSW2")
 	AM_RANGE(0x1400, 0x140f) AM_MIRROR(0x6000) AM_WRITE(centiped_paletteram_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x1481, 0x1481) AM_MIRROR(0x6000) AM_WRITE(bullsdrt_coin_count_w)
@@ -1615,10 +1615,9 @@ static MACHINE_CONFIG_START( centiped, centiped_state )
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(centiped)
+	MCFG_SCREEN_UPDATE_STATIC(centiped)
 
 	MCFG_GFXDECODE(centiped)
 	MCFG_PALETTE_LENGTH(4+4*4*4*4)
@@ -1680,7 +1679,7 @@ static MACHINE_CONFIG_DERIVED( milliped, centiped )
 
 	MCFG_VIDEO_START(milliped)
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(milliped)
+	MCFG_SCREEN_UPDATE_STATIC(milliped)
 
 	/* sound hardware */
 	MCFG_SOUND_REPLACE("pokey", POKEY, 12096000/8)
@@ -1706,7 +1705,7 @@ static MACHINE_CONFIG_DERIVED( warlords, centiped )
 	MCFG_PALETTE_INIT(warlords)
 	MCFG_VIDEO_START(warlords)
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(warlords)
+	MCFG_SCREEN_UPDATE_STATIC(warlords)
 
 	/* sound hardware */
 	MCFG_SOUND_REPLACE("pokey", POKEY, 12096000/8)
@@ -1721,7 +1720,7 @@ static MACHINE_CONFIG_DERIVED( mazeinv, milliped )
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_PROGRAM_MAP(mazeinv_map)
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(centiped)
+	MCFG_SCREEN_UPDATE_STATIC(centiped)
 MACHINE_CONFIG_END
 
 
@@ -1737,10 +1736,9 @@ static MACHINE_CONFIG_START( bullsdrt, centiped_state )
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(bullsdrt)
+	MCFG_SCREEN_UPDATE_STATIC(bullsdrt)
 
 	MCFG_GFXDECODE(centiped)
 	MCFG_PALETTE_LENGTH(4+4*4*4*4)
