@@ -298,10 +298,9 @@ static MACHINE_CONFIG_START( circus, circus_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(57)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(3500)	/* frames per second, vblank duration (complete guess) */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 31*8-1, 0*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(circus)
+	MCFG_SCREEN_UPDATE_STATIC(circus)
 
 	MCFG_GFXDECODE(circus)
 	MCFG_PALETTE_LENGTH(2)
@@ -336,10 +335,9 @@ static MACHINE_CONFIG_START( robotbwl, circus_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(57)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(3500) /* frames per second, vblank duration (complete guess) */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 31*8-1, 0*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(robotbwl)
+	MCFG_SCREEN_UPDATE_STATIC(robotbwl)
 
 	MCFG_GFXDECODE(robotbwl)
 	MCFG_PALETTE_LENGTH(2)
@@ -381,10 +379,9 @@ static MACHINE_CONFIG_START( crash, circus_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(57)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(3500) /* frames per second, vblank duration (complete guess) */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(40*8, 40*8) //TODO
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 31*8-1, 0*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(crash)
+	MCFG_SCREEN_UPDATE_STATIC(crash)
 
 	MCFG_GFXDECODE(circus)
 	MCFG_PALETTE_LENGTH(2)
@@ -418,10 +415,9 @@ static MACHINE_CONFIG_START( ripcord, circus_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(57)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(3500)	/* frames per second, vblank duration (complete guess) */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 31*8-1, 0*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(ripcord)
+	MCFG_SCREEN_UPDATE_STATIC(ripcord)
 
 	MCFG_GFXDECODE(circus)
 	MCFG_PALETTE_LENGTH(2)
