@@ -474,10 +474,9 @@ static MACHINE_CONFIG_START( cop01, cop01_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(cop01)
+	MCFG_SCREEN_UPDATE_STATIC(cop01)
 
 	MCFG_GFXDECODE(cop01)
 	MCFG_PALETTE_LENGTH(16+8*16+16*16)
@@ -517,10 +516,9 @@ static MACHINE_CONFIG_START( mightguy, cop01_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(cop01)
+	MCFG_SCREEN_UPDATE_STATIC(cop01)
 
 	MCFG_GFXDECODE(cop01)
 	MCFG_PALETTE_LENGTH(16+8*16+16*16)
