@@ -886,19 +886,19 @@ GFXDECODE_END
 static const char *const cosmica_sample_names[] =
 {
 	"*cosmica",
-	"backgr.wav",
-	"extend.wav",
-	"divea.wav",
-	"diveb1.wav",
-	"diveb2.wav",
-	"diveb3.wav",
-	"diveb4.wav",
-	"diveb5.wav",
-	"diveb6.wav",
-	"fire.wav",
-	"loudexp.wav",
-	"smallexp.wav",
-	"coin.wav",
+	"backgr",
+	"extend",
+	"divea",
+	"diveb1",
+	"diveb2",
+	"diveb3",
+	"diveb4",
+	"diveb5",
+	"diveb6",
+	"fire",
+	"loudexp",
+	"smallexp",
+	"coin",
 	0       /* end of array */
 };
 
@@ -913,17 +913,17 @@ static const samples_interface cosmica_samples_interface =
 static const char *const panic_sample_names[] =
 {
 	"*panic",
-	"walk.wav",
-	"upordown.wav",
-	"trapped.wav",
-	"falling.wav",
-	"escaping.wav",
-	"ekilled.wav",
-	"death.wav",
-	"elaugh.wav",
-	"extral.wav",
-	"oxygen.wav",
-	"coin.wav",
+	"walk",
+	"upordown",
+	"trapped",
+	"falling",
+	"escaping",
+	"ekilled",
+	"death",
+	"elaugh",
+	"extral",
+	"oxygen",
+	"coin",
 	0
 };
 
@@ -936,21 +936,21 @@ static const samples_interface panic_samples_interface =
 static const char *const cosmicg_sample_names[] =
 {
 	"*cosmicg",
-	"cg_m0.wav",	/* 8 Different pitches of March Sound */
-	"cg_m1.wav",
-	"cg_m2.wav",
-	"cg_m3.wav",
-	"cg_m4.wav",
-	"cg_m5.wav",
-	"cg_m6.wav",
-	"cg_m7.wav",
-	"cg_att.wav",	/* Killer Attack */
-	"cg_chnc.wav",	/* Bonus Chance  */
-	"cg_gotb.wav",	/* Got Bonus - have not got correct sound for */
-	"cg_dest.wav",	/* Gun Destroy */
-	"cg_gun.wav",	/* Gun Shot */
-	"cg_gotm.wav",	/* Got Monster */
-	"cg_ext.wav",	/* Coin Extend */
+	"cg_m0",	/* 8 Different pitches of March Sound */
+	"cg_m1",
+	"cg_m2",
+	"cg_m3",
+	"cg_m4",
+	"cg_m5",
+	"cg_m6",
+	"cg_m7",
+	"cg_att",	/* Killer Attack */
+	"cg_chnc",	/* Bonus Chance  */
+	"cg_gotb",	/* Got Bonus - have not got correct sound for */
+	"cg_dest",	/* Gun Destroy */
+	"cg_gun",	/* Gun Shot */
+	"cg_gotm",	/* Got Monster */
+	"cg_ext",	/* Coin Extend */
 	0
 };
 
@@ -1001,7 +1001,6 @@ static MACHINE_CONFIG_START( cosmic, cosmic_state )
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
 MACHINE_CONFIG_END
@@ -1031,7 +1030,7 @@ static MACHINE_CONFIG_DERIVED( panic, cosmic )
 
 	MCFG_PALETTE_INIT(panic)
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(panic)
+	MCFG_SCREEN_UPDATE_STATIC(panic)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1057,7 +1056,7 @@ static MACHINE_CONFIG_DERIVED( cosmica, cosmic )
 
 	MCFG_PALETTE_INIT(cosmica)
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(cosmica)
+	MCFG_SCREEN_UPDATE_STATIC(cosmica)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1089,10 +1088,9 @@ static MACHINE_CONFIG_START( cosmicg, cosmic_state )
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(cosmicg)
+	MCFG_SCREEN_UPDATE_STATIC(cosmicg)
 
 	MCFG_PALETTE_LENGTH(16)
 
@@ -1122,7 +1120,7 @@ static MACHINE_CONFIG_DERIVED( magspot, cosmic )
 
 	MCFG_PALETTE_INIT(magspot)
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(magspot)
+	MCFG_SCREEN_UPDATE_STATIC(magspot)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1138,7 +1136,7 @@ static MACHINE_CONFIG_DERIVED( devzone, magspot )
 
 	/* video hardware */
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(devzone)
+	MCFG_SCREEN_UPDATE_STATIC(devzone)
 MACHINE_CONFIG_END
 
 
@@ -1154,7 +1152,7 @@ static MACHINE_CONFIG_DERIVED( nomnlnd, cosmic )
 
 	MCFG_PALETTE_INIT(nomnlnd)
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(nomnlnd)
+	MCFG_SCREEN_UPDATE_STATIC(nomnlnd)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
