@@ -26,6 +26,7 @@
 #include "sound/dac.h"
 #include "rendlay.h"
 #include "audio/atarijsa.h"
+#include "video/atarimo.h"
 #include "includes/cyberbal.h"
 
 
@@ -35,37 +36,37 @@
  *
  *************************************/
 
-static void update_interrupts(running_machine *machine)
+static void update_interrupts(running_machine &machine)
 {
-	cyberbal_state *state = machine->driver_data<cyberbal_state>();
-	cputag_set_input_line(machine, "maincpu", 1, state->sound_int_state ? ASSERT_LINE : CLEAR_LINE);
-	cputag_set_input_line(machine, "extra", 1, state->video_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cyberbal_state *state = machine.driver_data<cyberbal_state>();
+	cputag_set_input_line(machine, "maincpu", 1, state->m_sound_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "extra", 1, state->m_video_int_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static MACHINE_START( cyberbal )
 {
-	cyberbal_state *state = machine->driver_data<cyberbal_state>();
+	cyberbal_state *state = machine.driver_data<cyberbal_state>();
 	atarigen_init(machine);
 
-	state_save_register_global(machine, state->fast_68k_int);
-	state_save_register_global(machine, state->io_68k_int);
-	state_save_register_global(machine, state->sound_data_from_68k);
-	state_save_register_global(machine, state->sound_data_from_6502);
-	state_save_register_global(machine, state->sound_data_from_68k_ready);
-	state_save_register_global(machine, state->sound_data_from_6502_ready);
+	state->save_item(NAME(state->m_fast_68k_int));
+	state->save_item(NAME(state->m_io_68k_int));
+	state->save_item(NAME(state->m_sound_data_from_68k));
+	state->save_item(NAME(state->m_sound_data_from_6502));
+	state->save_item(NAME(state->m_sound_data_from_68k_ready));
+	state->save_item(NAME(state->m_sound_data_from_6502_ready));
 }
 
 
 static MACHINE_RESET( cyberbal )
 {
-	cyberbal_state *state = machine->driver_data<cyberbal_state>();
+	cyberbal_state *state = machine.driver_data<cyberbal_state>();
 
 	atarigen_eeprom_reset(state);
 	atarigen_slapstic_reset(state);
 	atarigen_interrupt_reset(state, update_interrupts);
-	atarigen_scanline_timer_reset(*machine->primary_screen, cyberbal_scanline_update, 8);
-	atarigen_sound_io_reset(machine->device("audiocpu"));
+	atarigen_scanline_timer_reset(*machine.primary_screen, cyberbal_scanline_update, 8);
+	atarigen_sound_io_reset(machine.device("audiocpu"));
 
 	cyberbal_sound_reset(machine);
 
@@ -74,21 +75,21 @@ static MACHINE_RESET( cyberbal )
 }
 
 
-static void cyberbal2p_update_interrupts(running_machine *machine)
+static void cyberbal2p_update_interrupts(running_machine &machine)
 {
-	cyberbal_state *state = machine->driver_data<cyberbal_state>();
-	cputag_set_input_line(machine, "maincpu", 1, state->video_int_state ? ASSERT_LINE : CLEAR_LINE);
-	cputag_set_input_line(machine, "maincpu", 3, state->sound_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cyberbal_state *state = machine.driver_data<cyberbal_state>();
+	cputag_set_input_line(machine, "maincpu", 1, state->m_video_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 3, state->m_sound_int_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static MACHINE_RESET( cyberbal2p )
 {
-	cyberbal_state *state = machine->driver_data<cyberbal_state>();
+	cyberbal_state *state = machine.driver_data<cyberbal_state>();
 
 	atarigen_eeprom_reset(state);
 	atarigen_interrupt_reset(state, cyberbal2p_update_interrupts);
-	atarigen_scanline_timer_reset(*machine->primary_screen, cyberbal_scanline_update, 8);
+	atarigen_scanline_timer_reset(*machine.primary_screen, cyberbal_scanline_update, 8);
 	atarijsa_reset();
 }
 
@@ -102,27 +103,27 @@ static MACHINE_RESET( cyberbal2p )
 
 static READ16_HANDLER( special_port0_r )
 {
-	cyberbal_state *state = space->machine->driver_data<cyberbal_state>();
-	int temp = input_port_read(space->machine, "IN0");
-	if (state->cpu_to_sound_ready) temp ^= 0x0080;
+	cyberbal_state *state = space->machine().driver_data<cyberbal_state>();
+	int temp = input_port_read(space->machine(), "IN0");
+	if (state->m_cpu_to_sound_ready) temp ^= 0x0080;
 	return temp;
 }
 
 
 static READ16_HANDLER( special_port2_r )
 {
-	cyberbal_state *state = space->machine->driver_data<cyberbal_state>();
-	int temp = input_port_read(space->machine, "IN2");
-	if (state->cpu_to_sound_ready) temp ^= 0x2000;
+	cyberbal_state *state = space->machine().driver_data<cyberbal_state>();
+	int temp = input_port_read(space->machine(), "IN2");
+	if (state->m_cpu_to_sound_ready) temp ^= 0x2000;
 	return temp;
 }
 
 
 static READ16_HANDLER( sound_state_r )
 {
-	cyberbal_state *state = space->machine->driver_data<cyberbal_state>();
+	cyberbal_state *state = space->machine().driver_data<cyberbal_state>();
 	int temp = 0xffff;
-	if (state->cpu_to_sound_ready) temp ^= 0xffff;
+	if (state->m_cpu_to_sound_ready) temp ^= 0xffff;
 	return temp;
 }
 
@@ -136,7 +137,7 @@ static READ16_HANDLER( sound_state_r )
 
 static WRITE16_HANDLER( p2_reset_w )
 {
-	cputag_set_input_line(space->machine, "extra", INPUT_LINE_RESET, CLEAR_LINE);
+	cputag_set_input_line(space->machine(), "extra", INPUT_LINE_RESET, CLEAR_LINE);
 }
 
 
@@ -147,7 +148,7 @@ static WRITE16_HANDLER( p2_reset_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0xfc0000, 0xfc0fff) AM_READWRITE(atarigen_eeprom_r, atarigen_eeprom_w) AM_SHARE("eeprom")
 	AM_RANGE(0xfc8000, 0xfcffff) AM_READ(atarigen_sound_upper_r)
@@ -158,15 +159,15 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xfd8000, 0xfd9fff) AM_WRITE(atarigen_sound_upper_w)
 	AM_RANGE(0xfe0000, 0xfe0fff) AM_READ(special_port0_r)
 	AM_RANGE(0xfe1000, 0xfe1fff) AM_READ_PORT("IN1")
-	AM_RANGE(0xfe8000, 0xfe8fff) AM_RAM_WRITE(cyberbal_paletteram_1_w) AM_SHARE("share1") AM_BASE_MEMBER(cyberbal_state, paletteram_1)
-	AM_RANGE(0xfec000, 0xfecfff) AM_RAM_WRITE(cyberbal_paletteram_0_w) AM_SHARE("share2") AM_BASE_MEMBER(cyberbal_state, paletteram_0)
-	AM_RANGE(0xff0000, 0xff1fff) AM_RAM_WRITE(atarigen_playfield2_w)   AM_SHARE("share3") AM_BASE_MEMBER(cyberbal_state, playfield2)
-	AM_RANGE(0xff2000, 0xff2fff) AM_RAM_WRITE(atarigen_alpha2_w)       AM_SHARE("share4") AM_BASE_MEMBER(cyberbal_state, alpha2)
-	AM_RANGE(0xff3000, 0xff37ff) AM_RAM_WRITE(atarimo_1_spriteram_w)   AM_SHARE("share5") AM_BASE(&atarimo_1_spriteram)
+	AM_RANGE(0xfe8000, 0xfe8fff) AM_RAM_WRITE(cyberbal_paletteram_1_w) AM_SHARE("share1") AM_BASE_MEMBER(cyberbal_state, m_paletteram_1)
+	AM_RANGE(0xfec000, 0xfecfff) AM_RAM_WRITE(cyberbal_paletteram_0_w) AM_SHARE("share2") AM_BASE_MEMBER(cyberbal_state, m_paletteram_0)
+	AM_RANGE(0xff0000, 0xff1fff) AM_RAM_WRITE(atarigen_playfield2_w)   AM_SHARE("share3") AM_BASE_MEMBER(cyberbal_state, m_playfield2)
+	AM_RANGE(0xff2000, 0xff2fff) AM_RAM_WRITE(atarigen_alpha2_w)       AM_SHARE("share4") AM_BASE_MEMBER(cyberbal_state, m_alpha2)
+	AM_RANGE(0xff3000, 0xff37ff) AM_READWRITE(atarimo_1_spriteram_r, atarimo_1_spriteram_w)
 	AM_RANGE(0xff3800, 0xff3fff) AM_RAM                                           AM_SHARE("share6")
-	AM_RANGE(0xff4000, 0xff5fff) AM_RAM_WRITE(atarigen_playfield_w)    AM_SHARE("share7") AM_BASE_MEMBER(cyberbal_state, playfield)
-	AM_RANGE(0xff6000, 0xff6fff) AM_RAM_WRITE(atarigen_alpha_w)        AM_SHARE("share8") AM_BASE_MEMBER(cyberbal_state, alpha)
-	AM_RANGE(0xff7000, 0xff77ff) AM_RAM_WRITE(atarimo_0_spriteram_w)   AM_SHARE("share9") AM_BASE(&atarimo_0_spriteram)
+	AM_RANGE(0xff4000, 0xff5fff) AM_RAM_WRITE(atarigen_playfield_w)    AM_SHARE("share7") AM_BASE_MEMBER(cyberbal_state, m_playfield)
+	AM_RANGE(0xff6000, 0xff6fff) AM_RAM_WRITE(atarigen_alpha_w)        AM_SHARE("share8") AM_BASE_MEMBER(cyberbal_state, m_alpha)
+	AM_RANGE(0xff7000, 0xff77ff) AM_READWRITE(atarimo_0_spriteram_r, atarimo_0_spriteram_w)
 	AM_RANGE(0xff7800, 0xff9fff) AM_RAM                                           AM_SHARE("share10")
 	AM_RANGE(0xffa000, 0xffbfff) AM_READONLY AM_WRITENOP               AM_SHARE("share11")
 	AM_RANGE(0xffc000, 0xffffff) AM_RAM                                           AM_SHARE("share12")
@@ -180,7 +181,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( extra_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( extra_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0xfc0000, 0xfdffff) AM_WRITE(atarigen_video_int_ack_w)
 	AM_RANGE(0xfe0000, 0xfe0fff) AM_READ(special_port0_r)
@@ -189,11 +190,11 @@ static ADDRESS_MAP_START( extra_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xfec000, 0xfecfff) AM_RAM_WRITE(cyberbal_paletteram_0_w) AM_SHARE("share2")
 	AM_RANGE(0xff0000, 0xff1fff) AM_RAM_WRITE(atarigen_playfield2_w)   AM_SHARE("share3")
 	AM_RANGE(0xff2000, 0xff2fff) AM_RAM_WRITE(atarigen_alpha2_w)       AM_SHARE("share4")
-	AM_RANGE(0xff3000, 0xff37ff) AM_RAM_WRITE(atarimo_1_spriteram_w)   AM_SHARE("share5")
+	AM_RANGE(0xff3000, 0xff37ff) AM_READWRITE(atarimo_1_spriteram_r, atarimo_1_spriteram_w)
 	AM_RANGE(0xff3800, 0xff3fff) AM_RAM                                           AM_SHARE("share6")
 	AM_RANGE(0xff4000, 0xff5fff) AM_RAM_WRITE(atarigen_playfield_w)    AM_SHARE("share7")
 	AM_RANGE(0xff6000, 0xff6fff) AM_RAM_WRITE(atarigen_alpha_w)        AM_SHARE("share8")
-	AM_RANGE(0xff7000, 0xff77ff) AM_RAM_WRITE(atarimo_0_spriteram_w)   AM_SHARE("share9")
+	AM_RANGE(0xff7000, 0xff77ff) AM_READWRITE(atarimo_0_spriteram_r, atarimo_0_spriteram_w)
 	AM_RANGE(0xff7800, 0xff9fff) AM_RAM                                           AM_SHARE("share10")
 	AM_RANGE(0xffa000, 0xffbfff) AM_RAM                                           AM_SHARE("share11")
 	AM_RANGE(0xffc000, 0xffffff) AM_READONLY AM_WRITENOP               AM_SHARE("share12")
@@ -207,7 +208,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM
 	AM_RANGE(0x2000, 0x2001) AM_DEVREADWRITE("ymsnd", ym2151_r, ym2151_w)
 	AM_RANGE(0x2800, 0x2801) AM_WRITE(cyberbal_sound_68k_6502_w)
@@ -230,7 +231,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( sound_68k_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( sound_68k_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0xff8000, 0xff87ff) AM_READ(cyberbal_sound_68k_r)
 	AM_RANGE(0xff8800, 0xff8fff) AM_WRITE(cyberbal_sound_68k_w)
@@ -247,7 +248,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( cyberbal2p_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( cyberbal2p_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0xfc0000, 0xfc0003) AM_READ_PORT("IN0")
 	AM_RANGE(0xfc2000, 0xfc2003) AM_READ_PORT("IN1")
@@ -261,9 +262,9 @@ static ADDRESS_MAP_START( cyberbal2p_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xfd6000, 0xfd6003) AM_WRITE(atarigen_video_int_ack_w)
 	AM_RANGE(0xfd8000, 0xfd8003) AM_WRITE(atarigen_sound_upper_w)
 	AM_RANGE(0xfe0000, 0xfe0003) AM_READ(sound_state_r)
-	AM_RANGE(0xff0000, 0xff1fff) AM_RAM_WRITE(atarigen_playfield_w) AM_BASE_MEMBER(cyberbal_state, playfield)
-	AM_RANGE(0xff2000, 0xff2fff) AM_RAM_WRITE(atarigen_alpha_w) AM_BASE_MEMBER(cyberbal_state, alpha)
-	AM_RANGE(0xff3000, 0xff37ff) AM_RAM_WRITE(atarimo_0_spriteram_w) AM_BASE(&atarimo_0_spriteram)
+	AM_RANGE(0xff0000, 0xff1fff) AM_RAM_WRITE(atarigen_playfield_w) AM_BASE_MEMBER(cyberbal_state, m_playfield)
+	AM_RANGE(0xff2000, 0xff2fff) AM_RAM_WRITE(atarigen_alpha_w) AM_BASE_MEMBER(cyberbal_state, m_alpha)
+	AM_RANGE(0xff3000, 0xff37ff) AM_READWRITE(atarimo_0_spriteram_r, atarimo_0_spriteram_w)
 	AM_RANGE(0xff3800, 0xffffff) AM_RAM
 ADDRESS_MAP_END
 
@@ -447,7 +448,7 @@ static MACHINE_CONFIG_START( cyberbal, cyberbal_state )
 	MCFG_CPU_PROGRAM_MAP(sound_68k_map)
 	MCFG_CPU_PERIODIC_INT(cyberbal_sound_68k_irq_gen, 10000)
 
-	MCFG_QUANTUM_TIME(HZ(600))
+	MCFG_QUANTUM_TIME(attotime::from_hz(600))
 
 	MCFG_MACHINE_START(cyberbal)
 	MCFG_MACHINE_RESET(cyberbal)
@@ -459,19 +460,18 @@ static MACHINE_CONFIG_START( cyberbal, cyberbal_state )
 	MCFG_PALETTE_LENGTH(4096)
 
 	MCFG_SCREEN_ADD("lscreen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses an SOS-2 chip to generate video signals */
 	MCFG_SCREEN_RAW_PARAMS(ATARI_CLOCK_14MHz, 456*2, 0, 336*2, 262, 0, 240)
+	MCFG_SCREEN_UPDATE_STATIC(cyberbal_left)
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses an SOS-2 chip to generate video signals */
 	MCFG_SCREEN_RAW_PARAMS(ATARI_CLOCK_14MHz, 456*2, 0, 336*2, 262, 0, 240)
+	MCFG_SCREEN_UPDATE_STATIC(cyberbal_right)
 
 	MCFG_VIDEO_START(cyberbal)
-	MCFG_VIDEO_UPDATE(cyberbal)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
@@ -506,13 +506,12 @@ static MACHINE_CONFIG_START( cyberbal2p, cyberbal_state )
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses an SOS-2 chip to generate video signals */
 	MCFG_SCREEN_RAW_PARAMS(ATARI_CLOCK_14MHz, 456*2, 0, 336*2, 262, 0, 240)
+	MCFG_SCREEN_UPDATE_STATIC(cyberbal2p)
 
 	MCFG_VIDEO_START(cyberbal2p)
-	MCFG_VIDEO_UPDATE(cyberbal)
 
 	/* sound hardware */
 	MCFG_FRAGMENT_ADD(jsa_ii_mono)
@@ -1008,13 +1007,13 @@ ROM_END
 
 static DRIVER_INIT( cyberbal )
 {
-	atarigen_slapstic_init(machine->device("maincpu"), 0x018000, 0, 0);
+	atarigen_slapstic_init(machine.device("maincpu"), 0x018000, 0, 0);
 }
 
 
 static DRIVER_INIT( cyberbalt )
 {
-	atarigen_slapstic_init(machine->device("maincpu"), 0x018000, 0, 116);
+	atarigen_slapstic_init(machine.device("maincpu"), 0x018000, 0, 116);
 }
 
 
