@@ -396,10 +396,9 @@ static MACHINE_CONFIG_START( dbz, dbz_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(55)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 40*8)
 	MCFG_SCREEN_VISIBLE_AREA(0, 48*8-1, 0, 32*8-1)
-	MCFG_SCREEN_UPDATE(dbz)
+	MCFG_SCREEN_UPDATE_STATIC(dbz)
 
 	MCFG_GFXDECODE(dbz)
 
