@@ -1142,9 +1142,9 @@ static const ay8910_interface equites_8910intf =
 static const char *const alphamc07_sample_names[] =
 {
 	"*alphamc07",
-	"bongo1.wav",
-	"bongo2.wav",
-	"bongo3.wav",
+	"bongo1",
+	"bongo2",
+	"bongo3",
 	0
 };
 
@@ -1275,10 +1275,9 @@ static MACHINE_CONFIG_START( equites, equites_state )
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 3*8, 29*8-1)
-	MCFG_SCREEN_UPDATE(equites)
+	MCFG_SCREEN_UPDATE_STATIC(equites)
 
 	MCFG_GFXDECODE(equites)
 	MCFG_PALETTE_LENGTH(0x180)
@@ -1313,10 +1312,9 @@ static MACHINE_CONFIG_START( splndrbt, equites_state )
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(splndrbt)
+	MCFG_SCREEN_UPDATE_STATIC(splndrbt)
 
 	MCFG_GFXDECODE(splndrbt)
 	MCFG_PALETTE_LENGTH(0x280)
