@@ -79,12 +79,19 @@ public:
 	gei_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag) { }
 
+	virtual void video_start();
+
+	UINT32 screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
+
+	bitmap_ind16 m_bitmap;
+
 	UINT8 m_drawctrl[3];
 	UINT8 m_color[8];
 	int m_prevoffset;
 	int m_yadd;
 	int m_signature_answer;
 	int m_signature_pos;
+	UINT8 m_nmi_mask;
 };
 
 
@@ -115,7 +122,7 @@ static WRITE8_HANDLER( gei_bitmap_w )
 
 
 	for (i = 0; i < 8; i++)
-		*BITMAP_ADDR16(space->machine().generic.tmpbitmap, sy, sx+i) = state->m_color[8-i-1];
+		state->m_bitmap.pix16(sy, sx+i) = state->m_color[8-i-1];
 }
 
 static PALETTE_INIT(gei)
@@ -138,6 +145,17 @@ static PALETTE_INIT(quizvid)
 	}
 }
 
+void gei_state::video_start()
+{
+	machine().primary_screen->register_screen_bitmap(m_bitmap);
+}
+
+UINT32 gei_state::screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
+{
+	copybitmap(bitmap, m_bitmap, 0, 0, 0, 0, cliprect);
+	return 0;
+}
+
 static WRITE8_DEVICE_HANDLER( lamps_w )
 {
 	/* 5 button lamps */
@@ -157,6 +175,7 @@ static WRITE8_DEVICE_HANDLER( lamps_w )
 static WRITE8_DEVICE_HANDLER( sound_w )
 {
 	address_space *space = device->machine().device("maincpu")->memory().space(AS_PROGRAM);
+	gei_state *state = space->machine().driver_data<gei_state>();
 
 	/* bit 3 - coin lockout, lamp10 in poker / lamp6 in trivia test modes */
 	coin_lockout_global_w(device->machine(), ~data & 0x08);
@@ -166,7 +185,7 @@ static WRITE8_DEVICE_HANDLER( sound_w )
 	ticket_dispenser_w(device->machine().device("ticket"), 0, (data & 0x20)<< 2);
 
 	/* bit 6 enables NMI */
-	interrupt_enable_w(space, 0, data & 0x40);
+	state->m_nmi_mask = data & 0x40;
 
 	/* bit 7 goes directly to the sound amplifier */
 	dac_data_w(device->machine().device("dac"), ((data & 0x80) >> 7) * 255);
@@ -198,12 +217,13 @@ static WRITE8_DEVICE_HANDLER( lamps2_w )
 static WRITE8_DEVICE_HANDLER( nmi_w )
 {
 	address_space *space = device->machine().device("maincpu")->memory().space(AS_PROGRAM);
+	gei_state *state = space->machine().driver_data<gei_state>();
 
 	/* bit 4 - play/raise button lamp, lamp 9 in selection test mode  */
 	set_led_status(device->machine(), 8,data & 0x10);
 
 	/* bit 6 enables NMI */
-	interrupt_enable_w(space, 0, data & 0x40);
+	state->m_nmi_mask = data & 0x40;
 }
 
 static READ8_HANDLER( catchall )
@@ -1063,27 +1083,33 @@ static const ppi8255_interface findout_ppi8255_intf[2] =
 	}
 };
 
+static INTERRUPT_GEN( vblank_irq )
+{
+	gei_state *state = device->machine().driver_data<gei_state>();
+
+	if(state->m_nmi_mask)
+		device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
+}
+
+
 static MACHINE_CONFIG_START( getrivia, gei_state )
 	MCFG_CPU_ADD("maincpu",Z80,4000000) /* 4 MHz */
 	MCFG_CPU_PROGRAM_MAP(getrivia_map)
-	MCFG_CPU_VBLANK_INT("screen", nmi_line_pulse)
+	MCFG_CPU_VBLANK_INT("screen", vblank_irq)
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_UPDATE_DRIVER(gei_state, screen_update)
 	MCFG_SCREEN_SIZE(512, 256)
 	MCFG_SCREEN_VISIBLE_AREA(48, 511-48, 16, 255-16)
-	MCFG_SCREEN_UPDATE(generic_bitmapped)
 
 	MCFG_PALETTE_LENGTH(8)
 	MCFG_PALETTE_INIT(gei)
 
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MCFG_VIDEO_START(generic_bitmapped)
-
 	MCFG_PPI8255_ADD( "ppi8255_0", getrivia_ppi8255_intf[0] )
 	MCFG_PPI8255_ADD( "ppi8255_1", getrivia_ppi8255_intf[1] )
 	MCFG_TICKET_DISPENSER_ADD("ticket", 100, TICKET_MOTOR_ACTIVE_HIGH, TICKET_STATUS_ACTIVE_HIGH)
@@ -1263,7 +1289,7 @@ Sets will be listed by "series" - the program code version
  is not as important as maintaining the correct questions
  sets as per known series
 Missing sets will be filled as dumped, as question roms
- are interchangable, operators did thier own swaps
+ are interchangeable, operators did thier own swaps
 
 Note: Question roms that contain "#1" (or 2 ect)
       are corrected roms (spelling and / or answers)
@@ -1669,7 +1695,7 @@ ROM_START( gt103a3 )
 	ROM_REGION( 0x38000, "maincpu", 0 )
 	ROM_LOAD( "t_3a-8_1.bin",    0x00000, 0x4000, CRC(02aef306) SHA1(1ffc10c79a55d41ea36bcaab13cb3f02cb3f9712) )
 	ROM_LOAD( "rock-n-roll_alt", 0x10000, 0x8000, CRC(8eb83052) SHA1(93e3c1ae6c2048fb44ecafe1013b6a96da38fa84) ) /* Questions from an unknown set, will be corrected when verified */
-	ROM_LOAD( "history-geog.",   0x18000, 0x8000, CRC(c9a70fc3) SHA1(4021e5d702844416e8c798ed0a57c9ecd20b1d4b) ) /* These questions are likely mix-n-match do to opperator swaps   */
+	ROM_LOAD( "history-geog",    0x18000, 0x8000, CRC(c9a70fc3) SHA1(4021e5d702844416e8c798ed0a57c9ecd20b1d4b) ) /* These questions are likely mix-n-match do to opperator swaps   */
 	ROM_LOAD( "the_sixties",     0x20000, 0x8000, CRC(8cfa854e) SHA1(81428c12f99841db1c61b471ac8d00f0c411883b) ) /* Currently unverified are Series 12, 13 & 14 */
 	ROM_LOAD( "tv_comedies",     0x28000, 0x8000, CRC(992ae38e) SHA1(312780d651a85a1c433f587ff2ede579456d3fd9) )
 ROM_END
