@@ -317,10 +317,9 @@ static MACHINE_CONFIG_START( gijoe, gijoe_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(24, 24+288-1, 16, 16+224-1)
-	MCFG_SCREEN_UPDATE(gijoe)
+	MCFG_SCREEN_UPDATE_STATIC(gijoe)
 
 	MCFG_PALETTE_LENGTH(2048)
 
