@@ -350,10 +350,9 @@ static MACHINE_CONFIG_START( gradius3, gradius3_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 2*8, 30*8-1 )
-	MCFG_SCREEN_UPDATE(gradius3)
+	MCFG_SCREEN_UPDATE_STATIC(gradius3)
 
 	MCFG_PALETTE_LENGTH(2048)
 
