@@ -312,7 +312,6 @@ static MACHINE_CONFIG_START( gunsmoke, gunsmoke_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
@@ -321,7 +320,7 @@ static MACHINE_CONFIG_START( gunsmoke, gunsmoke_state )
 
 	MCFG_PALETTE_INIT(gunsmoke)
 	MCFG_VIDEO_START(gunsmoke)
-	MCFG_SCREEN_UPDATE(gunsmoke)
+	MCFG_SCREEN_UPDATE_STATIC(gunsmoke)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
