@@ -44,7 +44,7 @@ static WRITE8_HANDLER( hitme_vidram_w )
 
 	/* mark this tile dirty */
 	state->m_videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_tilemap, offset);
+	state->m_tilemap->mark_tile_dirty(offset);
 }
 
 
@@ -69,11 +69,11 @@ static VIDEO_START( barricad )
 }
 
 
-static SCREEN_UPDATE( hitme )
+static SCREEN_UPDATE_IND16( hitme )
 {
-	hitme_state *state = screen->machine().driver_data<hitme_state>();
+	hitme_state *state = screen.machine().driver_data<hitme_state>();
 	/* the card width resistor comes from an input port, scaled to the range 0-25 kOhms */
-	double width_resist = input_port_read(screen->machine(), "WIDTH") * 25000 / 100;
+	double width_resist = input_port_read(screen.machine(), "WIDTH") * 25000 / 100;
 	/* this triggers a oneshot for the following length of time */
 	double width_duration = 0.45 * 1000e-12 * width_resist;
 	/* the dot clock runs at the standard horizontal frequency * 320+16 clocks per scanline */
@@ -84,12 +84,12 @@ static SCREEN_UPDATE( hitme )
 	offs_t offs = 0;
 
 	/* start by drawing the tilemap */
-	tilemap_draw(bitmap, cliprect, state->m_tilemap, 0, 0);
+	state->m_tilemap->draw(bitmap, cliprect, 0, 0);
 
 	/* now loop over and invert anything */
 	for (y = 0; y < 19; y++)
 	{
-		int dy = bitmap->rowpixels;
+		int dy = bitmap.rowpixels();
 		for (inv = x = 0; x < 40; x++, offs++)
 		{
 			/* if the high bit is set, reset the oneshot */
@@ -99,7 +99,7 @@ static SCREEN_UPDATE( hitme )
 			/* invert pixels until we run out */
 			for (xx = 0; xx < 8 && inv; xx++, inv--)
 			{
-				UINT16 *dest = BITMAP_ADDR16(bitmap, y * 10, x * 8 + xx);
+				UINT16 *dest = &bitmap.pix16(y * 10, x * 8 + xx);
 				dest[0 * dy] ^= 1;
 				dest[1 * dy] ^= 1;
 				dest[2 * dy] ^= 1;
@@ -117,10 +117,10 @@ static SCREEN_UPDATE( hitme )
 }
 
 
-static SCREEN_UPDATE( barricad )
+static SCREEN_UPDATE_IND16( barricad )
 {
-	hitme_state *state = screen->machine().driver_data<hitme_state>();
-	tilemap_draw(bitmap, cliprect, state->m_tilemap, 0, 0);
+	hitme_state *state = screen.machine().driver_data<hitme_state>();
+	state->m_tilemap->draw(bitmap, cliprect, 0, 0);
 	return 0;
 }
 
@@ -330,10 +330,9 @@ static MACHINE_CONFIG_START( hitme, hitme_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(40*8, 19*10)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 19*10-1)
-	MCFG_SCREEN_UPDATE(hitme)
+	MCFG_SCREEN_UPDATE_STATIC(hitme)
 
 	MCFG_GFXDECODE(hitme)
 	MCFG_PALETTE_LENGTH(2)
@@ -363,7 +362,7 @@ static MACHINE_CONFIG_DERIVED( barricad, hitme )
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_SIZE(32*8, 24*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 24*8-1)
-	MCFG_SCREEN_UPDATE(barricad)
+	MCFG_SCREEN_UPDATE_STATIC(barricad)
 
 	MCFG_GFXDECODE(barricad)
 
@@ -620,7 +619,7 @@ Etched in copper on back    FAB 550595-C
 
 .h7 IM560?      handwritten HM0-CG  hard to read
 
-All chips we read as 82s141 - guessed becuase of 24 pin pinout and 512x8 rom according to mame
+All chips we read as 82s141 - guessed because of 24 pin pinout and 512x8 rom according to mame
 */
 
 ROM_START( hitme )
