@@ -36,7 +36,6 @@ fix comms so it boots, it's a bit of a hack for hyperduel at the moment ;-)
 
 #include "emu.h"
 #include "cpu/m68000/m68000.h"
-#include "deprecat.h"
 #include "sound/2151intf.h"
 #include "sound/okim6295.h"
 #include "sound/2413intf.h"
@@ -46,88 +45,88 @@ fix comms so it boots, it's a bit of a hack for hyperduel at the moment ;-)
                                 Interrupts
 ***************************************************************************/
 
-static void update_irq_state( running_machine *machine )
+static void update_irq_state( running_machine &machine )
 {
-	hyprduel_state *state = machine->driver_data<hyprduel_state>();
-	int irq = state->requested_int & ~*state->irq_enable;
+	hyprduel_state *state = machine.driver_data<hyprduel_state>();
+	int irq = state->m_requested_int & ~*state->m_irq_enable;
 
-	cpu_set_input_line(state->maincpu, 3, (irq & state->int_num) ? ASSERT_LINE : CLEAR_LINE);
+	device_set_input_line(state->m_maincpu, 3, (irq & state->m_int_num) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static TIMER_CALLBACK( vblank_end_callback )
 {
-	hyprduel_state *state = machine->driver_data<hyprduel_state>();
-	state->requested_int &= ~param;
+	hyprduel_state *state = machine.driver_data<hyprduel_state>();
+	state->m_requested_int &= ~param;
 }
 
-static INTERRUPT_GEN( hyprduel_interrupt )
+static TIMER_DEVICE_CALLBACK( hyprduel_interrupt )
 {
-	hyprduel_state *state = device->machine->driver_data<hyprduel_state>();
-	int line = RASTER_LINES - cpu_getiloops(device);
+	hyprduel_state *state = timer.machine().driver_data<hyprduel_state>();
+	int line = param;
 
-	if (line == RASTER_LINES)
+	if (line == 0) /* TODO: fix this! */
 	{
-		state->requested_int |= 0x01;		/* vblank */
-		state->requested_int |= 0x20;
-		cpu_set_input_line(device, 2, HOLD_LINE);
+		state->m_requested_int |= 0x01;		/* vblank */
+		state->m_requested_int |= 0x20;
+		device_set_input_line(state->m_maincpu, 2, HOLD_LINE);
 		/* the duration is a guess */
-		timer_set(device->machine, ATTOTIME_IN_USEC(2500), NULL, 0x20, vblank_end_callback);
+		timer.machine().scheduler().timer_set(attotime::from_usec(2500), FUNC(vblank_end_callback), 0x20);
 	}
 	else
-		state->requested_int |= 0x12;		/* hsync */
+		state->m_requested_int |= 0x12;		/* hsync */
 
-	update_irq_state(device->machine);
+	update_irq_state(timer.machine());
 }
 
 static READ16_HANDLER( hyprduel_irq_cause_r )
 {
-	hyprduel_state *state = space->machine->driver_data<hyprduel_state>();
-	return state->requested_int;
+	hyprduel_state *state = space->machine().driver_data<hyprduel_state>();
+	return state->m_requested_int;
 }
 
 static WRITE16_HANDLER( hyprduel_irq_cause_w )
 {
-	hyprduel_state *state = space->machine->driver_data<hyprduel_state>();
+	hyprduel_state *state = space->machine().driver_data<hyprduel_state>();
 	if (ACCESSING_BITS_0_7)
 	{
-		if (data == state->int_num)
-			state->requested_int &= ~(state->int_num & ~*state->irq_enable);
+		if (data == state->m_int_num)
+			state->m_requested_int &= ~(state->m_int_num & ~*state->m_irq_enable);
 		else
-			state->requested_int &= ~(data & *state->irq_enable);
+			state->m_requested_int &= ~(data & *state->m_irq_enable);
 
-		update_irq_state(space->machine);
+		update_irq_state(space->machine());
 	}
 }
 
 
 static WRITE16_HANDLER( hyprduel_subcpu_control_w )
 {
-	hyprduel_state *state = space->machine->driver_data<hyprduel_state>();
+	hyprduel_state *state = space->machine().driver_data<hyprduel_state>();
 
 	switch (data)
 	{
 		case 0x0d:
 		case 0x0f:
 		case 0x01:
-			if (!state->subcpu_resetline)
+			if (!state->m_subcpu_resetline)
 			{
-				cpu_set_input_line(state->subcpu, INPUT_LINE_RESET, ASSERT_LINE);
-				state->subcpu_resetline = 1;
+				device_set_input_line(state->m_subcpu, INPUT_LINE_RESET, ASSERT_LINE);
+				state->m_subcpu_resetline = 1;
 			}
 			break;
 
 		case 0x00:
-			if (state->subcpu_resetline)
+			if (state->m_subcpu_resetline)
 			{
-				cpu_set_input_line(state->subcpu, INPUT_LINE_RESET, CLEAR_LINE);
-				state->subcpu_resetline = 0;
+				device_set_input_line(state->m_subcpu, INPUT_LINE_RESET, CLEAR_LINE);
+				state->m_subcpu_resetline = 0;
 			}
-			cpu_spinuntil_int(space->cpu);
+			device_spin_until_interrupt(&space->device());
 			break;
 
 		case 0x0c:
 		case 0x80:
-			cpu_set_input_line(state->subcpu, 2, HOLD_LINE);
+			device_set_input_line(state->m_subcpu, 2, HOLD_LINE);
 			break;
 	}
 }
@@ -135,27 +134,27 @@ static WRITE16_HANDLER( hyprduel_subcpu_control_w )
 
 static READ16_HANDLER( hyprduel_cpusync_trigger1_r )
 {
-	hyprduel_state *state = space->machine->driver_data<hyprduel_state>();
-	if (state->cpu_trigger == 1001)
+	hyprduel_state *state = space->machine().driver_data<hyprduel_state>();
+	if (state->m_cpu_trigger == 1001)
 	{
-		cpuexec_trigger(space->machine, 1001);
-		state->cpu_trigger = 0;
+		space->machine().scheduler().trigger(1001);
+		state->m_cpu_trigger = 0;
 	}
 
-	return state->sharedram1[0x000408 / 2 + offset];
+	return state->m_sharedram1[0x000408 / 2 + offset];
 }
 
 static WRITE16_HANDLER( hyprduel_cpusync_trigger1_w )
 {
-	hyprduel_state *state = space->machine->driver_data<hyprduel_state>();
-	COMBINE_DATA(&state->sharedram1[0x00040e / 2 + offset]);
+	hyprduel_state *state = space->machine().driver_data<hyprduel_state>();
+	COMBINE_DATA(&state->m_sharedram1[0x00040e / 2 + offset]);
 
-	if (((state->sharedram1[0x00040e / 2] << 16) + state->sharedram1[0x000410 / 2]) != 0x00)
+	if (((state->m_sharedram1[0x00040e / 2] << 16) + state->m_sharedram1[0x000410 / 2]) != 0x00)
 	{
-		if (!state->cpu_trigger && !state->subcpu_resetline)
+		if (!state->m_cpu_trigger && !state->m_subcpu_resetline)
 		{
-			cpu_spinuntil_trigger(space->cpu, 1001);
-			state->cpu_trigger = 1001;
+			device_spin_until_trigger(&space->device(), 1001);
+			state->m_cpu_trigger = 1001;
 		}
 	}
 }
@@ -163,27 +162,27 @@ static WRITE16_HANDLER( hyprduel_cpusync_trigger1_w )
 
 static READ16_HANDLER( hyprduel_cpusync_trigger2_r )
 {
-	hyprduel_state *state = space->machine->driver_data<hyprduel_state>();
-	if (state->cpu_trigger == 1002)
+	hyprduel_state *state = space->machine().driver_data<hyprduel_state>();
+	if (state->m_cpu_trigger == 1002)
 	{
-		cpuexec_trigger(space->machine, 1002);
-		state->cpu_trigger = 0;
+		space->machine().scheduler().trigger(1002);
+		state->m_cpu_trigger = 0;
 	}
 
-	return state->sharedram3[(0xfff34c - 0xfe4000) / 2 + offset];
+	return state->m_sharedram3[(0xfff34c - 0xfe4000) / 2 + offset];
 }
 
 static WRITE16_HANDLER( hyprduel_cpusync_trigger2_w )
 {
-	hyprduel_state *state = space->machine->driver_data<hyprduel_state>();
-	COMBINE_DATA(&state->sharedram1[0x000408 / 2 + offset]);
+	hyprduel_state *state = space->machine().driver_data<hyprduel_state>();
+	COMBINE_DATA(&state->m_sharedram1[0x000408 / 2 + offset]);
 
 	if (ACCESSING_BITS_8_15)
 	{
-		if (!state->cpu_trigger && !state->subcpu_resetline)
+		if (!state->m_cpu_trigger && !state->m_subcpu_resetline)
 		{
-			cpu_spinuntil_trigger(space->cpu, 1002);
-			state->cpu_trigger = 1002;
+			device_spin_until_trigger(&space->device(), 1002);
+			state->m_cpu_trigger = 1002;
 		}
 	}
 }
@@ -191,8 +190,8 @@ static WRITE16_HANDLER( hyprduel_cpusync_trigger2_w )
 
 static TIMER_CALLBACK( magerror_irq_callback )
 {
-	hyprduel_state *state = machine->driver_data<hyprduel_state>();
-	cpu_set_input_line(state->subcpu, 1, HOLD_LINE);
+	hyprduel_state *state = machine.driver_data<hyprduel_state>();
+	device_set_input_line(state->m_subcpu, 1, HOLD_LINE);
 }
 
 /***************************************************************************
@@ -209,11 +208,11 @@ static TIMER_CALLBACK( magerror_irq_callback )
 
 static READ16_HANDLER( hyprduel_bankedrom_r )
 {
-	hyprduel_state *state = space->machine->driver_data<hyprduel_state>();
-	UINT8 *ROM = space->machine->region("gfx1")->base();
-	size_t  len = space->machine->region("gfx1")->bytes();
+	hyprduel_state *state = space->machine().driver_data<hyprduel_state>();
+	UINT8 *ROM = space->machine().region("gfx1")->base();
+	size_t  len = space->machine().region("gfx1")->bytes();
 
-	offset = offset * 2 + 0x10000 * (*state->rombank);
+	offset = offset * 2 + 0x10000 * (*state->m_rombank);
 
 	if (offset < len)
 		return ((ROM[offset + 0] << 8) + ROM[offset + 1]);
@@ -267,8 +266,8 @@ static READ16_HANDLER( hyprduel_bankedrom_r )
 
 static TIMER_CALLBACK( hyprduel_blit_done )
 {
-	hyprduel_state *state = machine->driver_data<hyprduel_state>();
-	state->requested_int |= 1 << state->blitter_bit;
+	hyprduel_state *state = machine.driver_data<hyprduel_state>();
+	state->m_requested_int |= 1 << state->m_blitter_bit;
 	update_irq_state(machine);
 }
 
@@ -285,28 +284,28 @@ INLINE void blt_write( address_space *space, const int tmap, const offs_t offs,
 		case 2:	hyprduel_vram_1_w(space, offs, data, mask);	break;
 		case 3:	hyprduel_vram_2_w(space, offs, data, mask);	break;
 	}
-//  logerror("%s : Blitter %X] %04X <- %04X & %04X\n", cpuexec_describe_context(space->machine), tmap, offs, data, mask);
+//  logerror("%s : Blitter %X] %04X <- %04X & %04X\n", space->machine().describe_context(), tmap, offs, data, mask);
 }
 
 
 static WRITE16_HANDLER( hyprduel_blitter_w )
 {
-	hyprduel_state *state = space->machine->driver_data<hyprduel_state>();
-	COMBINE_DATA(&state->blitter_regs[offset]);
+	hyprduel_state *state = space->machine().driver_data<hyprduel_state>();
+	COMBINE_DATA(&state->m_blitter_regs[offset]);
 
 	if (offset == 0xc / 2)
 	{
-		UINT8 *src = space->machine->region("gfx1")->base();
-		size_t  src_len = space->machine->region("gfx1")->bytes();
+		UINT8 *src = space->machine().region("gfx1")->base();
+		size_t  src_len = space->machine().region("gfx1")->bytes();
 
-		UINT32 tmap = (state->blitter_regs[0x00 / 2] << 16) + state->blitter_regs[0x02 / 2];
-		UINT32 src_offs = (state->blitter_regs[0x04 / 2] << 16) + state->blitter_regs[0x06 / 2];
-		UINT32 dst_offs = (state->blitter_regs[0x08 / 2] << 16) + state->blitter_regs[0x0a / 2];
+		UINT32 tmap = (state->m_blitter_regs[0x00 / 2] << 16) + state->m_blitter_regs[0x02 / 2];
+		UINT32 src_offs = (state->m_blitter_regs[0x04 / 2] << 16) + state->m_blitter_regs[0x06 / 2];
+		UINT32 dst_offs = (state->m_blitter_regs[0x08 / 2] << 16) + state->m_blitter_regs[0x0a / 2];
 
 		int shift = (dst_offs & 0x80) ? 0 : 8;
 		UINT16 mask = (dst_offs & 0x80) ? 0x00ff : 0xff00;
 
-//      logerror("CPU #0 PC %06X : Blitter regs %08X, %08X, %08X\n", cpu_get_pc(space->cpu), tmap, src_offs, dst_offs);
+//      logerror("CPU #0 PC %06X : Blitter regs %08X, %08X, %08X\n", cpu_get_pc(&space->device()), tmap, src_offs, dst_offs);
 
 		dst_offs >>= 7 + 1;
 		switch (tmap)
@@ -316,7 +315,7 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
 			case 3:
 				break;
 			default:
-				logerror("CPU #0 PC %06X : Blitter unknown destination: %08X\n", cpu_get_pc(space->cpu), tmap);
+				logerror("CPU #0 PC %06X : Blitter unknown destination: %08X\n", cpu_get_pc(&space->device()), tmap);
 				return;
 		}
 
@@ -326,7 +325,7 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
 
 			src_offs %= src_len;
 			b1 = blt_read(src, src_offs);
-//          logerror("CPU #0 PC %06X : Blitter opcode %02X at %06X\n", cpu_get_pc(space->cpu), b1, src_offs);
+//          logerror("CPU #0 PC %06X : Blitter opcode %02X at %06X\n", cpu_get_pc(&space->device()), b1, src_offs);
 			src_offs++;
 
 			count = ((~b1) & 0x3f) + 1;
@@ -342,7 +341,7 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
                        another blit. */
 					if (b1 == 0)
 					{
-						timer_set(space->machine, ATTOTIME_IN_USEC(500), NULL, 0, hyprduel_blit_done);
+						space->machine().scheduler().timer_set(attotime::from_usec(500), FUNC(hyprduel_blit_done));
 						return;
 					}
 
@@ -400,7 +399,7 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
 					{
 						dst_offs += 0x100;
 						dst_offs &= ~(0x100 - 1);
-						dst_offs |= (0x100 - 1) & (state->blitter_regs[0x0a / 2] >> (7 + 1));
+						dst_offs |= (0x100 - 1) & (state->m_blitter_regs[0x0a / 2] >> (7 + 1));
 					}
 					else
 					{
@@ -410,7 +409,7 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
 
 
 				default:
-					logerror("CPU #0 PC %06X : Blitter unknown opcode %02X at %06X\n", cpu_get_pc(space->cpu), b1, src_offs - 1);
+					logerror("CPU #0 PC %06X : Blitter unknown opcode %02X at %06X\n", cpu_get_pc(&space->device()), b1, src_offs - 1);
 					return;
 			}
 
@@ -423,39 +422,39 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
                                 Memory Maps
 ***************************************************************************/
 
-static ADDRESS_MAP_START( hyprduel_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( hyprduel_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
-	AM_RANGE(0x400000, 0x41ffff) AM_RAM_WRITE(hyprduel_vram_0_w) AM_BASE_MEMBER(hyprduel_state, vram_0)		/* Layer 0 */
-	AM_RANGE(0x420000, 0x43ffff) AM_RAM_WRITE(hyprduel_vram_1_w) AM_BASE_MEMBER(hyprduel_state, vram_1)		/* Layer 1 */
-	AM_RANGE(0x440000, 0x45ffff) AM_RAM_WRITE(hyprduel_vram_2_w) AM_BASE_MEMBER(hyprduel_state, vram_2)		/* Layer 2 */
+	AM_RANGE(0x400000, 0x41ffff) AM_RAM_WRITE(hyprduel_vram_0_w) AM_BASE_MEMBER(hyprduel_state, m_vram_0)		/* Layer 0 */
+	AM_RANGE(0x420000, 0x43ffff) AM_RAM_WRITE(hyprduel_vram_1_w) AM_BASE_MEMBER(hyprduel_state, m_vram_1)		/* Layer 1 */
+	AM_RANGE(0x440000, 0x45ffff) AM_RAM_WRITE(hyprduel_vram_2_w) AM_BASE_MEMBER(hyprduel_state, m_vram_2)		/* Layer 2 */
 	AM_RANGE(0x460000, 0x46ffff) AM_READ(hyprduel_bankedrom_r)		/* Banked ROM */
-	AM_RANGE(0x470000, 0x473fff) AM_RAM_WRITE(hyprduel_paletteram_w) AM_BASE_MEMBER(hyprduel_state, paletteram)	/* Palette */
-	AM_RANGE(0x474000, 0x474fff) AM_RAM AM_BASE_SIZE_MEMBER(hyprduel_state, spriteram, spriteram_size)			/* Sprites */
+	AM_RANGE(0x470000, 0x473fff) AM_RAM_WRITE(hyprduel_paletteram_w) AM_BASE_MEMBER(hyprduel_state, m_paletteram)	/* Palette */
+	AM_RANGE(0x474000, 0x474fff) AM_RAM AM_BASE_SIZE_MEMBER(hyprduel_state, m_spriteram, m_spriteram_size)			/* Sprites */
 	AM_RANGE(0x475000, 0x477fff) AM_RAM			/* only used memory test */
-	AM_RANGE(0x478000, 0x4787ff) AM_RAM AM_BASE_SIZE_MEMBER(hyprduel_state, tiletable, tiletable_size)	/* Tiles Set */
-	AM_RANGE(0x478840, 0x47884d) AM_WRITE(hyprduel_blitter_w) AM_BASE_MEMBER(hyprduel_state, blitter_regs)	/* Tiles Blitter */
-	AM_RANGE(0x478860, 0x47886b) AM_WRITE(hyprduel_window_w) AM_BASE_MEMBER(hyprduel_state, window)			/* Tilemap Window */
-	AM_RANGE(0x478870, 0x47887b) AM_RAM_WRITE(hyprduel_scrollreg_w) AM_BASE_MEMBER(hyprduel_state, scroll)		/* Scroll Regs */
+	AM_RANGE(0x478000, 0x4787ff) AM_RAM AM_BASE_SIZE_MEMBER(hyprduel_state, m_tiletable, m_tiletable_size)	/* Tiles Set */
+	AM_RANGE(0x478840, 0x47884d) AM_WRITE(hyprduel_blitter_w) AM_BASE_MEMBER(hyprduel_state, m_blitter_regs)	/* Tiles Blitter */
+	AM_RANGE(0x478860, 0x47886b) AM_WRITE(hyprduel_window_w) AM_BASE_MEMBER(hyprduel_state, m_window)			/* Tilemap Window */
+	AM_RANGE(0x478870, 0x47887b) AM_RAM_WRITE(hyprduel_scrollreg_w) AM_BASE_MEMBER(hyprduel_state, m_scroll)		/* Scroll Regs */
 	AM_RANGE(0x47887c, 0x47887d) AM_WRITE(hyprduel_scrollreg_init_w)
 	AM_RANGE(0x478880, 0x478881) AM_WRITENOP
 	AM_RANGE(0x478890, 0x478891) AM_WRITENOP
 	AM_RANGE(0x4788a0, 0x4788a1) AM_WRITENOP
 	AM_RANGE(0x4788a2, 0x4788a3) AM_READWRITE(hyprduel_irq_cause_r, hyprduel_irq_cause_w)	/* IRQ Cause,Acknowledge */
-	AM_RANGE(0x4788a4, 0x4788a5) AM_RAM AM_BASE_MEMBER(hyprduel_state, irq_enable)		/* IRQ Enable */
-	AM_RANGE(0x4788aa, 0x4788ab) AM_RAM AM_BASE_MEMBER(hyprduel_state, rombank)		/* Rom Bank */
-	AM_RANGE(0x4788ac, 0x4788ad) AM_RAM AM_BASE_MEMBER(hyprduel_state, screenctrl)	/* Screen Control */
-	AM_RANGE(0x479700, 0x479713) AM_RAM AM_BASE_MEMBER(hyprduel_state, videoregs)	/* Video Registers */
+	AM_RANGE(0x4788a4, 0x4788a5) AM_RAM AM_BASE_MEMBER(hyprduel_state, m_irq_enable)		/* IRQ Enable */
+	AM_RANGE(0x4788aa, 0x4788ab) AM_RAM AM_BASE_MEMBER(hyprduel_state, m_rombank)		/* Rom Bank */
+	AM_RANGE(0x4788ac, 0x4788ad) AM_RAM AM_BASE_MEMBER(hyprduel_state, m_screenctrl)	/* Screen Control */
+	AM_RANGE(0x479700, 0x479713) AM_RAM AM_BASE_MEMBER(hyprduel_state, m_videoregs)	/* Video Registers */
 	AM_RANGE(0x800000, 0x800001) AM_WRITE(hyprduel_subcpu_control_w)
-	AM_RANGE(0xc00000, 0xc07fff) AM_RAM AM_SHARE("share1") AM_BASE_MEMBER(hyprduel_state, sharedram1)
+	AM_RANGE(0xc00000, 0xc07fff) AM_RAM AM_SHARE("share1") AM_BASE_MEMBER(hyprduel_state, m_sharedram1)
 	AM_RANGE(0xe00000, 0xe00001) AM_READ_PORT("SERVICE") AM_WRITENOP
 	AM_RANGE(0xe00002, 0xe00003) AM_READ_PORT("DSW")
 	AM_RANGE(0xe00004, 0xe00005) AM_READ_PORT("P1_P2")
 	AM_RANGE(0xe00006, 0xe00007) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0xfe0000, 0xfe3fff) AM_RAM AM_SHARE("share2")
-	AM_RANGE(0xfe4000, 0xffffff) AM_RAM AM_SHARE("share3") AM_BASE_MEMBER(hyprduel_state, sharedram3)
+	AM_RANGE(0xfe4000, 0xffffff) AM_RAM AM_SHARE("share3") AM_BASE_MEMBER(hyprduel_state, m_sharedram3)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( hyprduel_map2, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( hyprduel_map2, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x003fff) AM_RAM AM_SHARE("share1")						/* shadow ($c00000 - $c03fff : vector) */
 	AM_RANGE(0x004000, 0x007fff) AM_READONLY AM_WRITENOP AM_SHARE("share3")			/* shadow ($fe4000 - $fe7fff : read only) */
 	AM_RANGE(0x400000, 0x400003) AM_DEVREADWRITE8("ymsnd", ym2151_r, ym2151_w, 0x00ff )
@@ -469,39 +468,39 @@ ADDRESS_MAP_END
 
 /* Magical Error - video is at 8x now */
 
-static ADDRESS_MAP_START( magerror_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( magerror_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x400000, 0x400001) AM_WRITE(hyprduel_subcpu_control_w)
-	AM_RANGE(0x800000, 0x81ffff) AM_RAM_WRITE(hyprduel_vram_0_w) AM_BASE_MEMBER(hyprduel_state, vram_0)		/* Layer 0 */
-	AM_RANGE(0x820000, 0x83ffff) AM_RAM_WRITE(hyprduel_vram_1_w) AM_BASE_MEMBER(hyprduel_state, vram_1)		/* Layer 1 */
-	AM_RANGE(0x840000, 0x85ffff) AM_RAM_WRITE(hyprduel_vram_2_w) AM_BASE_MEMBER(hyprduel_state, vram_2)		/* Layer 2 */
+	AM_RANGE(0x800000, 0x81ffff) AM_RAM_WRITE(hyprduel_vram_0_w) AM_BASE_MEMBER(hyprduel_state, m_vram_0)		/* Layer 0 */
+	AM_RANGE(0x820000, 0x83ffff) AM_RAM_WRITE(hyprduel_vram_1_w) AM_BASE_MEMBER(hyprduel_state, m_vram_1)		/* Layer 1 */
+	AM_RANGE(0x840000, 0x85ffff) AM_RAM_WRITE(hyprduel_vram_2_w) AM_BASE_MEMBER(hyprduel_state, m_vram_2)		/* Layer 2 */
 	AM_RANGE(0x860000, 0x86ffff) AM_READ(hyprduel_bankedrom_r)		/* Banked ROM */
-	AM_RANGE(0x870000, 0x873fff) AM_RAM_WRITE(hyprduel_paletteram_w) AM_BASE_MEMBER(hyprduel_state, paletteram)	/* Palette */
-	AM_RANGE(0x874000, 0x874fff) AM_RAM AM_BASE_SIZE_MEMBER(hyprduel_state, spriteram, spriteram_size)		/* Sprites */
+	AM_RANGE(0x870000, 0x873fff) AM_RAM_WRITE(hyprduel_paletteram_w) AM_BASE_MEMBER(hyprduel_state, m_paletteram)	/* Palette */
+	AM_RANGE(0x874000, 0x874fff) AM_RAM AM_BASE_SIZE_MEMBER(hyprduel_state, m_spriteram, m_spriteram_size)		/* Sprites */
 	AM_RANGE(0x875000, 0x877fff) AM_RAM			/* only used memory test */
-	AM_RANGE(0x878000, 0x8787ff) AM_RAM AM_BASE_SIZE_MEMBER(hyprduel_state, tiletable, tiletable_size)	/* Tiles Set */
-	AM_RANGE(0x878840, 0x87884d) AM_WRITE(hyprduel_blitter_w) AM_BASE_MEMBER(hyprduel_state, blitter_regs)	/* Tiles Blitter */
-	AM_RANGE(0x878860, 0x87886b) AM_WRITE(hyprduel_window_w) AM_BASE_MEMBER(hyprduel_state, window)			/* Tilemap Window */
-	AM_RANGE(0x878870, 0x87887b) AM_RAM_WRITE(hyprduel_scrollreg_w) AM_BASE_MEMBER(hyprduel_state, scroll)		/* Scroll Regs */
+	AM_RANGE(0x878000, 0x8787ff) AM_RAM AM_BASE_SIZE_MEMBER(hyprduel_state, m_tiletable, m_tiletable_size)	/* Tiles Set */
+	AM_RANGE(0x878840, 0x87884d) AM_WRITE(hyprduel_blitter_w) AM_BASE_MEMBER(hyprduel_state, m_blitter_regs)	/* Tiles Blitter */
+	AM_RANGE(0x878860, 0x87886b) AM_WRITE(hyprduel_window_w) AM_BASE_MEMBER(hyprduel_state, m_window)			/* Tilemap Window */
+	AM_RANGE(0x878870, 0x87887b) AM_RAM_WRITE(hyprduel_scrollreg_w) AM_BASE_MEMBER(hyprduel_state, m_scroll)		/* Scroll Regs */
 	AM_RANGE(0x87887c, 0x87887d) AM_WRITE(hyprduel_scrollreg_init_w)
 	AM_RANGE(0x878880, 0x878881) AM_WRITENOP
 	AM_RANGE(0x878890, 0x878891) AM_WRITENOP
 	AM_RANGE(0x8788a0, 0x8788a1) AM_WRITENOP
 	AM_RANGE(0x8788a2, 0x8788a3) AM_READWRITE(hyprduel_irq_cause_r, hyprduel_irq_cause_w)	/* IRQ Cause, Acknowledge */
-	AM_RANGE(0x8788a4, 0x8788a5) AM_RAM AM_BASE_MEMBER(hyprduel_state, irq_enable)		/* IRQ Enable */
-	AM_RANGE(0x8788aa, 0x8788ab) AM_RAM AM_BASE_MEMBER(hyprduel_state, rombank)		/* Rom Bank */
-	AM_RANGE(0x8788ac, 0x8788ad) AM_RAM AM_BASE_MEMBER(hyprduel_state, screenctrl)	/* Screen Control */
-	AM_RANGE(0x879700, 0x879713) AM_RAM AM_BASE_MEMBER(hyprduel_state, videoregs)	/* Video Registers */
-	AM_RANGE(0xc00000, 0xc1ffff) AM_RAM AM_SHARE("share1") AM_BASE_MEMBER(hyprduel_state, sharedram1)
+	AM_RANGE(0x8788a4, 0x8788a5) AM_RAM AM_BASE_MEMBER(hyprduel_state, m_irq_enable)		/* IRQ Enable */
+	AM_RANGE(0x8788aa, 0x8788ab) AM_RAM AM_BASE_MEMBER(hyprduel_state, m_rombank)		/* Rom Bank */
+	AM_RANGE(0x8788ac, 0x8788ad) AM_RAM AM_BASE_MEMBER(hyprduel_state, m_screenctrl)	/* Screen Control */
+	AM_RANGE(0x879700, 0x879713) AM_RAM AM_BASE_MEMBER(hyprduel_state, m_videoregs)	/* Video Registers */
+	AM_RANGE(0xc00000, 0xc1ffff) AM_RAM AM_SHARE("share1") AM_BASE_MEMBER(hyprduel_state, m_sharedram1)
 	AM_RANGE(0xe00000, 0xe00001) AM_READ_PORT("SERVICE") AM_WRITENOP
 	AM_RANGE(0xe00002, 0xe00003) AM_READ_PORT("DSW")
 	AM_RANGE(0xe00004, 0xe00005) AM_READ_PORT("P1_P2")
 	AM_RANGE(0xe00006, 0xe00007) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0xfe0000, 0xfe3fff) AM_RAM AM_SHARE("share2")
-	AM_RANGE(0xfe4000, 0xffffff) AM_RAM AM_SHARE("share3") AM_BASE_MEMBER(hyprduel_state, sharedram3)
+	AM_RANGE(0xfe4000, 0xffffff) AM_RAM AM_SHARE("share3") AM_BASE_MEMBER(hyprduel_state, m_sharedram3)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( magerror_map2, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( magerror_map2, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x003fff) AM_RAM AM_SHARE("share1")						/* shadow ($c00000 - $c03fff : vector) */
 	AM_RANGE(0x004000, 0x007fff) AM_READONLY AM_WRITENOP AM_SHARE("share3")			/* shadow ($fe4000 - $fe7fff : read only) */
 	AM_RANGE(0x400000, 0x400003) AM_NOP
@@ -607,10 +606,19 @@ INPUT_PORTS_END
 ***************************************************************************/
 
 /* 8x8x4 tiles */
-static GFXLAYOUT_RAW( layout_8x8x4, 4, 8, 8, 4*8, 32*8 )
+static const gfx_layout layout_8x8x4 =
+{
+	8,8,
+	RGN_FRAC(1,1),
+	4,
+	{ STEP4(0,1) },
+	{ 4*1,4*0, 4*3,4*2, 4*5,4*4, 4*7,4*6 },
+	{ STEP8(0,4*8) },
+	4*8*8
+};
 
 /* 8x8x8 tiles for later games */
-static GFXLAYOUT_RAW( layout_8x8x8h, 8, 8, 8, 8*8, 32*8 )
+static GFXLAYOUT_RAW( layout_8x8x8h, 8, 8, 8*8, 32*8 )
 
 static GFXDECODE_START( 14220 )
 	GFXDECODE_ENTRY( "gfx1", 0, layout_8x8x4,    0x0, 0x200 ) // [0] 4 Bit Tiles
@@ -623,8 +631,8 @@ GFXDECODE_END
 
 static void sound_irq( device_t *device, int state )
 {
-	hyprduel_state *hyprduel = device->machine->driver_data<hyprduel_state>();
-	cpu_set_input_line(hyprduel->subcpu, 1, HOLD_LINE);
+	hyprduel_state *hyprduel = device->machine().driver_data<hyprduel_state>();
+	device_set_input_line(hyprduel->m_subcpu, 1, HOLD_LINE);
 }
 
 static const ym2151_interface ym2151_config =
@@ -638,37 +646,37 @@ static const ym2151_interface ym2151_config =
 
 static MACHINE_RESET( hyprduel )
 {
-	hyprduel_state *state = machine->driver_data<hyprduel_state>();
+	hyprduel_state *state = machine.driver_data<hyprduel_state>();
 
 	/* start with cpu2 halted */
 	cputag_set_input_line(machine, "sub", INPUT_LINE_RESET, ASSERT_LINE);
-	state->subcpu_resetline = 1;
-	state->cpu_trigger = 0;
+	state->m_subcpu_resetline = 1;
+	state->m_cpu_trigger = 0;
 
-	state->requested_int = 0x00;
-	state->blitter_bit = 2;
-	*state->irq_enable = 0xff;
+	state->m_requested_int = 0x00;
+	state->m_blitter_bit = 2;
+	*state->m_irq_enable = 0xff;
 }
 
 static MACHINE_START( hyprduel )
 {
-	hyprduel_state *state = machine->driver_data<hyprduel_state>();
+	hyprduel_state *state = machine.driver_data<hyprduel_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->subcpu = machine->device("sub");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_subcpu = machine.device("sub");
 
-	state_save_register_global(machine, state->blitter_bit);
-	state_save_register_global(machine, state->requested_int);
-	state_save_register_global(machine, state->subcpu_resetline);
-	state_save_register_global(machine, state->cpu_trigger);
+	state->save_item(NAME(state->m_blitter_bit));
+	state->save_item(NAME(state->m_requested_int));
+	state->save_item(NAME(state->m_subcpu_resetline));
+	state->save_item(NAME(state->m_cpu_trigger));
 }
 
 static MACHINE_START( magerror )
 {
-	hyprduel_state *state = machine->driver_data<hyprduel_state>();
+	hyprduel_state *state = machine.driver_data<hyprduel_state>();
 
 	MACHINE_START_CALL(hyprduel);
-	timer_adjust_periodic(state->magerror_irq_timer, attotime_zero, 0, ATTOTIME_IN_HZ(968));		/* tempo? */
+	state->m_magerror_irq_timer->adjust(attotime::zero, 0, attotime::from_hz(968));		/* tempo? */
 }
 
 static MACHINE_CONFIG_START( hyprduel, hyprduel_state )
@@ -676,7 +684,7 @@ static MACHINE_CONFIG_START( hyprduel, hyprduel_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000,20000000/2)		/* 10MHz */
 	MCFG_CPU_PROGRAM_MAP(hyprduel_map)
-	MCFG_CPU_VBLANK_INT_HACK(hyprduel_interrupt,RASTER_LINES)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", hyprduel_interrupt, "screen", 0, 1)
 
 	MCFG_CPU_ADD("sub", M68000,20000000/2)		/* 10MHz */
 	MCFG_CPU_PROGRAM_MAP(hyprduel_map2)
@@ -690,15 +698,14 @@ static MACHINE_CONFIG_START( hyprduel, hyprduel_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 224)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, FIRST_VISIBLE_LINE, LAST_VISIBLE_LINE)
+	MCFG_SCREEN_UPDATE_STATIC(hyprduel)
 
 	MCFG_GFXDECODE(14220)
 	MCFG_PALETTE_LENGTH(8192)
 
 	MCFG_VIDEO_START(hyprduel_14220)
-	MCFG_VIDEO_UPDATE(hyprduel)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
@@ -719,7 +726,7 @@ static MACHINE_CONFIG_START( magerror, hyprduel_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000,20000000/2)		/* 10MHz */
 	MCFG_CPU_PROGRAM_MAP(magerror_map)
-	MCFG_CPU_VBLANK_INT_HACK(hyprduel_interrupt,RASTER_LINES)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", hyprduel_interrupt, "screen", 0, 1)
 
 	MCFG_CPU_ADD("sub", M68000,20000000/2)		/* 10MHz */
 	MCFG_CPU_PROGRAM_MAP(magerror_map2)
@@ -733,15 +740,14 @@ static MACHINE_CONFIG_START( magerror, hyprduel_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 224)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, FIRST_VISIBLE_LINE, LAST_VISIBLE_LINE)
+	MCFG_SCREEN_UPDATE_STATIC(hyprduel)
 
 	MCFG_GFXDECODE(14220)
 	MCFG_PALETTE_LENGTH(8192)
 
 	MCFG_VIDEO_START(magerror_14220)
-	MCFG_VIDEO_UPDATE(hyprduel)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
@@ -807,23 +813,23 @@ ROM_END
 
 static DRIVER_INIT( hyprduel )
 {
-	hyprduel_state *state = machine->driver_data<hyprduel_state>();
+	hyprduel_state *state = machine.driver_data<hyprduel_state>();
 
-	state->int_num = 0x02;
+	state->m_int_num = 0x02;
 
 	/* cpu synchronization (severe timings) */
-	memory_install_write16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xc0040e, 0xc00411, 0, 0, hyprduel_cpusync_trigger1_w);
-	memory_install_read16_handler(cputag_get_address_space(machine, "sub", ADDRESS_SPACE_PROGRAM), 0xc00408, 0xc00409, 0, 0, hyprduel_cpusync_trigger1_r);
-	memory_install_write16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xc00408, 0xc00409, 0, 0, hyprduel_cpusync_trigger2_w);
-	memory_install_read16_handler(cputag_get_address_space(machine, "sub", ADDRESS_SPACE_PROGRAM), 0xfff34c, 0xfff34d, 0, 0, hyprduel_cpusync_trigger2_r);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0xc0040e, 0xc00411, FUNC(hyprduel_cpusync_trigger1_w));
+	machine.device("sub")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0xc00408, 0xc00409, FUNC(hyprduel_cpusync_trigger1_r));
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0xc00408, 0xc00409, FUNC(hyprduel_cpusync_trigger2_w));
+	machine.device("sub")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0xfff34c, 0xfff34d, FUNC(hyprduel_cpusync_trigger2_r));
 }
 
 static DRIVER_INIT( magerror )
 {
-	hyprduel_state *state = machine->driver_data<hyprduel_state>();
+	hyprduel_state *state = machine.driver_data<hyprduel_state>();
 
-	state->int_num = 0x01;
-	state->magerror_irq_timer = timer_alloc(machine, magerror_irq_callback, NULL);
+	state->m_int_num = 0x01;
+	state->m_magerror_irq_timer = machine.scheduler().timer_alloc(FUNC(magerror_irq_callback));
 }
 
 
