@@ -52,57 +52,65 @@ Grndtour:
 #include "emu.h"
 #include "cpu/z80/z80.h"
 #include "cpu/z180/z180.h"
-#include "deprecat.h"
 #include "machine/8255ppi.h"
 #include "includes/iqblock.h"
 #include "sound/2413intf.h"
 
-static UINT8 *rambase;
 
 static WRITE8_HANDLER( iqblock_prot_w )
 {
-    rambase[0xe26] = data;
-    rambase[0xe27] = data;
-    rambase[0xe1c] = data;
+	iqblock_state *state = space->machine().driver_data<iqblock_state>();
+    state->m_rambase[0xe26] = data;
+    state->m_rambase[0xe27] = data;
+    state->m_rambase[0xe1c] = data;
 }
 
 static WRITE8_HANDLER( grndtour_prot_w )
 {
-	rambase[0xe39] = data;
-    rambase[0xe3a] = data;
-    rambase[0xe2f] = data;
+	iqblock_state *state = space->machine().driver_data<iqblock_state>();
+	state->m_rambase[0xe39] = data;
+    state->m_rambase[0xe3a] = data;
+    state->m_rambase[0xe2f] = data;
 
 }
 
 
-static INTERRUPT_GEN( iqblock_interrupt )
+static TIMER_DEVICE_CALLBACK( iqblock_irq )
 {
-	if (cpu_getiloops(device) & 1)
-		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);	/* ???? */
-	else
-		cpu_set_input_line(device, 0, ASSERT_LINE);			/* ???? */
+	iqblock_state *state = timer.machine().driver_data<iqblock_state>();
+	int scanline = param;
+
+	if((scanline % 16) != 0)
+		return;
+
+	if((scanline % 32) == 16)
+		device_set_input_line(state->m_maincpu, 0, HOLD_LINE);
+	else if	((scanline % 32) == 0)
+		device_set_input_line(state->m_maincpu, INPUT_LINE_NMI, PULSE_LINE);
 }
 
+
 static WRITE8_HANDLER( iqblock_irqack_w )
 {
-	cputag_set_input_line(space->machine, "maincpu", 0, CLEAR_LINE);
+	cputag_set_input_line(space->machine(), "maincpu", 0, CLEAR_LINE);
 }
 
 static READ8_HANDLER( extrarom_r )
 {
-	return space->machine->region("user1")->base()[offset];
+	return space->machine().region("user1")->base()[offset];
 }
 
 
 static WRITE8_DEVICE_HANDLER( port_C_w )
 {
+	iqblock_state *state = device->machine().driver_data<iqblock_state>();
 	/* bit 4 unknown; it is pulsed at the end of every NMI */
 
 	/* bit 5 seems to be 0 during screen redraw */
-	iqblock_videoenable = data & 0x20;
+	state->m_videoenable = data & 0x20;
 
 	/* bit 6 is coin counter */
-	coin_counter_w(device->machine, 0,data & 0x40);
+	coin_counter_w(device->machine(), 0,data & 0x40);
 
 	/* bit 7 could be a second coin counter, but coin 2 doesn't seem to work... */
 }
@@ -118,13 +126,13 @@ static const ppi8255_interface ppi8255_intf =
 };
 
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xefff) AM_ROM
-	AM_RANGE(0xf000, 0xffff) AM_RAM AM_BASE(&rambase)
+	AM_RANGE(0xf000, 0xffff) AM_RAM AM_BASE_MEMBER(iqblock_state, m_rambase)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( main_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( main_portmap, AS_IO, 8 )
 	AM_RANGE(0x2000, 0x23ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_split1_w)
 	AM_RANGE(0x2800, 0x2bff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_split2_w)
 	AM_RANGE(0x6000, 0x603f) AM_WRITE(iqblock_fgscroll_w)
@@ -265,13 +273,13 @@ GFXDECODE_END
 
 
 
-static MACHINE_CONFIG_START( iqblock, driver_device )
+static MACHINE_CONFIG_START( iqblock, iqblock_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80,12000000/2)	/* 6 MHz */
 	MCFG_CPU_PROGRAM_MAP(main_map)
 	MCFG_CPU_IO_MAP(main_portmap)
-	MCFG_CPU_VBLANK_INT_HACK(iqblock_interrupt,16)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", iqblock_irq, "screen", 0, 1)
 
 	MCFG_PPI8255_ADD( "ppi8255", ppi8255_intf )
 
@@ -279,15 +287,14 @@ static MACHINE_CONFIG_START( iqblock, driver_device )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 30*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(iqblock)
 
 	MCFG_GFXDECODE(iqblock)
 	MCFG_PALETTE_LENGTH(1024)
 
 	MCFG_VIDEO_START(iqblock)
-	MCFG_VIDEO_UPDATE(iqblock)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -425,7 +432,8 @@ ROM_END
 
 static DRIVER_INIT( iqblock )
 {
-	UINT8 *rom = machine->region("maincpu")->base();
+	iqblock_state *state = machine.driver_data<iqblock_state>();
+	UINT8 *rom = machine.region("maincpu")->base();
 	int i;
 
 	/* decrypt the program ROM */
@@ -437,17 +445,18 @@ static DRIVER_INIT( iqblock )
 	}
 
 	/* initialize pointers for I/O mapped RAM */
-	machine->generic.paletteram.u8         = rom + 0x12000;
-	machine->generic.paletteram2.u8       = rom + 0x12800;
-	iqblock_fgvideoram = rom + 0x16800;
-	iqblock_bgvideoram = rom + 0x17000;
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xfe26, 0xfe26, 0, 0, iqblock_prot_w);
-	iqblock_video_type=1;
+	machine.generic.paletteram.u8         = rom + 0x12000;
+	machine.generic.paletteram2.u8       = rom + 0x12800;
+	state->m_fgvideoram = rom + 0x16800;
+	state->m_bgvideoram = rom + 0x17000;
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0xfe26, 0xfe26, FUNC(iqblock_prot_w));
+	state->m_video_type=1;
 }
 
 static DRIVER_INIT( grndtour )
 {
-	UINT8 *rom = machine->region("maincpu")->base();
+	iqblock_state *state = machine.driver_data<iqblock_state>();
+	UINT8 *rom = machine.region("maincpu")->base();
 	int i;
 
 	/* decrypt the program ROM */
@@ -459,12 +468,12 @@ static DRIVER_INIT( grndtour )
 	}
 
 	/* initialize pointers for I/O mapped RAM */
-	machine->generic.paletteram.u8         = rom + 0x12000;
-	machine->generic.paletteram2.u8       = rom + 0x12800;
-	iqblock_fgvideoram = rom + 0x16800;
-	iqblock_bgvideoram = rom + 0x17000;
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xfe39, 0xfe39, 0, 0, grndtour_prot_w);
-	iqblock_video_type=0;
+	machine.generic.paletteram.u8         = rom + 0x12000;
+	machine.generic.paletteram2.u8       = rom + 0x12800;
+	state->m_fgvideoram = rom + 0x16800;
+	state->m_bgvideoram = rom + 0x17000;
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0xfe39, 0xfe39, FUNC(grndtour_prot_w));
+	state->m_video_type=0;
 }
 
 
