@@ -42,7 +42,6 @@ The 2 ay-8910 read ports are responsible for reading the sound commands.
 ***************************************************************************/
 
 #include "emu.h"
-#include "deprecat.h"
 #include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 #include "includes/jack.h"
@@ -752,7 +751,7 @@ static const gfx_layout charlayout =
 	8,8,	/* 8*8 characters */
 	RGN_FRAC(1,2),	/* 1024 characters */
 	2,	/* 2 bits per pixel */
-	{ RGN_FRAC(0,2), RGN_FRAC(1,2) },	/* the two bitplanes are seperated */
+	{ RGN_FRAC(0,2), RGN_FRAC(1,2) },	/* the two bitplanes are separated */
 	{ 0, 1, 2, 3, 4, 5, 6, 7 },
 	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8 },
 	8*8	/* every char takes 16 bytes */
@@ -835,10 +834,9 @@ static MACHINE_CONFIG_START( jack, jack_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(jack)
+	MCFG_SCREEN_UPDATE_STATIC(jack)
 
 	MCFG_GFXDECODE(jack)
 	MCFG_PALETTE_LENGTH(32)
@@ -860,15 +858,11 @@ static MACHINE_CONFIG_DERIVED( tripool, jack )
 	MCFG_CPU_PERIODIC_INT(irq0_line_hold,2*60) /* tripool needs 2 or the palette is broken */
 MACHINE_CONFIG_END
 
-static INTERRUPT_GEN( joinem_interrupts )
+static INTERRUPT_GEN( joinem_vblank_irq )
 {
-	if (cpu_getiloops(device) > 0)
-		device_set_input_line(device, 0, HOLD_LINE);
-	else
-	{
-		if (!(input_port_read(device->machine(), "IN2") & 0x80)) /* TODO: remove me */
-			device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
-	}
+	 /* TODO: looks hackish to me ... */
+	if (!(input_port_read(device->machine(), "IN2") & 0x80))
+		device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static MACHINE_CONFIG_DERIVED( joinem, jack )
@@ -876,14 +870,15 @@ static MACHINE_CONFIG_DERIVED( joinem, jack )
 	/* basic machine hardware */
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_PROGRAM_MAP(joinem_map)
-	MCFG_CPU_VBLANK_INT_HACK(joinem_interrupts,3)
+	MCFG_CPU_VBLANK_INT("screen",joinem_vblank_irq)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold,2*60)
 
 	MCFG_GFXDECODE(joinem)
 	MCFG_PALETTE_LENGTH(0x100)
 
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(joinem)
+	MCFG_SCREEN_UPDATE_STATIC(joinem)
 
 	MCFG_PALETTE_INIT(joinem)
 	MCFG_VIDEO_START(joinem)
@@ -902,7 +897,7 @@ static MACHINE_CONFIG_DERIVED( loverboy, jack )
 
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(joinem)
+	MCFG_SCREEN_UPDATE_STATIC(joinem)
 
 	MCFG_PALETTE_INIT(joinem)
 	MCFG_VIDEO_START(joinem)
