@@ -16,7 +16,7 @@ $8100-$8FFF = Work RAM
 
 Write memory
 
-$8030   - interrupt control register D0 = interupts on or off
+$8030   - interrupt control register D0 = interrupts on or off
 $8031   - unknown
 $8032   - unknown
 $8033   - unknown
@@ -95,7 +95,7 @@ public:
 	junofrst_state(const machine_config &mconfig, device_type type, const char *tag)
 		: tutankhm_state(mconfig, type, tag) { }
 
-	UINT8     m_blitterdata[4];
+	UINT8    m_blitterdata[4];
 	int      m_i8039_status;
 	int      m_last_irq;
 
@@ -267,7 +267,14 @@ static WRITE8_HANDLER( junofrst_coin_counter_w )
 	coin_counter_w(space->machine(), offset, data);
 }
 
+static WRITE8_HANDLER( junofrst_irq_enable_w )
+{
+	junofrst_state *state = space->machine().driver_data<junofrst_state>();
 
+	state->m_irq_enable = data & 1;
+	if (!state->m_irq_enable)
+		device_set_input_line(state->m_maincpu, 0, CLEAR_LINE);
+}
 
 static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_RAM AM_BASE_MEMBER(junofrst_state, m_videoram)
@@ -278,7 +285,7 @@ static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x8024, 0x8024) AM_READ_PORT("P1")
 	AM_RANGE(0x8028, 0x8028) AM_READ_PORT("P2")
 	AM_RANGE(0x802c, 0x802c) AM_READ_PORT("DSW1")
-	AM_RANGE(0x8030, 0x8030) AM_WRITE(interrupt_enable_w)
+	AM_RANGE(0x8030, 0x8030) AM_WRITE(junofrst_irq_enable_w)
 	AM_RANGE(0x8031, 0x8032) AM_WRITE(junofrst_coin_counter_w)
 	AM_RANGE(0x8033, 0x8033) AM_WRITEONLY AM_BASE_MEMBER(junofrst_state, m_scroll)  /* not used in Juno */
 	AM_RANGE(0x8034, 0x8035) AM_WRITE(flip_screen_w)
@@ -327,22 +334,20 @@ static INPUT_PORTS_START( junofrst )
 	KONAMI8_COCKTAIL_B213_UNK
 
 	PORT_START("DSW1")
-	KONAMI_COINAGE(DEF_STR( Free_Play ), "No Coin B")
+	KONAMI_COINAGE_LOC(DEF_STR( Free_Play ), "No Coin B", SW1)
 	/* "No Coin B" = coins produce sound, but no effect on coin counter */
 
 	PORT_START("DSW2")
-	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )		PORT_DIPLOCATION("SW2:1,2")
 	PORT_DIPSETTING(    0x03, "3" )
 	PORT_DIPSETTING(    0x02, "4" )
 	PORT_DIPSETTING(    0x01, "5" )
 	PORT_DIPSETTING(    0x00, "256 (Cheat)")
-	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Cabinet ) )
+	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Cabinet ) )		PORT_DIPLOCATION("SW2:3")
 	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( Cocktail ) )
-	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x70, 0x70, DEF_STR( Difficulty ) )
+	PORT_DIPUNUSED_DIPLOC( 0x08, IP_ACTIVE_LOW, "SW2:4" )
+	PORT_DIPNAME( 0x70, 0x70, DEF_STR( Difficulty ) )	PORT_DIPLOCATION("SW2:5,6,7")
 	PORT_DIPSETTING(    0x70, "1 (Easiest)" )
 	PORT_DIPSETTING(    0x60, "2" )
 	PORT_DIPSETTING(    0x50, "3" )
@@ -351,7 +356,7 @@ static INPUT_PORTS_START( junofrst )
 	PORT_DIPSETTING(    0x20, "6" )
 	PORT_DIPSETTING(    0x10, "7" )
 	PORT_DIPSETTING(    0x00, "8 (Hardest)" )
-	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) )
+	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) )	PORT_DIPLOCATION("SW2:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 INPUT_PORTS_END
@@ -382,6 +387,8 @@ static MACHINE_START( junofrst )
 
 	state->save_item(NAME(state->m_i8039_status));
 	state->save_item(NAME(state->m_last_irq));
+	state->save_item(NAME(state->m_irq_toggle));
+	state->save_item(NAME(state->m_irq_enable));
 	state->save_item(NAME(state->m_flip_x));
 	state->save_item(NAME(state->m_flip_y));
 	state->save_item(NAME(state->m_blitterdata));
@@ -401,12 +408,22 @@ static MACHINE_RESET( junofrst )
 	state->m_blitterdata[3] = 0;
 }
 
+static INTERRUPT_GEN( junofrst_30hz_irq )
+{
+	junofrst_state *state = device->machine().driver_data<junofrst_state>();
+
+	/* flip flops cause the interrupt to be signalled every other frame */
+	state->m_irq_toggle ^= 1;
+	if (state->m_irq_toggle && state->m_irq_enable)
+		device_set_input_line(device, 0, ASSERT_LINE);
+}
+
 static MACHINE_CONFIG_START( junofrst, junofrst_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6809, 1500000)			/* 1.5 MHz ??? */
 	MCFG_CPU_PROGRAM_MAP(main_map)
-	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_VBLANK_INT("screen", junofrst_30hz_irq)
 
 	MCFG_CPU_ADD("audiocpu", Z80,14318000/8)	/* 1.78975 MHz */
 	MCFG_CPU_PROGRAM_MAP(audio_map)
@@ -420,12 +437,11 @@ static MACHINE_CONFIG_START( junofrst, junofrst_state )
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_REFRESH_RATE(30)
+	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)	/* not sure about the visible area */
-	MCFG_SCREEN_UPDATE(tutankhm)
+	MCFG_SCREEN_UPDATE_STATIC(tutankhm)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
