@@ -233,9 +233,9 @@ static VIDEO_START( m2 )
 {
 }
 
-static SCREEN_UPDATE( m2 )
+static SCREEN_UPDATE_IND16( m2 )
 {
-	konamim2_state *state = screen->machine().driver_data<konamim2_state>();
+	konamim2_state *state = screen.machine().driver_data<konamim2_state>();
 	int i, j;
 
 	UINT32 fb_start = 0xffffffff;
@@ -250,7 +250,7 @@ static SCREEN_UPDATE( m2 )
 		for (j=0; j < 384; j++)
 		{
 			UINT16 *fb = &frame[(j*512)];
-			UINT16 *d = BITMAP_ADDR16(bitmap, j, 0);
+			UINT16 *d = &bitmap.pix16(j);
 			for (i=0; i < 512; i++)
 			{
 				d[i^3] = *fb++ & 0x7fff;
@@ -259,7 +259,7 @@ static SCREEN_UPDATE( m2 )
 	}
 	else
 	{
-		bitmap_fill(bitmap, cliprect, 0);
+		bitmap.fill(0, cliprect);
 	}
 	return 0;
 }
@@ -1171,10 +1171,9 @@ static MACHINE_CONFIG_START( m2, konamim2_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0, 511, 0, 383)
-	MCFG_SCREEN_UPDATE(m2)
+	MCFG_SCREEN_UPDATE_STATIC(m2)
 
 	MCFG_PALETTE_LENGTH(32768)
 	MCFG_PALETTE_INIT(RRRRR_GGGGG_BBBBB)
@@ -1280,6 +1279,12 @@ ROM_START( totlvicj )
 	DISK_IMAGE( "639jad01", 0, BAD_DUMP SHA1(39d41d5a9d1c40636d174c8bb8172b1121e313f8) )
 ROM_END
 
+ROM_START(3do_m2)
+	ROM_REGION64_BE( 0x100000, "boot", 0 )
+	ROM_SYSTEM_BIOS( 0, "panafz35", "Panasonic FZ-35S (3DO M2)" )
+	ROMX_LOAD( "fz35_jpn.bin", 0x000000, 0x100000, CRC(e1c5bfd3) SHA1(0a3e27d672be79eeee1d2dc2da60d82f6eba7934), ROM_BIOS(1) )
+ROM_END
+
 static DRIVER_INIT( m2 )
 {
 	konamim2_state *state = machine.driver_data<konamim2_state>();
@@ -1297,3 +1302,5 @@ GAME( 1998, heatof11, 0,        m2, m2, m2, ROT0, "Konami", "Heat of Eleven '98
 GAME( 1998, evilngt, 0,         m2, m2, m2, ROT0, "Konami", "Evil Night (ver UBA)", GAME_NOT_WORKING | GAME_NO_SOUND )
 GAME( 1998, evilngte,  evilngt,       m2, m2, m2, ROT0, "Konami", "Evil Night (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
 GAME( 1998, hellngt,  evilngt,  m2, m2, m2, ROT0, "Konami", "Hell Night (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
+
+CONS( 199?, 3do_m2,     0,      0,    m2,    m2,	0,      "3DO",  "3DO M2",   	GAME_NOT_WORKING | GAME_NO_SOUND )
