@@ -9,7 +9,7 @@ driver by Nicola Salmoria
     Snap Jack
     Cosmic Avenger
 
-  Simular or bootleg PCB:
+  Similar or bootleg PCB:
     Dorodon (by Falcon)
     Space Raider
 
@@ -67,26 +67,26 @@ TODO:
 /* Sound comm between CPU's */
 static READ8_HANDLER( sraider_sound_low_r )
 {
-	ladybug_state *state = space->machine->driver_data<ladybug_state>();
-	return state->sound_low;
+	ladybug_state *state = space->machine().driver_data<ladybug_state>();
+	return state->m_sound_low;
 }
 
 static READ8_HANDLER( sraider_sound_high_r )
 {
-	ladybug_state *state = space->machine->driver_data<ladybug_state>();
-	return state->sound_high;
+	ladybug_state *state = space->machine().driver_data<ladybug_state>();
+	return state->m_sound_high;
 }
 
 static WRITE8_HANDLER( sraider_sound_low_w )
 {
-	ladybug_state *state = space->machine->driver_data<ladybug_state>();
-	state->sound_low = data;
+	ladybug_state *state = space->machine().driver_data<ladybug_state>();
+	state->m_sound_low = data;
 }
 
 static WRITE8_HANDLER( sraider_sound_high_w )
 {
-	ladybug_state *state = space->machine->driver_data<ladybug_state>();
-	state->sound_high = data;
+	ladybug_state *state = space->machine().driver_data<ladybug_state>();
+	state->m_sound_high = data;
 }
 
 /* Protection? */
@@ -100,7 +100,7 @@ static READ8_HANDLER( sraider_8005_r )
 /* Unknown IO */
 static WRITE8_HANDLER( sraider_misc_w )
 {
-	ladybug_state *state = space->machine->driver_data<ladybug_state>();
+	ladybug_state *state = space->machine().driver_data<ladybug_state>();
 
 	switch(offset)
 	{
@@ -113,26 +113,26 @@ static WRITE8_HANDLER( sraider_misc_w )
 		case 0x05:
 		case 0x06:
 		case 0x07:
-			state->weird_value[offset & 7] = data & 1;
+			state->m_weird_value[offset & 7] = data & 1;
 			break;
 		/* These 6 bits are stored in the latch at N7 */
 		case 0x08:
-			state->sraider_0x30 = data&0x3f;
+			state->m_sraider_0x30 = data&0x3f;
 			break;
 		/* These 6 bits are stored in the latch at N8 */
 		case 0x10:
-			state->sraider_0x38 = data&0x3f;
+			state->m_sraider_0x38 = data&0x3f;
 			break;
 		default:
-			mame_printf_debug("(%04X) write to %02X\n", cpu_get_pc(space->cpu), offset);
+			mame_printf_debug("(%04X) write to %02X\n", cpu_get_pc(&space->device()), offset);
 			break;
 	}
 }
 
-static ADDRESS_MAP_START( ladybug_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( ladybug_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x5fff) AM_ROM
 	AM_RANGE(0x6000, 0x6fff) AM_RAM
-	AM_RANGE(0x7000, 0x73ff) AM_WRITEONLY AM_BASE_SIZE_MEMBER(ladybug_state, spriteram, spriteram_size)
+	AM_RANGE(0x7000, 0x73ff) AM_WRITEONLY AM_BASE_SIZE_MEMBER(ladybug_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x8000, 0x8fff) AM_READNOP
 	AM_RANGE(0x9000, 0x9000) AM_READ_PORT("IN0")
 	AM_RANGE(0x9001, 0x9001) AM_READ_PORT("IN1")
@@ -141,16 +141,16 @@ static ADDRESS_MAP_START( ladybug_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xa000, 0xa000) AM_WRITE(ladybug_flipscreen_w)
 	AM_RANGE(0xb000, 0xbfff) AM_DEVWRITE("sn1", sn76496_w)
 	AM_RANGE(0xc000, 0xcfff) AM_DEVWRITE("sn2", sn76496_w)
-	AM_RANGE(0xd000, 0xd3ff) AM_RAM_WRITE(ladybug_videoram_w) AM_BASE_MEMBER(ladybug_state, videoram)
-	AM_RANGE(0xd400, 0xd7ff) AM_RAM_WRITE(ladybug_colorram_w) AM_BASE_MEMBER(ladybug_state, colorram)
+	AM_RANGE(0xd000, 0xd3ff) AM_RAM_WRITE(ladybug_videoram_w) AM_BASE_MEMBER(ladybug_state, m_videoram)
+	AM_RANGE(0xd400, 0xd7ff) AM_RAM_WRITE(ladybug_colorram_w) AM_BASE_MEMBER(ladybug_state, m_colorram)
 	AM_RANGE(0xe000, 0xe000) AM_READ_PORT("IN2")
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( sraider_cpu1_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sraider_cpu1_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x5fff) AM_ROM
 	AM_RANGE(0x6000, 0x6fff) AM_RAM
-	AM_RANGE(0x7000, 0x73ff) AM_WRITEONLY AM_BASE_SIZE_MEMBER(ladybug_state, spriteram, spriteram_size)
+	AM_RANGE(0x7000, 0x73ff) AM_WRITEONLY AM_BASE_SIZE_MEMBER(ladybug_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x8005, 0x8005) AM_READ(sraider_8005_r)  // protection check?
 	AM_RANGE(0x8006, 0x8006) AM_WRITE(sraider_sound_low_w)
 	AM_RANGE(0x8007, 0x8007) AM_WRITE(sraider_sound_high_w)
@@ -158,24 +158,24 @@ static ADDRESS_MAP_START( sraider_cpu1_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x9001, 0x9001) AM_READ_PORT("IN1")
 	AM_RANGE(0x9002, 0x9002) AM_READ_PORT("DSW0")
 	AM_RANGE(0x9003, 0x9003) AM_READ_PORT("DSW1")
-	AM_RANGE(0xd000, 0xd3ff) AM_WRITE(ladybug_videoram_w) AM_BASE_MEMBER(ladybug_state, videoram)
-	AM_RANGE(0xd400, 0xd7ff) AM_WRITE(ladybug_colorram_w) AM_BASE_MEMBER(ladybug_state, colorram)
+	AM_RANGE(0xd000, 0xd3ff) AM_WRITE(ladybug_videoram_w) AM_BASE_MEMBER(ladybug_state, m_videoram)
+	AM_RANGE(0xd400, 0xd7ff) AM_WRITE(ladybug_colorram_w) AM_BASE_MEMBER(ladybug_state, m_colorram)
 	AM_RANGE(0xe000, 0xe000) AM_WRITENOP  //unknown 0x10 when in attract, 0x20 when coined/playing
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( sraider_cpu2_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sraider_cpu2_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x5fff) AM_ROM
 	AM_RANGE(0x6000, 0x63ff) AM_RAM
 	AM_RANGE(0x8000, 0x8000) AM_READ(sraider_sound_low_r)
 	AM_RANGE(0xa000, 0xa000) AM_READ(sraider_sound_high_r)
 	AM_RANGE(0xc000, 0xc000) AM_READNOP //some kind of sync
-	AM_RANGE(0xe000, 0xe0ff) AM_WRITEONLY AM_BASE_MEMBER(ladybug_state, grid_data)
+	AM_RANGE(0xe000, 0xe0ff) AM_WRITEONLY AM_BASE_MEMBER(ladybug_state, m_grid_data)
 	AM_RANGE(0xe800, 0xe800) AM_WRITE(sraider_io_w)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( sraider_cpu2_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( sraider_cpu2_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_DEVWRITE("sn1", sn76496_w)
 	AM_RANGE(0x08, 0x08) AM_DEVWRITE("sn2", sn76496_w)
@@ -189,19 +189,19 @@ ADDRESS_MAP_END
 
 static INPUT_CHANGED( coin1_inserted )
 {
-	ladybug_state *state = field->port->machine->driver_data<ladybug_state>();
+	ladybug_state *state = field.machine().driver_data<ladybug_state>();
 
 	/* left coin insertion causes an NMI */
-	cpu_set_input_line(state->maincpu, INPUT_LINE_NMI, newval ? ASSERT_LINE : CLEAR_LINE);
+	device_set_input_line(state->m_maincpu, INPUT_LINE_NMI, newval ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static INPUT_CHANGED( coin2_inserted )
 {
-	ladybug_state *state = field->port->machine->driver_data<ladybug_state>();
+	ladybug_state *state = field.machine().driver_data<ladybug_state>();
 
 	/* right coin insertion causes an IRQ */
 	if (newval)
-		cpu_set_input_line(state->maincpu, 0, HOLD_LINE);
+		device_set_input_line(state->m_maincpu, 0, HOLD_LINE);
 }
 
 
@@ -210,7 +210,7 @@ static INPUT_CHANGED( coin2_inserted )
 
 static CUSTOM_INPUT( ladybug_p1_control_r )
 {
-	return input_port_read(field->port->machine, LADYBUG_P1_CONTROL_PORT_TAG);
+	return input_port_read(field.machine(), LADYBUG_P1_CONTROL_PORT_TAG);
 }
 
 static CUSTOM_INPUT( ladybug_p2_control_r )
@@ -218,10 +218,10 @@ static CUSTOM_INPUT( ladybug_p2_control_r )
 	UINT32 ret;
 
 	/* upright cabinet only uses a single set of controls */
-	if (input_port_read(field->port->machine, "DSW0") & 0x20)
-		ret = input_port_read(field->port->machine, LADYBUG_P2_CONTROL_PORT_TAG);
+	if (input_port_read(field.machine(), "DSW0") & 0x20)
+		ret = input_port_read(field.machine(), LADYBUG_P2_CONTROL_PORT_TAG);
 	else
-		ret = input_port_read(field->port->machine, LADYBUG_P1_CONTROL_PORT_TAG);
+		ret = input_port_read(field.machine(), LADYBUG_P1_CONTROL_PORT_TAG);
 
 	return ret;
 }
@@ -286,7 +286,7 @@ static INPUT_PORTS_START( ladybug )
 	PORT_DIPSETTING(    0x0d, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_5C ) )
-	/* settings 0x00 thru 0x05 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x05 all give 1 Coin/1 Credit */
 	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x60, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( 3C_1C ) )
@@ -298,7 +298,7 @@ static INPUT_PORTS_START( ladybug )
 	PORT_DIPSETTING(    0xd0, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
-	/* settings 0x00 thru 0x50 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x50 all give 1 Coin/1 Credit */
 
 	PORT_START("COIN")	/* FAKE */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin1_inserted, 0)
@@ -387,7 +387,7 @@ static INPUT_PORTS_START( snapjack )
 	PORT_DIPSETTING(    0x0d, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_5C ) )
-	/* settings 0x00 thru 0x04 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x04 all give 1 Coin/1 Credit */
 	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x50, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x70, DEF_STR( 3C_1C ) )
@@ -400,7 +400,7 @@ static INPUT_PORTS_START( snapjack )
 	PORT_DIPSETTING(    0xd0, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
-	/* settings 0x00 thru 0x04 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x04 all give 1 Coin/1 Credit */
 
 	PORT_START("COIN")	/* FAKE */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin1_inserted, 0)
@@ -472,7 +472,7 @@ static INPUT_PORTS_START( cavenger )
 	PORT_DIPSETTING(    0x0d, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_5C ) )
-	/* settings 0x00 thru 0x05 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x05 all give 1 Coin/1 Credit */
 	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x60, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( 3C_1C ) )
@@ -484,7 +484,7 @@ static INPUT_PORTS_START( cavenger )
 	PORT_DIPSETTING(    0xd0, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
-	/* settings 0x00 thru 0x50 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x50 all give 1 Coin/1 Credit */
 
 	PORT_START("COIN")	/* FAKE */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin1_inserted, 0)
@@ -558,7 +558,7 @@ static INPUT_PORTS_START( dorodon )
 	PORT_DIPSETTING(    0x0d, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_5C ) )
-	/* settings 0x00 thru 0x05 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x05 all give 1 Coin/1 Credit */
 	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x60, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( 3C_1C ) )
@@ -570,7 +570,7 @@ static INPUT_PORTS_START( dorodon )
 	PORT_DIPSETTING(    0xd0, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
-	/* settings 0x00 thru 0x50 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x50 all give 1 Coin/1 Credit */
 
 	PORT_START("COIN")	/* FAKE */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin1_inserted, 0)
@@ -625,7 +625,7 @@ static INPUT_PORTS_START( sraider )
 	/* Free Play setting works when it's set for both */
 	PORT_START("DSW1")	/* DSW1 */
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
-	/* settings 0x00 thru 0x05 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x05 all give 1 Coin/1 Credit */
 	PORT_DIPSETTING(    0x06, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0x0a, DEF_STR( 2C_1C ) )
@@ -638,7 +638,7 @@ static INPUT_PORTS_START( sraider )
 	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
 	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_B ) )
-	/* settings 0x00 thru 0x50 all give 1 Coin/1 Credit */
+	/* settings 0x00 through 0x50 all give 1 Coin/1 Credit */
 	PORT_DIPSETTING(    0x60, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 2C_1C ) )
@@ -724,53 +724,53 @@ GFXDECODE_END
 
 static MACHINE_START( ladybug )
 {
-	ladybug_state *state = machine->driver_data<ladybug_state>();
-	state->maincpu = machine->device("maincpu");
+	ladybug_state *state = machine.driver_data<ladybug_state>();
+	state->m_maincpu = machine.device("maincpu");
 }
 
 static MACHINE_START( sraider )
 {
-	ladybug_state *state = machine->driver_data<ladybug_state>();
+	ladybug_state *state = machine.driver_data<ladybug_state>();
 
-	state->maincpu = machine->device("maincpu");
+	state->m_maincpu = machine.device("maincpu");
 
-	state_save_register_global(machine, state->grid_color);
-	state_save_register_global(machine, state->sound_low);
-	state_save_register_global(machine, state->sound_high);
-	state_save_register_global(machine, state->sraider_0x30);
-	state_save_register_global(machine, state->sraider_0x38);
-	state_save_register_global_array(machine, state->weird_value);
+	state->save_item(NAME(state->m_grid_color));
+	state->save_item(NAME(state->m_sound_low));
+	state->save_item(NAME(state->m_sound_high));
+	state->save_item(NAME(state->m_sraider_0x30));
+	state->save_item(NAME(state->m_sraider_0x38));
+	state->save_item(NAME(state->m_weird_value));
 
 	/* for stars */
-	state_save_register_global(machine, state->star_speed);
-	state_save_register_global(machine, state->stars_enable);
-	state_save_register_global(machine, state->stars_speed);
-	state_save_register_global(machine, state->stars_state);
-	state_save_register_global(machine, state->stars_offset);
-	state_save_register_global(machine, state->stars_count);
+	state->save_item(NAME(state->m_star_speed));
+	state->save_item(NAME(state->m_stars_enable));
+	state->save_item(NAME(state->m_stars_speed));
+	state->save_item(NAME(state->m_stars_state));
+	state->save_item(NAME(state->m_stars_offset));
+	state->save_item(NAME(state->m_stars_count));
 }
 
 static MACHINE_RESET( sraider )
 {
-	ladybug_state *state = machine->driver_data<ladybug_state>();
+	ladybug_state *state = machine.driver_data<ladybug_state>();
 	int i;
 
-	state->grid_color = 0;
-	state->sound_low = 0;
-	state->sound_high = 0;
-	state->sraider_0x30 = 0;
-	state->sraider_0x38 = 0;
+	state->m_grid_color = 0;
+	state->m_sound_low = 0;
+	state->m_sound_high = 0;
+	state->m_sraider_0x30 = 0;
+	state->m_sraider_0x38 = 0;
 
 	/* for stars */
-	state->star_speed = 0;
-	state->stars_enable = 0;
-	state->stars_speed = 0;
-	state->stars_state = 0;
-	state->stars_offset = 0;
-	state->stars_count = 0;
+	state->m_star_speed = 0;
+	state->m_stars_enable = 0;
+	state->m_stars_speed = 0;
+	state->m_stars_state = 0;
+	state->m_stars_offset = 0;
+	state->m_stars_count = 0;
 
 	for (i = 0; i < 8; i++)
-		state->weird_value[i] = 0;
+		state->m_weird_value[i] = 0;
 }
 
 static MACHINE_CONFIG_START( ladybug, ladybug_state )
@@ -785,16 +785,15 @@ static MACHINE_CONFIG_START( ladybug, ladybug_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 4*8, 28*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(ladybug)
 
 	MCFG_GFXDECODE(ladybug)
 	MCFG_PALETTE_LENGTH(4*8+4*16)
 
 	MCFG_PALETTE_INIT(ladybug)
 	MCFG_VIDEO_START(ladybug)
-	MCFG_VIDEO_UPDATE(ladybug)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -826,17 +825,16 @@ static MACHINE_CONFIG_START( sraider, ladybug_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 4*8, 28*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(sraider)
+	MCFG_SCREEN_VBLANK_STATIC(sraider)
 
 	MCFG_GFXDECODE(sraider)
 	MCFG_PALETTE_LENGTH(4*8+4*16+32+2)
 
 	MCFG_PALETTE_INIT(sraider)
 	MCFG_VIDEO_START(sraider)
-	MCFG_VIDEO_UPDATE(sraider)
-	MCFG_VIDEO_EOF(sraider)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1062,10 +1060,10 @@ static DRIVER_INIT( dorodon )
 	/* decode the opcodes */
 
 	offs_t i;
-	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = machine.device("maincpu")->memory().space(AS_PROGRAM);
 	UINT8 *decrypted = auto_alloc_array(machine, UINT8, 0x6000);
-	UINT8 *rom = machine->region("maincpu")->base();
-	UINT8 *table = machine->region("user1")->base();
+	UINT8 *rom = machine.region("maincpu")->base();
+	UINT8 *table = machine.region("user1")->base();
 
 	space->set_decrypted_region(0x0000, 0x5fff, decrypted);
 
