@@ -34,12 +34,12 @@ static WRITE8_HANDLER( laserbat_videoram_w )
 	if (state->m_video_page == 0)
 	{
 		state->m_videoram[offset] = data;
-		tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
+		state->m_bg_tilemap->mark_tile_dirty(offset);
 	}
 	else if (state->m_video_page == 1)
 	{
 		state->m_colorram[offset] = data;
-		tilemap_mark_tile_dirty(state->m_bg_tilemap, offset); // wrong!
+		state->m_bg_tilemap->mark_tile_dirty(offset); // wrong!
 	}
 }
 
@@ -130,7 +130,7 @@ static WRITE8_HANDLER( laserbat_cntmov_w )
     A10 SHPC
 
     The output of the 2716.14L is sent to the 82S100.10M
-    thru a parallel-to-serial shift register that is clocked
+    through a parallel-to-serial shift register that is clocked
     on (1H && 2H). The serial data sent is as follows:
 
     NAV0    D6, D4, D2, D0, 0, 0, 0, 0
@@ -503,45 +503,42 @@ static VIDEO_START( laserbat )
 	state->save_item(NAME(state->m_colorram));
 }
 
-static SCREEN_UPDATE( laserbat )
+static SCREEN_UPDATE_IND16( laserbat )
 {
-	laserbat_state *state = screen->machine().driver_data<laserbat_state>();
+	laserbat_state *state = screen.machine().driver_data<laserbat_state>();
 	int y;
-	bitmap_t *s2636_1_bitmap;
-	bitmap_t *s2636_2_bitmap;
-	bitmap_t *s2636_3_bitmap;
 
-	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
+	state->m_bg_tilemap->draw(bitmap, cliprect, 0, 0);
 
 	/* update the S2636 chips */
-	s2636_1_bitmap = s2636_update(state->m_s2636_1, cliprect);
-	s2636_2_bitmap = s2636_update(state->m_s2636_2, cliprect);
-	s2636_3_bitmap = s2636_update(state->m_s2636_3, cliprect);
+	bitmap_ind16 &s2636_1_bitmap = s2636_update(state->m_s2636_1, cliprect);
+	bitmap_ind16 &s2636_2_bitmap = s2636_update(state->m_s2636_2, cliprect);
+	bitmap_ind16 &s2636_3_bitmap = s2636_update(state->m_s2636_3, cliprect);
 
 	/* copy the S2636 images into the main bitmap */
-	for (y = cliprect->min_y; y <= cliprect->max_y; y++)
+	for (y = cliprect.min_y; y <= cliprect.max_y; y++)
 	{
 		int x;
 
-		for (x = cliprect->min_x; x <= cliprect->max_x; x++)
+		for (x = cliprect.min_x; x <= cliprect.max_x; x++)
 		{
-			int pixel1 = *BITMAP_ADDR16(s2636_1_bitmap, y, x);
-			int pixel2 = *BITMAP_ADDR16(s2636_2_bitmap, y, x);
-			int pixel3 = *BITMAP_ADDR16(s2636_3_bitmap, y, x);
+			int pixel1 = s2636_1_bitmap.pix16(y, x);
+			int pixel2 = s2636_2_bitmap.pix16(y, x);
+			int pixel3 = s2636_3_bitmap.pix16(y, x);
 
 			if (S2636_IS_PIXEL_DRAWN(pixel1))
-				*BITMAP_ADDR16(bitmap, y, x) = S2636_PIXEL_COLOR(pixel1);
+				bitmap.pix16(y, x) = S2636_PIXEL_COLOR(pixel1);
 
 			if (S2636_IS_PIXEL_DRAWN(pixel2))
-				*BITMAP_ADDR16(bitmap, y, x) = S2636_PIXEL_COLOR(pixel2);
+				bitmap.pix16(y, x) = S2636_PIXEL_COLOR(pixel2);
 
 			if (S2636_IS_PIXEL_DRAWN(pixel3))
-				*BITMAP_ADDR16(bitmap, y, x) = S2636_PIXEL_COLOR(pixel3);
+				bitmap.pix16(y, x) = S2636_PIXEL_COLOR(pixel3);
 		}
 	}
 
 	if (state->m_sprite_enable)
-		drawgfx_transpen(bitmap,cliprect,screen->machine().gfx[1],
+		drawgfx_transpen(bitmap,cliprect,screen.machine().gfx[1],
 		        state->m_sprite_code,
 				state->m_sprite_color,
 				0,0,
@@ -780,10 +777,9 @@ static MACHINE_CONFIG_START( laserbat, laserbat_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(50)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 29*8-1, 2*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(laserbat)
+	MCFG_SCREEN_UPDATE_STATIC(laserbat)
 
 	MCFG_GFXDECODE(laserbat)
 	MCFG_PALETTE_LENGTH(1024)
@@ -828,10 +824,9 @@ static MACHINE_CONFIG_START( catnmous, laserbat_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(laserbat)
+	MCFG_SCREEN_UPDATE_STATIC(laserbat)
 
 	MCFG_GFXDECODE(laserbat)
 	MCFG_PALETTE_LENGTH(1024)
@@ -945,6 +940,32 @@ ROM_START( lazarian )
 	ROM_LOAD( "lz82s100.10m", 0x0000, 0x00f5, CRC(c3eb562a) SHA1(65dff81b2e5321d530e5171dab9aa3809ab38b4d) )
 ROM_END
 
+/*
+Zaccaria "Cat 'N Mouse" 1982
+
+similar to "Quasar" execept it uses an 82s100 for color table lookup
+and has a larger program prom
+
+
+Cat N Mouse (Zaccaria 1982)
+
+CPU Board
+
+               2650    7b 6b 5b 3b 2b
+                       7c 6c 5c 3c 2c
+
+                       2636 2636 2636
+        11g 10g 8g
+     14l
+                  clr
+
+Sound Board 1b11107
+
+6802
+6821
+8910
+*/
+
 ROM_START( catnmous )
 	ROM_REGION( 0x8000, "maincpu", 0 )
 	ROM_LOAD( "02-1.7c",      0x0000, 0x0400, CRC(d26ec566) SHA1(ceb16f64a3c1ff25a9eab6549f1ae24085bb9e27) )
