@@ -27,91 +27,91 @@
 
 static READ8_HANDLER( deco16_bank_r )
 {
-	liberate_state *state = space->machine->driver_data<liberate_state>();
-	const UINT8 *ROM = space->machine->region("user1")->base();
+	liberate_state *state = space->machine().driver_data<liberate_state>();
+	const UINT8 *ROM = space->machine().region("user1")->base();
 
 	/* The tilemap bank can be swapped into main memory */
-	if (state->bank)
+	if (state->m_bank)
 		return ROM[offset];
 
 	/* Else the handler falls through to read the usual address */
 	if (offset < 0x400)
-		return state->colorram[offset];
+		return state->m_colorram[offset];
 	if (offset < 0x800)
-		return state->videoram[offset - 0x400];
+		return state->m_videoram[offset - 0x400];
 	if (offset < 0x1000)
-		return state->spriteram[offset - 0x800];
+		return state->m_spriteram[offset - 0x800];
 	if (offset < 0x2200)
 	{
-		logerror("%04x: Unmapped bank read %04x\n", cpu_get_pc(space->cpu), offset);
+		logerror("%04x: Unmapped bank read %04x\n", cpu_get_pc(&space->device()), offset);
 		return 0;
 	}
 	if (offset < 0x2800)
-		return state->scratchram[offset - 0x2200];
+		return state->m_scratchram[offset - 0x2200];
 
-	logerror("%04x: Unmapped bank read %04x\n", cpu_get_pc(space->cpu), offset);
+	logerror("%04x: Unmapped bank read %04x\n", cpu_get_pc(&space->device()), offset);
 	return 0;
 }
 
 static READ8_HANDLER( deco16_io_r )
 {
-	if (offset == 0) return input_port_read(space->machine, "IN1"); /* Player 1 controls */
-	if (offset == 1) return input_port_read(space->machine, "IN2"); /* Player 2 controls */
-	if (offset == 2) return input_port_read(space->machine, "IN3"); /* Vblank, coins */
-	if (offset == 3) return input_port_read(space->machine, "DSW1"); /* Dip 1 */
-	if (offset == 4) return input_port_read(space->machine, "DSW2"); /* Dip 2 */
+	if (offset == 0) return input_port_read(space->machine(), "IN1"); /* Player 1 controls */
+	if (offset == 1) return input_port_read(space->machine(), "IN2"); /* Player 2 controls */
+	if (offset == 2) return input_port_read(space->machine(), "IN3"); /* Vblank, coins */
+	if (offset == 3) return input_port_read(space->machine(), "DSW1"); /* Dip 1 */
+	if (offset == 4) return input_port_read(space->machine(), "DSW2"); /* Dip 2 */
 
-	logerror("%04x:  Read input %d\n", cpu_get_pc(space->cpu), offset);
+	logerror("%04x:  Read input %d\n", cpu_get_pc(&space->device()), offset);
 	return 0xff;
 }
 
 static WRITE8_HANDLER( deco16_bank_w )
 {
-	liberate_state *state = space->machine->driver_data<liberate_state>();
-	state->bank = data;
+	liberate_state *state = space->machine().driver_data<liberate_state>();
+	state->m_bank = data;
 
-	if (state->bank)
-		memory_install_read8_handler(cpu_get_address_space(state->maincpu, ADDRESS_SPACE_PROGRAM), 0x8000, 0x800f, 0, 0, deco16_io_r);
+	if (state->m_bank)
+		state->m_maincpu->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x8000, 0x800f, FUNC(deco16_io_r));
 	else
-		memory_install_read_bank(cpu_get_address_space(state->maincpu, ADDRESS_SPACE_PROGRAM), 0x8000, 0x800f, 0, 0, "bank1");
+		state->m_maincpu->memory().space(AS_PROGRAM)->install_read_bank(0x8000, 0x800f, "bank1");
 }
 
 static READ8_HANDLER( prosoccr_bank_r )
 {
-	liberate_state *state = space->machine->driver_data<liberate_state>();
-	const UINT8 *ROM = space->machine->region("user1")->base();
+	liberate_state *state = space->machine().driver_data<liberate_state>();
+	const UINT8 *ROM = space->machine().region("user1")->base();
 
 	/* The tilemap bank can be swapped into main memory */
-	if (state->bank)
+	if (state->m_bank)
 		return ROM[offset];
 
 	/* Else the handler falls through to read the usual address */
 	if (offset < 0x400)
-		return state->colorram[offset];
+		return state->m_colorram[offset];
 	if (offset < 0x800)
-		return state->videoram[offset - 0x400];
+		return state->m_videoram[offset - 0x400];
 	if (offset < 0xc00)
-		return state->colorram[offset - 0x800];
+		return state->m_colorram[offset - 0x800];
 	if (offset < 0x1000)
-		return state->spriteram[offset - 0xc00];
+		return state->m_spriteram[offset - 0xc00];
 	if (offset < 0x2200)
 	{
-		logerror("%04x: Unmapped bank read %04x\n", cpu_get_pc(space->cpu), offset);
+		logerror("%04x: Unmapped bank read %04x\n", cpu_get_pc(&space->device()), offset);
 		return 0;
 	}
 	if (offset < 0x2800)
-		return state->scratchram[offset - 0x2200];
+		return state->m_scratchram[offset - 0x2200];
 
-	logerror("%04x: Unmapped bank read %04x\n", cpu_get_pc(space->cpu), offset);
+	logerror("%04x: Unmapped bank read %04x\n", cpu_get_pc(&space->device()), offset);
 	return 0;
 }
 
 static READ8_HANDLER( prosoccr_charram_r )
 {
-	liberate_state *state = space->machine->driver_data<liberate_state>();
-	UINT8 *SRC_GFX = space->machine->region("shared_gfx")->base();
+	liberate_state *state = space->machine().driver_data<liberate_state>();
+	UINT8 *SRC_GFX = space->machine().region("shared_gfx")->base();
 
-	if (state->gfx_rom_readback)
+	if (state->m_gfx_rom_readback)
 	{
 		switch (offset & 0x1800)
 		{
@@ -125,22 +125,22 @@ static READ8_HANDLER( prosoccr_charram_r )
 	}
 
 	/* note: gfx_rom_readback == 1 never happens. */
-	return state->charram[offset + state->gfx_rom_readback * 0x1800];
+	return state->m_charram[offset + state->m_gfx_rom_readback * 0x1800];
 }
 
 static WRITE8_HANDLER( prosoccr_charram_w )
 {
-	liberate_state *state = space->machine->driver_data<liberate_state>();
-	UINT8 *FG_GFX = space->machine->region("fg_gfx")->base();
+	liberate_state *state = space->machine().driver_data<liberate_state>();
+	UINT8 *FG_GFX = space->machine().region("fg_gfx")->base();
 
-	if (state->bank)
+	if (state->m_bank)
 	{
 		prosoccr_io_w(space, offset & 0x0f, data);
 	}
 	else
 	{
 		/* note: gfx_rom_readback == 1 never happens. */
-		state->charram[offset + state->gfx_rom_readback * 0x1800] = data;
+		state->m_charram[offset + state->m_gfx_rom_readback * 0x1800] = data;
 
 		switch (offset & 0x1800)
 		{
@@ -162,14 +162,14 @@ static WRITE8_HANDLER( prosoccr_charram_w )
 	offset &= 0x7ff;
 
 	/* dirty char */
-	gfx_element_mark_dirty(space->machine->gfx[0], offset >> 3);
-//  gfx_element_mark_dirty(space->machine->gfx[0], (offset | 0x1800) >> 3);
+	gfx_element_mark_dirty(space->machine().gfx[0], offset >> 3);
+//  gfx_element_mark_dirty(space->machine().gfx[0], (offset | 0x1800) >> 3);
 }
 
 static WRITE8_HANDLER( prosoccr_char_bank_w )
 {
-	liberate_state *state = space->machine->driver_data<liberate_state>();
-	state->gfx_rom_readback = data & 1; //enable GFX rom read-back
+	liberate_state *state = space->machine().driver_data<liberate_state>();
+	state->m_gfx_rom_readback = data & 1; //enable GFX rom read-back
 
 	if (data & 0xfe)
 		printf("%02x\n", data);
@@ -177,19 +177,19 @@ static WRITE8_HANDLER( prosoccr_char_bank_w )
 
 static WRITE8_HANDLER( prosoccr_io_bank_w )
 {
-	liberate_state *state = space->machine->driver_data<liberate_state>();
-	state->bank = data & 1;
+	liberate_state *state = space->machine().driver_data<liberate_state>();
+	state->m_bank = data & 1;
 
-	if (state->bank)
-		memory_install_read8_handler(cpu_get_address_space(state->maincpu, ADDRESS_SPACE_PROGRAM), 0x8000, 0x800f, 0, 0, deco16_io_r);
+	if (state->m_bank)
+		state->m_maincpu->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x8000, 0x800f, FUNC(deco16_io_r));
 	else
-		memory_install_read8_handler(cpu_get_address_space(state->maincpu, ADDRESS_SPACE_PROGRAM), 0x8000, 0x800f, 0, 0, prosoccr_charram_r);
+		state->m_maincpu->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x8000, 0x800f, FUNC(prosoccr_charram_r));
 
 }
 
 static READ8_HANDLER( prosport_charram_r )
 {
-	UINT8 *FG_GFX = space->machine->region("progolf_fg_gfx")->base();
+	UINT8 *FG_GFX = space->machine().region("progolf_fg_gfx")->base();
 
 	switch (offset & 0x1800)
 	{
@@ -209,7 +209,7 @@ static READ8_HANDLER( prosport_charram_r )
 
 static WRITE8_HANDLER( prosport_charram_w )
 {
-	UINT8 *FG_GFX = space->machine->region("progolf_fg_gfx")->base();
+	UINT8 *FG_GFX = space->machine().region("progolf_fg_gfx")->base();
 
 	switch (offset & 0x1800)
 	{
@@ -230,8 +230,8 @@ static WRITE8_HANDLER( prosport_charram_w )
 	offset &= 0x7ff;
 
 	/* dirty char */
-	gfx_element_mark_dirty(space->machine->gfx[3], (offset + 0x800) >> 3);
-	gfx_element_mark_dirty(space->machine->gfx[3 + 4], (offset + 0x800) >> 5);
+	gfx_element_mark_dirty(space->machine().gfx[3], (offset + 0x800) >> 3);
+	gfx_element_mark_dirty(space->machine().gfx[3 + 4], (offset + 0x800) >> 5);
 }
 
 
@@ -241,65 +241,65 @@ static WRITE8_HANDLER( prosport_charram_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( prosport_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0200, 0x021f) AM_RAM_WRITE(prosport_paletteram_w) AM_BASE_MEMBER(liberate_state, paletteram)
+static ADDRESS_MAP_START( prosport_map, AS_PROGRAM, 8 )
+	AM_RANGE(0x0200, 0x021f) AM_RAM_WRITE(prosport_paletteram_w) AM_BASE_MEMBER(liberate_state, m_paletteram)
 	AM_RANGE(0x0000, 0x03ff) AM_MIRROR(0x2000) AM_RAM
-	AM_RANGE(0x0400, 0x07ff) AM_RAM_WRITE(prosport_bg_vram_w) AM_BASE_MEMBER(liberate_state, bg_vram)
+	AM_RANGE(0x0400, 0x07ff) AM_RAM_WRITE(prosport_bg_vram_w) AM_BASE_MEMBER(liberate_state, m_bg_vram)
 	AM_RANGE(0x0800, 0x1fff) AM_READWRITE(prosport_charram_r,prosport_charram_w) //0x1e00-0x1fff isn't charram!
 	AM_RANGE(0x2400, 0x2fff) AM_RAM
-	AM_RANGE(0x3000, 0x33ff) AM_RAM_WRITE(liberate_colorram_w) AM_BASE_MEMBER(liberate_state, colorram)
-	AM_RANGE(0x3400, 0x37ff) AM_RAM_WRITE(liberate_videoram_w) AM_BASE_MEMBER(liberate_state, videoram)
-	AM_RANGE(0x3800, 0x3fff) AM_RAM AM_BASE_MEMBER(liberate_state, spriteram)
+	AM_RANGE(0x3000, 0x33ff) AM_RAM_WRITE(liberate_colorram_w) AM_BASE_MEMBER(liberate_state, m_colorram)
+	AM_RANGE(0x3400, 0x37ff) AM_RAM_WRITE(liberate_videoram_w) AM_BASE_MEMBER(liberate_state, m_videoram)
+	AM_RANGE(0x3800, 0x3fff) AM_RAM AM_BASE_MEMBER(liberate_state, m_spriteram)
 	AM_RANGE(0x8000, 0x800f) AM_WRITE(prosport_io_w)
 	AM_RANGE(0x8000, 0x800f) AM_ROMBANK("bank1")
 	AM_RANGE(0x4000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( liberate_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( liberate_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_RAM
 	AM_RANGE(0x1000, 0x3fff) AM_ROM /* Mirror of main rom */
 	AM_RANGE(0x4000, 0x7fff) AM_READ(deco16_bank_r)
-	AM_RANGE(0x4000, 0x43ff) AM_WRITE(liberate_colorram_w) AM_BASE_MEMBER(liberate_state, colorram)
-	AM_RANGE(0x4400, 0x47ff) AM_WRITE(liberate_videoram_w) AM_BASE_MEMBER(liberate_state, videoram)
-	AM_RANGE(0x4800, 0x4fff) AM_WRITEONLY AM_BASE_MEMBER(liberate_state, spriteram)
-	AM_RANGE(0x6200, 0x67ff) AM_RAM AM_BASE_MEMBER(liberate_state, scratchram)
+	AM_RANGE(0x4000, 0x43ff) AM_WRITE(liberate_colorram_w) AM_BASE_MEMBER(liberate_state, m_colorram)
+	AM_RANGE(0x4400, 0x47ff) AM_WRITE(liberate_videoram_w) AM_BASE_MEMBER(liberate_state, m_videoram)
+	AM_RANGE(0x4800, 0x4fff) AM_WRITEONLY AM_BASE_MEMBER(liberate_state, m_spriteram)
+	AM_RANGE(0x6200, 0x67ff) AM_RAM AM_BASE_MEMBER(liberate_state, m_scratchram)
 	AM_RANGE(0x8000, 0x800f) AM_WRITE(deco16_io_w)
 	AM_RANGE(0x8000, 0x800f) AM_ROMBANK("bank1")
 	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( prosoccr_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( prosoccr_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_RAM
 	AM_RANGE(0x1000, 0x3fff) AM_ROM /* Mirror of main rom */
 	AM_RANGE(0x4000, 0x7fff) AM_READ(prosoccr_bank_r)
-	AM_RANGE(0x4000, 0x43ff) AM_MIRROR(0x800) AM_WRITE(liberate_colorram_w) AM_BASE_MEMBER(liberate_state, colorram)
-	AM_RANGE(0x4400, 0x47ff) AM_WRITE(liberate_videoram_w) AM_BASE_MEMBER(liberate_state, videoram)
-	AM_RANGE(0x4c00, 0x4fff) AM_WRITEONLY AM_BASE_MEMBER(liberate_state, spriteram)
-	AM_RANGE(0x6200, 0x67ff) AM_RAM AM_BASE_MEMBER(liberate_state, scratchram)
+	AM_RANGE(0x4000, 0x43ff) AM_MIRROR(0x800) AM_WRITE(liberate_colorram_w) AM_BASE_MEMBER(liberate_state, m_colorram)
+	AM_RANGE(0x4400, 0x47ff) AM_WRITE(liberate_videoram_w) AM_BASE_MEMBER(liberate_state, m_videoram)
+	AM_RANGE(0x4c00, 0x4fff) AM_WRITEONLY AM_BASE_MEMBER(liberate_state, m_spriteram)
+	AM_RANGE(0x6200, 0x67ff) AM_RAM AM_BASE_MEMBER(liberate_state, m_scratchram)
 	AM_RANGE(0x8000, 0x97ff) AM_READWRITE(prosoccr_charram_r, prosoccr_charram_w)
 	AM_RANGE(0x9800, 0x9800) AM_WRITE(prosoccr_char_bank_w)
 	AM_RANGE(0xa000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( deco16_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( deco16_io_map, AS_IO, 8 )
 	AM_RANGE(0x00, 0x00) AM_READ_PORT("IN0") AM_WRITE(deco16_bank_w)
 	AM_RANGE(0x01, 0x01) AM_READ_PORT("TILT")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( prosoccr_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( prosoccr_io_map, AS_IO, 8 )
 	AM_RANGE(0x00, 0x00) AM_READ_PORT("IN0") AM_WRITE(prosoccr_io_bank_w)
 	//AM_RANGE(0x01, 0x01) AM_READ_PORT("TILT")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( liberatb_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( liberatb_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x00fe, 0x00fe) AM_READ_PORT("IN0")
 	AM_RANGE(0x0000, 0x0fff) AM_RAM
 	AM_RANGE(0x1000, 0x3fff) AM_ROM /* Mirror of main rom */
 	AM_RANGE(0x4000, 0x7fff) AM_READ(deco16_bank_r)
-	AM_RANGE(0x4000, 0x43ff) AM_WRITE(liberate_colorram_w) AM_BASE_MEMBER(liberate_state, colorram)
-	AM_RANGE(0x4400, 0x47ff) AM_WRITE(liberate_videoram_w) AM_BASE_MEMBER(liberate_state, videoram)
-	AM_RANGE(0x4800, 0x4fff) AM_WRITEONLY AM_BASE_MEMBER(liberate_state, spriteram)
-	AM_RANGE(0x6200, 0x67ff) AM_WRITEONLY AM_BASE_MEMBER(liberate_state, scratchram)
+	AM_RANGE(0x4000, 0x43ff) AM_WRITE(liberate_colorram_w) AM_BASE_MEMBER(liberate_state, m_colorram)
+	AM_RANGE(0x4400, 0x47ff) AM_WRITE(liberate_videoram_w) AM_BASE_MEMBER(liberate_state, m_videoram)
+	AM_RANGE(0x4800, 0x4fff) AM_WRITEONLY AM_BASE_MEMBER(liberate_state, m_spriteram)
+	AM_RANGE(0x6200, 0x67ff) AM_WRITEONLY AM_BASE_MEMBER(liberate_state, m_scratchram)
 	AM_RANGE(0xf000, 0xf00f) AM_WRITE(deco16_io_w)
 	AM_RANGE(0xf000, 0xf000) AM_READ_PORT("IN1")
 	AM_RANGE(0xf001, 0xf001) AM_READ_PORT("IN2")
@@ -315,7 +315,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( prosoccr_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( prosoccr_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x01ff) AM_RAM
 	AM_RANGE(0x2000, 0x2000) AM_DEVWRITE("ay1", ay8910_data_w)
 	AM_RANGE(0x4000, 0x4000) AM_DEVWRITE("ay1", ay8910_address_w)
@@ -326,7 +326,7 @@ static ADDRESS_MAP_START( prosoccr_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( liberate_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( liberate_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x01ff) AM_RAM
 	AM_RANGE(0x1000, 0x1000) AM_WRITENOP
 	AM_RANGE(0x3000, 0x3000) AM_DEVWRITE("ay1", ay8910_data_w)
@@ -769,17 +769,17 @@ GFXDECODE_END
 
 static INTERRUPT_GEN( deco16_interrupt )
 {
-	liberate_state *state = device->machine->driver_data<liberate_state>();
-	int p = ~input_port_read(device->machine, "IN3");
-	if ((p & 0x43) && !state->latch)
+	liberate_state *state = device->machine().driver_data<liberate_state>();
+	int p = ~input_port_read(device->machine(), "IN3");
+	if ((p & 0x43) && !state->m_latch)
 	{
-		cpu_set_input_line(device, DECO16_IRQ_LINE, ASSERT_LINE);
-		state->latch = 1;
+		device_set_input_line(device, DECO16_IRQ_LINE, ASSERT_LINE);
+		state->m_latch = 1;
 	}
 	else
 	{
 		if (!(p & 0x43))
-			state->latch = 0;
+			state->m_latch = 0;
 	}
 }
 
@@ -787,7 +787,7 @@ static INTERRUPT_GEN( deco16_interrupt )
 static INTERRUPT_GEN( prosport_interrupt )
 {
 	/* ??? */
-	cpu_set_input_line(device, DECO16_IRQ_LINE, ASSERT_LINE);
+	device_set_input_line(device, DECO16_IRQ_LINE, ASSERT_LINE);
 }
 #endif
 
@@ -799,31 +799,31 @@ static INTERRUPT_GEN( prosport_interrupt )
 
 static MACHINE_START( liberate )
 {
-	liberate_state *state = machine->driver_data<liberate_state>();
+	liberate_state *state = machine.driver_data<liberate_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->audiocpu = machine->device("audiocpu");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_audiocpu = machine.device("audiocpu");
 
-	state_save_register_global(machine, state->background_disable);
-	state_save_register_global(machine, state->background_color);
-	state_save_register_global(machine, state->gfx_rom_readback);
-	state_save_register_global(machine, state->latch);
-	state_save_register_global(machine, state->bank);
+	state->save_item(NAME(state->m_background_disable));
+	state->save_item(NAME(state->m_background_color));
+	state->save_item(NAME(state->m_gfx_rom_readback));
+	state->save_item(NAME(state->m_latch));
+	state->save_item(NAME(state->m_bank));
 
-	state_save_register_global_array(machine, state->io_ram);
+	state->save_item(NAME(state->m_io_ram));
 }
 
 static MACHINE_RESET( liberate )
 {
-	liberate_state *state = machine->driver_data<liberate_state>();
+	liberate_state *state = machine.driver_data<liberate_state>();
 
-	memset(state->io_ram, 0, ARRAY_LENGTH(state->io_ram));
+	memset(state->m_io_ram, 0, ARRAY_LENGTH(state->m_io_ram));
 
-	state->background_disable = 0;
-	state->background_color = 0;
-	state->gfx_rom_readback = 0;
-	state->latch = 0;
-	state->bank = 0;
+	state->m_background_disable = 0;
+	state->m_background_color = 0;
+	state->m_gfx_rom_readback = 0;
+	state->m_latch = 0;
+	state->m_bank = 0;
 }
 
 static MACHINE_CONFIG_START( liberate, liberate_state )
@@ -838,7 +838,7 @@ static MACHINE_CONFIG_START( liberate, liberate_state )
 	MCFG_CPU_PROGRAM_MAP(liberate_sound_map)
 	MCFG_CPU_PERIODIC_INT(nmi_line_pulse,16*60) /* ??? */
 
-	MCFG_QUANTUM_TIME(HZ(12000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(12000))
 
 	MCFG_MACHINE_START(liberate)
 	MCFG_MACHINE_RESET(liberate)
@@ -847,16 +847,15 @@ static MACHINE_CONFIG_START( liberate, liberate_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529) /* 529ms Vblank duration?? */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(liberate)
 
 	MCFG_GFXDECODE(liberate)
 	MCFG_PALETTE_LENGTH(33)
 	MCFG_PALETTE_INIT(liberate)
 
 	MCFG_VIDEO_START(liberate)
-	MCFG_VIDEO_UPDATE(liberate)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -879,7 +878,8 @@ MACHINE_CONFIG_END
 static MACHINE_CONFIG_DERIVED( boomrang, liberate )
 
 	MCFG_VIDEO_START(boomrang)
-	MCFG_VIDEO_UPDATE(boomrang)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE_STATIC(boomrang)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( prosoccr, liberate )
@@ -894,15 +894,15 @@ static MACHINE_CONFIG_DERIVED( prosoccr, liberate )
 	MCFG_CPU_CLOCK(10000000/8) //xtal is 12 Mhz, divider is unknown
 	MCFG_CPU_PROGRAM_MAP(prosoccr_sound_map)
 
-	MCFG_QUANTUM_TIME(HZ(12000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(12000))
 
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(prosoccr)
 
 	MCFG_GFXDECODE(prosoccr)
 
 	MCFG_VIDEO_START(prosoccr)
-	MCFG_VIDEO_UPDATE(prosoccr)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_START( prosport, liberate_state )
@@ -917,7 +917,7 @@ static MACHINE_CONFIG_START( prosport, liberate_state )
 	MCFG_CPU_PROGRAM_MAP(liberate_sound_map)
 	MCFG_CPU_PERIODIC_INT(nmi_line_pulse,16*60) /* ??? */
 
-//  MCFG_QUANTUM_TIME(HZ(12000))
+//  MCFG_QUANTUM_TIME(attotime::from_hz(12000))
 
 	MCFG_MACHINE_START(liberate)
 	MCFG_MACHINE_RESET(liberate)
@@ -926,15 +926,14 @@ static MACHINE_CONFIG_START( prosport, liberate_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(1529) /* 529ms Vblank duration?? */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(prosport)
 
 	MCFG_GFXDECODE(prosport)
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_VIDEO_START(prosport)
-	MCFG_VIDEO_UPDATE(prosport)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1354,11 +1353,11 @@ ROM_END
  *
  *************************************/
 
-static void sound_cpu_decrypt(running_machine *machine)
+static void sound_cpu_decrypt(running_machine &machine)
 {
-	address_space *space = cputag_get_address_space(machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = machine.device("audiocpu")->memory().space(AS_PROGRAM);
 	UINT8 *decrypted = auto_alloc_array(machine, UINT8, 0x4000);
-	UINT8 *rom = machine->region("audiocpu")->base();
+	UINT8 *rom = machine.region("audiocpu")->base();
 	int i;
 
 	/* Bit swapping on sound cpu - Opcodes only */
@@ -1370,7 +1369,7 @@ static void sound_cpu_decrypt(running_machine *machine)
 
 static DRIVER_INIT( prosport )
 {
-	UINT8 *RAM = machine->region("maincpu")->base();
+	UINT8 *RAM = machine.region("maincpu")->base();
 	int i;
 
 	/* Main cpu has the nibbles swapped */
@@ -1384,15 +1383,15 @@ static DRIVER_INIT( yellowcb )
 {
 	DRIVER_INIT_CALL(prosport);
 
-	memory_install_read_port(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xa000, 0xa000, 0, 0, "IN0");
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_read_port(0xa000, 0xa000, "IN0");
 }
 
 static DRIVER_INIT( liberate )
 {
 	int A;
-	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = machine.device("maincpu")->memory().space(AS_PROGRAM);
 	UINT8 *decrypted = auto_alloc_array(machine, UINT8, 0x10000);
-	UINT8 *ROM = machine->region("maincpu")->base();
+	UINT8 *ROM = machine.region("maincpu")->base();
 
 	space->set_decrypted_region(0x0000, 0xffff, decrypted);
 
