@@ -407,8 +407,7 @@ static MACHINE_CONFIG_START( m52, m52_state )
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS(MASTER_CLOCK/3, 384, 136, 376, 282, 22, 274)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MCFG_SCREEN_UPDATE(m52)
+	MCFG_SCREEN_UPDATE_STATIC(m52)
 
 	MCFG_PALETTE_INIT(m52)
 	MCFG_VIDEO_START(m52)
