@@ -236,10 +236,9 @@ static MACHINE_CONFIG_START( m57, m57_state )
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(1790)	/* accurate frequency, measured on a Moon Patrol board, is 56.75Hz. */)
 				/* the Lode Runner manual (similar but different hardware) */
 				/* talks about 55Hz and 1790ms vblank duration. */
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 1*8, 31*8-1)
-	MCFG_SCREEN_UPDATE(m57)
+	MCFG_SCREEN_UPDATE_STATIC(m57)
 
 	MCFG_GFXDECODE(m57)
 	MCFG_PALETTE_LENGTH(32*8+32*8)
