@@ -482,10 +482,9 @@ static MACHINE_CONFIG_START( macs, macs_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(128*8, 128*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 128*8-1, 0*8, 128*8-1)
-	MCFG_SCREEN_UPDATE(st0016)
+	MCFG_SCREEN_UPDATE_STATIC(st0016)
 
 	MCFG_GFXDECODE(macs)
 	MCFG_PALETTE_LENGTH(16*16*4+1)
