@@ -111,21 +111,21 @@ static WRITE16_HANDLER( layer0_videoram_w )
 {
 	magic10_state *state = space->machine().driver_data<magic10_state>();
 	COMBINE_DATA(&state->m_layer0_videoram[offset]);
-	tilemap_mark_tile_dirty( state->m_layer0_tilemap, offset >> 1);
+	state->m_layer0_tilemap->mark_tile_dirty(offset >> 1);
 }
 
 static WRITE16_HANDLER( layer1_videoram_w )
 {
 	magic10_state *state = space->machine().driver_data<magic10_state>();
 	COMBINE_DATA(&state->m_layer1_videoram[offset]);
-	tilemap_mark_tile_dirty( state->m_layer1_tilemap, offset >> 1);
+	state->m_layer1_tilemap->mark_tile_dirty(offset >> 1);
 }
 
 static WRITE16_HANDLER( layer2_videoram_w )
 {
 	magic10_state *state = space->machine().driver_data<magic10_state>();
 	COMBINE_DATA(&state->m_layer2_videoram[offset]);
-	tilemap_mark_tile_dirty( state->m_layer2_tilemap, offset >> 1);
+	state->m_layer2_tilemap->mark_tile_dirty(offset >> 1);
 }
 
 static WRITE16_HANDLER( paletteram_w )
@@ -179,27 +179,27 @@ static VIDEO_START( magic10 )
 	state->m_layer1_tilemap = tilemap_create(machine, get_layer1_tile_info, tilemap_scan_rows, 16, 16, 32, 32);
 	state->m_layer2_tilemap = tilemap_create(machine, get_layer2_tile_info, tilemap_scan_rows, 8, 8, 64, 64);
 
-	tilemap_set_transparent_pen(state->m_layer1_tilemap, 0);
-	tilemap_set_transparent_pen(state->m_layer2_tilemap, 0);
+	state->m_layer1_tilemap->set_transparent_pen(0);
+	state->m_layer2_tilemap->set_transparent_pen(0);
 }
 
-static SCREEN_UPDATE( magic10 )
+static SCREEN_UPDATE_IND16( magic10 )
 {
-	magic10_state *state = screen->machine().driver_data<magic10_state>();
+	magic10_state *state = screen.machine().driver_data<magic10_state>();
 	/*TODO: understand where this comes from. */
-	tilemap_set_scrollx(state->m_layer2_tilemap, 0, state->m_layer2_offset[0]);
-	tilemap_set_scrolly(state->m_layer2_tilemap, 0, state->m_layer2_offset[1]);
+	state->m_layer2_tilemap->set_scrollx(0, state->m_layer2_offset[0]);
+	state->m_layer2_tilemap->set_scrolly(0, state->m_layer2_offset[1]);
 
 	/*
     4 and 6 are y/x global register writes.
     0 and 2 are y/x writes for the scrolling layer.
     */
-	tilemap_set_scrolly(state->m_layer1_tilemap, 0, (state->m_vregs[0/2] - state->m_vregs[4/2])+0);
-	tilemap_set_scrollx(state->m_layer1_tilemap, 0, (state->m_vregs[2/2] - state->m_vregs[6/2])+4);
+	state->m_layer1_tilemap->set_scrolly(0, (state->m_vregs[0/2] - state->m_vregs[4/2])+0);
+	state->m_layer1_tilemap->set_scrollx(0, (state->m_vregs[2/2] - state->m_vregs[6/2])+4);
 
-	tilemap_draw(bitmap, cliprect, state->m_layer0_tilemap, 0, 0);
-	tilemap_draw(bitmap, cliprect, state->m_layer1_tilemap, 0, 0);
-	tilemap_draw(bitmap, cliprect, state->m_layer2_tilemap, 0, 0);
+	state->m_layer0_tilemap->draw(bitmap, cliprect, 0, 0);
+	state->m_layer1_tilemap->draw(bitmap, cliprect, 0, 0);
+	state->m_layer2_tilemap->draw(bitmap, cliprect, 0, 0);
 
 	return 0;
 }
@@ -223,7 +223,7 @@ static READ16_HANDLER( hotslot_copro_r )
 
 static WRITE16_HANDLER( hotslot_copro_w )
 {
-	logerror("Writting to copro: %d \n", data);
+	logerror("Writing to copro: %d \n", data);
 }
 
 static WRITE16_HANDLER( magic10_out_w )
@@ -724,10 +724,9 @@ static MACHINE_CONFIG_START( magic10, magic10_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 44*8-1, 2*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(magic10)
+	MCFG_SCREEN_UPDATE_STATIC(magic10)
 
 	MCFG_PALETTE_LENGTH(0x100)
 	MCFG_GFXDECODE(magic10)
