@@ -405,10 +405,9 @@ static MACHINE_CONFIG_START( mainsnk, mainsnk_state )
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(36*8, 28*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 1*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(mainsnk)
+	MCFG_SCREEN_UPDATE_STATIC(mainsnk)
 
 	MCFG_GFXDECODE(mainsnk)
 	MCFG_PALETTE_LENGTH(0x400)
