@@ -326,10 +326,9 @@ static MACHINE_CONFIG_START( matmania, matmania_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
-	MCFG_SCREEN_UPDATE(matmania)
+	MCFG_SCREEN_UPDATE_STATIC(matmania)
 
 	MCFG_GFXDECODE(matmania)
 	MCFG_PALETTE_LENGTH(64+16)
@@ -428,10 +427,9 @@ static MACHINE_CONFIG_START( maniach, matmania_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
-	MCFG_SCREEN_UPDATE(maniach)
+	MCFG_SCREEN_UPDATE_STATIC(maniach)
 
 	MCFG_GFXDECODE(maniach)
 	MCFG_PALETTE_LENGTH(64+16)
