@@ -58,13 +58,13 @@ static WRITE8_HANDLER( mayumi_videoram_w )
 {
 	mayumi_state *state = space->machine().driver_data<mayumi_state>();
 	state->m_videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_tilemap, offset & 0x7ff);
+	state->m_tilemap->mark_tile_dirty(offset & 0x7ff);
 }
 
-static SCREEN_UPDATE( mayumi )
+static SCREEN_UPDATE_IND16( mayumi )
 {
-	mayumi_state *state = screen->machine().driver_data<mayumi_state>();
-	tilemap_draw(bitmap, cliprect, state->m_tilemap, 0, 0);
+	mayumi_state *state = screen.machine().driver_data<mayumi_state>();
+	state->m_tilemap->draw(bitmap, cliprect, 0, 0);
 	return 0;
 }
 
@@ -382,10 +382,9 @@ static MACHINE_CONFIG_START( mayumi, mayumi_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(2*8, 62*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(mayumi)
+	MCFG_SCREEN_UPDATE_STATIC(mayumi)
 
 	MCFG_GFXDECODE(mayumi)
 	MCFG_PALETTE_LENGTH(256)
