@@ -60,7 +60,7 @@ U92 & U93 are unpopulated
 NOS-SN-00.U53 Sound samples (Near the YMF286-K)
 
 NOS-B0-00.U58-
-NOS-B0-01.U59 \ Background (Seperate for each 038 chip?)
+NOS-B0-01.U59 \ Background (separate for each 038 chip?)
 NOS-B1-00.U60 /
 NOS-B1-01.U61-
 
@@ -458,11 +458,10 @@ static MACHINE_CONFIG_START( mcatadv, mcatadv_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0, 224-1)
-	MCFG_SCREEN_UPDATE(mcatadv)
-	MCFG_SCREEN_EOF(mcatadv) // Buffer Spriteram
+	MCFG_SCREEN_UPDATE_STATIC(mcatadv)
+	MCFG_SCREEN_VBLANK_STATIC(mcatadv) // Buffer Spriteram
 
 	MCFG_GFXDECODE(mcatadv)
 	MCFG_PALETTE_LENGTH(0x2000/2)
