@@ -62,10 +62,10 @@ Stephh's notes (based on the game M68000 code and some tests) :
   - 0xff7e16.b to 0xff7e19.b = ??? (range 0x30-0x33 * 3 + 0x00) - MSDigit first - see below
   - 0xff7e21.b = difficulty (range 0x00-0x02) - see below
 
-2) Adresses notes
+2) Addresses notes
 
-  - I can't tell what adresses 0xff7r12.l and 0xff7e16.l are supposed to be designed for :
-    they are written once at the begining of each level (code at 0x1a9030) but I haven't found
+  - I can't tell what addresses 0xff7r12.l and 0xff7e16.l are supposed to be designed for :
+    they are written once at the beginning of each level (code at 0x1a9030) but I haven't found
     when they were read back (I've only played the 2 first levels though as well as the bonus level,
     but I also watched all demo levels till the end after the games full credits).
     I guess they were originally designed for bonus lives (additional and first), but no evidence.
@@ -273,27 +273,26 @@ static WRITE16_HANDLER( aladmdb_w )
       - aladmdb_w : 1b2d18 - data = aa00 (only once on reset)
       - aladmdb_w : 1b2d42 - data = 0000 (only once on reset)
     */
-	logerror("aladmdb_w : %06x - data = %04x\n",cpu_get_pc(space->cpu),data);
+	logerror("aladmdb_w : %06x - data = %04x\n",cpu_get_pc(&space->device()),data);
 }
 
 static READ16_HANDLER( aladmdb_r )
 {
-	if (cpu_get_pc(space->cpu)==0x1b2a56)
+	md_boot_state *state = space->machine().driver_data<md_boot_state>();
+	if (cpu_get_pc(&space->device())==0x1b2a56)
 	{
-		static UINT16 mcu_port;
+		state->m_aladmdb_mcu_port = input_port_read(space->machine(), "MCU");
 
-		mcu_port = input_port_read(space->machine, "MCU");
-
-		if(mcu_port & 0x100)
-			return ((mcu_port & 0x0f) | 0x100); // coin inserted, calculate the number of coins
+		if (state->m_aladmdb_mcu_port & 0x100)
+			return ((state->m_aladmdb_mcu_port & 0x0f) | 0x100); // coin inserted, calculate the number of coins
 		else
 			return (0x100); //MCU status, needed if you fall into a pitfall
 	}
-	if (cpu_get_pc(space->cpu)==0x1b2a72) return 0x0000;
-	if (cpu_get_pc(space->cpu)==0x1b2d24) return (input_port_read(space->machine, "MCU") & 0x00f0) | 0x1200;    // difficulty
-	if (cpu_get_pc(space->cpu)==0x1b2d4e) return 0x0000;
+	if (cpu_get_pc(&space->device())==0x1b2a72) return 0x0000;
+	if (cpu_get_pc(&space->device())==0x1b2d24) return (input_port_read(space->machine(), "MCU") & 0x00f0) | 0x1200;    // difficulty
+	if (cpu_get_pc(&space->device())==0x1b2d4e) return 0x0000;
 
-	logerror("aladbl_r : %06x\n",cpu_get_pc(space->cpu));
+	logerror("aladbl_r : %06x\n",cpu_get_pc(&space->device()));
 
 	return 0x0000;
 }
@@ -301,22 +300,22 @@ static READ16_HANDLER( aladmdb_r )
 static READ16_HANDLER( mk3mdb_dsw_r )
 {
 	static const char *const dswname[3] = { "DSWA", "DSWB", "DSWC" };
-	return input_port_read(space->machine, dswname[offset]);
+	return input_port_read(space->machine(), dswname[offset]);
 }
 
 static READ16_HANDLER( ssf2mdb_dsw_r )
 {
 	static const char *const dswname[3] = { "DSWA", "DSWB", "DSWC" };
-	return input_port_read(space->machine, dswname[offset]);
+	return input_port_read(space->machine(), dswname[offset]);
 }
 
 static READ16_HANDLER( srmdb_dsw_r )
 {
 	static const char *const dswname[3] = { "DSWA", "DSWB", "DSWC" };
-	return input_port_read(space->machine, dswname[offset]);
+	return input_port_read(space->machine(), dswname[offset]);
 }
 
-static READ16_HANDLER(topshoot_200051_r)
+static READ16_HANDLER( topshoot_200051_r )
 {
 	return -0x5b;
 }
@@ -570,6 +569,16 @@ static INPUT_PORTS_START( topshoot ) /* Top Shooter Input Ports */
 	PORT_BIT( 0xfe, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
 
+/*************************************
+ *
+ *  Machine Configuration
+ *
+ *************************************/
+
+static MACHINE_CONFIG_START( megadrvb, md_boot_state )
+	MCFG_FRAGMENT_ADD(md_ntsc)
+MACHINE_CONFIG_END
+
 /*************************************
  *
  *  ROM definition(s)
@@ -650,14 +659,15 @@ static DRIVER_INIT( aladmdb )
      * Game does a check @ 1afc00 with work RAM fff57c that makes it play like the original console version (i.e. 8 energy hits instead of 2)
      */
 	#if ENERGY_CONSOLE_MODE
-	UINT16 *rom = (UINT16 *)machine->region("maincpu")->base();
+	UINT16 *rom = (UINT16 *)machine.region("maincpu")->base();
 	rom[0x1afc08/2] = 0x6600;
 	#endif
 
 	// 220000 = writes to mcu? 330000 = reads?
-	memory_install_write16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x220000, 0x220001, 0, 0, aladmdb_w);
-	memory_install_read16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x330000, 0x330001, 0, 0, aladmdb_r);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x220000, 0x220001, FUNC(aladmdb_w));
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x330000, 0x330001, FUNC(aladmdb_r));
 
+	megadrive_6buttons_pad = 0;
 	DRIVER_INIT_CALL(megadrij);
 }
 
@@ -665,28 +675,27 @@ static DRIVER_INIT( aladmdb )
 // after this decode look like intentional changes
 static DRIVER_INIT( mk3mdb )
 {
-	int x;
-	UINT8 *rom = machine->region("maincpu")->base();
+	UINT8 *rom = machine.region("maincpu")->base();
 
-	for (x=0x000001;x<0x100001;x+=2)
+	for (int x = 0x000001; x < 0x100001; x += 2)
 	{
-		if (x&0x80000)
+		if (x & 0x80000)
 		{
-			rom[x] = rom[x]^0xff;
+			rom[x] = rom[x] ^ 0xff;
 			rom[x] = BITSWAP8(rom[x], 0,3,2,5,4,6,7,1);
 		}
 		else
 		{
-			rom[x] = rom[x]^0xff;
+			rom[x] = rom[x] ^ 0xff;
 			rom[x] = BITSWAP8(rom[x], 4,0,7,1,3,6,2,5);
 		}
 	}
 
-	for (x=0x100001;x<0x400000;x+=2)
+	for (int x = 0x100001; x < 0x400000; x += 2)
 	{
-		if (x&0x80000)
+		if (x & 0x80000)
 		{
-			rom[x] = rom[x]^0xff;
+			rom[x] = rom[x] ^ 0xff;
 			rom[x] = BITSWAP8(rom[x], 2,7,5,4,1,0,3,6);
 		}
 		else
@@ -705,50 +714,50 @@ static DRIVER_INIT( mk3mdb )
 	rom[0x07] = 0x02;
 	rom[0x06] = 0x10;
 
-	memory_install_read16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x770070, 0x770075, 0, 0, mk3mdb_dsw_r );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x770070, 0x770075, FUNC(mk3mdb_dsw_r) );
 
+	megadrive_6buttons_pad = 1;
 	DRIVER_INIT_CALL(megadriv);
 }
 
 static DRIVER_INIT( ssf2mdb )
 {
-	memory_nop_write(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xA130F0, 0xA130FF, 0, 0); // custom banking is disabled (!)
-	memory_install_read_bank(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x400000, 0x5fffff, 0, 0, "bank5");
-	memory_unmap_write(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x400000, 0x5fffff, 0, 0);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->nop_write(0xA130F0, 0xA130FF); // custom banking is disabled (!)
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_read_bank(0x400000, 0x5fffff, "bank5");
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->unmap_write(0x400000, 0x5fffff);
 
-	memory_set_bankptr(machine,  "bank5", machine->region( "maincpu" )->base() + 0x400000 );
+	memory_set_bankptr(machine,  "bank5", machine.region( "maincpu" )->base() + 0x400000 );
 
-	memory_install_read16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x770070, 0x770075, 0, 0, ssf2mdb_dsw_r );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x770070, 0x770075, FUNC(ssf2mdb_dsw_r) );
 
+	megadrive_6buttons_pad = 1;
 	DRIVER_INIT_CALL(megadrij);
-
 }
 
 static DRIVER_INIT( srmdb )
 {
-	int x;
-	UINT8* rom = machine->region("maincpu")->base();
+	UINT8* rom = machine.region("maincpu")->base();
 
 	/* todo, reduce bitswaps to single swap */
-	for (x=0x00001;x<0x40000;x+=2)
+	for (int x = 0x00001; x < 0x40000; x += 2)
 	{
 		rom[x] = rom[x] ^ 0xff;
-		rom[x] = BITSWAP8(rom[x], 7,6,5,4,3,2,1,0 );
-		rom[x] = BITSWAP8(rom[x], 1,6,5,4,3,2,7,0 );
-		rom[x] = BITSWAP8(rom[x], 7,6,5,3,4,2,1,0 );
-		rom[x] = BITSWAP8(rom[x], 7,6,5,2,3,4,1,0 );
-		rom[x] = BITSWAP8(rom[x], 5,6,7,4,3,2,1,0 );
-		rom[x] = BITSWAP8(rom[x], 7,5,6,4,3,2,1,0 );
+		rom[x] = BITSWAP8(rom[x], 7,6,5,4,3,2,1,0);
+		rom[x] = BITSWAP8(rom[x], 1,6,5,4,3,2,7,0);
+		rom[x] = BITSWAP8(rom[x], 7,6,5,3,4,2,1,0);
+		rom[x] = BITSWAP8(rom[x], 7,6,5,2,3,4,1,0);
+		rom[x] = BITSWAP8(rom[x], 5,6,7,4,3,2,1,0);
+		rom[x] = BITSWAP8(rom[x], 7,5,6,4,3,2,1,0);
 	}
 
-	for (x=0x40001;x<0x80000;x+=2)
+	for (int x = 0x40001; x < 0x80000; x += 2)
 	{
-		rom[x] = BITSWAP8(rom[x], 7,6,5,4,3,2,1,0 );
-		rom[x] = BITSWAP8(rom[x], 7,6,1,4,3,2,5,0 );
-		rom[x] = BITSWAP8(rom[x], 7,6,5,4,0,2,1,3 );
-		rom[x] = BITSWAP8(rom[x], 2,6,5,4,3,7,1,0 );
-		rom[x] = BITSWAP8(rom[x], 7,6,5,0,3,2,1,4 );
-		rom[x] = BITSWAP8(rom[x], 7,6,5,1,3,2,4,0 );
+		rom[x] = BITSWAP8(rom[x], 7,6,5,4,3,2,1,0);
+		rom[x] = BITSWAP8(rom[x], 7,6,1,4,3,2,5,0);
+		rom[x] = BITSWAP8(rom[x], 7,6,5,4,0,2,1,3);
+		rom[x] = BITSWAP8(rom[x], 2,6,5,4,3,7,1,0);
+		rom[x] = BITSWAP8(rom[x], 7,6,5,0,3,2,1,4);
+		rom[x] = BITSWAP8(rom[x], 7,6,5,1,3,2,4,0);
 
 	}
 
@@ -761,19 +770,21 @@ static DRIVER_INIT( srmdb )
 	rom[0x06] = 0xd2;
 	rom[0x07] = 0x00;
 
-	memory_install_read16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x770070, 0x770075, 0, 0, srmdb_dsw_r );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x770070, 0x770075, FUNC(srmdb_dsw_r) );
 
+	megadrive_6buttons_pad = 0;
 	DRIVER_INIT_CALL(megadriv);
 }
 
 static DRIVER_INIT(topshoot)
 {
-	memory_install_read16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x200050, 0x200051, 0, 0, topshoot_200051_r );
-	memory_install_read_port(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x200042, 0x200043, 0, 0, "IN0");
-	memory_install_read_port(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x200044, 0x200045, 0, 0, "IN1");
-	memory_install_read_port(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x200046, 0x200047, 0, 0, "IN2");
-	memory_install_read_port(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x200048, 0x200049, 0, 0, "IN3");
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x200050, 0x200051, FUNC(topshoot_200051_r) );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_read_port(0x200042, 0x200043, "IN0");
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_read_port(0x200044, 0x200045, "IN1");
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_read_port(0x200046, 0x200047, "IN2");
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_read_port(0x200048, 0x200049, "IN3");
 
+	megadrive_6buttons_pad = 0;
 	DRIVER_INIT_CALL(megadriv);
 }
 
@@ -783,8 +794,8 @@ static DRIVER_INIT(topshoot)
  *
  *************************************/
 
-GAME( 1993, aladmdb,  0, megadriv,   aladmdb,  aladmdb,  ROT0, "bootleg / Sega",   "Aladdin (bootleg of Japanese Megadrive version)", 0)
-GAME( 1996, mk3mdb,   0, megadriv,   mk3mdb,   mk3mdb,   ROT0, "bootleg / Midway", "Mortal Kombat 3 (bootleg of Megadrive version)", 0)
-GAME( 1994, ssf2mdb,  0, megadriv,   ssf2mdb,  ssf2mdb,  ROT0, "bootleg / Capcom", "Super Street Fighter II - The New Challengers (bootleg of Japanese MegaDrive version)", 0)
-GAME( 1993, srmdb,    0, megadriv,   srmdb,    srmdb,    ROT0, "bootleg / Konami", "Sunset Riders (bootleg of Megadrive version)", 0)
+GAME( 1993, aladmdb,  0, megadrvb,   aladmdb,  aladmdb,  ROT0, "bootleg / Sega",   "Aladdin (bootleg of Japanese Megadrive version)", 0)
+GAME( 1996, mk3mdb,   0, megadrvb,   mk3mdb,   mk3mdb,   ROT0, "bootleg / Midway", "Mortal Kombat 3 (bootleg of Megadrive version)", 0)
+GAME( 1994, ssf2mdb,  0, megadrvb,   ssf2mdb,  ssf2mdb,  ROT0, "bootleg / Capcom", "Super Street Fighter II - The New Challengers (bootleg of Japanese MegaDrive version)", 0)
+GAME( 1993, srmdb,    0, megadrvb,   srmdb,    srmdb,    ROT0, "bootleg / Konami", "Sunset Riders (bootleg of Megadrive version)", 0)
 GAME( 1995, topshoot, 0, md_bootleg, topshoot, topshoot, ROT0, "Sun Mixing",       "Top Shooter", 0)
