@@ -51,7 +51,6 @@ PS4  J8635      PS4  J8541       PS4  J8648
 ***************************************************************************/
 
 #include "emu.h"
-#include "deprecat.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m6805/m6805.h"
 #include "sound/2203intf.h"
@@ -483,7 +482,7 @@ static MACHINE_CONFIG_START( mexico86, mexico86_state )
 
 	MCFG_CPU_ADD("mcu", M68705, 4000000) /* xtal is 4MHz, divided by 4 internally */
 	MCFG_CPU_PROGRAM_MAP(mexico86_m68705_map)
-	MCFG_CPU_VBLANK_INT_HACK(mexico86_m68705_interrupt,2)
+	MCFG_CPU_VBLANK_INT("screen",mexico86_m68705_interrupt)
 
 	MCFG_CPU_ADD("sub", Z80, 8000000/2)      /* 4 MHz, Uses 8Mhz OSC */
 	MCFG_CPU_PROGRAM_MAP(mexico86_sub_cpu_map)
@@ -498,10 +497,9 @@ static MACHINE_CONFIG_START( mexico86, mexico86_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0)  /* frames per second, vblank duration */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(mexico86)
+	MCFG_SCREEN_UPDATE_STATIC(mexico86)
 
 	MCFG_GFXDECODE(mexico86)
 	MCFG_PALETTE_LENGTH(256)
@@ -528,7 +526,7 @@ static MACHINE_CONFIG_DERIVED( knightb, mexico86 )
 
 	/* video hardware */
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(kikikai)
+	MCFG_SCREEN_UPDATE_STATIC(kikikai)
 MACHINE_CONFIG_END
 
 
@@ -543,7 +541,7 @@ static MACHINE_CONFIG_DERIVED( kikikai, knightb )
 
 	/* video hardware */
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(kikikai)
+	MCFG_SCREEN_UPDATE_STATIC(kikikai)
 MACHINE_CONFIG_END
 
 
@@ -558,7 +556,7 @@ ROM_START( kikikai )
 	ROM_LOAD( "a85-17.h16", 0x00000, 0x08000, CRC(c141d5ab) SHA1(fe3622ba283e514416c43a44f83f922a958b27cd) ) /* 1st half, main code        */
 	ROM_CONTINUE(           0x20000, 0x08000 )             /* 2nd half, banked at 0x8000 */
 	ROM_LOAD( "a85-16.h18", 0x10000, 0x10000, CRC(4094d750) SHA1(05e0ad177a3eb144b203784ecb6242a0fc5c4d4d) ) /* banked at 0x8000           */
-	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) //AT: set as default to avoid banking problems
+	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) // set as default to avoid banking problems
 
 	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a85-11.f6", 0x0000, 0x8000, CRC(cc3539db) SHA1(4239a40fdee65cba613e4b4ec54cf7899480e366) )
@@ -584,7 +582,7 @@ ROM_START( knightb )
 	ROM_LOAD( "a85-17.h16", 0x00000, 0x08000, CRC(c141d5ab) SHA1(fe3622ba283e514416c43a44f83f922a958b27cd) ) /* 1st half, main code        */
 	ROM_CONTINUE(           0x20000, 0x08000 )             /* 2nd half, banked at 0x8000 */
 	ROM_LOAD( "a85-16.h18", 0x10000, 0x10000, CRC(4094d750) SHA1(05e0ad177a3eb144b203784ecb6242a0fc5c4d4d) ) /* banked at 0x8000           */
-	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) //AT: set as default to avoid banking problems
+	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) // set as default to avoid banking problems
 
 	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a85-11.f6", 0x0000, 0x8000, CRC(cc3539db) SHA1(4239a40fdee65cba613e4b4ec54cf7899480e366) )
@@ -609,7 +607,7 @@ ROM_START( kicknrun )
 	ROM_LOAD( "a87-08.h16", 0x00000, 0x08000, CRC(715e1b04) SHA1(60b7259758ec73f1cc945556e9c2b25766b745a8) ) /* 1st half, main code        */
 	ROM_CONTINUE(           0x20000, 0x08000 )             /* 2nd half, banked at 0x8000 */
 	ROM_LOAD( "a87-07.h18", 0x10000, 0x10000, CRC(6cb6ebfe) SHA1(fca61fc2ad8fadc1e15b9ff84c7469b68d16e885) ) /* banked at 0x8000           */
-	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) //AT: set as default to avoid banking problems
+	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) // set as default to avoid banking problems
 
 	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a87-06.f6", 0x0000, 0x8000, CRC(1625b587) SHA1(7336384e13c114915de5e439df5731ce3fc2054a) )
@@ -642,7 +640,7 @@ ROM_START( kicknrunu )
 	ROM_LOAD( "a87-23.h16", 0x00000, 0x08000, CRC(37182560) SHA1(8db393131f50af88b2e7489d6aae65bad0a5a65b) ) /* 1st half, main code        */
 	ROM_CONTINUE(           0x20000, 0x08000 )             /* 2nd half, banked at 0x8000 */
 	ROM_LOAD( "a87-22.h18", 0x10000, 0x10000, CRC(3b5a8354) SHA1(e0db4cb0657989d5a21f9a8d4e8f842adba636ad) ) /* banked at 0x8000           */
-	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) //AT: set as default to avoid banking problems
+	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) // set as default to avoid banking problems
 
 	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a87-06.f6", 0x0000, 0x8000, CRC(1625b587) SHA1(7336384e13c114915de5e439df5731ce3fc2054a) )
@@ -675,7 +673,7 @@ ROM_START( mexico86 )
 	ROM_LOAD( "2_g.bin",    0x00000, 0x08000, CRC(2bbfe0fb) SHA1(8f047e001ea8e49d28f73e546c82812af1c2533c) ) /* 1st half, main code        */
 	ROM_CONTINUE(           0x20000, 0x08000 )             /* 2nd half, banked at 0x8000 */
 	ROM_LOAD( "1_f.bin",    0x10000, 0x10000, CRC(0b93e68e) SHA1(c6fbcce83103e3e71a7a1ef9f18a10622ed6b951) ) /* banked at 0x8000           */
-	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) //AT: set as default to avoid banking problems
+	ROM_COPY(  "maincpu", 0x10000, 0x08000, 0x04000 ) //set as default to avoid banking problems
 
 	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a87-06.f6", 0x0000, 0x8000, CRC(1625b587) SHA1(7336384e13c114915de5e439df5731ce3fc2054a) )
