@@ -1033,8 +1033,7 @@ static MACHINE_CONFIG_START( midvcommon, midvunit_state )
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS(MIDVUNIT_VIDEO_CLOCK/2, 666, 0, 512, 432, 0, 400)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MCFG_SCREEN_UPDATE(midvunit)
+	MCFG_SCREEN_UPDATE_STATIC(midvunit)
 
 	MCFG_VIDEO_START(midvunit)
 MACHINE_CONFIG_END
