@@ -422,10 +422,9 @@ static MACHINE_CONFIG_START( mugsmash, mugsmash_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
-	MCFG_SCREEN_UPDATE(mugsmash)
+	MCFG_SCREEN_UPDATE_STATIC(mugsmash)
 	MCFG_GFXDECODE(mugsmash)
 
 	MCFG_PALETTE_LENGTH(0x300)
