@@ -201,10 +201,9 @@ static MACHINE_CONFIG_START( mustache, mustache_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(56.747)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 0, 31*8-1)
-	MCFG_SCREEN_UPDATE(mustache)
+	MCFG_SCREEN_UPDATE_STATIC(mustache)
 
 	MCFG_GFXDECODE(mustache)
 	MCFG_PALETTE_LENGTH(8*16+16*8)
