@@ -432,10 +432,9 @@ static MACHINE_CONFIG_START( naughtyb, naughtyb_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(36*8, 28*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 0*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(naughtyb)
+	MCFG_SCREEN_UPDATE_STATIC(naughtyb)
 
 	MCFG_GFXDECODE(naughtyb)
 	MCFG_PALETTE_LENGTH(256)
@@ -467,10 +466,9 @@ static MACHINE_CONFIG_START( popflame, naughtyb_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(36*8, 28*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 0*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(naughtyb)
+	MCFG_SCREEN_UPDATE_STATIC(naughtyb)
 
 	MCFG_GFXDECODE(naughtyb)
 	MCFG_PALETTE_LENGTH(256)
