@@ -21,17 +21,46 @@
           Zsolt Vasvari
 
 
-    The arcade version of the Neo-Geo system is called Multi Video System (MVS).
-    It is a cartridge based system.
-    MVS hardware was produced in 1 / 2 / 4 and 6 Slot versions.
+    The Neo-Geo Multi Video System (MVS), is an arcade system board, being the first product in the Neo-Geo family, and released in 1990 by SNK.
+    It was known to the coin-op industry, and offered arcade operators the ability to put up to 6 different arcade titles into a single cabinet,
+    a key economic consideration for operators with limited floorspace (games for the Neo-Geo are cartridge based and are easily exchangeable).
+    It comes in many different cabinets but basically consists of an add on board that can be linked to a standard Jamma system.
+    The system was discontinued in 2004.
+    Source (modified): http://en.wikipedia.org/wiki/Neo_Geo
 
-    Known hardware (incomplete):
-    ============================
 
-    1 Slot: MV1 / MV1A / MV1B (MV1B CHX) / MV1C / MV1F (MV1FT / MV1FS) / MV1FZ
-    2 Slot: MV2F / MV2F-01
-    4 Slot: MV4F / MV4FS
-    6 Slot: MV6F
+    MVS motherboards were produced in 1 / 2 / 4 and 6 Slot versions.
+
+    Known motherboards:
+    ===================
+
+    1 Slot:
+    NEO-MVH MV1
+    NEO-MVH MV1A
+    NEO-MVH MV1B
+    NEO-MVH MV1B CHX
+    NEO-MVH MV1C
+    NEO-MVH MV1F
+    NEO-MVH MV1FS
+    NEO-MVH MV1FT
+    NEO-MVH MV1FZ
+    NEO-MVH MV1FZS
+
+    2 Slot:
+    NEO-MVH MV2
+    NEO-MVH MV2F
+    NEO-MVH MV2F-01
+
+    4 Slot:
+    NEO-MVH MV4
+    NEO-MVH MV4F
+    NEO-MVH MV4FS
+    NEO-MVH MV4FT
+    NEO-MVH MV4FT2
+
+    6 Slot:
+    NEO-MVH MV6
+    NEO-MVH MV6F
 
 
     Neo-Geo Motherboard (info - courtesy of Guru):
@@ -68,86 +97,6 @@
           |---------------------------------------------------------------------|
 
 
-    MVS cart pinout
-    ===============
-
-    kindly submitted by Apollo69 (apollo69@columbus.rr.com)
-    =================================================================
-                CTRG1                            CTRG2
-    =================================================================
-         GND = 01A | 01B = GND            GND = 01A | 01B = GND
-         GND = 02A | 02B = GND            GND = 02A | 02B = GND
-          P0 = 03A | 03B = P1             GND = 03A | 03B = GND
-          P2 = 04A | 04B = P3             GND = 04A | 04B = GND
-          P4 = 05A | 05B = P5              D0 = 05A | 05B = A1
-          P6 = 06A | 06B = P7              D1 = 06A | 06B = A2
-          P8 = 07A | 07B = P9              D2 = 07A | 07B = A3
-         P10 = 08A | 08B = P11             D3 = 08A | 08B = A4
-         P12 = 09A | 09B = P13             D4 = 09A | 09B = A5
-         P14 = 10A | 10B = P15             D5 = 10A | 10B = A6
-         P16 = 11A | 11B = P17             D6 = 11A | 11B = A7
-         P18 = 12A | 12B = P19             D7 = 12A | 12B = A8
-         P20 = 13A | 13B = P21             D8 = 13A | 13B = A9
-         P22 = 14A | 14B = P23             D9 = 14A | 14B = A10
-       PCK1B = 15A | 15B = 24M            D10 = 15A | 15B = A11
-       PCK2B = 16A | 16B = 12M            D11 = 16A | 16B = A12
-         2H1 = 17A | 17B = 8M             D12 = 17A | 17B = A13
-         CA4 = 18A | 18B = RESET          D13 = 18A | 18B = A14
-         CR0 = 19A | 19B = CR1            D14 = 19A | 19B = A15
-         CR2 = 20A | 20B = CR3            D15 = 20A | 20B = A16
-         CR4 = 21A | 21B = CR5            R/W = 21A | 21B = A17
-         CR6 = 22A | 22B = CR7             AS = 22A | 22B = A18
-         CR8 = 23A | 23B = CR9         ROMOEU = 23A | 23B = A19
-        CR10 = 24A | 24B = CR11        ROMOEL = 24A | 24B = 68KCLKB
-        CR12 = 25A | 25B = CR13       PORTOEU = 25A | 25B = ROMWAIT
-        CR14 = 26A | 26B = CR15       PORTOEL = 26A | 26B = PWAIT0
-        CR16 = 27A | 27B = CR17       PORTWEU = 27A | 27B = PWAIT1
-        CR18 = 28A | 28B = CR19       PORTWEL = 28A | 28B = PDTACT
-         VCC = 29A | 29B = VCC            VCC = 29A | 29B = VCC
-         VCC = 30A | 30B = VCC            VCC = 30A | 30B = VCC
-         VCC = 31A | 31B = VCC            VCC = 31A | 31B = VCC
-         VCC = 32A | 32B = VCC            VCC = 32A | 32B = VCC
-        CR20 = 33A | 33B = CR21      PORTADRS = 33A | 33B = 4MB
-        CR22 = 34A | 34B = CR23            NC = 34A | 34B = ROMOE
-        CR24 = 35A | 35B = CR25            NC = 35A | 35B = RESET
-        CR26 = 36A | 36B = CR27            NC = 36A | 36B = NC
-        CR28 = 37A | 37B = CR29            NC = 37A | 37B = NC
-        CR30 = 38A | 38B = CR31            NC = 38A | 38B = NC
-          NC = 39A | 39B = FIX00           NC = 39A | 39B = NC
-          NC = 40A | 40B = FIX01           NC = 40A | 40B = NC
-          NC = 41A | 41B = FIX02           NC = 41A | 41B = SDPAD0
-     SYSTEMB = 42A | 42B = FIX03      SYSTEMB = 42A | 42B = SDPAD1
-        SDA0 = 43A | 43B = FIX04        SDPA8 = 43A | 43B = SDPAD2
-        SDA1 = 44A | 44B = FIX05        SDPA9 = 44A | 44B = SDPAD3
-        SDA2 = 45A | 45B = FIX06       SDPA10 = 45A | 45B = SDPAD4
-        SDA3 = 46A | 46B = FIX07       SDPA11 = 46A | 46B = SDPAD5
-        SDA4 = 47A | 47B = SDRD0       SDPMPX = 47A | 47B = SDPAD6
-        SDA5 = 48A | 48B = SDRD1        SDPOE = 48A | 48B = SDPAD7
-        SDA6 = 49A | 49B = SDROM        SDRA8 = 49A | 49B = SDRA00
-        SDA7 = 50A | 50B = SDMRD        SDRA9 = 50A | 50B = SDRA01
-        SDA8 = 51A | 51B = SDDO        SDRA20 = 51A | 51B = SDRA02
-        SDA9 = 52A | 52B = SDD1        SDRA21 = 52A | 52B = SDRA03
-       SDA10 = 53A | 53B = SDD2        SDRA22 = 53A | 53B = SDRA04
-       SDA11 = 54A | 54B = SDD3        SDRA23 = 54A | 54B = SDRA05
-       SDA12 = 55A | 55B = SDD4        SDRMPX = 55A | 55B = SDRA06
-       SDA13 = 56A | 56B = SDD5         SDROE = 56A | 56B = SDRA07
-       SDA14 = 57A | 57B = SDD6           GND = 57A | 57B = GND
-       SDA15 = 58A | 58B = SDD7           GND = 58A | 58B = GND
-         GND = 59A | 59B = GND            GND = 59A | 59B = GND
-         GND = 60A | 60B = GND            GND = 60A | 60B = GND
-
-    CTRG1 (CHA)  = Contains gfx data ('C' - rom), text layer data ('S' - rom) and sound driver ('M' - rom)
-    CTRG2 (PROG) = Contains sample data ('V' - rom) and program code ('P' - rom)
-
-NOTE: On CTRG2-B, The "A" lines start at "A1". If you trace this on an
-    actual cart, you will see that this is actually "A0" (A0 - A18).
-
-    These are from a very hard to read copy of the schematics, so
-    I hope that I got the pin names correct.
-
-    Apollo69 10/19/99
-
-
     Known driver issues/to-do's:
     ============================
 
@@ -198,7 +147,7 @@ NOTE: On CTRG2-B, The "A" lines start at "A1". If you trace this on an
 #include "machine/pd4990a.h"
 #include "cpu/z80/z80.h"
 #include "sound/2610intf.h"
-
+#include "imagedev/cartslot.h"
 #include "neogeo.lh"
 
 
@@ -439,7 +388,7 @@ static CUSTOM_INPUT( multiplexed_controller_r )
 	return input_port_read_safe(field.machine(), cntrl[port][state->m_controller_select & 0x01], 0x00);
 }
 
-
+#if 1 // this needs to be added dynamically somehow
 static CUSTOM_INPUT( mahjong_controller_r )
 {
 	neogeo_state *state = field.machine().driver_data<neogeo_state>();
@@ -464,7 +413,7 @@ cpu #0 (PC=00C18C40): unmapped memory word write to 00380000 = 0000 & 00FF
 
 	return ret;
 }
-
+#endif
 
 static WRITE16_HANDLER( io_control_w )
 {
@@ -870,7 +819,7 @@ static void audio_cpu_banking_init( running_machine &machine )
 	}
 
 	/* set initial audio banks --
-       how does this really work, or is it even neccessary? */
+       how does this really work, or is it even necessary? */
 	state->m_audio_cpu_banks[0] = 0x1e;
 	state->m_audio_cpu_banks[1] = 0x0e;
 	state->m_audio_cpu_banks[2] = 0x06;
@@ -1044,7 +993,7 @@ static MACHINE_START( neogeo )
 	neogeo_state *state = machine.driver_data<neogeo_state>();
 
 	/* configure NVRAM */
-	machine.device<nvram_device>("saveram")->set_base(save_ram, 0x2000);
+	machine.device<nvram_device>("saveram")->set_base(save_ram, 0x10000);
 
 	/* set the BIOS bank */
 	memory_set_bankptr(machine, NEOGEO_BANK_BIOS, machine.region("mainbios")->base());
@@ -1323,6 +1272,86 @@ INPUT_PORTS_END
 
 
 
+
+
+
+DEVICE_IMAGE_LOAD( neo_cartridge )
+{
+	UINT32 size;
+	device_t* ym = image.device().machine().device("ymsnd");
+
+	// first check software list
+	if(image.software_entry() != NULL)
+	{
+		// create memory regions
+		size = image.get_software_region_length("maincpu");
+		image.device().machine().region_free(":maincpu");
+		image.device().machine().region_alloc(":maincpu",size, 2, ENDIANNESS_BIG);
+		memcpy(image.device().machine().region("maincpu")->base(),image.get_software_region("maincpu"),size);
+
+		// for whatever reason (intentional, or design flaw) software loaded via software lists is swapped in endianess vs. the standard ROM loading, regardless of the above.  Swap it to keep consistency
+		for (int i=0; i<size/2;i++)
+		{
+			UINT16* ROM = (UINT16*)image.device().machine().region("maincpu")->base();
+			ROM[i] = ((ROM[i]&0xff00)>>8) | ((ROM[i]&0x00ff)<<8);
+		}
+
+		size = image.get_software_region_length("fixed");
+		image.device().machine().region_free(":fixed");
+		image.device().machine().region_alloc(":fixed",size,1, ENDIANNESS_LITTLE);
+		memcpy(image.device().machine().region("fixed")->base(),image.get_software_region("fixed"),size);
+
+		if(image.get_software_region("audiocpu") != NULL)
+		{
+			size = image.get_software_region_length("audiocpu");
+			image.device().machine().region_free(":audiocpu");
+			image.device().machine().region_alloc(":audiocpu",size+0x10000,1, ENDIANNESS_LITTLE);
+			memcpy(image.device().machine().region("audiocpu")->base(),image.get_software_region("audiocpu"),size);
+			memcpy(image.device().machine().region("audiocpu")->base()+0x10000,image.get_software_region("audiocpu"),size); // avoid reloading in XML, should just improve banking instead tho?
+		}
+
+
+		size = image.get_software_region_length("ymsnd");
+		image.device().machine().region_free(":ymsnd");
+		image.device().machine().region_alloc(":ymsnd",size,1, ENDIANNESS_LITTLE);
+		memcpy(image.device().machine().region("ymsnd")->base(),image.get_software_region("ymsnd"),size);
+		if(image.get_software_region("ymsnd.deltat") != NULL)
+		{
+			size = image.get_software_region_length("ymsnd.deltat");
+			image.device().machine().region_free(":ymsnd.deltat");
+			image.device().machine().region_alloc(":ymsnd.deltat",size,1, ENDIANNESS_LITTLE);
+			memcpy(image.device().machine().region("ymsnd.deltat")->base(),image.get_software_region("ymsnd.deltat"),size);
+		}
+		else
+			image.device().machine().region_free(":ymsnd.deltat");  // removing the region will fix sound glitches in non-Delta-T games
+		ym->reset();
+		size = image.get_software_region_length("sprites");
+		image.device().machine().region_free(":sprites");
+		image.device().machine().region_alloc(":sprites",size,1, ENDIANNESS_LITTLE);
+		memcpy(image.device().machine().region("sprites")->base(),image.get_software_region("sprites"),size);
+		if(image.get_software_region("audiocrypt") != NULL)  // encrypted Z80 code
+		{
+			size = image.get_software_region_length("audiocrypt");
+			image.device().machine().region_alloc(":audiocrypt",size,1, ENDIANNESS_LITTLE);
+			memcpy(image.device().machine().region("audiocrypt")->base(),image.get_software_region("audiocrypt"),size);
+			// allocate the audiocpu region to decrypt data into
+			image.device().machine().region_free(":audiocpu");
+			image.device().machine().region_alloc(":audiocpu",size+0x10000,1, ENDIANNESS_LITTLE);
+		}
+
+		// setup cartridge ROM area
+		image.device().machine().device("maincpu")->memory().space(AS_PROGRAM)->install_read_bank(0x000080,0x0fffff,"cart_rom");
+		memory_set_bankptr(image.device().machine(),"cart_rom",&image.device().machine().region("maincpu")->base()[0x80]);
+
+		// handle possible protection
+		mvs_install_protection(image);
+
+		return IMAGE_INIT_PASS;
+	}
+	return IMAGE_INIT_FAIL;
+}
+
+
 /*************************************
  *
  *  Machine driver
@@ -1352,9 +1381,8 @@ static MACHINE_CONFIG_START( neogeo, neogeo_state )
 	MCFG_DEFAULT_LAYOUT(layout_neogeo)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_RAW_PARAMS(NEOGEO_PIXEL_CLOCK, NEOGEO_HTOTAL, NEOGEO_HBEND, NEOGEO_HBSTART, NEOGEO_VTOTAL, NEOGEO_VBEND, NEOGEO_VBSTART)
-	MCFG_SCREEN_UPDATE(neogeo)
+	MCFG_SCREEN_UPDATE_STATIC(neogeo)
 
 	/* audio hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
@@ -1370,6 +1398,18 @@ static MACHINE_CONFIG_START( neogeo, neogeo_state )
 	MCFG_UPD4990A_ADD("upd4990a")
 MACHINE_CONFIG_END
 
+static MACHINE_CONFIG_DERIVED( mvs, neogeo )
+
+	MCFG_MEMCARD_HANDLER(neogeo)
+
+    MCFG_CARTSLOT_ADD("cart")
+	MCFG_CARTSLOT_LOAD(neo_cartridge)
+	MCFG_CARTSLOT_INTERFACE("neo_cart")
+
+	MCFG_SOFTWARE_LIST_ADD("cart_list","neogeo")
+MACHINE_CONFIG_END
+
+
 /*************************************
  *
  *  Driver initalization
