@@ -68,21 +68,21 @@ static VIDEO_START( nightgal )
 	state->save_item(NAME(state->m_blit_buffer));
 }
 
-static SCREEN_UPDATE( nightgal )
+static SCREEN_UPDATE_IND16( nightgal )
 {
-	nightgal_state *state = screen->machine().driver_data<nightgal_state>();
+	nightgal_state *state = screen.machine().driver_data<nightgal_state>();
 	int x, y;
 
-	for (y = cliprect->min_y; y <= cliprect->max_y; ++y)
+	for (y = cliprect.min_y; y <= cliprect.max_y; ++y)
 	{
-		UINT8 *src = &state->m_blit_buffer[y * 512 / 2 + cliprect->min_x];
-		UINT16 *dst = BITMAP_ADDR16(bitmap, y, cliprect->min_x);
+		UINT8 *src = &state->m_blit_buffer[y * 512 / 2 + cliprect.min_x];
+		UINT16 *dst = &bitmap.pix16(y, cliprect.min_x);
 
-		for (x = cliprect->min_x; x <= cliprect->max_x; x += 2)
+		for (x = cliprect.min_x; x <= cliprect.max_x; x += 2)
 		{
 			UINT32 srcpix = *src++;
-			*dst++ = screen->machine().pens[srcpix & 0xf];
-			*dst++ = screen->machine().pens[(srcpix >> 4) & 0xf];
+			*dst++ = screen.machine().pens[srcpix & 0xf];
+			*dst++ = screen.machine().pens[(srcpix >> 4) & 0xf];
 		}
 	}
 
@@ -277,10 +277,10 @@ static PALETTE_INIT( nightgal )
 
 /*
 (note:when I say "0x80" I just mean a negative result)
-master-slave algorythm
+master-slave algorithm
 -z80 writes the data for the mcu;
 -z80 writes 0 to c200;
--it waits with the bit 0x80 on c100 clears (i.e. the z80 halts),when this happens the z80 continues his logic algorythm (so stop it until we are done!!!)
+-it waits with the bit 0x80 on c100 clears (i.e. the z80 halts),when this happens the z80 continues his logic algorithm (so stop it until we are done!!!)
 
 -nsc takes an irq
 -puts ff to [1100]
@@ -877,10 +877,9 @@ static MACHINE_CONFIG_START( royalqn, nightgal_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 256-1, 0, 256-1)
-	MCFG_SCREEN_UPDATE(nightgal)
+	MCFG_SCREEN_UPDATE_STATIC(nightgal)
 	MCFG_PALETTE_INIT(nightgal)
 
 	MCFG_PALETTE_LENGTH(0x10)
