@@ -5,9 +5,6 @@ Photo Play (c) 199? Funworld
 Preliminary driver by Angelo Salese
 
 TODO:
-- asserts with "i386: Invalid REP/opcode 2E combination", but it puts something if you disable that
-  assert (i386\i386ops.c, line:1083), what is the cause?
-- Puts "BIOS ROM checksum error" on POST just like California Chase, maybe a CPU bug or missing MMU?
 - Puts a FDC error, needs a DASM investigation / work-around.
 
 *******************************************************************************************************/
@@ -25,7 +22,7 @@ TODO:
 #include "machine/8042kbdc.h"
 #include "machine/pckeybrd.h"
 #include "machine/idectrl.h"
-
+#include "video/pc_vga.h"
 
 class photoply_state : public driver_device
 {
@@ -33,13 +30,10 @@ public:
 	photoply_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag) { }
 
-	UINT32 *m_vga_vram;
-	UINT8 m_vga_regs[0x19];
 	int m_dma_channel;
 	UINT8 m_dma_offset[2][4];
 	UINT8 m_at_pages[0x10];
 	UINT8 m_vga_address;
-	struct { int r,g,b,offs,offs_internal; } m_pal;
 
 	device_t	*m_pit8253;
 	device_t	*m_pic8259_1;
@@ -49,81 +43,6 @@ public:
 };
 
 
-#define SET_VISIBLE_AREA(_x_,_y_) \
-	{ \
-	rectangle visarea; \
-	visarea.min_x = 0; \
-	visarea.max_x = _x_-1; \
-	visarea.min_y = 0; \
-	visarea.max_y = _y_-1; \
-	machine.primary_screen->configure(_x_, _y_, visarea, machine.primary_screen->frame_period().attoseconds ); \
-	} \
-
-#define RES_320x200 0
-#define RES_640x200 1
-
-static VIDEO_START(photoply)
-{
-}
-
-static void cga_alphanumeric_tilemap(running_machine &machine, bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs,UINT8 gfx_num)
-{
-	photoply_state *state = machine.driver_data<photoply_state>();
-	UINT32 offs,x,y,max_x,max_y;
-	int tile,color;
-
-	/*define the visible area*/
-	switch(size)
-	{
-		case RES_320x200:
-			SET_VISIBLE_AREA(320,200);
-			max_x = 40;
-			max_y = 25;
-			break;
-		case RES_640x200:
-			SET_VISIBLE_AREA(640,200);
-			max_x = 80;
-			max_y = 25;
-			break;
-		default:
-			fatalerror("Unknown size");
-	}
-
-	offs = map_offs;
-
-	for(y=0;y<max_y;y++)
-		for(x=0;x<max_x;x+=2)
-		{
-			tile =  (state->m_vga_vram[offs] & 0x00ff0000)>>16;
-			color = (state->m_vga_vram[offs] & 0xff000000)>>24;
-
-			drawgfx_opaque(bitmap,cliprect,machine.gfx[gfx_num],
-					tile,
-					color,
-					0,0,
-					(x+1)*8,y*8);
-
-
-			tile =  (state->m_vga_vram[offs] & 0x000000ff);
-			color = (state->m_vga_vram[offs] & 0x0000ff00)>>8;
-
-			drawgfx_opaque(bitmap,cliprect,machine.gfx[gfx_num],
-					tile,
-					color,
-					0,0,
-					(x+0)*8,y*8);
-
-			offs++;
-		}
-}
-
-
-static SCREEN_UPDATE(photoply)
-{
-	cga_alphanumeric_tilemap(screen->machine(),bitmap,cliprect,RES_640x200,0x18000/4,0);
-
-	return 0;
-}
 
 /******************
 DMA8237 Controller
@@ -313,7 +232,7 @@ static const struct pit8253_config at_pit8254_config =
 
 static ADDRESS_MAP_START( photoply_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x0009ffff) AM_RAM
-	AM_RANGE(0x000a0000, 0x000bffff) AM_RAM AM_BASE_MEMBER(photoply_state, m_vga_vram)
+	AM_RANGE(0x000a0000, 0x000bffff) AM_RAM // VGA RAM
 	AM_RANGE(0x000c0000, 0x000c7fff) AM_RAM AM_REGION("video_bios", 0) //???
 	AM_RANGE(0x000c8000, 0x000cffff) AM_RAM AM_REGION("video_bios", 0)
 	AM_RANGE(0x000d0000, 0x000dffff) AM_RAM AM_REGION("ex_bios", 0)
@@ -321,61 +240,7 @@ static ADDRESS_MAP_START( photoply_map, AS_PROGRAM, 32 )
 	AM_RANGE(0xfffe0000, 0xffffffff) AM_ROM AM_REGION("bios", 0)
 ADDRESS_MAP_END
 
-static READ32_HANDLER( kludge_r )
-{
-	return space->machine().rand();
-}
 
-/* 3c8-3c9 -> ramdac*/
-static WRITE32_HANDLER( vga_ramdac_w )
-{
-	photoply_state *state = space->machine().driver_data<photoply_state>();
-	if (ACCESSING_BITS_0_7)
-	{
-		//printf("%02x X\n",data);
-		state->m_pal.offs = state->m_pal.offs_internal = data;
-	}
-	if (ACCESSING_BITS_8_15)
-	{
-		//printf("%02x\n",data);
-		data>>=8;
-		switch(state->m_pal.offs_internal)
-		{
-			case 0:
-				state->m_pal.r = ((data & 0x3f) << 2) | ((data & 0x30) >> 4);
-				state->m_pal.offs_internal++;
-				break;
-			case 1:
-				state->m_pal.g = ((data & 0x3f) << 2) | ((data & 0x30) >> 4);
-				state->m_pal.offs_internal++;
-				break;
-			case 2:
-				state->m_pal.b = ((data & 0x3f) << 2) | ((data & 0x30) >> 4);
-				palette_set_color(space->machine(), 0x200+state->m_pal.offs, MAKE_RGB(state->m_pal.r, state->m_pal.g, state->m_pal.b));
-				state->m_pal.offs_internal = 0;
-				state->m_pal.offs++;
-				break;
-		}
-	}
-}
-
-static WRITE32_HANDLER( vga_regs_w )
-{
-	photoply_state *state = space->machine().driver_data<photoply_state>();
-
-	if (ACCESSING_BITS_0_7)
-		state->m_vga_address = data;
-	if (ACCESSING_BITS_8_15)
-	{
-		if(state->m_vga_address < 0x19)
-		{
-			state->m_vga_regs[state->m_vga_address] = data>>8;
-			logerror("VGA reg %02x with data %02x\n",state->m_vga_address,state->m_vga_regs[state->m_vga_address]);
-		}
-		else
-			logerror("Warning: used undefined VGA reg %02x with data %02x\n",state->m_vga_address,data>>8);
-	}
-}
 
 static ADDRESS_MAP_START( photoply_io, AS_IO, 32 )
 	AM_RANGE(0x0000, 0x001f) AM_DEVREADWRITE8("dma8237_1", i8237_r, i8237_w, 0xffffffff)
@@ -386,19 +251,11 @@ static ADDRESS_MAP_START( photoply_io, AS_IO, 32 )
 	AM_RANGE(0x0080, 0x009f) AM_READWRITE8(dma_page_select_r,dma_page_select_w, 0xffffffff)//TODO
 	AM_RANGE(0x00a0, 0x00bf) AM_DEVREADWRITE8("pic8259_2", pic8259_r, pic8259_w, 0xffffffff)
 	AM_RANGE(0x00c0, 0x00df) AM_DEVREADWRITE8("dma8237_2", i8237_r, i8237_w, 0xffff)
+	AM_RANGE(0x00e8, 0x00eb) AM_NOP
 	AM_RANGE(0x0278, 0x027f) AM_RAM //parallel port 2
 	AM_RANGE(0x0378, 0x037f) AM_RAM //parallel port
-	AM_RANGE(0x03c0, 0x03c3) AM_RAM
-	AM_RANGE(0x03cc, 0x03cf) AM_RAM
-	AM_RANGE(0x03b4, 0x03b7) AM_WRITE(vga_regs_w)
-	AM_RANGE(0x03c4, 0x03c7) AM_RAM //vga regs
-	AM_RANGE(0x03c8, 0x03cb) AM_WRITE(vga_ramdac_w)
-	AM_RANGE(0x03b8, 0x03bb) AM_READ(kludge_r) //hv_retrace
-	AM_RANGE(0x03c8, 0x03cb) AM_READ(kludge_r) //hv_retrace
-	AM_RANGE(0x03d4, 0x03d7) AM_WRITE(vga_regs_w)
-	AM_RANGE(0x03d8, 0x03db) AM_RAM
 	AM_RANGE(0x03bc, 0x03bf) AM_RAM //parallel port 3
-	AM_RANGE(0x03f4, 0x03f7) AM_READ(kludge_r) // fdc
+//  AM_RANGE(0x03f4, 0x03f7) AM_READ(kludge_r) // fdc
 ADDRESS_MAP_END
 
 #define AT_KEYB_HELPER(bit, text, key1) \
@@ -435,51 +292,6 @@ static INPUT_PORTS_START( photoply )
 	PORT_START("pc_keyboard_7")
 INPUT_PORTS_END
 
-static const rgb_t defcolors[]=
-{
-	MAKE_RGB(0x00,0x00,0x00),
-	MAKE_RGB(0x00,0x00,0xaa),
-	MAKE_RGB(0x00,0xaa,0x00),
-	MAKE_RGB(0x00,0xaa,0xaa),
-	MAKE_RGB(0xaa,0x00,0x00),
-	MAKE_RGB(0xaa,0x00,0xaa),
-	MAKE_RGB(0xaa,0xaa,0x00),
-	MAKE_RGB(0xaa,0xaa,0xaa),
-	MAKE_RGB(0x55,0x55,0x55),
-	MAKE_RGB(0x55,0x55,0xff),
-	MAKE_RGB(0x55,0xff,0x55),
-	MAKE_RGB(0x55,0xff,0xff),
-	MAKE_RGB(0xff,0x55,0x55),
-	MAKE_RGB(0xff,0x55,0xff),
-	MAKE_RGB(0xff,0xff,0x55),
-	MAKE_RGB(0xff,0xff,0xff)
-};
-
-static PALETTE_INIT(pcat_286)
-{
-	/*Note:palette colors are 6bpp...
-    xxxx xx--
-    */
-	int ix,iy;
-
-	for(ix=0;ix<0x300;ix++)
-		palette_set_color(machine, ix,MAKE_RGB(0x00,0x00,0x00));
-
-	//regular colors
-	for(iy=0;iy<0x10;iy++)
-	{
-		for(ix=0;ix<0x10;ix++)
-		{
-			palette_set_color(machine,(ix*2)+1+(iy*0x20),defcolors[ix]);
-			palette_set_color(machine,(ix*2)+0+(iy*0x20),defcolors[iy]);
-		}
-	}
-
-	//bitmap mode
-	for(ix=0;ix<0x10;ix++)
-		palette_set_color(machine, 0x200+ix,defcolors[ix]);
-	//todo: 256 colors
-}
 
 static void photoply_set_keyb_int(running_machine &machine, int state)
 {
@@ -491,9 +303,6 @@ static void photoply_set_keyb_int(running_machine &machine, int state)
 static MACHINE_START( photoply )
 {
 	photoply_state *state = machine.driver_data<photoply_state>();
-//  bank = -1;
-//  lastvalue = -1;
-//  hv_blank = 0;
 	device_set_irq_callback(machine.device("maincpu"), irq_callback);
 	state->m_pit8253 = machine.device( "pit8254" );
 	state->m_pic8259_1 = machine.device( "pic8259_1" );
@@ -520,6 +329,7 @@ static GFXDECODE_START( photoply )
 	//there's also a 8x16 entry (just after the 8x8)
 GFXDECODE_END
 
+static READ8_HANDLER( vga_setting ) { return 0xff; } // hard-code to color
 
 static MACHINE_CONFIG_START( photoply, photoply_state )
 	/* basic machine hardware */
@@ -527,15 +337,6 @@ static MACHINE_CONFIG_START( photoply, photoply_state )
 	MCFG_CPU_PROGRAM_MAP(photoply_map)
 	MCFG_CPU_IO_MAP(photoply_io)
 
-	/* video hardware */
-	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_SIZE(64*8, 32*8)
-	MCFG_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(photoply)
-
 	MCFG_GFXDECODE( photoply )
 
 	MCFG_MACHINE_START(photoply)
@@ -548,11 +349,7 @@ static MACHINE_CONFIG_START( photoply, photoply_state )
 	MCFG_I8237_ADD( "dma8237_2", XTAL_14_31818MHz/3, dma8237_2_config )
 	MCFG_PIT8254_ADD( "pit8254", at_pit8254_config )
 
-	MCFG_PALETTE_INIT(pcat_286)
-
-	MCFG_PALETTE_LENGTH(0x300)
-
-	MCFG_VIDEO_START(photoply)
+	MCFG_FRAGMENT_ADD( pcvideo_vga )
 MACHINE_CONFIG_END
 
 
@@ -570,8 +367,13 @@ ROM_START(photoply)
 	ROM_LOAD("vga.bin", 0x000000, 0x8000, CRC(7a859659) SHA1(ff667218261969c48082ec12aa91088a01b0cb2a) )
 
 	DISK_REGION( "ide" )
-	DISK_IMAGE( "photoply", 0,NO_DUMP )
+	DISK_IMAGE( "pp201", 0, SHA1(23e1940d485d19401e7d0ad912ddad2cf2ea10b4) )
 ROM_END
 
+static DRIVER_INIT( photoply )
+{
+	pc_vga_init(machine, vga_setting, NULL);
+	pc_vga_io_init(machine, machine.device("maincpu")->memory().space(AS_PROGRAM), 0xa0000, machine.device("maincpu")->memory().space(AS_IO), 0x0000);
+}
 
-GAME( 199?, photoply,  0,   photoply, photoply, 0, ROT0, "Funworld", "PhotoPlay", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 199?, photoply,  0,   photoply, photoply, photoply, ROT0, "Funworld", "Photo Play 2000 (v2.01)", GAME_NOT_WORKING|GAME_NO_SOUND )
