@@ -273,10 +273,9 @@ static MACHINE_CONFIG_START( pirates, pirates_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(36*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(pirates)
+	MCFG_SCREEN_UPDATE_STATIC(pirates)
 
 	MCFG_PALETTE_LENGTH(0x2000)
 
