@@ -256,10 +256,9 @@ static MACHINE_CONFIG_START( portrait, portrait_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(50)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 54*8-1, 0*8, 40*8-1)
-	MCFG_SCREEN_UPDATE(portrait)
+	MCFG_SCREEN_UPDATE_STATIC(portrait)
 
 	MCFG_GFXDECODE(portrait)
 	MCFG_PALETTE_LENGTH(0x800)
