@@ -54,7 +54,7 @@ The Following Section of Code in Gunbird causes reads from the
 
 This causes Gunbird to crash if the ROM Region Size
 allocated during loading is smaller than the ROM
-region as it trys to read beyond the allocated rom region
+region as it tries to read beyond the allocated rom region
 
 This was pointed out by Bart Puype
 
@@ -598,12 +598,12 @@ static INPUT_PORTS_START( samuraia )
         1 1 1 0 Taiwan With FBI logo??
 
     ************************************************/
-	PORT_DIPNAME( 0x000000ff, 0x000000ff, "Country" )
+	PORT_DIPNAME( 0x000000ff, 0x000000ff, DEF_STR( Region ) )
 	PORT_DIPSETTING(          0x000000ff, DEF_STR( World ) )
 	PORT_DIPSETTING(          0x000000ef, "USA & Canada" )
-	PORT_DIPSETTING(          0x000000df, "Korea" )
-	PORT_DIPSETTING(          0x000000bf, "Hong Kong" )
-	PORT_DIPSETTING(          0x0000007f, "Taiwan" )
+	PORT_DIPSETTING(          0x000000df, DEF_STR( Korea ) )
+	PORT_DIPSETTING(          0x000000bf, DEF_STR( Hong_Kong ) )
+	PORT_DIPSETTING(          0x0000007f, DEF_STR( Taiwan ) )
 	PORT_BIT( 0x0000ff00, IP_ACTIVE_LOW, IPT_UNKNOWN )	// unused?
 INPUT_PORTS_END
 
@@ -625,12 +625,12 @@ static INPUT_PORTS_START( sngkace )
 
     ************************************************/
 #if 0 // See Patch in MACHINE_RESET, only text not logo
-	PORT_DIPNAME( 0x000000ff, 0x000000ff, "Country" )
+	PORT_DIPNAME( 0x000000ff, 0x000000ff, DEF_STR( Region ) )
 	PORT_DIPSETTING(          0x000000ff, DEF_STR( Japan ) )
 	PORT_DIPSETTING(          0x000000ef, "USA & Canada" )
-	PORT_DIPSETTING(          0x000000df, "Korea" )
-	PORT_DIPSETTING(          0x000000bf, "Hong Kong" )
-	PORT_DIPSETTING(          0x0000007f, "Taiwan" )
+	PORT_DIPSETTING(          0x000000df, DEF_STR( Korea ) )
+	PORT_DIPSETTING(          0x000000bf, DEF_STR( Hong_Kong ) )
+	PORT_DIPSETTING(          0x0000007f, DEF_STR( Taiwan ) )
 #endif
 	PORT_BIT( 0x000000ff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
@@ -674,13 +674,13 @@ static INPUT_PORTS_START( btlkroad )
         Other   World
 
     ************************************************/
-	PORT_DIPNAME( 0x0000000f, 0x00000000, "Copyright (Country)" )
-	PORT_DIPSETTING(          0x0000000f, "Psikyo (Japan)" )
-	PORT_DIPSETTING(          0x0000000e, "Jaleco+Psikyo (USA & Canada)" )
-	PORT_DIPSETTING(          0x0000000c, "Psikyo (Korea)" )
-	PORT_DIPSETTING(          0x0000000a, "Psikyo (Hong Kong)" )
-	PORT_DIPSETTING(          0x00000006, "Psikyo (Taiwan)" )
-	PORT_DIPSETTING(          0x00000000, "Psikyo (World)" )
+	PORT_DIPNAME( 0x0000000f, 0x00000000, DEF_STR( Region ) )
+	PORT_DIPSETTING(          0x0000000f, DEF_STR( Japan ) )
+	PORT_DIPSETTING(          0x0000000e, "USA & Canada (Jaleco license)" )
+	PORT_DIPSETTING(          0x0000000c, DEF_STR( Korea ) )
+	PORT_DIPSETTING(          0x0000000a, DEF_STR( Hong_Kong ) )
+	PORT_DIPSETTING(          0x00000006, DEF_STR( Taiwan ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR( World ) )
 	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000020, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -761,12 +761,12 @@ static INPUT_PORTS_START( gunbird )
     Has no effects on Japan or Korea versions.
 
     ************************************************/
-	PORT_DIPNAME( 0x0000000f, 0x0000000f, "Country" )
+	PORT_DIPNAME( 0x0000000f, 0x0000000f, DEF_STR( Region ) )
 	PORT_DIPSETTING(          0x0000000f, DEF_STR( World ) )
 	PORT_DIPSETTING(          0x0000000e, DEF_STR( USA ) )
-	PORT_DIPSETTING(          0x0000000d, "Korea" )
-	PORT_DIPSETTING(          0x0000000b, "Hong Kong" )
-	PORT_DIPSETTING(          0x00000007, "Taiwan" )
+	PORT_DIPSETTING(          0x0000000d, DEF_STR( Korea ) )
+	PORT_DIPSETTING(          0x0000000b, DEF_STR( Hong_Kong ) )
+	PORT_DIPSETTING(          0x00000007, DEF_STR( Taiwan ) )
 	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000020, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -831,12 +831,12 @@ static INPUT_PORTS_START( s1945 )
     No effect on set s1945j or s1945k
 
     ************************************************/
-	PORT_DIPNAME( 0x0000000f, 0x0000000f, "Country" )
+	PORT_DIPNAME( 0x0000000f, 0x0000000f, DEF_STR( Region ) )
 	PORT_DIPSETTING(          0x0000000f, DEF_STR( World ) )
-	PORT_DIPSETTING(          0x0000000e, "U.S.A & Canada" )
-	PORT_DIPSETTING(          0x0000000d, "Korea" )
-	PORT_DIPSETTING(          0x0000000b, "Hong Kong" )
-	PORT_DIPSETTING(          0x00000007, "Taiwan" )
+	PORT_DIPSETTING(          0x0000000e, "USA & Canada" )
+	PORT_DIPSETTING(          0x0000000d, DEF_STR( Korea ) )
+	PORT_DIPSETTING(          0x0000000b, DEF_STR( Hong_Kong ) )
+	PORT_DIPSETTING(          0x00000007, DEF_STR( Taiwan ) )
 	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000020, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -887,7 +887,7 @@ static INPUT_PORTS_START( s1945a )
     Bit 0 1 2 3
         1 1 1 1 Japan, anything but 0x0f = "World"
     ************************************************/
-	PORT_DIPNAME( 0x0000000f, 0x0000000f, "Country" )
+	PORT_DIPNAME( 0x0000000f, 0x0000000f, DEF_STR( Region ) )
 	PORT_DIPSETTING(          0x0000000f, DEF_STR( Japan ) )
 	PORT_DIPSETTING(          0x0000000e, DEF_STR( World ) )
 INPUT_PORTS_END
@@ -947,12 +947,12 @@ static INPUT_PORTS_START( tengai )
         1 1 1 0 Taiwan
 
     ************************************************/
-	PORT_DIPNAME( 0x0000000f, 0x0000000f, "Country" )
+	PORT_DIPNAME( 0x0000000f, 0x0000000f, DEF_STR( Region ) )
 	PORT_DIPSETTING(          0x0000000f, DEF_STR( World ) )
-	PORT_DIPSETTING(          0x0000000e, "U.S.A & Canada" )
-	PORT_DIPSETTING(          0x0000000d, "Korea" )
-	PORT_DIPSETTING(          0x0000000b, "Hong Kong" )
-	PORT_DIPSETTING(          0x00000007, "Taiwan" )
+	PORT_DIPSETTING(          0x0000000e, "USA & Canada" )
+	PORT_DIPSETTING(          0x0000000d, DEF_STR( Korea ) )
+	PORT_DIPSETTING(          0x0000000b, DEF_STR( Hong_Kong ) )
+	PORT_DIPSETTING(          0x00000007, DEF_STR( Taiwan ) )
 	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000020, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -985,7 +985,7 @@ static INPUT_PORTS_START( tengaij )
     Text for other regions is present though.
 
     ************************************************/
-	PORT_DIPNAME( 0x0000000f, 0x0000000f, "Country" )
+	PORT_DIPNAME( 0x0000000f, 0x0000000f, DEF_STR( Region ) )
 	PORT_DIPSETTING(          0x0000000f, DEF_STR( Japan ) )
 	PORT_DIPSETTING(          0x0000000e, DEF_STR( World ) )
 INPUT_PORTS_END
@@ -1078,11 +1078,10 @@ static MACHINE_CONFIG_START( sngkace, psikyo_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(59.3)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)	// we're using IPT_VBLANK
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0, 256-32-1)
-	MCFG_SCREEN_UPDATE(psikyo)
-	MCFG_SCREEN_EOF(psikyo)
+	MCFG_SCREEN_UPDATE_STATIC(psikyo)
+	MCFG_SCREEN_VBLANK_STATIC(psikyo)
 
 	MCFG_GFXDECODE(psikyo)
 	MCFG_PALETTE_LENGTH(0x1000)
@@ -1130,11 +1129,10 @@ static MACHINE_CONFIG_START( gunbird, psikyo_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(59.3)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)	// we're using IPT_VBLANK
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0, 256-32-1)
-	MCFG_SCREEN_UPDATE(psikyo)
-	MCFG_SCREEN_EOF(psikyo)
+	MCFG_SCREEN_UPDATE_STATIC(psikyo)
+	MCFG_SCREEN_VBLANK_STATIC(psikyo)
 
 	MCFG_GFXDECODE(psikyo)
 	MCFG_PALETTE_LENGTH(0x1000)
@@ -1166,11 +1164,10 @@ static MACHINE_CONFIG_START( s1945bl, psikyo_state ) /* Bootleg hardware based o
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(59.3)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)	// we're using IPT_VBLANK
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0, 256-32-1)
-	MCFG_SCREEN_UPDATE(psikyo_bootleg)
-	MCFG_SCREEN_EOF(psikyo)
+	MCFG_SCREEN_UPDATE_STATIC(psikyo_bootleg)
+	MCFG_SCREEN_VBLANK_STATIC(psikyo)
 
 	MCFG_GFXDECODE(psikyo)
 	MCFG_PALETTE_LENGTH(0x1000)
@@ -1223,11 +1220,10 @@ static MACHINE_CONFIG_START( s1945, psikyo_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(59.90)    /* verified on pcb */
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)	// we're using IPT_VBLANK
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0, 256-32-1)
-	MCFG_SCREEN_UPDATE(psikyo)
-	MCFG_SCREEN_EOF(psikyo)
+	MCFG_SCREEN_UPDATE_STATIC(psikyo)
+	MCFG_SCREEN_VBLANK_STATIC(psikyo)
 
 	MCFG_GFXDECODE(psikyo)
 	MCFG_PALETTE_LENGTH(0x1000)
