@@ -134,8 +134,6 @@ ROMs -
 #include "rendlay.h"
 #include "includes/psikyo4.h"
 
-#define ROMTEST 1 /* Does necessary stuff to perform rom test, uses RAM as it doesn't dispose of GFX after decoding */
-
 
 static const gfx_layout layout_16x16x8 =
 {
@@ -263,7 +261,7 @@ static WRITE32_HANDLER( ps4_screen1_brt_w )
 
 	if (ACCESSING_BITS_0_7)
 	{
-		/* Need seperate brightness for both screens if displaying together */
+		/* Need separate brightness for both screens if displaying together */
 		double brt1 = data & 0xff;
 
 		if (brt1 > 0x7f)
@@ -282,7 +280,7 @@ static WRITE32_HANDLER( ps4_screen1_brt_w )
 	}
 	else
 	{
-		/* I believe this to be seperate rgb brightness due to strings in hotdebut, unused in 4 dumped games */
+		/* I believe this to be separate rgb brightness due to strings in hotdebut, unused in 4 dumped games */
 		if((data & mem_mask) != 0)
 			logerror("Unk Scr 1 rgb? brt write %08x mask %08x\n", data, mem_mask);
 	}
@@ -294,7 +292,7 @@ static WRITE32_HANDLER( ps4_screen2_brt_w )
 
 	if (ACCESSING_BITS_0_7)
 	{
-		/* Need seperate brightness for both screens if displaying together */
+		/* Need separate brightness for both screens if displaying together */
 		double brt2 = data & 0xff;
 
 		if (brt2 > 0x7f)
@@ -314,7 +312,7 @@ static WRITE32_HANDLER( ps4_screen2_brt_w )
 	}
 	else
 	{
-		/* I believe this to be seperate rgb brightness due to strings in hotdebut, unused in 4 dumped games */
+		/* I believe this to be separate rgb brightness due to strings in hotdebut, unused in 4 dumped games */
 		if((data & mem_mask) != 0)
 			logerror("Unk Scr 2 rgb? brt write %08x mask %08x\n", data, mem_mask);
 	}
@@ -325,26 +323,13 @@ static WRITE32_HANDLER( ps4_vidregs_w )
 	psikyo4_state *state = space->machine().driver_data<psikyo4_state>();
 	COMBINE_DATA(&state->m_vidregs[offset]);
 
-#if ROMTEST
 	if (offset == 2) /* Configure bank for gfx test */
 	{
 		if (ACCESSING_BITS_0_15)	// Bank
-		{
-//          memory_set_bank(space->machine(), "bank2", state->m_vidregs[offset] & 0x1fff);  /* Bank comes from vidregs */
-			memory_set_bankptr(space->machine(), "bank2", space->machine().region("gfx1")->base() + 0x2000 * (state->m_vidregs[offset] & 0x1fff)); /* Bank comes from vidregs */		}
+			memory_set_bankptr(space->machine(), "bank2", space->machine().region("gfx1")->base() + 0x2000 * (state->m_vidregs[offset] & 0x1fff)); /* Bank comes from vidregs */
 	}
-#endif
 }
 
-#if ROMTEST
-static READ32_HANDLER( ps4_sample_r ) /* Send sample data for test */
-{
-	psikyo4_state *state = space->machine().driver_data<psikyo4_state>();
-	UINT8 *ROM = space->machine().region("ymf")->base();
-	return ROM[state->m_sample_offs++] << 16;
-}
-#endif
-
 #define PCM_BANK_NO(n)	((state->m_io_select[0] >> (n * 4 + 24)) & 0x07)
 
 static void set_hotgmck_pcm_bank( running_machine &machine, int n )
@@ -388,18 +373,14 @@ static ADDRESS_MAP_START( ps4_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x03003ff8, 0x03003ffb) AM_WRITE(ps4_screen2_brt_w) // screen 2 brightness
 	AM_RANGE(0x03003ffc, 0x03003fff) AM_WRITE(ps4_bgpen_2_dword_w) AM_BASE_MEMBER(psikyo4_state, m_bgpen_2) // screen 2 clear colour
 	AM_RANGE(0x03004000, 0x03005fff) AM_RAM_WRITE(ps4_paletteram32_RRRRRRRRGGGGGGGGBBBBBBBBxxxxxxxx_dword_w) AM_BASE_MEMBER(psikyo4_state, m_paletteram) // palette
-	AM_RANGE(0x05000000, 0x05000003) AM_DEVREAD8("ymf", ymf278b_r, 0xffffffff) // read YMF status
-	AM_RANGE(0x05000000, 0x05000007) AM_DEVWRITE8("ymf", ymf278b_w, 0xffffffff)
+	AM_RANGE(0x03006000, 0x03007fff) AM_ROMBANK("bank2") // data for rom tests (gfx), data is controlled by vidreg
+	AM_RANGE(0x05000000, 0x05000007) AM_DEVREADWRITE8("ymf", ymf278b_r, ymf278b_w, 0xffffffff)
 	AM_RANGE(0x05800000, 0x05800003) AM_READ_PORT("P1_P2")
 	AM_RANGE(0x05800004, 0x05800007) AM_READ_PORT("P3_P4")
 	AM_RANGE(0x05800008, 0x0580000b) AM_WRITEONLY AM_BASE_MEMBER(psikyo4_state, m_io_select) // Used by Mahjong games to choose input (also maps normal loderndf inputs to offsets)
 
 	AM_RANGE(0x06000000, 0x060fffff) AM_RAM AM_BASE_MEMBER(psikyo4_state, m_ram) // main RAM (1 meg)
 
-#if ROMTEST
-	AM_RANGE(0x05000004, 0x05000007) AM_READ(ps4_sample_r) // data for rom tests (Used to verify Sample rom)
-	AM_RANGE(0x03006000, 0x03007fff) AM_ROMBANK("bank2") // data for rom tests (gfx), data is controlled by vidreg
-#endif
 ADDRESS_MAP_END
 
 
@@ -425,13 +406,9 @@ static INPUT_PORTS_START( hotgmck )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_SERVICE1 )	// Screen 1
 	PORT_SERVICE_NO_TOGGLE( 0x20, IP_ACTIVE_LOW)
-#if ROMTEST
 	PORT_DIPNAME( 0x40, 0x40, "Debug" ) /* Unknown effects */
 	PORT_DIPSETTING(	0x40, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
-#else
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
-#endif
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE2 )	// Screen 2
 
 	PORT_START("KEY0")	/* fake player 1 controls 1st bank */
@@ -523,13 +500,9 @@ static INPUT_PORTS_START( loderndf )
 	PORT_BIT( 0x00000008, IP_ACTIVE_LOW, IPT_COIN4 )	// Screen 2 - 2nd slot
 	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_SERVICE1 )	// Screen 1
 	PORT_SERVICE_NO_TOGGLE( 0x00000020, IP_ACTIVE_LOW)
-#if ROMTEST
 	PORT_DIPNAME( 0x00000040, 0x00000040, "Debug" ) /* Must be high for rom test, unknown other side-effects */
 	PORT_DIPSETTING(	      0x00000040, DEF_STR( Off ) )
 	PORT_DIPSETTING(	      0x00000000, DEF_STR( On ) )
-#else
-	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_UNKNOWN )
-#endif
 	PORT_BIT( 0x00000080, IP_ACTIVE_LOW, IPT_SERVICE2 )	// Screen 2
 	PORT_BIT( 0x00000100, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000200, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -611,13 +584,9 @@ static INPUT_PORTS_START( hotdebut )
 	PORT_BIT( 0x00000008, IP_ACTIVE_LOW, IPT_COIN4 )	// Screen 2 - 2nd slot
 	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_SERVICE1 )	// Screen 1
 	PORT_SERVICE_NO_TOGGLE( 0x00000020, IP_ACTIVE_LOW)
-#if ROMTEST
 	PORT_DIPNAME( 0x00000040, 0x00000040, "Debug" ) /* Must be high for rom test, unknown other side-effects */
 	PORT_DIPSETTING(	      0x00000040, DEF_STR( Off ) )
 	PORT_DIPSETTING(	      0x00000000, DEF_STR( On ) )
-#else
-	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_UNKNOWN )
-#endif
 	PORT_BIT( 0x00000080, IP_ACTIVE_LOW, IPT_SERVICE2 )	// Screen 2
 	PORT_BIT( 0x00000100, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00000200, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -704,14 +673,6 @@ static MACHINE_START( psikyo4 )
 
 	state->m_maincpu = machine.device("maincpu");
 
-#if ROMTEST
-//  FIXME: Too many banks! it cannot be handled in this way, currently
-//  memory_configure_bank(machine, "bank2", 0, 0x2000, machine.region("gfx1")->base(), 0x2000);
-
-	state->m_sample_offs = 0;
-	state->save_item(NAME(state->m_sample_offs));
-#endif
-
 	state->save_item(NAME(state->m_oldbrt1));
 	state->save_item(NAME(state->m_oldbrt2));
 }
@@ -743,20 +704,18 @@ static MACHINE_CONFIG_START( ps4big, psikyo4_state )
 	MCFG_DEFAULT_LAYOUT(layout_dualhsxs)
 
 	MCFG_SCREEN_ADD("lscreen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(psikyo4)
+	MCFG_SCREEN_UPDATE_STATIC(psikyo4_left)
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(psikyo4)
+	MCFG_SCREEN_UPDATE_STATIC(psikyo4_right)
 
 	MCFG_VIDEO_START(psikyo4)
 
@@ -958,7 +917,7 @@ ROM_START( loderndf )
 	ROM_LOAD32_WORD( "1l.u3",  0x1000000, 0x800000, CRC(7a9cd21e) SHA1(dfb36625c2aae3e774ec2451051b7038e0767b6d) )
 	ROM_LOAD32_WORD( "1h.u12", 0x1000002, 0x800000, CRC(78f40d0d) SHA1(243acb73a183a41a3e35a2c746ad31dd6fcd3ef4) )
 
-	ROM_REGION( 0x800000, "ymf", ROMREGION_ERASE00 )
+	ROM_REGION( 0x800000, "ymf", 0 )
 	ROM_LOAD( "snd0.u10", 0x000000, 0x800000, CRC(2da3788f) SHA1(199d4d750a107cbdf8c16cd5b097171743769d9c) ) // Fails hidden rom test (banking problem?)
 ROM_END
 
@@ -973,7 +932,7 @@ ROM_START( loderndfa )
 	ROM_LOAD32_WORD( "1l.u3",  0x1000000, 0x800000, CRC(7a9cd21e) SHA1(dfb36625c2aae3e774ec2451051b7038e0767b6d) )
 	ROM_LOAD32_WORD( "1h.u12", 0x1000002, 0x800000, CRC(78f40d0d) SHA1(243acb73a183a41a3e35a2c746ad31dd6fcd3ef4) )
 
-	ROM_REGION( 0x800000, "ymf", ROMREGION_ERASE00 )
+	ROM_REGION( 0x800000, "ymf", 0 )
 	ROM_LOAD( "snd0.u10", 0x000000, 0x800000, CRC(2da3788f) SHA1(199d4d750a107cbdf8c16cd5b097171743769d9c) ) // Fails hidden rom test (banking problem?)
 ROM_END
 
@@ -990,71 +949,10 @@ ROM_START( hotdebut )
 	ROM_LOAD32_WORD( "2l.u4",  0x1000000, 0x400000, CRC(9d2d1bb1) SHA1(33b41aa50be3040871b6dc6faee0bd99c5e46cd3) )
 	ROM_LOAD32_WORD( "2h.u13", 0x1000002, 0x400000, CRC(a7753c4d) SHA1(adb33de478064cc9255d1bb5c63acc5d8bfbb8eb) )
 
-	ROM_REGION( 0x400000, "ymf", ROMREGION_ERASE00 )
+	ROM_REGION( 0x400000, "ymf", 0 )
 	ROM_LOAD( "snd0.u10", 0x000000, 0x400000, CRC(eef28aa7) SHA1(d10d3f62a2e4c2a8e5fccece9c272f8ead50e5ed) )
 ROM_END
 
-/* are these right? should i fake the counter return?
-   'speedups / idle skipping isn't needed for 'hotgmck, hgkairak'
-   as the core catches and skips the idle loops automatically'
-*/
-
-static READ32_HANDLER( loderndf_speedup_r )
-{
-/*
-PC  :00001B3C: MOV.L   @R14,R3  R14 = 0x6000020
-PC  :00001B3E: ADD     #$01,R3
-PC  :00001B40: MOV.L   R3,@R14
-PC  :00001B42: MOV.L   @($54,PC),R1
-PC  :00001B44: MOV.L   @R1,R2
-PC  :00001B46: TST     R2,R2
-PC  :00001B48: BT      $00001B3C
-*/
-	psikyo4_state *state = space->machine().driver_data<psikyo4_state>();
-
-	if (cpu_get_pc(&space->device()) == 0x00001b3e)
-		device_spin_until_interrupt(&space->device());
-
-	return state->m_ram[0x000020 / 4];
-}
-
-static READ32_HANDLER( loderdfa_speedup_r )
-{
-/*
-PC  :00001B48: MOV.L   @R14,R3  R14 = 0x6000020
-PC  :00001B4A: ADD     #$01,R3
-PC  :00001B4C: MOV.L   R3,@R14
-PC  :00001B4E: MOV.L   @($54,PC),R1
-PC  :00001B50: MOV.L   @R1,R2
-PC  :00001B52: TST     R2,R2
-PC  :00001B54: BT      $00001B48
-*/
-	psikyo4_state *state = space->machine().driver_data<psikyo4_state>();
-
-	if (cpu_get_pc(&space->device()) == 0x00001b4a)
-		device_spin_until_interrupt(&space->device());
-
-	return state->m_ram[0x000020 / 4];
-}
-
-static READ32_HANDLER( hotdebut_speedup_r )
-{
-/*
-PC  :000029EC: MOV.L   @R14,R2
-PC  :000029EE: ADD     #$01,R2
-PC  :000029F0: MOV.L   R2,@R14
-PC  :000029F2: MOV.L   @($64,PC),R1
-PC  :000029F4: MOV.L   @R1,R3
-PC  :000029F6: TST     R3,R3
-PC  :000029F8: BT      $000029EC
-*/
-	psikyo4_state *state = space->machine().driver_data<psikyo4_state>();
-
-	if (cpu_get_pc(&space->device()) == 0x000029ee)
-		device_spin_until_interrupt(&space->device());
-
-	return state->m_ram[0x00001c / 4];
-}
 
 static void hotgmck_pcm_bank_postload(running_machine &machine)
 {
@@ -1085,29 +983,13 @@ static DRIVER_INIT( hotgmck )
 	install_hotgmck_pcm_bank(machine);	// Banked PCM ROM
 }
 
-static DRIVER_INIT( loderndf )
-{
-	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x6000020, 0x6000023, FUNC(loderndf_speedup_r) );
-}
-
-static DRIVER_INIT( loderdfa )
-{
-	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x6000020, 0x6000023, FUNC(loderdfa_speedup_r) );
-}
-
-static DRIVER_INIT( hotdebut )
-{
-	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x600001c, 0x600001f, FUNC(hotdebut_speedup_r) );
-}
-
-
-/*     YEAR  NAME      PARENT    MACHINE    INPUT     INIT      MONITOR COMPANY   FULLNAME FLAGS */
 
+/*    YEAR  NAME      PARENT    MACHINE    INPUT     INIT      MONITOR COMPANY   FULLNAME     FLAGS */
 GAME( 1997, hotgmck,  0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick (Japan)", 0 )
 GAME( 1998, hgkairak, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick Kairakuten (Japan)", 0 )
 GAME( 1999, hotgmck3, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick 3 Digital Surfing (Japan)", 0 )
 GAME( 2000, hotgm4ev, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Taisen Hot Gimmick 4 Ever (Japan)", 0 )
 GAME( 2001, hotgmcki, 0,        ps4big,    hotgmck,  hotgmck,  ROT0,   "Psikyo", "Mahjong Hot Gimmick Integral (Japan)", 0 )
-GAME( 2000, loderndf, 0,        ps4small,  loderndf, loderndf, ROT0,   "Psikyo", "Lode Runner - The Dig Fight (ver. B)", 0 )
-GAME( 2000, loderndfa,loderndf, ps4small,  loderndf, loderdfa, ROT0,   "Psikyo", "Lode Runner - The Dig Fight (ver. A)", 0 )
-GAME( 2000, hotdebut, 0,        ps4small,  hotdebut, hotdebut, ROT0,   "Psikyo / Moss", "Quiz de Idol! Hot Debut (Japan)", 0 )
+GAME( 2000, loderndf, 0,        ps4small,  loderndf, 0,        ROT0,   "Psikyo", "Lode Runner - The Dig Fight (ver. B)", 0 )
+GAME( 2000, loderndfa,loderndf, ps4small,  loderndf, 0,        ROT0,   "Psikyo", "Lode Runner - The Dig Fight (ver. A)", 0 )
+GAME( 2000, hotdebut, 0,        ps4small,  hotdebut, 0,        ROT0,   "Psikyo / Moss", "Quiz de Idol! Hot Debut (Japan)", 0 )
