@@ -206,26 +206,26 @@ TODO:
 
 static WRITE8_HANDLER( rallyx_interrupt_vector_w )
 {
-	rallyx_state *state = space->machine->driver_data<rallyx_state>();
+	rallyx_state *state = space->machine().driver_data<rallyx_state>();
 
-	cpu_set_input_line_vector(state->maincpu, 0, data);
-	cpu_set_input_line(state->maincpu, 0, CLEAR_LINE);
+	device_set_input_line_vector(state->m_maincpu, 0, data);
+	device_set_input_line(state->m_maincpu, 0, CLEAR_LINE);
 }
 
 
 static WRITE8_HANDLER( rallyx_bang_w )
 {
-	rallyx_state *state = space->machine->driver_data<rallyx_state>();
+	rallyx_state *state = space->machine().driver_data<rallyx_state>();
 
-	if (data == 0 && state->last_bang != 0)
-		sample_start(state->samples, 0, 0, 0);
+	if (data == 0 && state->m_last_bang != 0)
+		sample_start(state->m_samples, 0, 0, 0);
 
-	state->last_bang = data;
+	state->m_last_bang = data;
 }
 
 static WRITE8_HANDLER( rallyx_latch_w )
 {
-	rallyx_state *state = space->machine->driver_data<rallyx_state>();
+	rallyx_state *state = space->machine().driver_data<rallyx_state>();
 	int bit = data & 1;
 
 	switch (offset)
@@ -235,34 +235,35 @@ static WRITE8_HANDLER( rallyx_latch_w )
 			break;
 
 		case 0x01:	/* INT ON */
-			cpu_interrupt_enable(state->maincpu, bit);
+			state->m_main_irq_mask = bit;
 			if (!bit)
-				cpu_set_input_line(state->maincpu, 0, CLEAR_LINE);
+				device_set_input_line(state->m_maincpu, 0, CLEAR_LINE);
 			break;
 
 		case 0x02:	/* SOUND ON */
 			/* this doesn't work in New Rally X so I'm not supporting it */
-//          pacman_sound_enable_w(space->machine->device("namco"), bit);
+//          pacman_sound_enable_w(space->machine().device("namco"), bit);
 			break;
 
 		case 0x03:	/* FLIP */
-			flip_screen_set(space->machine, bit);
+			flip_screen_set_no_update(space->machine(), bit);
+			space->machine().tilemap().set_flip_all(bit * (TILEMAP_FLIPX | TILEMAP_FLIPY));
 			break;
 
 		case 0x04:
-			set_led_status(space->machine, 0, bit);
+			set_led_status(space->machine(), 0, bit);
 			break;
 
 		case 0x05:
-			set_led_status(space->machine, 1, bit);
+			set_led_status(space->machine(), 1, bit);
 			break;
 
 		case 0x06:
-			coin_lockout_w(space->machine, 0, !bit);
+			coin_lockout_w(space->machine(), 0, !bit);
 			break;
 
 		case 0x07:
-			coin_counter_w(space->machine, 0, bit);
+			coin_counter_w(space->machine(), 0, bit);
 			break;
 	}
 }
@@ -270,7 +271,7 @@ static WRITE8_HANDLER( rallyx_latch_w )
 
 static WRITE8_HANDLER( locomotn_latch_w )
 {
-	rallyx_state *state = space->machine->driver_data<rallyx_state>();
+	rallyx_state *state = space->machine().driver_data<rallyx_state>();
 	int bit = data & 1;
 
 	switch (offset)
@@ -280,7 +281,7 @@ static WRITE8_HANDLER( locomotn_latch_w )
 			break;
 
 		case 0x01:	/* INTST */
-			cpu_interrupt_enable(state->maincpu, bit);
+			state->m_main_irq_mask = bit;
 			break;
 
 		case 0x02:	/* MUT */
@@ -288,18 +289,19 @@ static WRITE8_HANDLER( locomotn_latch_w )
 			break;
 
 		case 0x03:	/* FLIP */
-			flip_screen_set(space->machine, bit);
+			flip_screen_set_no_update(space->machine(), bit);
+			space->machine().tilemap().set_flip_all(bit * (TILEMAP_FLIPX | TILEMAP_FLIPY));
 			break;
 
 		case 0x04:	/* OUT1 */
-			coin_counter_w(space->machine, 0, bit);
+			coin_counter_w(space->machine(), 0, bit);
 			break;
 
 		case 0x05:	/* OUT2 */
 			break;
 
 		case 0x06:	/* OUT3 */
-			coin_counter_w(space->machine, 1,bit);
+			coin_counter_w(space->machine(), 1,bit);
 			break;
 
 		case 0x07:	/* STARSON */
@@ -315,14 +317,14 @@ static WRITE8_HANDLER( locomotn_latch_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( rallyx_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( rallyx_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
-	AM_RANGE(0x8000, 0x8fff) AM_RAM_WRITE(rallyx_videoram_w) AM_BASE_MEMBER(rallyx_state, videoram)
+	AM_RANGE(0x8000, 0x8fff) AM_RAM_WRITE(rallyx_videoram_w) AM_BASE_MEMBER(rallyx_state, m_videoram)
 	AM_RANGE(0x9800, 0x9fff) AM_RAM
 	AM_RANGE(0xa000, 0xa000) AM_READ_PORT("P1")
 	AM_RANGE(0xa080, 0xa080) AM_READ_PORT("P2")
 	AM_RANGE(0xa100, 0xa100) AM_READ_PORT("DSW")
-	AM_RANGE(0xa000, 0xa00f) AM_WRITEONLY AM_BASE_MEMBER(rallyx_state, radarattr)
+	AM_RANGE(0xa000, 0xa00f) AM_WRITEONLY AM_BASE_MEMBER(rallyx_state, m_radarattr)
 	AM_RANGE(0xa080, 0xa080) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0xa100, 0xa11f) AM_DEVWRITE("namco", pacman_sound_w)
 	AM_RANGE(0xa130, 0xa130) AM_WRITE(rallyx_scrollx_w)
@@ -331,21 +333,21 @@ static ADDRESS_MAP_START( rallyx_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xa180, 0xa187) AM_WRITE(rallyx_latch_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0, 0) AM_WRITE(rallyx_interrupt_vector_w)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( jungler_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( jungler_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
-	AM_RANGE(0x8000, 0x8fff) AM_RAM_WRITE(rallyx_videoram_w) AM_BASE_MEMBER(rallyx_state, videoram)
+	AM_RANGE(0x8000, 0x8fff) AM_RAM_WRITE(rallyx_videoram_w) AM_BASE_MEMBER(rallyx_state, m_videoram)
 	AM_RANGE(0x9800, 0x9fff) AM_RAM
 	AM_RANGE(0xa000, 0xa000) AM_READ_PORT("P1")
 	AM_RANGE(0xa080, 0xa080) AM_READ_PORT("P2")
 	AM_RANGE(0xa100, 0xa100) AM_READ_PORT("DSW1")
 	AM_RANGE(0xa180, 0xa180) AM_READ_PORT("DSW2")
-	AM_RANGE(0xa000, 0xa00f) AM_MIRROR(0x00f0) AM_WRITEONLY AM_BASE_MEMBER(rallyx_state, radarattr)	// jungler writes to a03x
+	AM_RANGE(0xa000, 0xa00f) AM_MIRROR(0x00f0) AM_WRITEONLY AM_BASE_MEMBER(rallyx_state, m_radarattr)	// jungler writes to a03x
 	AM_RANGE(0xa080, 0xa080) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0xa100, 0xa100) AM_WRITE(soundlatch_w)
 	AM_RANGE(0xa130, 0xa130) AM_WRITE(rallyx_scrollx_w)	/* only jungler and tactcian */
@@ -855,7 +857,7 @@ static const namco_interface namco_config =
 static const char *const rallyx_sample_names[] =
 {
 	"*rallyx",
-	"bang.wav",
+	"bang",
 	0	/* end of array */
 };
 
@@ -875,21 +877,37 @@ static const samples_interface rallyx_samples_interface =
 
 static MACHINE_START( rallyx )
 {
-	rallyx_state *state = machine->driver_data<rallyx_state>();
+	rallyx_state *state = machine.driver_data<rallyx_state>();
 
-	state->maincpu = machine->device<cpu_device>("maincpu");
-	state->samples = machine->device("samples");
+	state->m_maincpu = machine.device<cpu_device>("maincpu");
+	state->m_samples = machine.device("samples");
 
-	state_save_register_global(machine, state->last_bang);
-	state_save_register_global(machine, state->stars_enable);
+	state->save_item(NAME(state->m_last_bang));
+	state->save_item(NAME(state->m_stars_enable));
 }
 
 static MACHINE_RESET( rallyx )
 {
-	rallyx_state *state = machine->driver_data<rallyx_state>();
+	rallyx_state *state = machine.driver_data<rallyx_state>();
 
-	state->last_bang = 0;
-	state->stars_enable = 0;
+	state->m_last_bang = 0;
+	state->m_stars_enable = 0;
+}
+
+static INTERRUPT_GEN( rallyx_vblank_irq )
+{
+	rallyx_state *state = device->machine().driver_data<rallyx_state>();
+
+	if(state->m_main_irq_mask)
+		device_set_input_line(device, 0, ASSERT_LINE);
+}
+
+static INTERRUPT_GEN( jungler_vblank_irq )
+{
+	rallyx_state *state = device->machine().driver_data<rallyx_state>();
+
+	if(state->m_main_irq_mask)
+		device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static MACHINE_CONFIG_START( rallyx, rallyx_state )
@@ -898,7 +916,7 @@ static MACHINE_CONFIG_START( rallyx, rallyx_state )
 	MCFG_CPU_ADD("maincpu", Z80, MASTER_CLOCK/6)	/* 3.072 MHz */
 	MCFG_CPU_PROGRAM_MAP(rallyx_map)
 	MCFG_CPU_IO_MAP(io_map)
-	MCFG_CPU_VBLANK_INT("screen", irq0_line_assert)
+	MCFG_CPU_VBLANK_INT("screen", rallyx_vblank_irq)
 
 	MCFG_MACHINE_START(rallyx)
 	MCFG_MACHINE_RESET(rallyx)
@@ -909,16 +927,15 @@ static MACHINE_CONFIG_START( rallyx, rallyx_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60.606060)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(36*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(rallyx)
 
 	MCFG_GFXDECODE(rallyx)
 	MCFG_PALETTE_LENGTH(64*4+4)
 
 	MCFG_PALETTE_INIT(rallyx)
 	MCFG_VIDEO_START(rallyx)
-	MCFG_VIDEO_UPDATE(rallyx)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -938,7 +955,7 @@ static MACHINE_CONFIG_START( jungler, rallyx_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, MASTER_CLOCK/6)	/* 3.072 MHz */
 	MCFG_CPU_PROGRAM_MAP(jungler_map)
-	MCFG_CPU_VBLANK_INT("screen", nmi_line_pulse)
+	MCFG_CPU_VBLANK_INT("screen", jungler_vblank_irq)
 
 	MCFG_MACHINE_START(rallyx)
 	MCFG_MACHINE_RESET(rallyx)
@@ -949,16 +966,15 @@ static MACHINE_CONFIG_START( jungler, rallyx_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0)	/* frames per second, vblank duration */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(36*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(jungler)
 
 	MCFG_GFXDECODE(jungler)
 	MCFG_PALETTE_LENGTH(64*4+4+64)
 
 	MCFG_PALETTE_INIT(jungler)
 	MCFG_VIDEO_START(jungler)
-	MCFG_VIDEO_UPDATE(jungler)
 
 	/* sound hardware */
 	MCFG_FRAGMENT_ADD(locomotn_sound)
@@ -971,7 +987,8 @@ static MACHINE_CONFIG_DERIVED( tactcian, jungler )
 
 	/* video hardware */
 	MCFG_VIDEO_START(locomotn)
-	MCFG_VIDEO_UPDATE(locomotn)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE_STATIC(locomotn)
 MACHINE_CONFIG_END
 
 
@@ -982,8 +999,8 @@ static MACHINE_CONFIG_DERIVED( locomotn, jungler )
 	/* video hardware */
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(locomotn)
 	MCFG_VIDEO_START(locomotn)
-	MCFG_VIDEO_UPDATE(locomotn)
 MACHINE_CONFIG_END
 
 
@@ -994,8 +1011,8 @@ static MACHINE_CONFIG_DERIVED( commsega, jungler )
 	/* video hardware */
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(locomotn)
 	MCFG_VIDEO_START(commsega)
-	MCFG_VIDEO_UPDATE(locomotn)
 MACHINE_CONFIG_END
 
 
@@ -1183,6 +1200,30 @@ ROM_START( junglers )
 	ROM_LOAD( "6331-1.10a",   0x0140, 0x0020, CRC(b8861096) SHA1(26fad384ed7a1a1e0ba719b5578e2dbb09334a25) ) /* video timing (not used) */
 ROM_END
 
+ROM_START( savanna )
+	ROM_REGION( 0x10000, "maincpu", 0 )
+	ROM_LOAD( "sav1.bin",     0x0000, 0x1000, CRC(958c57eb) SHA1(b804ef99bb2f5658de508d3f9f83ca491012a51f) )
+	ROM_LOAD( "sav2.bin",     0x1000, 0x1000, CRC(61ea4d46) SHA1(575ffe9fc7d5777c8f2d2b449623c353f42a4249) )
+	ROM_LOAD( "sav3.bin",     0x2000, 0x1000, CRC(557c7925) SHA1(84d8eb2fdb7ee9098805be9f457a37f51e4bc3b8) )
+	ROM_LOAD( "sav4.bin",     0x3000, 0x1000, CRC(b38b6cbd) SHA1(76ab41097bceb3d73c95ab8a89df702e554ba403) )
+
+	ROM_REGION( 0x10000, "tpsound", 0 )
+	ROM_LOAD( "1b",           0x0000, 0x1000, CRC(f86999c3) SHA1(4660bd7826219b1bad7d9178918823196d4fd8d6) )
+
+	ROM_REGION( 0x1000, "gfx1", 0 )
+	ROM_LOAD( "5k",           0x0000, 0x0800, CRC(924262bf) SHA1(593f59630b3bd369aef0819992106b4e6e6a241f) )
+	ROM_LOAD( "5m",           0x0800, 0x0800, CRC(131a08ac) SHA1(167a0710a2a153f7f7c6839d2340e5aa725ef039) )
+
+	ROM_REGION( 0x0100, "gfx2", 0 )
+	ROM_LOAD( "82s129.10g",   0x0000, 0x0100, CRC(c59c51b7) SHA1(e8ac60fed9ba16c61a4c3c09e27f8c3f4e254014) ) /* dots */
+
+	ROM_REGION( 0x0160, "proms", 0 )
+	ROM_LOAD( "18s030.8b",    0x0000, 0x0020, CRC(55a7e6d1) SHA1(f9e4ff3b165235db2fd8dab94c43bc686c3ad29b) ) /* palette */
+	ROM_LOAD( "tbp24s10.9d",  0x0020, 0x0100, CRC(d223f7b8) SHA1(87b62f09d4eda09c16d99d1554017d18e52b5886) ) /* loookup table */
+	ROM_LOAD( "18s030.7a",    0x0120, 0x0020, CRC(8f574815) SHA1(4f84162db9d58b64742c67dc689eb665b9862fb3) ) /* video layout (not used) */
+	ROM_LOAD( "6331-1.10a",   0x0140, 0x0020, CRC(b8861096) SHA1(26fad384ed7a1a1e0ba719b5578e2dbb09334a25) ) /* video timing (not used) */
+ROM_END
+
 ROM_START( tactcian )
 	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "tacticia.001", 0x0000, 0x1000, CRC(99163e39) SHA1(0a863f358a0bb065a9e2c41fcf4c20d370001dfe) )
@@ -1382,6 +1423,7 @@ GAME( 1981, nrallyx,  0,        rallyx,   nrallyx,  0, ROT0,  "Namco", "New Rall
 GAME( 1981, nrallyxb, nrallyx,  rallyx,   nrallyx,  0, ROT0,  "Namco", "New Rally X (bootleg?) ", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
 GAME( 1981, jungler,  0,        jungler,  jungler,  0, ROT90, "Konami", "Jungler", GAME_SUPPORTS_SAVE )
 GAME( 1981, junglers, jungler,  jungler,  jungler,  0, ROT90, "Konami (Stern Electronics license)", "Jungler (Stern Electronics)", GAME_SUPPORTS_SAVE )
+GAME( 1981, savanna,  jungler,  jungler,  jungler,  0, ROT90, "bootleg (Olympia)", "Savanna (Jungler bootleg)", GAME_SUPPORTS_SAVE ) // or licensed from Konami?
 GAME( 1982, tactcian, 0,        tactcian, tactcian, 0, ROT90, "Konami (Sega license)", "Tactician (set 1)", GAME_SUPPORTS_SAVE )
 GAME( 1981, tactcian2,tactcian, tactcian, tactcian, 0, ROT90, "Konami (Sega license)", "Tactician (set 2)", GAME_SUPPORTS_SAVE )
 GAME( 1982, locomotn, 0,        locomotn, locomotn, 0, ROT90, "Konami (Centuri license)", "Loco-Motion", GAME_SUPPORTS_SAVE )
