@@ -367,11 +367,10 @@ static MACHINE_CONFIG_START( zerohour, ladybug_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 4*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(redclash)
-	MCFG_SCREEN_EOF(redclash)
+	MCFG_SCREEN_UPDATE_STATIC(redclash)
+	MCFG_SCREEN_VBLANK_STATIC(redclash)
 
 	MCFG_GFXDECODE(redclash)
 	MCFG_PALETTE_LENGTH(4*8+4*16+32)
@@ -396,11 +395,10 @@ static MACHINE_CONFIG_START( redclash, ladybug_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 4*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(redclash)
-	MCFG_SCREEN_EOF(redclash)
+	MCFG_SCREEN_UPDATE_STATIC(redclash)
+	MCFG_SCREEN_VBLANK_STATIC(redclash)
 
 	MCFG_GFXDECODE(redclash)
 	MCFG_PALETTE_LENGTH(4*8+4*16+32)
