@@ -101,7 +101,6 @@ $8000 - $ffff   ROM
 ***************************************************************************/
 
 #include "emu.h"
-#include "deprecat.h"
 #include "cpu/m6502/m6502.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/m6805/m6805.h"
@@ -122,7 +121,7 @@ struct _renegade_adpcm_state
 	UINT8 m_nibble;
 	UINT8 m_playing;
 	UINT8 *m_base;
-};
+} _renegade_adpcm_state_dummy;
 
 DECLARE_LEGACY_SOUND_DEVICE(RENEGADE_ADPCM, renegade_adpcm);
 
@@ -638,25 +637,15 @@ static WRITE8_HANDLER( bankswitch_w )
 	}
 }
 
-static INTERRUPT_GEN( renegade_interrupt )
+static TIMER_DEVICE_CALLBACK( renegade_interrupt )
 {
-#if 0
-	int port = input_port_read(machine, "IN1") & 0xc0;
-	if (port != 0xc0)
-	{
-		if (state->m_coin == 0)
-		{
-			state->m_coin = 1;
-			return irq0_line_hold();
-		}
-	}
-	else state->m_coin = 0;
-#endif
+	renegade_state *state = timer.machine().driver_data<renegade_state>();
+	int scanline = param;
 
-	if (cpu_getiloops(device))
-		device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
-	else
-		device_set_input_line(device, 0, HOLD_LINE);
+	if (scanline == 112) // ???
+		device_set_input_line(state->m_maincpu, INPUT_LINE_NMI, PULSE_LINE);
+	else if(scanline == 240)
+		device_set_input_line(state->m_maincpu, 0, HOLD_LINE);
 }
 
 static WRITE8_HANDLER( renegade_coin_counter_w )
@@ -927,7 +916,7 @@ static MACHINE_CONFIG_START( renegade, renegade_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6502, 12000000/8)	/* 1.5 MHz (measured) */
 	MCFG_CPU_PROGRAM_MAP(renegade_map)
-	MCFG_CPU_VBLANK_INT_HACK(renegade_interrupt,2)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", renegade_interrupt, "screen", 0, 1)
 
 	MCFG_CPU_ADD("audiocpu", M6809, 12000000/8)
 	MCFG_CPU_PROGRAM_MAP(renegade_sound_map)	/* IRQs are caused by the main CPU */
@@ -942,10 +931,9 @@ static MACHINE_CONFIG_START( renegade, renegade_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500)*2)  /* not accurate */
-    MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
     MCFG_SCREEN_SIZE(32*8, 32*8)
     MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 0, 30*8-1)
-    MCFG_SCREEN_UPDATE(renegade)
+    MCFG_SCREEN_UPDATE_STATIC(renegade)
 
     MCFG_GFXDECODE(renegade)
     MCFG_PALETTE_LENGTH(256)
