@@ -69,7 +69,6 @@
 
 #include "emu.h"
 #include "cpu/z80/z80.h"
-#include "deprecat.h"
 #include "sound/dac.h"
 #include "sound/sn76477.h"
 #include "sound/ay8910.h"
@@ -615,12 +614,11 @@ static MACHINE_CONFIG_START( route16, route16_state )
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 256-1, 0, 256-1)
 	MCFG_SCREEN_REFRESH_RATE(57)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)	/* frames per second, vblank duration */
-	MCFG_SCREEN_UPDATE(route16)
+	MCFG_SCREEN_UPDATE_STATIC(route16)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -648,7 +646,7 @@ static MACHINE_CONFIG_DERIVED( stratvox, route16 )
 
 	/* video hardware */
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(stratvox)
+	MCFG_SCREEN_UPDATE_STATIC(stratvox)
 
 	/* sound hardware */
 	MCFG_SOUND_MODIFY("ay8910")
@@ -687,7 +685,7 @@ static MACHINE_CONFIG_DERIVED( ttmahjng, route16 )
 
 	/* video hardware */
 	MCFG_SCREEN_MODIFY("screen")
-	MCFG_SCREEN_UPDATE(ttmahjng)
+	MCFG_SCREEN_UPDATE_STATIC(ttmahjng)
 MACHINE_CONFIG_END
 
 
