@@ -60,6 +60,12 @@ static WRITE8_HANDLER( sbasketb_coin_counter_w )
 	coin_counter_w(space->machine(), offset, data);
 }
 
+static WRITE8_HANDLER( irq_mask_w )
+{
+	sbasketb_state *state = space->machine().driver_data<sbasketb_state>();
+
+	state->m_irq_mask = data & 1;
+}
 
 static ADDRESS_MAP_START( sbasketb_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x2000, 0x2fff) AM_RAM
@@ -71,7 +77,7 @@ static ADDRESS_MAP_START( sbasketb_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x3c10, 0x3c10) AM_READNOP    /* ???? */
 	AM_RANGE(0x3c20, 0x3c20) AM_WRITEONLY AM_BASE_MEMBER(sbasketb_state, m_palettebank)
 	AM_RANGE(0x3c80, 0x3c80) AM_WRITE(sbasketb_flipscreen_w)
-	AM_RANGE(0x3c81, 0x3c81) AM_WRITE(interrupt_enable_w)
+	AM_RANGE(0x3c81, 0x3c81) AM_WRITE(irq_mask_w)
 	AM_RANGE(0x3c83, 0x3c84) AM_WRITE(sbasketb_coin_counter_w)
 	AM_RANGE(0x3c85, 0x3c85) AM_WRITEONLY AM_BASE_MEMBER(sbasketb_state, m_spriteram_select)
 	AM_RANGE(0x3d00, 0x3d00) AM_WRITE(soundlatch_w)
@@ -171,13 +177,20 @@ static GFXDECODE_START( sbasketb )
 	GFXDECODE_ENTRY( "gfx2", 0, spritelayout, 16*16, 16*16 )
 GFXDECODE_END
 
+static INTERRUPT_GEN( vblank_irq )
+{
+	sbasketb_state *state = device->machine().driver_data<sbasketb_state>();
+
+	if(state->m_irq_mask)
+		device_set_input_line(device, 0, HOLD_LINE);
+}
 
 static MACHINE_CONFIG_START( sbasketb, sbasketb_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6809, 1400000)        /* 1.400 MHz ??? */
 	MCFG_CPU_PROGRAM_MAP(sbasketb_map)
-	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_VBLANK_INT("screen", vblank_irq)
 
 	MCFG_CPU_ADD("audiocpu", Z80, XTAL_14_31818MHz / 4)	/* 3.5795 MHz */
 	MCFG_CPU_PROGRAM_MAP(sbasketb_sound_map)
@@ -186,10 +199,9 @@ static MACHINE_CONFIG_START( sbasketb, sbasketb_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(sbasketb)
+	MCFG_SCREEN_UPDATE_STATIC(sbasketb)
 
 	MCFG_GFXDECODE(sbasketb)
 	MCFG_PALETTE_LENGTH(16*16+16*16*16)
