@@ -77,12 +77,12 @@ static READ16_HANDLER ( sderby_input_r )
 	switch (offset)
 	{
 		case 0x00 >> 1:
-			return input_port_read(space->machine, "IN0");
+			return input_port_read(space->machine(), "IN0");
 		case 0x02 >> 1:
 			return 0xffff;			// to avoid game to reset (needs more work)
 	}
 
-	logerror("sderby_input_r : offset = %x - PC = %06x\n",offset*2,cpu_get_pc(space->cpu));
+	logerror("sderby_input_r : offset = %x - PC = %06x\n",offset*2,cpu_get_pc(&space->device()));
 
 	return 0xffff;
 }
@@ -92,11 +92,11 @@ static READ16_HANDLER( roulette_input_r )
 	switch (offset)
 	{
 		case 0x00 >> 1:
-			return input_port_read(space->machine, "IN0");
+			return input_port_read(space->machine(), "IN0");
 		case 0x02 >> 1:
-			return input_port_read(space->machine, "IN1");
+			return input_port_read(space->machine(), "IN1");
 		case 0x04 >> 1:
-			return input_port_read(space->machine, "IN2");
+			return input_port_read(space->machine(), "IN2");
 	}
 
 	return 0xffff;
@@ -113,7 +113,7 @@ static READ16_HANDLER( roulette_input_r )
     Offset: 0x70800e - 0x70800f.
 
     Writes to the MCU are always the same values.
-    At begining, the code writes 3 values: 0x53, 0x5a and 0x0d.
+    At beginning, the code writes 3 values: 0x53, 0x5a and 0x0d.
     Then, whith each placed bet the code normally writes 0x4e.
     After that, there are 2 reads expecting the MCU response.
 
@@ -126,7 +126,7 @@ static READ16_HANDLER( roulette_input_r )
 
 static READ16_HANDLER( rprot_r )
 {
-	logerror("rprot_r : offset = %02x\n",cpu_get_pc(space->cpu));
+	logerror("rprot_r : offset = %02x\n",cpu_get_pc(&space->device()));
 
 /* This is the only mask I found that allow a normal play.
    Using other values, the game hangs waiting for response,
@@ -135,7 +135,7 @@ static READ16_HANDLER( rprot_r )
    If someone more skilled in 68K code can help to trace it,
    searching for an accurated response, I'll appreciate.
 */
-	return space->machine->rand() & 0x1f;
+	return space->machine().rand() & 0x1f;
 }
 
 static WRITE16_HANDLER( rprot_w )
@@ -188,7 +188,7 @@ static WRITE16_HANDLER( sderby_out_w )
 	output_set_lamp_value(2, (data >> 1) & 1);		/* Lamp 2 - BET */
 	output_set_lamp_value(3, (data >> 15) & 1);		/* Lamp 3 - END OF RACE */
 
-	coin_counter_w(space->machine, 0, data & 0x2000);
+	coin_counter_w(space->machine(), 0, data & 0x2000);
 }
 
 
@@ -237,7 +237,7 @@ static WRITE16_HANDLER( scmatto_out_w )
 	output_set_lamp_value(6, (data >> 5) & 1);		/* Lamp 6 - START  */
 	output_set_lamp_value(7, (data >> 6) & 1);		/* Lamp 7 - BET    */
 
-	coin_counter_w(space->machine, 0, data & 0x2000);
+	coin_counter_w(space->machine(), 0, data & 0x2000);
 }
 
 
@@ -274,15 +274,15 @@ static WRITE16_HANDLER( roulette_out_w )
 *       Memory Maps        *
 ***************************/
 
-static ADDRESS_MAP_START( sderby_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( sderby_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
-	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(sderby_videoram_w) AM_BASE_MEMBER(sderby_state,videoram)		/* bg */
-	AM_RANGE(0x101000, 0x101fff) AM_RAM_WRITE(sderby_md_videoram_w) AM_BASE_MEMBER(sderby_state,md_videoram)	/* mid */
-	AM_RANGE(0x102000, 0x103fff) AM_RAM_WRITE(sderby_fg_videoram_w) AM_BASE_MEMBER(sderby_state,fg_videoram)	/* fg */
+	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(sderby_videoram_w) AM_BASE_MEMBER(sderby_state,m_videoram)		/* bg */
+	AM_RANGE(0x101000, 0x101fff) AM_RAM_WRITE(sderby_md_videoram_w) AM_BASE_MEMBER(sderby_state,m_md_videoram)	/* mid */
+	AM_RANGE(0x102000, 0x103fff) AM_RAM_WRITE(sderby_fg_videoram_w) AM_BASE_MEMBER(sderby_state,m_fg_videoram)	/* fg */
 	AM_RANGE(0x104000, 0x10400b) AM_WRITE(sderby_scroll_w)
 	AM_RANGE(0x10400c, 0x10400d) AM_WRITENOP	/* ??? - check code at 0x000456 (executed once at startup) */
 	AM_RANGE(0x10400e, 0x10400f) AM_WRITENOP	/* ??? - check code at 0x000524 (executed once at startup) */
-	AM_RANGE(0x200000, 0x200fff) AM_RAM AM_BASE_MEMBER(sderby_state,spriteram) AM_SIZE_MEMBER(sderby_state,spriteram_size)
+	AM_RANGE(0x200000, 0x200fff) AM_RAM AM_BASE_MEMBER(sderby_state,m_spriteram) AM_SIZE_MEMBER(sderby_state,m_spriteram_size)
 	AM_RANGE(0x308000, 0x30800d) AM_READ(sderby_input_r)
 	AM_RANGE(0x308008, 0x308009) AM_WRITE(sderby_out_w)	/* output port */
 	AM_RANGE(0x30800e, 0x30800f) AM_DEVREADWRITE8_MODERN("oki", okim6295_device, read, write, 0x00ff)
@@ -292,11 +292,11 @@ static ADDRESS_MAP_START( sderby_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xffc000, 0xffffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( spacewin_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( spacewin_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
-	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(sderby_videoram_w) AM_BASE_MEMBER(sderby_state,videoram)		/* bg */
-	AM_RANGE(0x101000, 0x101fff) AM_RAM_WRITE(sderby_md_videoram_w) AM_BASE_MEMBER(sderby_state,md_videoram)	/* mid */
-	AM_RANGE(0x102000, 0x103fff) AM_RAM_WRITE(sderby_fg_videoram_w) AM_BASE_MEMBER(sderby_state,fg_videoram)	/* fg */
+	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(sderby_videoram_w) AM_BASE_MEMBER(sderby_state,m_videoram)		/* bg */
+	AM_RANGE(0x101000, 0x101fff) AM_RAM_WRITE(sderby_md_videoram_w) AM_BASE_MEMBER(sderby_state,m_md_videoram)	/* mid */
+	AM_RANGE(0x102000, 0x103fff) AM_RAM_WRITE(sderby_fg_videoram_w) AM_BASE_MEMBER(sderby_state,m_fg_videoram)	/* fg */
 	AM_RANGE(0x104000, 0x10400b) AM_WRITE(sderby_scroll_w)	/* tilemaps offset control */
 	AM_RANGE(0x10400c, 0x10400d) AM_WRITENOP	/* seems another video register. constantly used */
 	AM_RANGE(0x10400e, 0x10400f) AM_WRITENOP	/* seems another video register. constantly used */
@@ -307,18 +307,18 @@ static ADDRESS_MAP_START( spacewin_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x30800e, 0x30800f) AM_DEVREADWRITE8_MODERN("oki", okim6295_device, read, write, 0x00ff)
 	AM_RANGE(0x380000, 0x380fff) AM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0xd00000, 0xd001ff) AM_RAM
-	AM_RANGE(0x800000, 0x800fff) AM_RAM AM_BASE_MEMBER(sderby_state,spriteram) AM_SIZE_MEMBER(sderby_state,spriteram_size)
+	AM_RANGE(0x800000, 0x800fff) AM_RAM AM_BASE_MEMBER(sderby_state,m_spriteram) AM_SIZE_MEMBER(sderby_state,m_spriteram_size)
 	AM_RANGE(0x801000, 0x80100d) AM_WRITENOP	/* unknown */
 	AM_RANGE(0x8f0000, 0x8f07ff) AM_RAM AM_SHARE("nvram")	/* 16K Dallas DS1220Y-200 NVRAM */
 	AM_RANGE(0x8fc000, 0x8fffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( roulette_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( roulette_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
-	AM_RANGE(0x440000, 0x440fff) AM_WRITEONLY AM_BASE_MEMBER(sderby_state,spriteram) AM_SIZE_MEMBER(sderby_state,spriteram_size)
-	AM_RANGE(0x500000, 0x500fff) AM_RAM_WRITE(sderby_videoram_w) AM_BASE_MEMBER(sderby_state,videoram)			/* bg */
-	AM_RANGE(0x501000, 0x501fff) AM_RAM_WRITE(sderby_md_videoram_w) AM_BASE_MEMBER(sderby_state,md_videoram)	/* mid */
-	AM_RANGE(0x502000, 0x503fff) AM_RAM_WRITE(sderby_fg_videoram_w) AM_BASE_MEMBER(sderby_state,fg_videoram)	/* fg */
+	AM_RANGE(0x440000, 0x440fff) AM_WRITEONLY AM_BASE_MEMBER(sderby_state,m_spriteram) AM_SIZE_MEMBER(sderby_state,m_spriteram_size)
+	AM_RANGE(0x500000, 0x500fff) AM_RAM_WRITE(sderby_videoram_w) AM_BASE_MEMBER(sderby_state,m_videoram)			/* bg */
+	AM_RANGE(0x501000, 0x501fff) AM_RAM_WRITE(sderby_md_videoram_w) AM_BASE_MEMBER(sderby_state,m_md_videoram)	/* mid */
+	AM_RANGE(0x502000, 0x503fff) AM_RAM_WRITE(sderby_fg_videoram_w) AM_BASE_MEMBER(sderby_state,m_fg_videoram)	/* fg */
 	AM_RANGE(0x504000, 0x50400b) AM_RAM_WRITE(sderby_scroll_w)
 	AM_RANGE(0x50400e, 0x50400f) AM_WRITENOP
 
@@ -465,14 +465,13 @@ static MACHINE_CONFIG_START( sderby, sderby_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(4*8, 44*8-1, 3*8, 33*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(sderby)
 
 	MCFG_GFXDECODE(sderby)
 	MCFG_PALETTE_LENGTH(0x1000)
 	MCFG_VIDEO_START(sderby)
-	MCFG_VIDEO_UPDATE(sderby)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_OKIM6295_ADD("oki", 1056000, OKIM6295_PIN7_HIGH) /* clock frequency & pin 7 not verified */
@@ -490,14 +489,13 @@ static MACHINE_CONFIG_START( spacewin, sderby_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(4*8, 44*8-1, 3*8, 33*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(pmroulet)
 
 	MCFG_GFXDECODE(sderby)
 	MCFG_PALETTE_LENGTH(0x1000)
 	MCFG_VIDEO_START(sderby)
-	MCFG_VIDEO_UPDATE(pmroulet)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_OKIM6295_ADD("oki", 1056000, OKIM6295_PIN7_HIGH) /* clock frequency & pin 7 not verified */
@@ -515,14 +513,13 @@ static MACHINE_CONFIG_START( pmroulet, sderby_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500)) /* not accurate */
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(4*8, 44*8-1, 3*8, 33*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(pmroulet)
 
 	MCFG_GFXDECODE(sderby)
 	MCFG_PALETTE_LENGTH(0x1000)
 	MCFG_VIDEO_START(sderby)
-	MCFG_VIDEO_UPDATE(pmroulet)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_OKIM6295_ADD("oki", 1056000, OKIM6295_PIN7_HIGH) /* clock frequency & pin 7 not verified */
@@ -628,7 +625,84 @@ ROM_START( spacewin )
 	ROM_LOAD( "8.u145", 0x080000, 0x20000, CRC(541a73fd) SHA1(fede5e2fcbb18e90cc50995d44e831c3f9b56614) )
 ROM_END
 
-ROM_START( pmroulet )
+
+/*
+Croupier (PlaYMark)
+-------------------
+
+1x MC68000FN12 (U24, QFP)
+1x unknown scratched 40-pin DIP IC (U39)
+
+1x OKI M6295 (U34, near ROM 1)
+1x Resonator 1000J (Y1)
+
+2x KM6264BL-10L SRAM (U2/U6, near ROMs 2 & 3)
+2x KM6264BL-10 SRAM (U36/U37, near ROMs 4, 5, 6, 7 & 8)
+1x DALLAS DS1220Y-100 NONVOLATILE SRAM (U17)
+
+2x ACTEL A1020B PL84C
+4x GAL 22CV10-25LNC (U1, U77, U111, U112. Undumped)
+
+1x 24.000000 MHz. Xtal. (XTL1)
+1x 28.000000 MHz. Xtal. (XTL2)
+
+1x Pot (TR1, near OKI M6295)
+1x Push Button.
+1x JAMMA connector.
+
+ROMs:
+-----
+
+1.bin : AMD Am27C020.
+checksum : 03FC0000h
+CRC-32 : B7094978h
+
+2.bin : ST M27C1001.
+checksum : 00B958B6h
+CRC-32 : E7941975h
+
+3.bin : ST M27C1001.
+checksum : 011DE502h
+CRC-32 : 29D06A38h
+
+4.bin : MACRONIX MX27C4000.
+checksum : 01CADC6Ch
+CRC-32 : EFCDDAC9h
+
+5.bin : MACRONIX MX27C4000.
+checksum : 01F8DEB8h
+CRC-32 : BC75EF8Fh
+
+6.bin : MACRONIX MX27C4000.
+checksum : 0195B5C0h
+CRC-32 : E47D5F55h
+
+7.bin : MACRONIX MX27C4000.
+checksum : 013483F4h
+CRC-32 : 0FA6CE7Dh
+
+8.bin : MACRONIX MX27C4000.
+checksum : 0106A95Ch
+CRC-32 : D4C2B7DAh
+
+*/
+ROM_START( croupier )
+	ROM_REGION( 0x40000, "maincpu", 0 ) /* 68000 code */
+	ROM_LOAD16_BYTE( "2.bin", 0x00000, 0x20000, CRC(e7941975) SHA1(ea32cd51b8d87205a1d6c6a83ebf8b50e03c55fc))
+	ROM_LOAD16_BYTE( "3.bin", 0x00001, 0x20000, CRC(29d06a38) SHA1(c6fdca1a31fad9abf854e521e593f3ec8018ae6d))
+
+	ROM_REGION( 0x080000, "oki", 0 ) /* samples are ok */
+	ROM_LOAD( "1.bin", 0x00000, 0x40000, CRC(6673de85) SHA1(df390cd6268efc0e743a9020f19bc0cbeb757cfa))
+
+	ROM_REGION( 0x280000, "gfx1", 0 ) /* sprites */
+	ROM_LOAD( "4.bin", 0x000000, 0x80000, CRC(efcddac9) SHA1(72435ec478b70a067d47f3daf7c224169ee5827a))
+	ROM_LOAD( "5.bin", 0x080000, 0x80000, CRC(bc75ef8f) SHA1(1f3dc457e5ae143d53cfef0e1fcb4586dceefb67))
+	ROM_LOAD( "6.bin", 0x100000, 0x80000, CRC(e47d5f55) SHA1(a341e24f98125265cb3986f8c7ce84eedd056b71))
+	ROM_LOAD( "7.bin", 0x180000, 0x80000, CRC(0fa6ce7d) SHA1(5ba96c9c0625a131d890d9c0c0f65cb2a03fa084))
+	ROM_LOAD( "8.bin", 0x200000, 0x80000, CRC(d4c2b7da) SHA1(515be861443acc5b911241dbaafa42e02f79985a))
+ROM_END
+
+ROM_START( croupiera )
 	ROM_REGION( 0x40000, "maincpu", 0 ) /* 68000 code */
 	ROM_LOAD16_BYTE( "2.bin", 0x00000, 0x20000, CRC(1677a2de) SHA1(4dcbb3c1ce9b65e06ba7e0cffa00c0c8016538f5))
 	ROM_LOAD16_BYTE( "3.bin", 0x00001, 0x20000, CRC(11acaac2) SHA1(19e7bbbf4356fc9a866f9f36d0568c42d6a36c07))
@@ -649,7 +723,8 @@ ROM_END
 *        Game Drivers         *
 ******************************/
 
-/*     YEAR  NAME      PARENT  MACHINE   INPUT     INIT   ROT    COMPANY     FULLNAME                       FLAGS                                          LAYOUT  */
-GAMEL( 1996, sderby,   0,      sderby,   sderby,   0,     ROT0, "Playmark", "Super Derby",                  0,                                             layout_sderby   )
-GAMEL( 1996, spacewin, 0,      spacewin, spacewin, 0,     ROT0, "Playmark", "Scacco Matto / Space Win",     0,                                             layout_spacewin )
-GAMEL( 1997, pmroulet, 0,      pmroulet, pmroulet, 0,     ROT0, "Playmark", "Croupier (Playmark Roulette)", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING, layout_pmroulet )
+/*     YEAR  NAME       PARENT    MACHINE   INPUT     INIT   ROT    COMPANY     FULLNAME                               FLAGS                                          LAYOUT  */
+GAMEL( 1996, sderby,    0,        sderby,   sderby,   0,     ROT0, "Playmark", "Super Derby",                          0,                                             layout_sderby   )
+GAMEL( 1996, spacewin,  0,        spacewin, spacewin, 0,     ROT0, "Playmark", "Scacco Matto / Space Win",             0,                                             layout_spacewin )
+GAMEL( 1997, croupier,  0,        pmroulet, pmroulet, 0,     ROT0, "Playmark", "Croupier (Playmark Roulette v.20.05)", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING, layout_pmroulet )
+GAMEL( 1997, croupiera, croupier, pmroulet, pmroulet, 0,     ROT0, "Playmark", "Croupier (Playmark Roulette v.09.04)", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING, layout_pmroulet )
