@@ -20,7 +20,7 @@ Todo:
 #include "emu.h"
 #include "cpu/z80/z80.h"
 #include "render.h"
-#include "machine/laserdsc.h"
+#include "machine/ldv1000.h"
 
 #define SCHEMATIC_CLOCK (20000000)
 
@@ -28,7 +28,8 @@ class segald_state : public driver_device
 {
 public:
 	segald_state(const machine_config &mconfig, device_type type, const char *tag)
-		: driver_device(mconfig, type, tag) { }
+		: driver_device(mconfig, type, tag),
+		  m_laserdisc(*this, "laserdisc") { }
 
 	UINT8 m_nmi_enable;
 
@@ -37,14 +38,14 @@ public:
 	UINT8* m_fix_RAM;
 	UINT8* m_out_RAM;
 
-	device_t *m_laserdisc;
+	required_device<pioneer_ldv1000_device> m_laserdisc;
 	UINT8 m_ldv1000_input_latch;
 	UINT8 m_ldv1000_output_latch;
 
 };
 
 /* VIDEO GOODS */
-static void astron_draw_characters(running_machine &machine, bitmap_t *bitmap,const rectangle *cliprect)
+static void astron_draw_characters(running_machine &machine, bitmap_ind16 &bitmap,const rectangle &cliprect)
 {
 	segald_state *state = machine.driver_data<segald_state>();
 	UINT8 characterX, characterY;
@@ -60,7 +61,7 @@ static void astron_draw_characters(running_machine &machine, bitmap_t *bitmap,co
 	}
 }
 
-static void astron_draw_sprites(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void astron_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	/* Heisted from Daphne */
 	const UINT8 SPR_Y_TOP     = 0;
@@ -89,12 +90,12 @@ static void astron_draw_sprites(running_machine &machine, bitmap_t *bitmap, cons
 }
 
 
-static SCREEN_UPDATE( astron )
+static SCREEN_UPDATE_IND16( astron )
 {
-	bitmap_fill(bitmap, cliprect, 0);
+	bitmap.fill(0, cliprect);
 
-	astron_draw_characters(screen->machine(), bitmap, cliprect);
-	astron_draw_sprites(screen->machine(), bitmap, cliprect);
+	astron_draw_characters(screen.machine(), bitmap, cliprect);
+	astron_draw_sprites(screen.machine(), bitmap, cliprect);
 
 	return 0;
 }
@@ -108,7 +109,7 @@ static READ8_HANDLER( astron_DISC_read )
 	segald_state *state = space->machine().driver_data<segald_state>();
 
 	if (state->m_nmi_enable)
-		state->m_ldv1000_input_latch = laserdisc_data_r(state->m_laserdisc);
+		state->m_ldv1000_input_latch = state->m_laserdisc->status_r();
 
 	logerror("DISC read   (0x%04x) @ 0x%04x [0x%x]\n", state->m_ldv1000_input_latch, offset, cpu_get_pc(&space->device()));
 
@@ -150,7 +151,7 @@ static WRITE8_HANDLER( astron_DISC_write )
 	state->m_ldv1000_output_latch = data;
 
 	if (state->m_nmi_enable)
-		laserdisc_data_w(state->m_laserdisc, state->m_ldv1000_output_latch);
+		state->m_laserdisc->data_w(state->m_ldv1000_output_latch);
 }
 
 static WRITE8_HANDLER( astron_OUT_write )
@@ -277,8 +278,8 @@ static INPUT_PORTS_START( astron )
 	PORT_DIPSETTING(    0xf0, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0xc0, "1C/1C 2C/1C 3C/3C 4C/4C 5C/6C" )
 	PORT_DIPSETTING(    0x40, "1C/1C 2C/1C 3C/3C 4C/5C" )
-	PORT_DIPSETTING(    0x60, DEF_STR( 2C_3C ) )
 	PORT_DIPSETTING(    0x80, "1C/1C 2C/3C" )
+	PORT_DIPSETTING(    0x60, DEF_STR( 2C_3C ) )
 	PORT_DIPSETTING(    0x70, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(    0x00, "1C/2C 2C/4C 3C/6C 4C/8C 5C/11C" )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_3C ) )
@@ -294,8 +295,8 @@ static INPUT_PORTS_START( astron )
 	PORT_DIPSETTING(    0x0f, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x0c, "1C/1C 2C/1C 3C/3C 4C/4C 5C/6C" )
 	PORT_DIPSETTING(    0x04, "1C/1C 2C/1C 3C/3C 4C/5C" )
-	PORT_DIPSETTING(    0x06, DEF_STR( 2C_3C ) )
 	PORT_DIPSETTING(    0x08, "1C/1C 2C/3C" )
+	PORT_DIPSETTING(    0x06, DEF_STR( 2C_3C ) )
 	PORT_DIPSETTING(    0x07, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(    0x00, "1C/2C 2C/4C 3C/6C 4C/8C 5C/11C" )
 	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_3C ) )
@@ -323,9 +324,7 @@ static INPUT_PORTS_START( astron )
 	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Allow_Continue ) ) PORT_DIPLOCATION("SW2:7")
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unused ) ) PORT_DIPLOCATION("SW2:8")
-	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPUNUSED_DIPLOC( 0x01, IP_ACTIVE_LOW, "SW2:8" )
 
 	PORT_START("IN0")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )                                           /* SW0 = nonJAMMA pin 15 = coin1 & coin2 (?) */
@@ -338,14 +337,14 @@ static INPUT_PORTS_START( astron )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )                                          /* SW7 = nonJAMMA pin 19 = unused? */
 
 	PORT_START("IN1")
-	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT )								  /* SW8  = nonJAMMA pin 9  = right */
-	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) 								  /* SW9  = nonJAMMA pin 10 = left */
-	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )   								  /* SW10 = nonJAMMA pin 11 = up */
-	PORT_BIT ( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) 								  /* SW11 = nonJAMMA pin 12 = down */
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )       								  /* SW12 = nonJAMMA pin 13 = fire */
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_UNUSED )        								  /* SW13 = nonJAMMA pin 14 = unused? */
-	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )        								  /* SW14 = nonJAMMA pin V  = unused? */
-	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )        								  /* SW15 = nonJAMMA pin W  = unused? */
+	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT )                                  /* SW8  = nonJAMMA pin 9  = right */
+	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )                                   /* SW9  = nonJAMMA pin 10 = left */
+	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )                                     /* SW10 = nonJAMMA pin 11 = up */
+	PORT_BIT ( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )                                   /* SW11 = nonJAMMA pin 12 = down */
+	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )                                         /* SW12 = nonJAMMA pin 13 = fire */
+	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_UNUSED )                                          /* SW13 = nonJAMMA pin 14 = unused? */
+	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )                                          /* SW14 = nonJAMMA pin V  = unused? */
+	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )                                          /* SW15 = nonJAMMA pin W  = unused? */
 INPUT_PORTS_END
 
 static GFXDECODE_START( segald )
@@ -356,9 +355,6 @@ GFXDECODE_END
 
 static MACHINE_START( astron )
 {
-	segald_state *state = machine.driver_data<segald_state>();
-
-	state->m_laserdisc = machine.device("laserdisc");
 }
 
 
@@ -373,11 +369,11 @@ static MACHINE_CONFIG_START( astron, segald_state )
 
 	MCFG_MACHINE_START(astron)
 
-	MCFG_LASERDISC_ADD("laserdisc", PIONEER_LDV1000, "screen", "ldsound")
-	MCFG_LASERDISC_OVERLAY(astron, 256, 256, BITMAP_FORMAT_INDEXED16)
+	MCFG_LASERDISC_LDV1000_ADD("laserdisc")
+	MCFG_LASERDISC_OVERLAY_STATIC(256, 256, astron)
 
 	/* video hardware */
-	MCFG_LASERDISC_SCREEN_ADD_NTSC("screen", BITMAP_FORMAT_INDEXED16)
+	MCFG_LASERDISC_SCREEN_ADD_NTSC("screen", "laserdisc")
 
 	MCFG_GFXDECODE(segald)
 	MCFG_PALETTE_LENGTH(256)
@@ -385,7 +381,7 @@ static MACHINE_CONFIG_START( astron, segald_state )
 	/* sound hardare */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MCFG_SOUND_ADD("ldsound", LASERDISC_SOUND, 0)
+	MCFG_SOUND_MODIFY("laserdisc")
 	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
 	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
 MACHINE_CONFIG_END
@@ -601,10 +597,10 @@ static DRIVER_INIT( astron )
 }
 
 
-/*    YEAR  NAME      PARENT   MACHINE  INPUT   INIT    MONITOR COMPANY FULLNAME                                   FLAGS) */
-GAME( 1983, astron,   0,       astron,  astron, astron, ROT0,   "Sega", "Astron Belt",							   GAME_NOT_WORKING|GAME_NO_SOUND)
-GAME( 1983, astronp,  astron,  astron,  astron, astron, ROT0,   "Sega", "Astron Belt (Pioneer LDV1000)",		   GAME_NOT_WORKING|GAME_NO_SOUND)
-GAME( 1983, cobraseg, astron,  astron,  astron, astron, ROT0,   "Sega", "Cobra Command (Sega LaserDisc Hardware)", GAME_NOT_WORKING|GAME_NO_SOUND)
-GAME( 1983, galaxyr,  0,       astron,  astron, astron, ROT0,   "Sega", "Galaxy Ranger",						   GAME_NOT_WORKING|GAME_NO_SOUND)
-GAME( 1983, galaxyrp, galaxyr, astron,  astron, astron, ROT0,   "Sega", "Galaxy Ranger (Pioneer LDV1000)",		   GAME_NOT_WORKING|GAME_NO_SOUND)
-GAME( 1983, sblazerp, galaxyr, astron,  astron, astron, ROT0,   "Sega", "Star Blazer (Pioneer LDV1000)",		   GAME_NOT_WORKING|GAME_NO_SOUND)
+//    YEAR, NAME,     PARENT,  MACHINE,INPUT,  INIT,   MONITOR,COMPANY,FULLNAME,FLAGS
+GAME( 1983, astron,   0,       astron, astron, astron, ROT0,   "Sega", "Astron Belt", GAME_NOT_WORKING|GAME_NO_SOUND)
+GAME( 1983, astronp,  astron,  astron, astron, astron, ROT0,   "Sega", "Astron Belt (Pioneer LDV1000)", GAME_NOT_WORKING|GAME_NO_SOUND)
+GAME( 1983, cobraseg, astron,  astron, astron, astron, ROT0,   "Sega", "Cobra Command (Sega LaserDisc Hardware)", GAME_NOT_WORKING|GAME_NO_SOUND)
+GAME( 1983, galaxyr,  0,       astron, astron, astron, ROT0,   "Sega", "Galaxy Ranger", GAME_NOT_WORKING|GAME_NO_SOUND)
+GAME( 1983, galaxyrp, galaxyr, astron, astron, astron, ROT0,   "Sega", "Galaxy Ranger (Pioneer LDV1000)", GAME_NOT_WORKING|GAME_NO_SOUND)
+GAME( 1983, sblazerp, galaxyr, astron, astron, astron, ROT0,   "Sega", "Star Blazer (Pioneer LDV1000)", GAME_NOT_WORKING|GAME_NO_SOUND)
