@@ -94,7 +94,7 @@ static WRITE8_DEVICE_HANDLER( friskyt_portB_w )
 
 	//logerror("PC %04x: 8910 port B = %02x\n", cpu_get_pc(&space->device()), data);
 	/* bit 0 is IRQ enable */
-	cpu_interrupt_enable(device->machine().device("maincpu"), data & 1);
+	state->m_irq_mask = data & 1;
 
 	/* bit 1 flips screen */
 
@@ -390,6 +390,15 @@ static const ay8910_interface ay8910_config =
 	DEVCB_HANDLER(friskyt_portB_w)
 };
 
+static INTERRUPT_GEN( vblank_irq )
+{
+	seicross_state *state = device->machine().driver_data<seicross_state>();
+
+	if(state->m_irq_mask)
+		device_set_input_line(device, 0, HOLD_LINE);
+
+}
+
 
 static MACHINE_CONFIG_START( nvram, seicross_state )
 
@@ -397,7 +406,7 @@ static MACHINE_CONFIG_START( nvram, seicross_state )
 	MCFG_CPU_ADD("maincpu", Z80, 3072000)	/* 3.072 MHz? */
 	MCFG_CPU_PROGRAM_MAP(main_map)
 	MCFG_CPU_IO_MAP(main_portmap)
-	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_VBLANK_INT("screen", vblank_irq)
 
 	MCFG_CPU_ADD("mcu", NSC8105, 6000000)	/* ??? */
 	MCFG_CPU_PROGRAM_MAP(mcu_nvram_map)
@@ -411,10 +420,9 @@ static MACHINE_CONFIG_START( nvram, seicross_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */	/* frames per second, vblank duration */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(seicross)
+	MCFG_SCREEN_UPDATE_STATIC(seicross)
 
 	MCFG_GFXDECODE(seicross)
 	MCFG_PALETTE_LENGTH(64)
