@@ -101,7 +101,7 @@ MB8421-90LP  D74-02  84256A-70L             26.6860MHz  TCO640FIO
 
 
 Sub Board K91X0488A
- Basicly a few connectors, Caps, resistors & ADC0809CNN
+ basically a few connectors, Caps, resistors & ADC0809CNN
 
 Chips:
  Main: MC68000P12F
@@ -566,11 +566,10 @@ static MACHINE_CONFIG_START( slapshot, slapshot_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(slapshot)
-	MCFG_SCREEN_EOF(taito_no_buffer)
+	MCFG_SCREEN_UPDATE_STATIC(slapshot)
+	MCFG_SCREEN_VBLANK_STATIC(taito_no_buffer)
 
 	MCFG_GFXDECODE(slapshot)
 	MCFG_PALETTE_LENGTH(8192)
@@ -615,11 +614,10 @@ static MACHINE_CONFIG_START( opwolf3, slapshot_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(slapshot)
-	MCFG_SCREEN_EOF(taito_no_buffer)
+	MCFG_SCREEN_UPDATE_STATIC(slapshot)
+	MCFG_SCREEN_VBLANK_STATIC(taito_no_buffer)
 
 	MCFG_GFXDECODE(slapshot)
 	MCFG_PALETTE_LENGTH(8192)
