@@ -28,6 +28,8 @@ driver by Zsolt Vasvari
 a000-a3ff   R/W X/Y scroll position of each character (can be scrolled up
                 to 7 pixels in each direction)
 
+TODO:
+- fix cliprect for sprites that goes out of screen if possible
 
 ***************************************************************************/
 
@@ -40,65 +42,71 @@ a000-a3ff   R/W X/Y scroll position of each character (can be scrolled up
 
 static WRITE8_HANDLER( spcforce_SN76496_latch_w )
 {
-	spcforce_state *state = space->machine->driver_data<spcforce_state>();
+	spcforce_state *state = space->machine().driver_data<spcforce_state>();
 
-	state->sn76496_latch = data;
+	state->m_sn76496_latch = data;
 }
 
 static READ8_HANDLER( spcforce_SN76496_select_r )
 {
-	spcforce_state *state = space->machine->driver_data<spcforce_state>();
+	spcforce_state *state = space->machine().driver_data<spcforce_state>();
 
-	if (~state->sn76496_select & 0x40) return sn76496_ready_r(space->machine->device("sn1"));
-	if (~state->sn76496_select & 0x20) return sn76496_ready_r(space->machine->device("sn2"));
-	if (~state->sn76496_select & 0x10) return sn76496_ready_r(space->machine->device("sn3"));
+	if (~state->m_sn76496_select & 0x40) return sn76496_ready_r(space->machine().device("sn1"));
+	if (~state->m_sn76496_select & 0x20) return sn76496_ready_r(space->machine().device("sn2"));
+	if (~state->m_sn76496_select & 0x10) return sn76496_ready_r(space->machine().device("sn3"));
 
 	return 0;
 }
 
 static WRITE8_HANDLER( spcforce_SN76496_select_w )
 {
-	spcforce_state *state = space->machine->driver_data<spcforce_state>();
+	spcforce_state *state = space->machine().driver_data<spcforce_state>();
 
-	state->sn76496_select = data;
+	state->m_sn76496_select = data;
 
-	if (~data & 0x40) sn76496_w(space->machine->device("sn1"), 0, state->sn76496_latch);
-	if (~data & 0x20) sn76496_w(space->machine->device("sn2"), 0, state->sn76496_latch);
-	if (~data & 0x10) sn76496_w(space->machine->device("sn3"), 0, state->sn76496_latch);
+	if (~data & 0x40) sn76496_w(space->machine().device("sn1"), 0, state->m_sn76496_latch);
+	if (~data & 0x20) sn76496_w(space->machine().device("sn2"), 0, state->m_sn76496_latch);
+	if (~data & 0x10) sn76496_w(space->machine().device("sn3"), 0, state->m_sn76496_latch);
 }
 
 static READ8_HANDLER( spcforce_t0_r )
 {
 	/* SN76496 status according to Al - not supported by MAME?? */
-	return space->machine->rand() & 1;
+	return space->machine().rand() & 1;
 }
 
 
 static WRITE8_HANDLER( spcforce_soundtrigger_w )
 {
-	cputag_set_input_line(space->machine, "audiocpu", 0, (~data & 0x08) ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(space->machine(), "audiocpu", 0, (~data & 0x08) ? ASSERT_LINE : CLEAR_LINE);
 }
 
+static WRITE8_HANDLER( irq_mask_w )
+{
+	spcforce_state *state = space->machine().driver_data<spcforce_state>();
 
-static ADDRESS_MAP_START( spcforce_map, ADDRESS_SPACE_PROGRAM, 8 )
+	state->m_irq_mask = data & 1;
+}
+
+static ADDRESS_MAP_START( spcforce_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x43ff) AM_RAM
 	AM_RANGE(0x7000, 0x7000) AM_READ_PORT("DSW") AM_WRITE(soundlatch_w)
 	AM_RANGE(0x7001, 0x7001) AM_READ_PORT("P1") AM_WRITE(spcforce_soundtrigger_w)
 	AM_RANGE(0x7002, 0x7002) AM_READ_PORT("P2")
 	AM_RANGE(0x700b, 0x700b) AM_WRITE(spcforce_flip_screen_w)
-	AM_RANGE(0x700e, 0x700e) AM_WRITE(interrupt_enable_w)
+	AM_RANGE(0x700e, 0x700e) AM_WRITE(irq_mask_w)
 	AM_RANGE(0x700f, 0x700f) AM_WRITENOP
-	AM_RANGE(0x8000, 0x83ff) AM_RAM AM_BASE_MEMBER(spcforce_state, videoram)
-	AM_RANGE(0x9000, 0x93ff) AM_RAM AM_BASE_MEMBER(spcforce_state, colorram)
-	AM_RANGE(0xa000, 0xa3ff) AM_RAM AM_BASE_MEMBER(spcforce_state, scrollram)
+	AM_RANGE(0x8000, 0x83ff) AM_RAM AM_BASE_MEMBER(spcforce_state, m_videoram)
+	AM_RANGE(0x9000, 0x93ff) AM_RAM AM_BASE_MEMBER(spcforce_state, m_colorram)
+	AM_RANGE(0xa000, 0xa3ff) AM_RAM AM_BASE_MEMBER(spcforce_state, m_scrollram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( spcforce_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( spcforce_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( spcforce_sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( spcforce_sound_io_map, AS_IO, 8 )
 	AM_RANGE(MCS48_PORT_BUS, MCS48_PORT_BUS) AM_READ(soundlatch_r)
 	AM_RANGE(MCS48_PORT_P1, MCS48_PORT_P1) AM_WRITE(spcforce_SN76496_latch_w)
 	AM_RANGE(MCS48_PORT_P2, MCS48_PORT_P2) AM_READWRITE(spcforce_SN76496_select_r, spcforce_SN76496_select_w)
@@ -199,7 +207,7 @@ static const gfx_layout charlayout =
 	8,8,    /* 8*8 chars */
 	512,    /* 512 characters */
 	3,      /* 3 bits per pixel */
-	{ 2*512*8*8, 512*8*8, 0 },  /* The bitplanes are seperate */
+	{ 2*512*8*8, 512*8*8, 0 },  /* The bitplanes are separate */
 	{ 0, 1, 2, 3, 4, 5, 6, 7},
 	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8},
 	8*8     /* every char takes 8 consecutive bytes */
@@ -237,6 +245,13 @@ static PALETTE_INIT( spcforce )
 	}
 }
 
+static INTERRUPT_GEN( vblank_irq )
+{
+	spcforce_state *state = device->machine().driver_data<spcforce_state>();
+
+	if(state->m_irq_mask)
+		device_set_input_line(device, 3, HOLD_LINE);
+}
 
 static MACHINE_CONFIG_START( spcforce, spcforce_state )
 
@@ -244,7 +259,7 @@ static MACHINE_CONFIG_START( spcforce, spcforce_state )
 	/* FIXME: The 8085A had a max clock of 6MHz, internally divided by 2! */
 	MCFG_CPU_ADD("maincpu", I8085A, 8000000 * 2)        /* 4.00 MHz??? */
 	MCFG_CPU_PROGRAM_MAP(spcforce_map)
-	MCFG_CPU_VBLANK_INT("screen", irq3_line_pulse)
+	MCFG_CPU_VBLANK_INT("screen", vblank_irq)
 
 	MCFG_CPU_ADD("audiocpu", I8035, 6144000)		/* divisor ??? */
 	MCFG_CPU_PROGRAM_MAP(spcforce_sound_map)
@@ -254,15 +269,14 @@ static MACHINE_CONFIG_START( spcforce, spcforce_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 28*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(spcforce)
 
 	MCFG_GFXDECODE(spcforce)
 	MCFG_PALETTE_LENGTH(sizeof(colortable_source) / sizeof(colortable_source[0]))
 
 	MCFG_PALETTE_INIT(spcforce)
-	MCFG_VIDEO_UPDATE(spcforce)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
