@@ -518,10 +518,9 @@ static MACHINE_CONFIG_START( splash, splash_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(2*8, 48*8-1, 2*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(splash)
+	MCFG_SCREEN_UPDATE_STATIC(splash)
 
 	MCFG_GFXDECODE(splash)
 	MCFG_PALETTE_LENGTH(2048)
@@ -576,11 +575,10 @@ static MACHINE_CONFIG_START( roldfrog, splash_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(2*8, 48*8-1, 2*8, 32*8-1)
 
-	MCFG_SCREEN_UPDATE(splash)
+	MCFG_SCREEN_UPDATE_STATIC(splash)
 
 	MCFG_GFXDECODE(splash)
 	MCFG_PALETTE_LENGTH(2048)
@@ -659,10 +657,9 @@ static MACHINE_CONFIG_START( funystrp, splash_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 48*8-1, 2*8, 32*8-1)
-	MCFG_SCREEN_UPDATE(funystrp)
+	MCFG_SCREEN_UPDATE_STATIC(funystrp)
 
 	MCFG_GFXDECODE(splash)
 	MCFG_PALETTE_LENGTH(2048)
