@@ -133,7 +133,7 @@ WRITE16_HANDLER( paletteram16_xbgr_word_be_sprites2_w )
 
 WRITE16_HANDLER( paletteram16_xbgr_word_be_sprites_w )
 {
-	// hack??? we have to call this otherwise the sprite colours for some selected tiles are wrong (most noticable on the 2nd level of quest mode)
+	// hack??? we have to call this otherwise the sprite colours for some selected tiles are wrong (most noticeable on the 2nd level of quest mode)
 	// however if we simply mirror the memory both ways the how to play screen ends up with bad colours
 	// we use the 2nd copy of palette ram for low priority tiles only..
 	// is this related to the bootleg only, or does the original have this issue too?
@@ -276,57 +276,57 @@ static INPUT_PORTS_START( sshangha )
 
 	/* Dips seem inverted with respect to other Deco games */
 	PORT_START("DSW")	/* 0xfec04b.b - 0xfec04a.b, inverted bits order */
-	PORT_DIPNAME( 0x0080, 0x0080, DEF_STR( Demo_Sounds ) )	// To be confirmed
+	PORT_DIPNAME( 0x0080, 0x0080, DEF_STR( Demo_Sounds ) )	PORT_DIPLOCATION("SW1:1")
 	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0080, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Flip_Screen ) )
+	PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Flip_Screen ) )	PORT_DIPLOCATION("SW1:2")
 	PORT_DIPSETTING(      0x0040, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_SERVICE( 0x0020, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x0010, 0x0010, "Coin Mode" )			// Check code at 0x000010f2
+	PORT_SERVICE_DIPLOC(  0x0020, IP_ACTIVE_LOW, "SW1:3" )
+	PORT_DIPNAME( 0x0010, 0x0010, "Coin Mode" ) 		PORT_DIPLOCATION("SW1:4") /* Manual states "Always Off" - Check code at 0x000010f2 */
 	PORT_DIPSETTING(      0x0010, "Mode 1" )
 	PORT_DIPSETTING(      0x0000, "Mode 2" )
-	PORT_DIPNAME( 0x000c, 0x000c, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(      0x0008, DEF_STR( 2C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
-	PORT_DIPSETTING(      0x000c, DEF_STR( 1C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
-	PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
-	PORT_DIPSETTING(      0x0004, DEF_STR( 1C_2C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
-	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
-	PORT_DIPSETTING(      0x0008, DEF_STR( 3C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
-	PORT_DIPSETTING(      0x000c, DEF_STR( 1C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
-	PORT_DIPSETTING(      0x0004, DEF_STR( 1C_4C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
-	PORT_DIPNAME( 0x0003, 0x0003, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(      0x0002, DEF_STR( 2C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
-	PORT_DIPSETTING(      0x0003, DEF_STR( 1C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
-	PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
-	PORT_DIPSETTING(      0x0001, DEF_STR( 1C_2C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
-	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
-	PORT_DIPSETTING(      0x0002, DEF_STR( 3C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
-	PORT_DIPSETTING(      0x0003, DEF_STR( 1C_1C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
-	PORT_DIPSETTING(      0x0001, DEF_STR( 1C_4C ) ) PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
-	PORT_DIPNAME( 0xc000, 0xc000, DEF_STR( Difficulty ) )
+	PORT_DIPNAME( 0x000c, 0x000c, DEF_STR( Coin_A ) )	PORT_DIPLOCATION("SW1:5,6")
+	PORT_DIPSETTING(      0x0008, DEF_STR( 2C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
+	PORT_DIPSETTING(      0x000c, DEF_STR( 1C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
+	PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
+	PORT_DIPSETTING(      0x0004, DEF_STR( 1C_2C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
+	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
+	PORT_DIPSETTING(      0x0008, DEF_STR( 3C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
+	PORT_DIPSETTING(      0x000c, DEF_STR( 1C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
+	PORT_DIPSETTING(      0x0004, DEF_STR( 1C_4C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
+	PORT_DIPNAME( 0x0003, 0x0003, DEF_STR( Coin_B ) )	PORT_DIPLOCATION("SW1:7,8")
+	PORT_DIPSETTING(      0x0002, DEF_STR( 2C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
+	PORT_DIPSETTING(      0x0003, DEF_STR( 1C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
+	PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
+	PORT_DIPSETTING(      0x0001, DEF_STR( 1C_2C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_EQUALS, 0x0010) //Mode 1
+	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
+	PORT_DIPSETTING(      0x0002, DEF_STR( 3C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
+	PORT_DIPSETTING(      0x0003, DEF_STR( 1C_1C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
+	PORT_DIPSETTING(      0x0001, DEF_STR( 1C_4C ) )		PORT_CONDITION("DSW", 0x0010, PORTCOND_NOTEQUALS, 0x0010) //Mode 2
+	PORT_DIPNAME( 0xc000, 0xc000, DEF_STR( Difficulty ) )	PORT_DIPLOCATION("SW2:1,2")
 	PORT_DIPSETTING(      0x4000, DEF_STR( Easy ) )
 	PORT_DIPSETTING(      0xc000, DEF_STR( Normal ) )
 	PORT_DIPSETTING(      0x8000, DEF_STR( Hard ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Hardest ) )
 #if SSHANGHA_HACK
-	PORT_DIPNAME( 0x2000, 0x2000, "Debug Mode" )
+	PORT_DIPNAME( 0x2000, 0x2000, "Debug Mode" )		PORT_DIPLOCATION("SW2:3")
 	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 #else
-	PORT_DIPUNUSED( 0x2000, IP_ACTIVE_LOW )                   // See notes
+	PORT_DIPUNUSED_DIPLOC( 0x2000, 0x2000, "SW2:3" )	/* Listed as "Unused" - However see notes */
 #endif
-	PORT_DIPUNUSED( 0x1000, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x0800, 0x0800, "Tile Animation" )
+	PORT_DIPUNUSED_DIPLOC( 0x1000, 0x1000, "SW2:4" )	/* Listed as "Unused" */
+	PORT_DIPNAME( 0x0800, 0x0800, "Tile Animation" )	PORT_DIPLOCATION("SW2:5")
 	PORT_DIPSETTING(      0x0000, DEF_STR( No ) )
 	PORT_DIPSETTING(      0x0800, DEF_STR( Yes ) )
-	PORT_DIPNAME( 0x0400, 0x0400, "Use Mahjong Tiles" )
+	PORT_DIPNAME( 0x0400, 0x0400, "Use Mahjong Tiles" )	PORT_DIPLOCATION("SW2:6")
 	PORT_DIPSETTING(      0x0000, DEF_STR( No ) )
 	PORT_DIPSETTING(      0x0400, DEF_STR( Yes ) )
-	PORT_DIPNAME( 0x0200, 0x0200, "Adult Mode" )
+	PORT_DIPNAME( 0x0200, 0x0200, "Paradise (Adult) Course" )	PORT_DIPLOCATION("SW2:7")
 	PORT_DIPSETTING(      0x0000, DEF_STR( No ) )
 	PORT_DIPSETTING(      0x0200, DEF_STR( Yes ) )
-	PORT_DIPNAME( 0x0100, 0x0100, "Quest Mode" )
+	PORT_DIPNAME( 0x0100, 0x0100, "Quest Course" )		PORT_DIPLOCATION("SW2:8")
 	PORT_DIPSETTING(      0x0000, DEF_STR( No ) )
 	PORT_DIPSETTING(      0x0100, DEF_STR( Yes ) )
 INPUT_PORTS_END
@@ -416,10 +416,9 @@ static MACHINE_CONFIG_START( sshangha, sshangha_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
-	MCFG_SCREEN_UPDATE(sshangha)
+	MCFG_SCREEN_UPDATE_STATIC(sshangha)
 
 	MCFG_GFXDECODE(sshangha)
 	MCFG_PALETTE_LENGTH(0x4000)
