@@ -270,9 +270,8 @@ static MACHINE_CONFIG_START( starfire, starfire_state )
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_RAW_PARAMS(STARFIRE_PIXEL_CLOCK, STARFIRE_HTOTAL, STARFIRE_HBEND, STARFIRE_HBSTART, STARFIRE_VTOTAL, STARFIRE_VBEND, STARFIRE_VBSTART)
-	MCFG_SCREEN_UPDATE(starfire)
+	MCFG_SCREEN_UPDATE_STATIC(starfire)
 
 	MCFG_VIDEO_START(starfire)
 
