@@ -130,11 +130,11 @@ static VIDEO_START(sub)
 {
 }
 
-static SCREEN_UPDATE(sub)
+static SCREEN_UPDATE_IND16(sub)
 {
-	sub_state *state = screen->machine().driver_data<sub_state>();
-	const gfx_element *gfx = screen->machine().gfx[0];
-	const gfx_element *gfx_1 = screen->machine().gfx[1];
+	sub_state *state = screen.machine().driver_data<sub_state>();
+	const gfx_element *gfx = screen.machine().gfx[0];
+	const gfx_element *gfx_1 = screen.machine().gfx[1];
 	int y,x;
 	int count = 0;
 
@@ -336,7 +336,7 @@ static INPUT_PORTS_START( sub )
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Cabinet ) )
-	PORT_DIPSETTING(    0x20, DEF_STR( Upright ) )	/* Seperate controls for each player */
+	PORT_DIPSETTING(    0x20, DEF_STR( Upright ) )	/* separate controls for each player */
 	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) ) /* Controls via player 1 for both, but need to get x/y screen flip working to fully test */
 	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
@@ -435,10 +435,9 @@ static MACHINE_CONFIG_START( sub, sub_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 256-1, 16, 256-16-1)
-	MCFG_SCREEN_UPDATE(sub)
+	MCFG_SCREEN_UPDATE_STATIC(sub)
 
 	MCFG_GFXDECODE(sub)
 	MCFG_PALETTE_LENGTH(0x400)
