@@ -1,8 +1,30 @@
 /*  Taito Wolf System
 
     Driver by Ville Linde
+
+AMD M4-128N/64 stamped 'E58-01'
+AMD MACH231 stamped 'E58-02'
+AMD MACH211 stamped 'E58-03'
+Zoom ZFX2
+Zoom ZSG-2
+Taito TC0510NIO
+Panasonic MN1020019
+1x RAM NEC 42S4260
+1x RAM GM71C4400
+12x RAM Alliance AS4C256K16E0-35 (256k x 16)
+Mitsubishi M66220
+Fujitsu MB87078
+Atmel 93C66 EEPROM (4kb probably for high scores, test mode settings etc)
+ICS GENDAC ICS5342-3
+3DFX 500-0003-03 F805281.1 FBI
+3DFX 500-0004-02 F804701.1 TMU
+some logic
+clocks 50MHz (near 3DFX) and 14.31818MHz (near RAMDAC)
+
 */
 
+#define ENABLE_VGA 0
+
 #include "emu.h"
 #include "cpu/i386/i386.h"
 #include "memconv.h"
@@ -16,7 +38,9 @@
 #include "machine/8042kbdc.h"
 #include "machine/pckeybrd.h"
 #include "machine/idectrl.h"
-
+#if ENABLE_VGA
+#include "video/pc_vga.h"
+#endif
 
 class taitowlf_state : public driver_device
 {
@@ -24,7 +48,6 @@ public:
 	taitowlf_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag) { }
 
-	UINT32 *m_cga_ram;
 	UINT32 *m_bios_ram;
 	UINT8 m_mxtc_config_reg[256];
 	UINT8 m_piix4_config_reg[4][256];
@@ -39,75 +62,38 @@ public:
 	device_t	*m_dma8237_2;
 };
 
+#if !ENABLE_VGA
+static SCREEN_UPDATE_RGB32( taitowlf )
+{
+	int x,y,count;
+	const UINT8 *blit_ram = screen.machine().region("user5")->base();
+
+	bitmap.fill(get_black_pen(screen.machine()), cliprect);
+
+	count = (0);
+
+	for(y=0;y<256;y++)
+	{
+		for(x=0;x<512;x++)
+		{
+			UINT32 color;
+
+			color = (blit_ram[count] & 0xff);
+
+			if(cliprect.contains(x+0, y))
+				bitmap.pix32(y, x+0) = screen.machine().pens[color];
+
+			count++;
+		}
+	}
+
+	return 0;
+}
+#endif
 
 static void ide_interrupt(device_t *device, int state);
 
 
-static const rgb_t cga_palette[16] =
-{
-	MAKE_RGB( 0x00, 0x00, 0x00 ), MAKE_RGB( 0x00, 0x00, 0xaa ), MAKE_RGB( 0x00, 0xaa, 0x00 ), MAKE_RGB( 0x00, 0xaa, 0xaa ),
-	MAKE_RGB( 0xaa, 0x00, 0x00 ), MAKE_RGB( 0xaa, 0x00, 0xaa ), MAKE_RGB( 0xaa, 0x55, 0x00 ), MAKE_RGB( 0xaa, 0xaa, 0xaa ),
-	MAKE_RGB( 0x55, 0x55, 0x55 ), MAKE_RGB( 0x55, 0x55, 0xff ), MAKE_RGB( 0x55, 0xff, 0x55 ), MAKE_RGB( 0x55, 0xff, 0xff ),
-	MAKE_RGB( 0xff, 0x55, 0x55 ), MAKE_RGB( 0xff, 0x55, 0xff ), MAKE_RGB( 0xff, 0xff, 0x55 ), MAKE_RGB( 0xff, 0xff, 0xff ),
-};
-
-static VIDEO_START(taitowlf)
-{
-	int i;
-	for (i=0; i < 16; i++)
-	{
-		palette_set_color(machine, i, cga_palette[i]);
-	}
-}
-
-static void draw_char(bitmap_t *bitmap, const rectangle *cliprect, const gfx_element *gfx, int ch, int att, int x, int y)
-{
-	int i,j;
-	const UINT8 *dp;
-	int index = 0;
-	dp = gfx_element_get_data(gfx, ch);
-
-	for (j=y; j < y+8; j++)
-	{
-		UINT16 *p = BITMAP_ADDR16(bitmap, j, 0);
-		for (i=x; i < x+8; i++)
-		{
-			UINT8 pen = dp[index++];
-			if (pen)
-				p[i] = gfx->color_base + (att & 0xf);
-			else
-				p[i] = gfx->color_base  + ((att >> 4) & 0x7);
-		}
-	}
-}
-
-static SCREEN_UPDATE(taitowlf)
-{
-	taitowlf_state *state = screen->machine().driver_data<taitowlf_state>();
-	int i, j;
-	const gfx_element *gfx = screen->machine().gfx[0];
-	UINT32 *cga = state->m_cga_ram;
-	int index = 0;
-
-	bitmap_fill(bitmap, cliprect, 0);
-
-	for (j=0; j < 25; j++)
-	{
-		for (i=0; i < 80; i+=2)
-		{
-			int att0 = (cga[index] >> 8) & 0xff;
-			int ch0 = (cga[index] >> 0) & 0xff;
-			int att1 = (cga[index] >> 24) & 0xff;
-			int ch1 = (cga[index] >> 16) & 0xff;
-
-			draw_char(bitmap, cliprect, gfx, ch0, att0, i*8, j*8);
-			draw_char(bitmap, cliprect, gfx, ch1, att1, (i*8)+8, j*8);
-			index++;
-		}
-	}
-	return 0;
-}
-
 static READ8_DEVICE_HANDLER(at_dma8237_2_r)
 {
 	return i8237_r(device, offset / 2);
@@ -473,8 +459,12 @@ static WRITE32_HANDLER(at_page32_w)
 
 static ADDRESS_MAP_START( taitowlf_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x0009ffff) AM_RAM
-	AM_RANGE(0x000a0000, 0x000affff) AM_RAM
-	AM_RANGE(0x000b0000, 0x000b7fff) AM_RAM AM_BASE_MEMBER(taitowlf_state, m_cga_ram)
+	AM_RANGE(0x000a0000, 0x000bffff) AM_RAM
+	#if ENABLE_VGA
+	AM_RANGE(0x000c0000, 0x000c7fff) AM_RAM AM_REGION("video_bios", 0)
+	#else
+	AM_RANGE(0x000c0000, 0x000c7fff) AM_NOP
+	#endif
 	AM_RANGE(0x000e0000, 0x000effff) AM_RAM
 	AM_RANGE(0x000f0000, 0x000fffff) AM_ROMBANK("bank1")
 	AM_RANGE(0x000f0000, 0x000fffff) AM_WRITE(bios_ram_w)
@@ -503,28 +493,7 @@ ADDRESS_MAP_END
 
 /*****************************************************************************/
 
-static const gfx_layout CGA_charlayout =
-{
-	8,8,					/* 8 x 16 characters */
-    256,                    /* 256 characters */
-    1,                      /* 1 bits per pixel */
-    { 0 },                  /* no bitplanes; 1 bit per pixel */
-    /* x offsets */
-    { 0,1,2,3,4,5,6,7 },
-    /* y offsets */
-	{ 0*8,1*8,2*8,3*8,
-	  4*8,5*8,6*8,7*8 },
-    8*8                     /* every char takes 8 bytes */
-};
-
-static GFXDECODE_START( CGA )
-/* Support up to four CGA fonts */
-	GFXDECODE_ENTRY( "gfx1", 0x0000, CGA_charlayout,              0, 256 )   /* Font 0 */
-	GFXDECODE_ENTRY( "gfx1", 0x0800, CGA_charlayout,              0, 256 )   /* Font 1 */
-	GFXDECODE_ENTRY( "gfx1", 0x1000, CGA_charlayout,              0, 256 )   /* Font 2 */
-	GFXDECODE_ENTRY( "gfx1", 0x1800, CGA_charlayout,              0, 256 )   /* Font 3*/
-GFXDECODE_END
-
+#if 0
 #define AT_KEYB_HELPER(bit, text, key1) \
 	PORT_BIT( bit, IP_ACTIVE_HIGH, IPT_KEYPAD) PORT_NAME(text) PORT_CODE(key1)
 
@@ -558,6 +527,7 @@ static INPUT_PORTS_START(taitowlf)
 
 	PORT_START("pc_keyboard_7")
 INPUT_PORTS_END
+#endif
 
 static IRQ_CALLBACK(irq_callback)
 {
@@ -643,6 +613,18 @@ static const struct pit8253_config taitowlf_pit8254_config =
 	}
 };
 
+#if !ENABLE_VGA
+/* debug purpose*/
+static PALETTE_INIT( taitowlf )
+{
+	palette_set_color(machine,0x70,MAKE_RGB(0xff,0xff,0xff));
+	palette_set_color(machine,0x71,MAKE_RGB(0xff,0xff,0xff));
+	palette_set_color(machine,0x01,MAKE_RGB(0x55,0x00,0x00));
+	palette_set_color(machine,0x10,MAKE_RGB(0xaa,0x00,0x00));
+	palette_set_color(machine,0x00,MAKE_RGB(0x00,0x00,0x00));
+}
+#endif
+
 static MACHINE_CONFIG_START( taitowlf, taitowlf_state )
 
 	/* basic machine hardware */
@@ -665,19 +647,20 @@ static MACHINE_CONFIG_START( taitowlf, taitowlf_state )
 	MCFG_IDE_CONTROLLER_ADD("ide", ide_interrupt)
 	MCFG_MC146818_ADD( "rtc", MC146818_STANDARD )
 
+	/* video hardware */
+	#if ENABLE_VGA
+	MCFG_FRAGMENT_ADD( pcvideo_vga )
+	#else
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MCFG_SCREEN_SIZE(640, 480)
-	MCFG_SCREEN_VISIBLE_AREA(0, 639, 0, 199)
-	MCFG_SCREEN_UPDATE(taitowlf)
-
-	MCFG_GFXDECODE(CGA)
-	MCFG_PALETTE_LENGTH(16)
-
-	MCFG_VIDEO_START(taitowlf)
+	MCFG_SCREEN_SIZE(512, 256)
+	MCFG_SCREEN_VISIBLE_AREA(0, 512-1, 0, 256-1)
+	MCFG_PALETTE_LENGTH(256)
+	MCFG_SCREEN_UPDATE_STATIC(taitowlf)
+	MCFG_PALETTE_INIT(taitowlf)
+	#endif
 MACHINE_CONFIG_END
 
 static void set_gate_a20(running_machine &machine, int a20)
@@ -705,7 +688,7 @@ static int taitowlf_get_out2(running_machine &machine)
 
 static const struct kbdc8042_interface at8042 =
 {
-	KBDC8042_AT386, set_gate_a20, keyboard_interrupt, taitowlf_get_out2
+	KBDC8042_AT386, set_gate_a20, keyboard_interrupt, NULL, taitowlf_get_out2
 };
 
 static void taitowlf_set_keyb_int(running_machine &machine, int state)
@@ -714,6 +697,10 @@ static void taitowlf_set_keyb_int(running_machine &machine, int state)
 	pic8259_ir1_w(drvstate->m_pic8259_1, state);
 }
 
+#if ENABLE_VGA
+static READ8_HANDLER( vga_setting ) { return 0xff; } // hard-code to color
+#endif
+
 static DRIVER_INIT( taitowlf )
 {
 	taitowlf_state *state = machine.driver_data<taitowlf_state>();
@@ -724,6 +711,10 @@ static DRIVER_INIT( taitowlf )
 	intel82439tx_init(machine);
 
 	kbdc8042_init(machine, &at8042);
+	#if ENABLE_VGA
+	pc_vga_init(machine, vga_setting, NULL);
+	pc_vga_io_init(machine, machine.device("maincpu")->memory().space(AS_PROGRAM), 0xa0000, machine.device("maincpu")->memory().space(AS_IO), 0x0000);
+	#endif
 }
 
 /*****************************************************************************/
@@ -732,8 +723,11 @@ ROM_START(pf2012)
 	ROM_REGION32_LE(0x40000, "user1", 0)
 	ROM_LOAD("p5tx-la.bin", 0x00000, 0x40000, CRC(072e6d51) SHA1(70414349b37e478fc28ecbaba47ad1033ae583b7))
 
-	ROM_REGION(0x08100, "gfx1", 0)
-    ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd))
+	#if ENABLE_VGA
+	ROM_REGION( 0x8000, "video_bios", 0 ) // debug
+	ROM_LOAD16_BYTE( "trident_tgui9680_bios.bin", 0x0000, 0x4000, BAD_DUMP CRC(1eebde64) SHA1(67896a854d43a575037613b3506aea6dae5d6a19) )
+	ROM_CONTINUE(                                 0x0001, 0x4000 )
+	#endif
 
 	ROM_REGION32_LE(0x400000, "user3", 0)		// Program ROM disk
 	ROM_LOAD("u1.bin", 0x000000, 0x200000, CRC(8f4c09cb) SHA1(0969a92fec819868881683c580f9e01cbedf4ad2))
@@ -766,4 +760,4 @@ ROM_END
 
 /*****************************************************************************/
 
-GAME(1997, pf2012, 0,	taitowlf, taitowlf, taitowlf,	ROT0,   "Taito",  "Psychic Force 2012", GAME_NOT_WORKING | GAME_NO_SOUND)
+GAME(1997, pf2012, 0,	taitowlf, pc_keyboard, taitowlf,	ROT0,   "Taito",  "Psychic Force 2012", GAME_NOT_WORKING | GAME_NO_SOUND)
