@@ -58,7 +58,7 @@ public:
 static VIDEO_START( tcl )
 {
 }
-static SCREEN_UPDATE( tcl )
+static SCREEN_UPDATE_IND16( tcl )
 {
 	return 0;
 }
@@ -131,10 +131,9 @@ static MACHINE_CONFIG_START( tcl, tcl_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(tcl)
+	MCFG_SCREEN_UPDATE_STATIC(tcl)
 
 	MCFG_GFXDECODE(tcl)
 	MCFG_PALETTE_LENGTH(16*16)
