@@ -1,11 +1,10 @@
 /* Tecmo System
  Driver by Farfetch, David Haywood & Tomasz Slanina
-  Protection simulation by nuapete
+ Protection simulation by nuapete
 
  ToDo:
-  Dump / Decap MCUs to allow for proper protection emulation.
-  Fix Sound (sound roms should be good, do they need descrambling, or is our sound core bad?
-     some YMZ280B samples sound -terrible-)
+  - Dump / Decap MCUs to allow for proper protection emulation.
+  - tkdenshoa pcb shows some garbage sprites at the top during y-scroll
 
 
 T.Slanina 20040530 :
@@ -136,7 +135,7 @@ t501.uad1       23c4001 dip32 maskrom
 
 /*
 
-Touki Denshou -Angel Eyes-
+Toukidenshou -Angel Eyes-
 (c)1996 Tecmo
 Tecmo System Board
 
@@ -191,84 +190,12 @@ ae500w07.ad1 - M6295 Samples (23c4001)
 #include "sound/ymz280b.h"
 
 
-static TILE_GET_INFO( get_bg0tile_info )
-{
-	tecmosys_state *state = machine.driver_data<tecmosys_state>();
-
-	SET_TILE_INFO(
-			1,
-			state->m_bg0tilemap_ram[2*tile_index+1],
-			(state->m_bg0tilemap_ram[2*tile_index]&0x3f),
-			TILE_FLIPYX((state->m_bg0tilemap_ram[2*tile_index]&0xc0)>>6));
-}
-
-static WRITE16_HANDLER( bg0_tilemap_w )
-{
-	tecmosys_state *state = space->machine().driver_data<tecmosys_state>();
-	COMBINE_DATA(&state->m_bg0tilemap_ram[offset]);
-	tilemap_mark_tile_dirty(state->m_bg0tilemap,offset/2);
-}
-
-static TILE_GET_INFO( get_bg1tile_info )
-{
-	tecmosys_state *state = machine.driver_data<tecmosys_state>();
-
-	SET_TILE_INFO(
-			2,
-			state->m_bg1tilemap_ram[2*tile_index+1],
-			(state->m_bg1tilemap_ram[2*tile_index]&0x3f),
-			TILE_FLIPYX((state->m_bg1tilemap_ram[2*tile_index]&0xc0)>>6));
-}
-
-static WRITE16_HANDLER( bg1_tilemap_w )
-{
-	tecmosys_state *state = space->machine().driver_data<tecmosys_state>();
-	COMBINE_DATA(&state->m_bg1tilemap_ram[offset]);
-	tilemap_mark_tile_dirty(state->m_bg1tilemap,offset/2);
-}
-
-static TILE_GET_INFO( get_bg2tile_info )
-{
-	tecmosys_state *state = machine.driver_data<tecmosys_state>();
-
-	SET_TILE_INFO(
-			3,
-			state->m_bg2tilemap_ram[2*tile_index+1],
-			(state->m_bg2tilemap_ram[2*tile_index]&0x3f),
-			TILE_FLIPYX((state->m_bg2tilemap_ram[2*tile_index]&0xc0)>>6));
-}
-
-static WRITE16_HANDLER( bg2_tilemap_w )
-{
-	tecmosys_state *state = space->machine().driver_data<tecmosys_state>();
-	COMBINE_DATA(&state->m_bg2tilemap_ram[offset]);
-	tilemap_mark_tile_dirty(state->m_bg2tilemap,offset/2);
-}
-
-static TILE_GET_INFO( get_tile_info )
-{
-	tecmosys_state *state = machine.driver_data<tecmosys_state>();
-
-	SET_TILE_INFO(
-			0,
-			state->m_fgtilemap_ram[2*tile_index+1],
-			(state->m_fgtilemap_ram[2*tile_index]&0x3f),
-			TILE_FLIPYX((state->m_fgtilemap_ram[2*tile_index]&0xc0)>>6));
-}
-
-static WRITE16_HANDLER( fg_tilemap_w )
-{
-	tecmosys_state *state = space->machine().driver_data<tecmosys_state>();
-	COMBINE_DATA(&state->m_fgtilemap_ram[offset]);
-	tilemap_mark_tile_dirty(state->m_txt_tilemap,offset/2);
-}
-
-
 // It looks like this needs a synch between z80 and 68k ??? See z80:006A-0091
 static READ16_HANDLER( sound_r )
 {
 	if (ACCESSING_BITS_0_7)
 	{
+		space->machine().scheduler().synchronize();
 		return soundlatch2_r( space,  0 );
 	}
 
@@ -279,6 +206,7 @@ static WRITE16_HANDLER( sound_w )
 {
 	if (ACCESSING_BITS_0_7)
 	{
+		space->machine().scheduler().synchronize();
 		soundlatch_w(space, 0x00, data & 0xff);
 		cputag_set_input_line(space->machine(), "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 	}
@@ -293,7 +221,6 @@ static WRITE16_HANDLER( sound_w )
     - 880000 & 03, crash
 */
 
-
 static WRITE16_HANDLER( unk880000_w )
 {
 	tecmosys_state *state = space->machine().driver_data<tecmosys_state>();
@@ -342,14 +269,12 @@ static READ16_HANDLER( unk880000_r )
 	}
 }
 
-
 static READ16_DEVICE_HANDLER( eeprom_r )
 {
 	eeprom_device *eeprom = downcast<eeprom_device *>(device);
 	 return ((eeprom->read_bit() & 0x01) << 11);
 }
 
-
 static WRITE16_DEVICE_HANDLER( eeprom_w )
 {
 	if ( ACCESSING_BITS_8_15 )
@@ -361,42 +286,6 @@ static WRITE16_DEVICE_HANDLER( eeprom_w )
 	}
 }
 
-
-INLINE void set_color_555(running_machine &machine, pen_t color, int rshift, int gshift, int bshift, UINT16 data)
-{
-	palette_set_color_rgb(machine, color, pal5bit(data >> rshift), pal5bit(data >> gshift), pal5bit(data >> bshift));
-}
-
-
-static WRITE16_HANDLER( tilemap_paletteram16_xGGGGGRRRRRBBBBB_word_w )
-{
-	tecmosys_state *state = space->machine().driver_data<tecmosys_state>();
-	COMBINE_DATA(&state->m_tilemap_paletteram16[offset]);
-	set_color_555(space->machine(), offset+0x4000, 5, 10, 0, state->m_tilemap_paletteram16[offset]);
-}
-
-static WRITE16_HANDLER( bg0_tilemap_lineram_w )
-{
-	tecmosys_state *state = space->machine().driver_data<tecmosys_state>();
-	COMBINE_DATA(&state->m_bg0tilemap_lineram[offset]);
-	if (data!=0x0000) popmessage("non 0 write to bg0 lineram %04x %04x",offset,data);
-}
-
-static WRITE16_HANDLER( bg1_tilemap_lineram_w )
-{
-	tecmosys_state *state = space->machine().driver_data<tecmosys_state>();
-	COMBINE_DATA(&state->m_bg1tilemap_lineram[offset]);
-	if (data!=0x0000) popmessage("non 0 write to bg1 lineram %04x %04x",offset,data);
-}
-
-static WRITE16_HANDLER( bg2_tilemap_lineram_w )
-{
-	tecmosys_state *state = space->machine().driver_data<tecmosys_state>();
-	COMBINE_DATA(&state->m_bg2tilemap_lineram[offset]);
-	if (data!=0x0000) popmessage("non 0 write to bg2 lineram %04x %04x",offset,data);
-}
-
-
 static ADDRESS_MAP_START( main_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x200000, 0x20ffff) AM_RAM // work ram
@@ -437,6 +326,40 @@ static ADDRESS_MAP_START( main_map, AS_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 
+static WRITE8_HANDLER( tecmosys_z80_bank_w )
+{
+	memory_set_bank(space->machine(), "bank1", data);
+}
+
+static WRITE8_HANDLER( tecmosys_oki_bank_w )
+{
+	UINT8 upperbank = (data & 0x30) >> 4;
+	UINT8 lowerbank = (data & 0x03) >> 0;
+	UINT8* region = space->machine().region("oki")->base();
+
+	memcpy( region+0x00000, region+0x80000 + lowerbank * 0x20000, 0x20000  );
+	memcpy( region+0x20000, region+0x80000 + upperbank * 0x20000, 0x20000  );
+}
+
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK("bank1")
+	AM_RANGE(0xe000, 0xf7ff) AM_RAM
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( io_map, AS_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x03) AM_DEVREADWRITE("ymf", ymf262_r, ymf262_w)
+	AM_RANGE(0x10, 0x10) AM_DEVREADWRITE_MODERN("oki", okim6295_device, read, write)
+	AM_RANGE(0x20, 0x20) AM_WRITE(tecmosys_oki_bank_w)
+	AM_RANGE(0x30, 0x30) AM_WRITE(tecmosys_z80_bank_w)
+	AM_RANGE(0x40, 0x40) AM_READ(soundlatch_r)
+	AM_RANGE(0x50, 0x50) AM_WRITE(soundlatch2_w)
+	AM_RANGE(0x60, 0x61) AM_DEVREADWRITE("ymz", ymz280b_r, ymz280b_w)
+ADDRESS_MAP_END
+
+
+
 static INPUT_PORTS_START( deroon )
 	PORT_START("P1")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )		PORT_8WAY PORT_PLAYER(1)
@@ -477,6 +400,8 @@ static INPUT_PORTS_START( deroon )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
+
+
 static const gfx_layout gfxlayout =
 {
    8,8,
@@ -501,9 +426,6 @@ static const gfx_layout gfxlayout2 =
 	128*8
 };
 
-
-
-
 static GFXDECODE_START( tecmosys )
 	GFXDECODE_ENTRY( "gfx2", 0, gfxlayout,   0x4400, 0x40 )
 	GFXDECODE_ENTRY( "gfx3", 0, gfxlayout2,  0x4000, 0x40 )
@@ -512,350 +434,6 @@ static GFXDECODE_START( tecmosys )
 
 GFXDECODE_END
 
-static WRITE8_HANDLER( deroon_bankswitch_w )
-{
-	memory_set_bankptr(space->machine(),  "bank1", space->machine().region("audiocpu")->base() + ((data-2) & 0x0f) * 0x4000 + 0x10000 );
-}
-
-static WRITE8_HANDLER( tecmosys_oki_bank_w )
-{
-	UINT8 upperbank = (data & 0x30) >> 4;
-	UINT8 lowerbank = (data & 0x03) >> 0;
-	UINT8* region = space->machine().region("oki")->base();
-
-	memcpy( region+0x00000, region+0x80000 + lowerbank * 0x20000, 0x20000  );
-	memcpy( region+0x20000, region+0x80000 + upperbank * 0x20000, 0x20000  );
-}
-
-static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_ROM
-	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK("bank1")
-	AM_RANGE(0xe000, 0xf7ff) AM_RAM
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( io_map, AS_IO, 8 )
-	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x00, 0x03) AM_DEVREADWRITE("ymf", ymf262_r, ymf262_w)
-	AM_RANGE(0x10, 0x10) AM_DEVWRITE_MODERN("oki", okim6295_device, write)
-	AM_RANGE(0x20, 0x20) AM_WRITE(tecmosys_oki_bank_w)
-	AM_RANGE(0x30, 0x30) AM_WRITE(deroon_bankswitch_w)
-	AM_RANGE(0x40, 0x40) AM_READ(soundlatch_r)
-	AM_RANGE(0x50, 0x50) AM_WRITE(soundlatch2_w)
-	AM_RANGE(0x60, 0x61) AM_DEVREADWRITE("ymz", ymz280b_r, ymz280b_w)
-ADDRESS_MAP_END
-
-
-static VIDEO_START(deroon)
-{
-	tecmosys_state *state = machine.driver_data<tecmosys_state>();
-	state->m_sprite_bitmap = auto_bitmap_alloc(machine,320,240,BITMAP_FORMAT_INDEXED16);
-	bitmap_fill(state->m_sprite_bitmap, NULL, 0x4000);
-
-	state->m_tmp_tilemap_composebitmap = auto_bitmap_alloc(machine,320,240,BITMAP_FORMAT_INDEXED16);
-	state->m_tmp_tilemap_renderbitmap = auto_bitmap_alloc(machine,320,240,BITMAP_FORMAT_INDEXED16);
-
-	bitmap_fill(state->m_tmp_tilemap_composebitmap, NULL, 0x0000);
-	bitmap_fill(state->m_tmp_tilemap_renderbitmap, NULL, 0x0000);
-
-
-	state->m_txt_tilemap = tilemap_create(machine, get_tile_info,tilemap_scan_rows,8,8,32*2,32*2);
-	tilemap_set_transparent_pen(state->m_txt_tilemap,0);
-
-	state->m_bg0tilemap = tilemap_create(machine, get_bg0tile_info,tilemap_scan_rows,16,16,32,32);
-	tilemap_set_transparent_pen(state->m_bg0tilemap,0);
-
-	state->m_bg1tilemap = tilemap_create(machine, get_bg1tile_info,tilemap_scan_rows,16,16,32,32);
-	tilemap_set_transparent_pen(state->m_bg1tilemap,0);
-
-	state->m_bg2tilemap = tilemap_create(machine, get_bg2tile_info,tilemap_scan_rows,16,16,32,32);
-	tilemap_set_transparent_pen(state->m_bg2tilemap,0);
-
-}
-
-static void tecmosys_render_sprites_to_bitmap(running_machine &machine, bitmap_t *bitmap, UINT16 extrax, UINT16 extray )
-{
-	tecmosys_state *state = machine.driver_data<tecmosys_state>();
-	UINT8 *gfxsrc    = machine.region       ( "gfx1" )->base();
-	int i;
-
-	/* render sprites (with priority information) to temp bitmap */
-	bitmap_fill(state->m_sprite_bitmap, NULL, 0x0000);
-	/* there are multiple spritelists in here, to allow for buffering */
-	for (i=(state->m_spritelist*0x4000)/2;i<((state->m_spritelist+1)*0x4000)/2;i+=8)
-	{
-		int xcnt,ycnt;
-		int drawx, drawy;
-		UINT16* dstptr;
-
-		int x, y;
-		int address;
-		int xsize = 16;
-		int ysize = 16;
-		int colour;
-		int flipx, flipy;
-		int priority;
-		int zoomx, zoomy;
-
-		x = state->m_spriteram[i+0]+386;
-		y = (state->m_spriteram[i+1]+1);
-
-		x-= extrax;
-		y-= extray;
-
-		y&=0x1ff;
-		x&=0x3ff;
-
-		if (x&0x200) x-=0x400;
-		if (y&0x100) y-=0x200;
-
-		address =  state->m_spriteram[i+5]| ((state->m_spriteram[i+4]&0x000f)<<16);
-
-		address<<=8;
-
-		flipx = (state->m_spriteram[i+4]&0x0040)>>6;
-		flipy = (state->m_spriteram[i+4]&0x0080)>>7; // used by some move effects in tkdensho
-
-
-		zoomx = (state->m_spriteram[i+2] & 0x0fff)>>0; // zoom?
-		zoomy = (state->m_spriteram[i+3] & 0x0fff)>>0; // zoom?
-
-		if ((!zoomx) || (!zoomy)) continue;
-
-		ysize =  ((state->m_spriteram[i+6] & 0x00ff))*16;
-		xsize =  (((state->m_spriteram[i+6] & 0xff00)>>8))*16;
-
-		colour =  ((state->m_spriteram[i+4] & 0x3f00))>>8;
-
-		priority = ((state->m_spriteram[i+4] & 0x0030))>>4;
-
-
-		if (state->m_spriteram[i+4] & 0x8000) continue;
-
-		for (ycnt = 0; ycnt < ysize; ycnt++)
-		{
-			int actualycnt = (ycnt * zoomy) >> 8;
-			int actualysize = (ysize * zoomy) >> 8;
-
-			if (flipy) drawy = y + (actualysize-1) - actualycnt;
-			else drawy = y + actualycnt;
-
-
-			for (xcnt = 0; xcnt < xsize; xcnt++)
-			{
-				int actualxcnt = (xcnt * zoomx) >> 8;
-				int actualxsize = (xsize *zoomx) >> 8;
-
-				if (flipx) drawx = x + (actualxsize-1) - actualxcnt;
-				else drawx = x + actualxcnt;
-
-				if ((drawx>=0 && drawx<320) && (drawy>=0 && drawy<240))
-				{
-					UINT8 data;
-
-					dstptr = BITMAP_ADDR16(state->m_sprite_bitmap, drawy, drawx);
-
-
-					data =  (gfxsrc[address]);
-
-
-					if(data) dstptr[0] = (data + (colour*0x100)) | (priority << 14);
-				}
-
-
-
-				address++;
-
-			}
-		}
-
-	}
-}
-
-static void tecmosys_tilemap_copy_to_compose(tecmosys_state *state, UINT16 pri)
-{
-	int y,x;
-	UINT16 *srcptr;
-	UINT16 *dstptr;
-	for (y=0;y<240;y++)
-	{
-		srcptr = BITMAP_ADDR16(state->m_tmp_tilemap_renderbitmap, y, 0);
-		dstptr = BITMAP_ADDR16(state->m_tmp_tilemap_composebitmap, y, 0);
-		for (x=0;x<320;x++)
-		{
-			if ((srcptr[x]&0xf)!=0x0)
-			    dstptr[x] =  (srcptr[x]&0x7ff) | pri;
-		}
-	}
-}
-
-static void tecmosys_do_final_mix(running_machine &machine, bitmap_t* bitmap)
-{
-	tecmosys_state *state = machine.driver_data<tecmosys_state>();
-	const pen_t *paldata = machine.pens;
-	int y,x;
-	UINT16 *srcptr;
-	UINT16 *srcptr2;
-	UINT32 *dstptr;
-
-
-	for (y=0;y<240;y++)
-	{
-
-		srcptr = BITMAP_ADDR16(state->m_tmp_tilemap_composebitmap, y, 0);
-		srcptr2 = BITMAP_ADDR16(state->m_sprite_bitmap, y, 0);
-
-
-		dstptr = BITMAP_ADDR32(bitmap, y, 0);
-		for (x=0;x<320;x++)
-		{
-			UINT16 pri, pri2;
-			UINT16 penvalue;
-			UINT16 penvalue2;
-			UINT32 colour;
-			UINT32 colour2;
-
-			pri = srcptr[x] & 0xc000;
-			pri2 = srcptr2[x] & 0xc000;
-
-			penvalue = state->m_tilemap_paletteram16[srcptr[x]&0x7ff];
-			colour =   paldata[(srcptr[x]&0x7ff) | 0x4000];
-
-			if (srcptr2[x]&0x3fff)
-			{
-				penvalue2 = machine.generic.paletteram.u16[srcptr2[x]&0x3fff];
-				colour2 = paldata[srcptr2[x]&0x3fff];
-			}
-			else
-			{
-				penvalue2 = state->m_tilemap_paletteram16[srcptr[x]&0x7ff];
-				colour2 =   paldata[(srcptr[x]&0x7ff) | 0x4000];
-			}
-
-			if ((penvalue & 0x8000) && (penvalue2 & 0x8000)) // blend
-			{
-				int r,g,b;
-				int r2,g2,b2;
-				b = (colour & 0x000000ff) >> 0;
-				g = (colour & 0x0000ff00) >> 8;
-				r = (colour & 0x00ff0000) >> 16;
-
-				b2 = (colour2 & 0x000000ff) >> 0;
-				g2 = (colour2 & 0x0000ff00) >> 8;
-				r2 = (colour2 & 0x00ff0000) >> 16;
-
-				r = (r + r2) >> 1;
-				g = (g + g2) >> 1;
-				b = (b + b2) >> 1;
-
-				dstptr[x] = b | (g<<8) | (r<<16);
-			}
-			else if (pri2 >= pri)
-			{
-				dstptr[x] = colour2;
-			}
-			else
-			{
-				dstptr[x] = colour;
-			}
-		}
-	}
-}
-
-static SCREEN_UPDATE(deroon)
-{
-	tecmosys_state *state = screen->machine().driver_data<tecmosys_state>();
-
-	bitmap_fill(bitmap,cliprect,screen->machine().pens[0x4000]);
-
-
-	tilemap_set_scrolly( state->m_bg0tilemap, 0, state->m_c80000regs[1]+16);
-	tilemap_set_scrollx( state->m_bg0tilemap, 0, state->m_c80000regs[0]+104);
-
-	tilemap_set_scrolly( state->m_bg1tilemap, 0, state->m_a80000regs[1]+17);
-	tilemap_set_scrollx( state->m_bg1tilemap, 0, state->m_a80000regs[0]+106);
-
-	tilemap_set_scrolly( state->m_bg2tilemap, 0, state->m_b00000regs[1]+17);
-	tilemap_set_scrollx( state->m_bg2tilemap, 0, state->m_b00000regs[0]+106);
-
-	bitmap_fill(state->m_tmp_tilemap_composebitmap,cliprect,0);
-
-	bitmap_fill(state->m_tmp_tilemap_renderbitmap,cliprect,0);
-	tilemap_draw(state->m_tmp_tilemap_renderbitmap,cliprect,state->m_bg0tilemap,0,0);
-	tecmosys_tilemap_copy_to_compose(state, 0x0000);
-
-	bitmap_fill(state->m_tmp_tilemap_renderbitmap,cliprect,0);
-	tilemap_draw(state->m_tmp_tilemap_renderbitmap,cliprect,state->m_bg1tilemap,0,0);
-	tecmosys_tilemap_copy_to_compose(state, 0x4000);
-
-	bitmap_fill(state->m_tmp_tilemap_renderbitmap,cliprect,0);
-	tilemap_draw(state->m_tmp_tilemap_renderbitmap,cliprect,state->m_bg2tilemap,0,0);
-	tecmosys_tilemap_copy_to_compose(state, 0x8000);
-
-	bitmap_fill(state->m_tmp_tilemap_renderbitmap,cliprect,0);
-	tilemap_draw(state->m_tmp_tilemap_renderbitmap,cliprect,state->m_txt_tilemap,0,0);
-	tecmosys_tilemap_copy_to_compose(state, 0xc000);
-
-
-	tecmosys_do_final_mix(screen->machine(), bitmap);
-
-/*
-    popmessage("%04x %04x %04x %04x | %04x %04x %04x %04x | %04x %04x %04x %04x  | %04x %04x %04x %04x  | %04x %04x %04x %04x  | %04x %04x %04x %04x",
-        state->m_880000regs[0x0],  state->m_880000regs[0x1],  state->m_880000regs[0x2],  state->m_880000regs[0x3],
-        state->m_880000regs[0x4],  state->m_880000regs[0x5],  state->m_880000regs[0x6],  state->m_880000regs[0x7],
-        state->m_880000regs[0x8],  state->m_880000regs[0x9],  state->m_880000regs[0xa],  state->m_880000regs[0xb],
-        state->m_880000regs[0xc],  state->m_880000regs[0xd],  state->m_880000regs[0xe],  state->m_880000regs[0xf],
-        state->m_880000regs[0x10], state->m_880000regs[0x11], state->m_880000regs[0x12], state->m_880000regs[0x13],
-        state->m_880000regs[0x14], state->m_880000regs[0x15], state->m_880000regs[0x16], state->m_880000regs[0x17]);
-*/
-
-//  popmessage("%04x %04x %04x | %04x %04x %04x",
-//    state->m_c00000regs[0],     state->m_c00000regs[1],     state->m_c00000regs[2],
-//    state->m_c80000regs[0],     state->m_c80000regs[1],     state->m_c80000regs[2]);
-
-//  popmessage("%04x %04x %04x | %04x %04x %04x",
-//    state->m_b00000regs[0],     state->m_b00000regs[1],     state->m_b00000regs[2],
-//    state->m_a80000regs[0],     state->m_a80000regs[1],     state->m_a80000regs[2]);
-
-	// prepare sprites for NEXT frame - causes 1 frame palette errors, but prevents sprite lag in tkdensho, which is correct?
-	tecmosys_render_sprites_to_bitmap(screen->machine(), bitmap, state->m_880000regs[0x0], state->m_880000regs[0x1]);
-
-
-	return 0;
-}
-
-/*
->>> R.Belmont wrote:
-> Here's the sound info (I got it playing in M1, I
-> didn't bother "porting" it since the main game doesn't
-> even boot).
->
-> memory map:
-> 0000-7fff: fixed program ROM
-> 8000-bfff: banked ROM
-> e000-f7ff: work RAM
->
-> I/O ports:
-
-> 0-3: YMF262 OPL3
-> 0x10: OKIM6295
-> 0x30: bank select, in 0x4000 byte units based at the
-> start of the ROM (so 2 = 0x8000).
-> 0x40: latch from 68000
-> 0x50: latch to 68000
-> 0x60/0x61: YMZ280B
->
-> IRQ from YMF262 goes to Z80 IRQ.
->
-> NMI is asserted when the 68000 writes a command.
->
-> Z80 clock appears to be 8 MHz (music slows down in
-> "intense" sections if it's 4 MHz, and the crystals are
-> all in the area of 16 MHz).
->
-> The YMZ280B samples for both games may be misdumped,
-> deroon has lots of "bad" noises but tkdensho only has
-> a few.
-*/
 
 
 static void sound_irq(device_t *device, int irq)
@@ -869,17 +447,24 @@ static const ymf262_interface tecmosys_ymf262_interface =
 	sound_irq		/* irq */
 };
 
+static MACHINE_START( tecmosys )
+{
+//  tecmosys_state *state = machine.driver_data<tecmosys_state>();
+	memory_configure_bank(machine, "bank1", 0, 16, machine.region("audiocpu")->base(), 0x4000);
+}
 
 static MACHINE_CONFIG_START( deroon, tecmosys_state )
-	MCFG_CPU_ADD("maincpu", M68000, 16000000)
+	MCFG_CPU_ADD("maincpu", M68000, XTAL_16MHz)
 	MCFG_CPU_PROGRAM_MAP(main_map)
 	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold)
 	MCFG_WATCHDOG_VBLANK_INIT(400) // guess
 
-	MCFG_CPU_ADD("audiocpu", Z80, 16000000/2 )	/* 8 MHz ??? */
+	MCFG_CPU_ADD("audiocpu", Z80, XTAL_16MHz/2 )
 	MCFG_CPU_PROGRAM_MAP(sound_map)
 	MCFG_CPU_IO_MAP(io_map)
 
+	MCFG_MACHINE_START(tecmosys)
+
 	MCFG_GFXDECODE(tecmosys)
 
 	MCFG_EEPROM_93C46_ADD("eeprom")
@@ -889,30 +474,29 @@ static MACHINE_CONFIG_START( deroon, tecmosys_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(57.4458)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(3000))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(deroon)
+	MCFG_SCREEN_UPDATE_STATIC(tecmosys)
 
 	MCFG_PALETTE_LENGTH(0x4000+0x800)
 
-	MCFG_VIDEO_START(deroon)
+	MCFG_VIDEO_START(tecmosys)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MCFG_SOUND_ADD("ymf", YMF262, 14318180)
+	MCFG_SOUND_ADD("ymf", YMF262, XTAL_14_31818MHz)
 	MCFG_SOUND_CONFIG(tecmosys_ymf262_interface)
 	MCFG_SOUND_ROUTE(0, "lspeaker", 1.00)
 	MCFG_SOUND_ROUTE(1, "rspeaker", 1.00)
 	MCFG_SOUND_ROUTE(2, "lspeaker", 1.00)
 	MCFG_SOUND_ROUTE(3, "rspeaker", 1.00)
 
-	MCFG_OKIM6295_ADD("oki", 16000000/8, OKIM6295_PIN7_HIGH)
+	MCFG_OKIM6295_ADD("oki", XTAL_16MHz/8, OKIM6295_PIN7_HIGH)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.50)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.50)
 
-	MCFG_SOUND_ADD("ymz", YMZ280B, 16900000)
+	MCFG_SOUND_ADD("ymz", YMZ280B, XTAL_16_9344MHz)
 	MCFG_SOUND_ROUTE(0, "lspeaker", 0.30)
 	MCFG_SOUND_ROUTE(1, "rspeaker", 0.30)
 MACHINE_CONFIG_END
@@ -923,9 +507,8 @@ ROM_START( deroon )
 	ROM_LOAD16_BYTE( "t001.upau1", 0x00000, 0x80000, CRC(14b92c18) SHA1(b47b8c828222a3f7c0fe9271899bd38171d972fb) )
 	ROM_LOAD16_BYTE( "t002.upal1", 0x00001, 0x80000, CRC(0fb05c68) SHA1(5140592e15414770fb46d5ac9ba8f76e3d4ab323) )
 
-	ROM_REGION( 0x048000, "audiocpu", 0 ) // Sound Porgram
-	ROM_LOAD( "t003.uz1", 0x000000, 0x008000, CRC(8bdfafa0) SHA1(c0cf3eb7a65d967958fe2aace171859b0faf7753) )
-	ROM_CONTINUE(         0x010000, 0x038000 ) /* banked part */
+	ROM_REGION( 0x040000, "audiocpu", 0 ) // Sound Program
+	ROM_LOAD( "t003.uz1", 0x000000, 0x040000, CRC(8bdfafa0) SHA1(c0cf3eb7a65d967958fe2aace171859b0faf7753) )
 
 	ROM_REGION( 0x2200, "cpu2", 0 ) // MCU is a 68HC11A8 with 8k ROM, 512 bytes EEPROM
 	ROM_LOAD( "deroon_68hc11a8.rom",    0x0000, 0x2000, NO_DUMP )
@@ -965,9 +548,9 @@ ROM_START( tkdensho )
 	ROM_LOAD16_BYTE( "aeprge-2.pal", 0x00000, 0x80000, CRC(25e453d6) SHA1(9c84e2af42eff5cc9b14c1759d5bab42fa7bb663) )
 	ROM_LOAD16_BYTE( "aeprgo-2.pau", 0x00001, 0x80000, CRC(22d59510) SHA1(5ade482d6ab9a22df2ee8337458c22cfa9045c73) )
 
-	ROM_REGION( 0x038000, "audiocpu", 0 ) // Sound Porgram
-	ROM_LOAD( "aesprg-2.z1", 0x000000, 0x008000, CRC(43550ab6) SHA1(2580129ef8ebd9295249175de4ba985c752e06fe) )
-	ROM_CONTINUE(            0x010000, 0x018000 ) /* banked part */
+	ROM_REGION( 0x040000, "audiocpu", 0 ) // Sound Program
+	ROM_LOAD( "aesprg-2.z1", 0x000000, 0x020000, CRC(43550ab6) SHA1(2580129ef8ebd9295249175de4ba985c752e06fe) )
+	ROM_RELOAD(              0x020000, 0x020000) // for banks
 
 	ROM_REGION( 0x2200, "cpu2", 0 ) // MCU is a 68HC11A8 with 8k ROM, 512 bytes EEPROM
 	ROM_LOAD( "tkdensho_68hc11a8.rom",    0x0000, 0x2000, NO_DUMP )
@@ -996,7 +579,7 @@ ROM_START( tkdensho )
 	ROM_REGION( 0x100000, "gfx5", 0 ) // 16x16 4bpp tiles
 	ROM_LOAD( "ae202w76.bc1",  0x000000, 0x0100000, CRC(5cc857ca) SHA1(2553fb5220433acc15dfb726dc064fe333e51d88) )
 
-	ROM_REGION( 0x800000, "ymz", 0 ) // YMZ280B Samples
+	ROM_REGION( 0x400000, "ymz", 0 ) // YMZ280B Samples
 	ROM_LOAD( "ae400t23.ya1", 0x000000, 0x200000, CRC(c6ffb043) SHA1(e0c6c5f6b840f63c9a685a2c3be66efa4935cbeb) )
 	ROM_LOAD( "ae401t24.yb1", 0x200000, 0x200000, CRC(d83f1a73) SHA1(412b7ac9ff09a984c28b7d195330d78c4aac3dc5) )
 
@@ -1009,9 +592,9 @@ ROM_START( tkdenshoa )
 	ROM_LOAD16_BYTE( "aeprge.pal", 0x00000, 0x80000, CRC(17a209ff) SHA1(b5dbea9868cbb89d4e27bf19fdb616ac256985b4) )
 	ROM_LOAD16_BYTE( "aeprgo.pau", 0x00001, 0x80000, CRC(d265e6a1) SHA1(f39d8ce115f197a660f5210b2483108854eb12a9) )
 
-	ROM_REGION( 0x038000, "audiocpu", 0 ) // Sound Porgram
-	ROM_LOAD( "aesprg-2.z1", 0x000000, 0x008000, CRC(43550ab6) SHA1(2580129ef8ebd9295249175de4ba985c752e06fe) )
-	ROM_CONTINUE(            0x010000, 0x018000 ) /* banked part */
+	ROM_REGION( 0x040000, "audiocpu", 0 ) // Sound Program
+	ROM_LOAD( "aesprg-2.z1", 0x000000, 0x020000, CRC(43550ab6) SHA1(2580129ef8ebd9295249175de4ba985c752e06fe) )
+	ROM_RELOAD(              0x020000, 0x020000) // for banks
 
 	ROM_REGION( 0x2200, "cpu2", 0 ) // MCU is a 68HC11A8 with 8k ROM, 512 bytes EEPROM
 	ROM_LOAD( "tkdensho_68hc11a8.rom",    0x0000, 0x2000, NO_DUMP )
@@ -1040,7 +623,7 @@ ROM_START( tkdenshoa )
 	ROM_REGION( 0x100000, "gfx5", 0 ) // 16x16 4bpp tiles
 	ROM_LOAD( "ae202w76.bc1",  0x000000, 0x0100000, CRC(5cc857ca) SHA1(2553fb5220433acc15dfb726dc064fe333e51d88) )
 
-	ROM_REGION( 0x800000, "ymz", 0 ) // YMZ280B Samples
+	ROM_REGION( 0x400000, "ymz", 0 ) // YMZ280B Samples
 	ROM_LOAD( "ae400t23.ya1", 0x000000, 0x200000, CRC(c6ffb043) SHA1(e0c6c5f6b840f63c9a685a2c3be66efa4935cbeb) )
 	ROM_LOAD( "ae401t24.yb1", 0x200000, 0x200000, CRC(d83f1a73) SHA1(412b7ac9ff09a984c28b7d195330d78c4aac3dc5) )
 
@@ -1048,48 +631,46 @@ ROM_START( tkdenshoa )
 	ROM_LOAD( "ae500w07.ad1", 0x080000, 0x080000, CRC(3734f92c) SHA1(048555b5aa89eaf983305c439ba08d32b4a1bb80) )
 ROM_END
 
-static void tecmosys_decramble(running_machine &machine)
+static void tecmosys_descramble(running_machine &machine)
 {
-	UINT8 *gfxsrc    = machine.region       ( "gfx1" )->base();
-	size_t  srcsize = machine.region( "gfx1" )->bytes();
+	UINT8 *gfxsrc  = machine.region( "gfx1" )->base();
+	size_t srcsize = machine.region( "gfx1" )->bytes();
 	int i;
 
 	for (i=0; i < srcsize; i+=4)
 	{
 		UINT8 tmp[4];
 
-		tmp[2] = ((gfxsrc[i+0]&0xf0)>>0) | ((gfxsrc[i+1]&0xf0)>>4); //  0,1,2,3  8,9,10, 11
-		tmp[3] = ((gfxsrc[i+0]&0x0f)<<4) | ((gfxsrc[i+1]&0x0f)<<0); // 4,5,6,7, 12,13,14,15
-		tmp[0] = ((gfxsrc[i+2]&0xf0)>>0) | ((gfxsrc[i+3]&0xf0)>>4);// 16,17,18,19,24,25,26,27
-		tmp[1] = ((gfxsrc[i+2]&0x0f)<<4) | ((gfxsrc[i+3]&0x0f)>>0);// 20,21,22,23, 28,29,30,31
+		tmp[2] = ((gfxsrc[i+0]&0xf0)>>0) | ((gfxsrc[i+1]&0xf0)>>4); //  0, 1, 2, 3   8, 9,10,11
+		tmp[3] = ((gfxsrc[i+0]&0x0f)<<4) | ((gfxsrc[i+1]&0x0f)<<0); //  4, 5, 6, 7, 12,13,14,15
+		tmp[0] = ((gfxsrc[i+2]&0xf0)>>0) | ((gfxsrc[i+3]&0xf0)>>4); // 16,17,18,19, 24,25,26,27
+		tmp[1] = ((gfxsrc[i+2]&0x0f)<<4) | ((gfxsrc[i+3]&0x0f)>>0); // 20,21,22,23, 28,29,30,31
 
 		gfxsrc[i+0] = tmp[0];
 		gfxsrc[i+1] = tmp[1];
 		gfxsrc[i+2] = tmp[2];
 		gfxsrc[i+3] = tmp[3];
-
 	}
-
 }
 
 static DRIVER_INIT( deroon )
 {
-	tecmosys_decramble(machine);
-	tecmosys_prot_init(machine, 0);
+	tecmosys_descramble(machine);
+	tecmosys_prot_init(machine, 0); // machine/tecmosys.c
 }
 
 static DRIVER_INIT( tkdensho )
 {
-	tecmosys_decramble(machine);
+	tecmosys_descramble(machine);
 	tecmosys_prot_init(machine, 1);
 }
 
 static DRIVER_INIT( tkdensha )
 {
-	tecmosys_decramble(machine);
+	tecmosys_descramble(machine);
 	tecmosys_prot_init(machine, 2);
 }
 
 GAME( 1995, deroon,           0, deroon, deroon, deroon,     ROT0, "Tecmo", "Deroon DeroDero", 0 )
-GAME( 1996, tkdensho,         0, deroon, deroon, tkdensho,   ROT0, "Tecmo", "Touki Denshou -Angel Eyes- (VER. 960614)", 0 )
-GAME( 1996, tkdenshoa, tkdensho, deroon, deroon, tkdensha,   ROT0, "Tecmo", "Touki Denshou -Angel Eyes- (VER. 960427)", 0 )
+GAME( 1996, tkdensho,         0, deroon, deroon, tkdensho,   ROT0, "Tecmo", "Toukidenshou - Angel Eyes (VER. 960614)", 0 )
+GAME( 1996, tkdenshoa, tkdensho, deroon, deroon, tkdensha,   ROT0, "Tecmo", "Toukidenshou - Angel Eyes (VER. 960427)", 0 )
