@@ -240,8 +240,7 @@ static MACHINE_CONFIG_START( toobin, toobin_state )
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS(MASTER_CLOCK/2, 640, 0, 512, 416, 0, 384)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MCFG_SCREEN_UPDATE(toobin)
+	MCFG_SCREEN_UPDATE_STATIC(toobin)
 
 	MCFG_GFXDECODE(toobin)
 	MCFG_PALETTE_LENGTH(1024)
