@@ -186,9 +186,8 @@ static MACHINE_CONFIG_START( tourtabl, tourtabl_state )
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS( MASTER_CLOCK, 228, 34, 34 + 160, 262, 46, 46 + 200 )
-	MCFG_SCREEN_UPDATE(tia)
+	MCFG_SCREEN_UPDATE_STATIC(tia)
 
 	MCFG_PALETTE_LENGTH(TIA_PALETTE_LENGTH)
 	MCFG_PALETTE_INIT(tia_NTSC)
