@@ -198,10 +198,9 @@ static MACHINE_CONFIG_START( tryout, tryout_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
-	MCFG_SCREEN_UPDATE(tryout)
+	MCFG_SCREEN_UPDATE_STATIC(tryout)
 
 	MCFG_GFXDECODE(tryout)
 	MCFG_PALETTE_LENGTH(0x20)
