@@ -920,10 +920,9 @@ static MACHINE_CONFIG_START( tubep, tubep_state )
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 264)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(tubep)
+	MCFG_SCREEN_UPDATE_STATIC(tubep)
 
 	MCFG_PALETTE_LENGTH(32 + 256*64)
 
@@ -981,10 +980,9 @@ static MACHINE_CONFIG_START( rjammer, tubep_state )
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 264)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(rjammer)
+	MCFG_SCREEN_UPDATE_STATIC(rjammer)
 
 	MCFG_PALETTE_LENGTH(64)
 
