@@ -30,16 +30,16 @@ public:
 
 
 
-static SCREEN_UPDATE( ultrsprt )
+static SCREEN_UPDATE_IND16( ultrsprt )
 {
-	ultrsprt_state *state = screen->machine().driver_data<ultrsprt_state>();
+	ultrsprt_state *state = screen.machine().driver_data<ultrsprt_state>();
 	int i, j;
 
 	UINT8 *ram = (UINT8 *)state->m_vram;
 
 	for (j=0; j < 400; j++)
 	{
-		UINT16 *dest = BITMAP_ADDR16(bitmap, j, 0);
+		UINT16 *dest = &bitmap.pix16(j);
 		int fb_index = j * 1024;
 
 		for (i=0; i < 512; i++)
@@ -232,10 +232,9 @@ static MACHINE_CONFIG_START( ultrsprt, ultrsprt_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(512, 400)
 	MCFG_SCREEN_VISIBLE_AREA(0, 511, 0, 399)
-	MCFG_SCREEN_UPDATE(ultrsprt)
+	MCFG_SCREEN_UPDATE_STATIC(ultrsprt)
 
 	MCFG_PALETTE_LENGTH(8192)
 
