@@ -599,10 +599,9 @@ static MACHINE_CONFIG_START( burglarx, unico_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(0x180, 0xe0)
 	MCFG_SCREEN_VISIBLE_AREA(0, 0x180-1, 0, 0xe0-1)
-	MCFG_SCREEN_UPDATE(unico)
+	MCFG_SCREEN_UPDATE_STATIC(unico)
 
 	MCFG_GFXDECODE(unico)
 	MCFG_PALETTE_LENGTH(8192)
@@ -645,10 +644,9 @@ static MACHINE_CONFIG_START( zeropnt, unico_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(0x180, 0xe0)
 	MCFG_SCREEN_VISIBLE_AREA(0, 0x180-1, 0, 0xe0-1)
-	MCFG_SCREEN_UPDATE(unico)
+	MCFG_SCREEN_UPDATE_STATIC(unico)
 
 	MCFG_GFXDECODE(unico)
 	MCFG_PALETTE_LENGTH(8192)
@@ -688,10 +686,9 @@ static MACHINE_CONFIG_START( zeropnt2, unico_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(0x180, 0xe0)
 	MCFG_SCREEN_VISIBLE_AREA(0, 0x180-1, 0, 0xe0-1)
-	MCFG_SCREEN_UPDATE(zeropnt2)
+	MCFG_SCREEN_UPDATE_STATIC(zeropnt2)
 
 	MCFG_GFXDECODE(unico)
 	MCFG_PALETTE_LENGTH(8192)
