@@ -40,7 +40,7 @@ static PALETTE_INIT(vega)
 
 }
 
-static SCREEN_UPDATE(vega)
+static SCREEN_UPDATE_IND16(vega)
 {
 	return 0;
 }
@@ -53,10 +53,9 @@ static MACHINE_CONFIG_START( vega, vega_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 28*8-1)
-	MCFG_SCREEN_UPDATE(vega)
+	MCFG_SCREEN_UPDATE_STATIC(vega)
 
 	MCFG_PALETTE_LENGTH(0x100)
 
@@ -146,4 +145,4 @@ DRIVER_INIT(vegaa)
 }
 #endif
 
-GAME( 19??, vega,   0, vega, vega, 0, ROT270, "Olympia?", "Vega", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 19??, vega,   0, vega, vega, 0, ROT270, "Olympia?", "Vega", GAME_IS_SKELETON )
