@@ -16,33 +16,30 @@
 #include "videopin.lh"
 #include "sound/discrete.h"
 
-static attotime time_pushed;
-static attotime time_released;
 
-static UINT8 prev = 0;
-static UINT8 mask = 0;
 
 static WRITE8_DEVICE_HANDLER(videopin_out1_w);
 static WRITE8_DEVICE_HANDLER(videopin_out2_w);
 
 
-static void update_plunger(running_machine *machine)
+static void update_plunger(running_machine &machine)
 {
+	videopin_state *state = machine.driver_data<videopin_state>();
 	UINT8 val = input_port_read(machine, "IN2");
 
-	if (prev != val)
+	if (state->m_prev != val)
 	{
 		if (val == 0)
 		{
-			time_released = timer_get_time(machine);
+			state->m_time_released = machine.time();
 
-			if (!mask)
+			if (!state->m_mask)
 				cputag_set_input_line(machine, "maincpu", INPUT_LINE_NMI, ASSERT_LINE);
 		}
 		else
-			time_pushed = timer_get_time(machine);
+			state->m_time_pushed = machine.time();
 
-		prev = val;
+		state->m_prev = val;
 	}
 }
 
@@ -60,15 +57,15 @@ static TIMER_CALLBACK( interrupt_callback )
 	if (scanline >= 263)
 		scanline = 32;
 
-	timer_set(machine, machine->primary_screen->time_until_pos(scanline), NULL, scanline, interrupt_callback);
+	machine.scheduler().timer_set(machine.primary_screen->time_until_pos(scanline), FUNC(interrupt_callback), scanline);
 }
 
 
 static MACHINE_RESET( videopin )
 {
-	device_t *discrete = machine->device("discrete");
+	device_t *discrete = machine.device("discrete");
 
-	timer_set(machine, machine->primary_screen->time_until_pos(32), NULL, 32, interrupt_callback);
+	machine.scheduler().timer_set(machine.primary_screen->time_until_pos(32), FUNC(interrupt_callback), 32);
 
 	/* both output latches are cleared on reset */
 
@@ -77,15 +74,16 @@ static MACHINE_RESET( videopin )
 }
 
 
-static double calc_plunger_pos(running_machine *machine)
+static double calc_plunger_pos(running_machine &machine)
 {
-	return (attotime_to_double(timer_get_time(machine)) - attotime_to_double(time_released)) * (attotime_to_double(time_released) - attotime_to_double(time_pushed) + 0.2);
+	videopin_state *state = machine.driver_data<videopin_state>();
+	return (machine.time().as_double() - state->m_time_released.as_double()) * (state->m_time_released.as_double() - state->m_time_pushed.as_double() + 0.2);
 }
 
 
 static READ8_HANDLER( videopin_misc_r )
 {
-	double plunger = calc_plunger_pos(space->machine);
+	double plunger = calc_plunger_pos(space->machine());
 
 	// The plunger of the ball shooter has a black piece of
 	// plastic (flag) attached to it. When the plunger flag passes
@@ -96,7 +94,7 @@ static READ8_HANDLER( videopin_misc_r )
 	// signals received. This results in the MPU displaying the
 	// ball being shot onto the playfield at a certain speed.
 
-	UINT8 val = input_port_read(space->machine, "IN1");
+	UINT8 val = input_port_read(space->machine(), "IN1");
 
 	if (plunger >= 0.000 && plunger <= 0.001)
 	{
@@ -113,7 +111,7 @@ static READ8_HANDLER( videopin_misc_r )
 
 static WRITE8_HANDLER( videopin_led_w )
 {
-	int i = (space->machine->primary_screen->vpos() >> 5) & 7;
+	int i = (space->machine().primary_screen->vpos() >> 5) & 7;
 	static const char *const matrix[8][4] =
 	{
 		{ "LED26", "LED18", "LED11", "LED13" },
@@ -132,14 +130,15 @@ static WRITE8_HANDLER( videopin_led_w )
 	output_set_value(matrix[i][3], (data >> 3) & 1);
 
 	if (i == 7)
-		set_led_status(space->machine, 0, data & 8);   /* start button */
+		set_led_status(space->machine(), 0, data & 8);   /* start button */
 
-	cputag_set_input_line(space->machine, "maincpu", 0, CLEAR_LINE);
+	cputag_set_input_line(space->machine(), "maincpu", 0, CLEAR_LINE);
 }
 
 
 static WRITE8_DEVICE_HANDLER( videopin_out1_w )
 {
+	videopin_state *state = device->machine().driver_data<videopin_state>();
 	/* D0 => OCTAVE0  */
 	/* D1 => OCTACE1  */
 	/* D2 => OCTAVE2  */
@@ -149,12 +148,12 @@ static WRITE8_DEVICE_HANDLER( videopin_out1_w )
 	/* D6 => NOT USED */
 	/* D7 => NOT USED */
 
-	mask = ~data & 0x10;
+	state->m_mask = ~data & 0x10;
 
-	if (mask)
-		cputag_set_input_line(device->machine, "maincpu", INPUT_LINE_NMI, CLEAR_LINE);
+	if (state->m_mask)
+		cputag_set_input_line(device->machine(), "maincpu", INPUT_LINE_NMI, CLEAR_LINE);
 
-	coin_lockout_global_w(device->machine, ~data & 0x08);
+	coin_lockout_global_w(device->machine(), ~data & 0x08);
 
 	/* Convert octave data to divide value and write to sound */
 	discrete_sound_w(device, VIDEOPIN_OCTAVE_DATA, (0x01 << (~data & 0x07)) & 0xfe);
@@ -172,7 +171,7 @@ static WRITE8_DEVICE_HANDLER( videopin_out2_w )
 	/* D6 => BELL      */
 	/* D7 => ATTRACT   */
 
-	coin_counter_w(device->machine, 0, data & 0x10);
+	coin_counter_w(device->machine(), 0, data & 0x10);
 
 	discrete_sound_w(device, VIDEOPIN_BELL_EN, data & 0x40);	// Bell
 	discrete_sound_w(device, VIDEOPIN_BONG_EN, data & 0x20);	// Bong
@@ -194,9 +193,9 @@ static WRITE8_DEVICE_HANDLER( videopin_note_dvsr_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x01ff) AM_RAM
-	AM_RANGE(0x0200, 0x07ff) AM_RAM_WRITE(videopin_video_ram_w) AM_BASE(&videopin_video_ram)
+	AM_RANGE(0x0200, 0x07ff) AM_RAM_WRITE(videopin_video_ram_w) AM_BASE_MEMBER(videopin_state, m_video_ram)
 	AM_RANGE(0x0800, 0x0800) AM_READ(videopin_misc_r) AM_DEVWRITE("discrete", videopin_note_dvsr_w)
 	AM_RANGE(0x0801, 0x0801) AM_WRITE(videopin_led_w)
 	AM_RANGE(0x0802, 0x0802) AM_WRITE(watchdog_reset_w)
@@ -321,7 +320,7 @@ GFXDECODE_END
  *
  *************************************/
 
-static MACHINE_CONFIG_START( videopin, driver_device )
+static MACHINE_CONFIG_START( videopin, videopin_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6502, 12096000 / 16)
@@ -332,16 +331,15 @@ static MACHINE_CONFIG_START( videopin, driver_device )
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(304, 263)
 	MCFG_SCREEN_VISIBLE_AREA(0, 303, 0, 255)
+	MCFG_SCREEN_UPDATE_STATIC(videopin)
 
 	MCFG_GFXDECODE(videopin)
 	MCFG_PALETTE_LENGTH(2)
 
 	MCFG_PALETTE_INIT(black_and_white)
 	MCFG_VIDEO_START(videopin)
-	MCFG_VIDEO_UPDATE(videopin)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
