@@ -15,7 +15,6 @@ likewise be a 2 screen game
 ***************************************************************************/
 #include "emu.h"
 #include "cpu/m68000/m68000.h"
-#include "deprecat.h"
 #include "video/konicdev.h"
 #include "machine/eeprom.h"
 #include "cpu/z80/z80.h"
@@ -55,6 +54,7 @@ static WRITE16_HANDLER( eeprom_w )
 		/* bit 2 is data */
 		/* bit 3 is clock (active high) */
 		/* bit 4 is cs (active low) */
+		/* bit 5 is enabled in IRQ3, disabled in IRQ5 (sprite DMA start?) */
 		input_port_write(space->machine(), "EEPROMOUT", data, 0xff);
 	}
 	if (ACCESSING_BITS_8_15)
@@ -88,10 +88,12 @@ static WRITE16_HANDLER( sound_irq_w )
 
 static WRITE16_HANDLER( xmen_18fa00_w )
 {
+	xmen_state *state = space->machine().driver_data<xmen_state>();
+
 	if(ACCESSING_BITS_0_7)
 	{
 		/* bit 2 is interrupt enable */
-		interrupt_enable_w(space, 0, data & 0x04);
+		state->m_vblank_irq_mask = data & 0x04;
 	}
 }
 
@@ -258,8 +260,8 @@ INPUT_PORTS_END
 
 static CUSTOM_INPUT( xmen_frame_r )
 {
-	xmen_state *state = field.machine().driver_data<xmen_state>();
-	return state->m_current_frame;
+	//xmen_state *state = field.machine().driver_data<xmen_state>();
+	return field.machine().primary_screen->frame_number() & 1;
 }
 
 static INPUT_PORTS_START( xmen6p )
@@ -295,15 +297,6 @@ static INPUT_PORTS_START( xmen6p )
 INPUT_PORTS_END
 
 
-
-static INTERRUPT_GEN( xmen_interrupt )
-{
-	if (cpu_getiloops(device) == 0)
-		irq5_line_hold(device);
-	else
-		irq3_line_hold(device);
-}
-
 static MACHINE_START( xmen )
 {
 	xmen_state *state = machine.driver_data<xmen_state>();
@@ -325,6 +318,7 @@ static MACHINE_START( xmen )
 	state->save_item(NAME(state->m_sprite_colorbase));
 	state->save_item(NAME(state->m_layer_colorbase));
 	state->save_item(NAME(state->m_layerpri));
+	state->save_item(NAME(state->m_vblank_irq_mask));
 	machine.save().register_postload(save_prepost_delegate(FUNC(sound_reset_bank), &machine));
 }
 
@@ -341,6 +335,7 @@ static MACHINE_RESET( xmen )
 
 	state->m_sprite_colorbase = 0;
 	state->m_sound_curbank = 0;
+	state->m_vblank_irq_mask = 0;
 }
 
 static const k052109_interface xmen_k052109_intf =
@@ -361,12 +356,26 @@ static const k053247_interface xmen_k053246_intf =
 	xmen_sprite_callback
 };
 
+static TIMER_DEVICE_CALLBACK( xmen_scanline )
+{
+	xmen_state *state = timer.machine().driver_data<xmen_state>();
+	int scanline = param;
+
+	if(scanline == 240 && state->m_vblank_irq_mask) // vblank-out irq
+		cputag_set_input_line(timer.machine(), "maincpu", 3, HOLD_LINE);
+
+	if(scanline == 0) // sprite DMA irq?
+		cputag_set_input_line(timer.machine(), "maincpu", 5, HOLD_LINE);
+
+}
+
+
 static MACHINE_CONFIG_START( xmen, xmen_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000, XTAL_16MHz)	/* verified on pcb */
 	MCFG_CPU_PROGRAM_MAP(main_map)
-	MCFG_CPU_VBLANK_INT_HACK(xmen_interrupt,2)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", xmen_scanline, "screen", 0, 1)
 
 	MCFG_CPU_ADD("audiocpu", Z80, XTAL_16MHz/2)	/* verified on pcb */
 	MCFG_CPU_PROGRAM_MAP(sound_map)
@@ -382,10 +391,9 @@ static MACHINE_CONFIG_START( xmen, xmen_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(59.17)   /* verified on pcb */
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(13*8, (64-13)*8-1, 2*8, 30*8-1 )	/* correct, same issue of TMNT2 */
-	MCFG_SCREEN_UPDATE(xmen)
+	MCFG_SCREEN_UPDATE_STATIC(xmen)
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_K052109_ADD("k052109", xmen_k052109_intf)
@@ -404,41 +412,6 @@ static MACHINE_CONFIG_START( xmen, xmen_state )
 	MCFG_SOUND_ROUTE(1, "rspeaker", 0.80)
 MACHINE_CONFIG_END
 
-
-static MACHINE_START( xmen6p )
-{
-	xmen_state *state = machine.driver_data<xmen_state>();
-
-	MACHINE_START_CALL(xmen);
-
-	state->save_item(NAME(state->m_current_frame));
-}
-
-static MACHINE_RESET( xmen6p )
-{
-	xmen_state *state = machine.driver_data<xmen_state>();
-	state->m_current_frame = 0x00;
-}
-
-static INTERRUPT_GEN( xmen6p_interrupt )
-{
-	if (cpu_getiloops(device) == 0)
-	{
-		irq5_line_hold(device);
-
-
-	}
-	else
-	{
-//      if (xmen_irqenabled & 0x04)
-//      {
-			irq3_line_hold(device);
-//          state->m_current_frame = 0x00;
-
-//      }
-	}
-}
-
 static const k053247_interface xmen6p_k053246_intf =
 {
 	"lscreen",	/* is this correct? */
@@ -454,13 +427,13 @@ static MACHINE_CONFIG_START( xmen6p, xmen_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000, 16000000)	/* ? */
 	MCFG_CPU_PROGRAM_MAP(6p_main_map)
-	MCFG_CPU_VBLANK_INT_HACK(xmen6p_interrupt,2)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", xmen_scanline, "lscreen", 0, 1)
 
 	MCFG_CPU_ADD("audiocpu", Z80,8000000)	/* verified with M1, guessed but accurate */
 	MCFG_CPU_PROGRAM_MAP(sound_map)
 
-	MCFG_MACHINE_START(xmen6p)
-	MCFG_MACHINE_RESET(xmen6p)
+	MCFG_MACHINE_START(xmen)
+	MCFG_MACHINE_RESET(xmen)
 
 	MCFG_EEPROM_ADD("eeprom", eeprom_intf)
 
@@ -470,21 +443,19 @@ static MACHINE_CONFIG_START( xmen6p, xmen_state )
 	MCFG_DEFAULT_LAYOUT(layout_dualhsxs)
 
 	MCFG_SCREEN_ADD("lscreen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(12*8, 48*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(xmen6p)
+	MCFG_SCREEN_UPDATE_STATIC(xmen6p_left)
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(16*8, 52*8-1, 2*8, 30*8-1)
-	MCFG_SCREEN_UPDATE(xmen6p)
-	MCFG_SCREEN_EOF(xmen6p)
+	MCFG_SCREEN_UPDATE_STATIC(xmen6p_right)
+	MCFG_SCREEN_VBLANK_STATIC(xmen6p)
 
 	MCFG_VIDEO_START(xmen6p)
 
@@ -645,6 +616,35 @@ ROM_START( xmene )
 	ROM_LOAD( "xmen_eba.nv", 0x0000, 0x0080, CRC(37f8e77a) SHA1(0b92caba33486c6fd104806aa96f735743bb2221) )
 ROM_END
 
+
+ROM_START( xmena )
+	ROM_REGION( 0x100000, "maincpu", 0 )
+	ROM_LOAD16_BYTE( "065-ada.10d",  0x00000, 0x20000, CRC(b8276624) SHA1(5b601393faa4bf578d84b590eb2360ad400368a5) ) /* Asia 4 Player version */
+	ROM_LOAD16_BYTE( "065-ada.10f",  0x00001, 0x20000, CRC(c68582ad) SHA1(d2ca23cc0ad08e7f3d5c533f6fe43d4c215c114e) )
+	ROM_LOAD16_BYTE( "065-a02.9d",     0x80000, 0x40000, CRC(b31dc44c) SHA1(4bdac05826b4d6d4fe46686ede5190e2f73eefc5) )
+	ROM_LOAD16_BYTE( "065-a03.9f",     0x80001, 0x40000, CRC(13842fe6) SHA1(b61f094eb94336edb8708d3437ead9b853b2d6e6) )
+
+	ROM_REGION( 0x30000, "audiocpu", 0 )		/* 64k+128k for sound cpu */
+	ROM_LOAD( "065-a01.6f",   0x00000, 0x20000, CRC(147d3a4d) SHA1(a14409fe991e803b9e7812303e3a9ebd857d8b01) )
+	ROM_RELOAD(               0x10000, 0x20000 )
+
+	ROM_REGION( 0x200000, "gfx1", 0 )	/* graphics (addressable by the main CPU) */
+	ROM_LOAD( "065-a08.15l",   0x000000, 0x100000, CRC(6b649aca) SHA1(2595f314517738e8614facf578cc951a6c36a180) )	/* tiles */
+	ROM_LOAD( "065-a07.16l",   0x100000, 0x100000, CRC(c5dc8fc4) SHA1(9887cb002c8b72be7ce933cb397f00cdc5506c8c) )
+
+	ROM_REGION( 0x400000, "gfx2", 0 )	/* graphics (addressable by the main CPU) */
+	ROM_LOAD( "065-a09.2h",  0x000000, 0x100000, CRC(ea05d52f) SHA1(7f2c14f907355856fb94e3a67b73aa1919776835) )	/* sprites */
+	ROM_LOAD( "065-a10.2l",  0x100000, 0x100000, CRC(96b91802) SHA1(641943557b59b91f0edd49ec8a73cef7d9268b32) )
+	ROM_LOAD( "065-a12.1h",  0x200000, 0x100000, CRC(321ed07a) SHA1(5b00ed676daeea974bdce6701667cfe573099dad) )
+	ROM_LOAD( "065-a11.1l",  0x300000, 0x100000, CRC(46da948e) SHA1(168ac9178ee5bad5931557fb549e1237971d7839) )
+
+	ROM_REGION( 0x200000, "k054539", 0 )	/* samples for the 054539 */
+	ROM_LOAD( "065-a06.1f",  0x000000, 0x200000, CRC(5adbcee0) SHA1(435feda697193bc51db80eba46be474cbbc1de4b) )
+
+	ROM_REGION16_BE( 0x80, "eeprom", 0 )
+	ROM_LOAD( "xmen_ada.nv", 0x0000, 0x0080, CRC(a77a3891) SHA1(84ec257790d5c1859ffcbc9371a72ea99d7f8928) )
+ROM_END
+
 ROM_START( xmen2pe )
 	ROM_REGION( 0x100000, "maincpu", 0 )
 	ROM_LOAD16_BYTE( "065-eaa04.10d",  0x00000, 0x20000, CRC(502861e7) SHA1(f96aab2d2006703065de5bd7e341f929d04f5f60) ) /* Europe 2 Player version */
@@ -840,9 +840,10 @@ ROM_START( xmen6pu )
 	ROM_LOAD( "xmen_ucb.nv", 0x0000, 0x0080, CRC(f3d0f682) SHA1(b0d4655c651238ae028ffb59a704acba798f93f8) )
 ROM_END
 
-GAME( 1992, xmen,    0,    xmen,   xmen,    0,   ROT0, "Konami", "X-Men (4 Players ver UBB)", GAME_SUPPORTS_SAVE ) /* Second "version" letter denotes players, A=2 players, B=4 players, C=6 players ??? */
+GAME( 1992, xmen,    0,    xmen,   xmen,    0,   ROT0, "Konami", "X-Men (4 Players ver UBB)", GAME_SUPPORTS_SAVE ) /* Second "version" letter denotes players, A=2 players, D/B=4 players, C=6 players ??? */
 GAME( 1992, xmenj,   xmen, xmen,   xmen,    0,   ROT0, "Konami", "X-Men (4 Players ver JBA)", GAME_SUPPORTS_SAVE )
 GAME( 1992, xmene,   xmen, xmen,   xmen,    0,   ROT0, "Konami", "X-Men (4 Players ver EBA)", GAME_SUPPORTS_SAVE )
+GAME( 1992, xmena,   xmen, xmen,   xmen,    0,   ROT0, "Konami", "X-Men (4 Players ver ADA)", GAME_SUPPORTS_SAVE )
 GAME( 1992, xmen2pe, xmen, xmen,   xmen2p,  0,   ROT0, "Konami", "X-Men (2 Players ver EAA)", GAME_SUPPORTS_SAVE )
 GAME( 1992, xmen2pa, xmen, xmen,   xmen2p,  0,   ROT0, "Konami", "X-Men (2 Players ver AAA)", GAME_SUPPORTS_SAVE )
 GAME( 1992, xmen2pj, xmen, xmen,   xmen2p,  0,   ROT0, "Konami", "X-Men (2 Players ver JAA)", GAME_SUPPORTS_SAVE )
