@@ -94,7 +94,7 @@ _________________________|___________________________
 #include "includes/yiear.h"
 
 
-static READ8_DEVICE_HANDLER( yiear_speech_r )
+READ8_DEVICE_HANDLER( yiear_speech_r )
 {
 	if (vlm5030_bsy(device))
 		return 1;
@@ -102,40 +102,48 @@ static READ8_DEVICE_HANDLER( yiear_speech_r )
 		return 0;
 }
 
-static WRITE8_DEVICE_HANDLER( yiear_VLM5030_control_w )
+WRITE8_DEVICE_HANDLER( yiear_VLM5030_control_w )
 {
 	/* bit 0 is latch direction */
 	vlm5030_st(device, (data >> 1) & 1);
 	vlm5030_rst(device, (data >> 2) & 1);
 }
 
-static INTERRUPT_GEN( yiear_nmi_interrupt )
+static INTERRUPT_GEN( yiear_vblank_interrupt )
 {
-	yiear_state *state = device->machine->driver_data<yiear_state>();
+	yiear_state *state = device->machine().driver_data<yiear_state>();
 
-	/* can't use nmi_line_pulse() because interrupt_enable_w() effects it */
-	if (state->yiear_nmi_enable)
-		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
+	if (state->m_yiear_irq_enable)
+		device_set_input_line(device, 0, HOLD_LINE);
 }
 
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static INTERRUPT_GEN( yiear_nmi_interrupt )
+{
+	yiear_state *state = device->machine().driver_data<yiear_state>();
+
+	if (state->m_yiear_nmi_enable)
+		device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
+}
+
+
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0000) AM_DEVREAD("vlm", yiear_speech_r)
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(yiear_control_w)
 	AM_RANGE(0x4800, 0x4800) AM_WRITE(konami_SN76496_latch_w)
 	AM_RANGE(0x4900, 0x4900) AM_DEVWRITE("snsnd", konami_SN76496_w)
 	AM_RANGE(0x4a00, 0x4a00) AM_DEVWRITE("vlm", yiear_VLM5030_control_w)
 	AM_RANGE(0x4b00, 0x4b00) AM_DEVWRITE("vlm", vlm5030_data_w)
-	AM_RANGE(0x4c00, 0x4c00) AM_READ_PORT("DSW1")
-	AM_RANGE(0x4d00, 0x4d00) AM_READ_PORT("DSW2")
+	AM_RANGE(0x4c00, 0x4c00) AM_READ_PORT("DSW2")
+	AM_RANGE(0x4d00, 0x4d00) AM_READ_PORT("DSW3")
 	AM_RANGE(0x4e00, 0x4e00) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x4e01, 0x4e01) AM_READ_PORT("P1")
 	AM_RANGE(0x4e02, 0x4e02) AM_READ_PORT("P2")
-	AM_RANGE(0x4e03, 0x4e03) AM_READ_PORT("DSW3")
+	AM_RANGE(0x4e03, 0x4e03) AM_READ_PORT("DSW1")
 	AM_RANGE(0x4f00, 0x4f00) AM_WRITE(watchdog_reset_w)
-	AM_RANGE(0x5000, 0x502f) AM_RAM AM_BASE_SIZE_MEMBER(yiear_state, spriteram, spriteram_size)
-	AM_RANGE(0x5400, 0x542f) AM_RAM AM_BASE_MEMBER(yiear_state, spriteram2)
-	AM_RANGE(0x5800, 0x5fff) AM_WRITE(yiear_videoram_w) AM_BASE_MEMBER(yiear_state, videoram)
+	AM_RANGE(0x5000, 0x502f) AM_RAM AM_BASE_SIZE_MEMBER(yiear_state, m_spriteram, m_spriteram_size)
+	AM_RANGE(0x5400, 0x542f) AM_RAM AM_BASE_MEMBER(yiear_state, m_spriteram2)
+	AM_RANGE(0x5800, 0x5fff) AM_WRITE(yiear_videoram_w) AM_BASE_MEMBER(yiear_state, m_videoram)
 	AM_RANGE(0x5000, 0x5fff) AM_RAM
 	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
@@ -159,7 +167,7 @@ static INPUT_PORTS_START( yiear )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1) PORT_CODE("NONE")
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1) /*WTF? PORT_CODE("NONE")*/
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START("P2")
@@ -169,44 +177,45 @@ static INPUT_PORTS_START( yiear )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_COCKTAIL PORT_CODE("NONE")
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_COCKTAIL /*WTF? PORT_CODE("NONE")*/
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START("DSW1")
-	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Lives ) )
+	KONAMI_COINAGE_LOC(DEF_STR( Free_Play ), "Invalid", SW1)
+	/* "Invalid" = both coin slots disabled */
+
+	PORT_START("DSW2")
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )		PORT_DIPLOCATION("SW2:1,2")
 	PORT_DIPSETTING(    0x03, "1" )
 	PORT_DIPSETTING(    0x02, "2" )
 	PORT_DIPSETTING(    0x01, "3" )
 	PORT_DIPSETTING(    0x00, "5" )
-	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Cabinet ) )
+	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Cabinet ) )		PORT_DIPLOCATION("SW2:3")
 	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( Cocktail ) )
-	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Bonus_Life ) )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Bonus_Life ) )	PORT_DIPLOCATION("SW2:4")
 	PORT_DIPSETTING(    0x08, "30000 80000" )
 	PORT_DIPSETTING(    0x00, "40000 90000" )
-	PORT_DIPNAME( 0x30, 0x10, DEF_STR( Difficulty ) )
+	PORT_DIPNAME( 0x30, 0x10, DEF_STR( Difficulty ) )	PORT_DIPLOCATION("SW2:5,6")
 	PORT_DIPSETTING(    0x30, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( Normal ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( Difficult ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Very_Difficult ) )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) )
+	PORT_DIPUNUSED_DIPLOC( 0x40, IP_ACTIVE_LOW, "SW2:7" )
+	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) )	PORT_DIPLOCATION("SW2:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START("DSW2")
-	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Flip_Screen ) )
+	PORT_START("DSW3")
+	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Flip_Screen ) )	PORT_DIPLOCATION("SW3:1")
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x02, "Upright Controls" )
+	PORT_DIPNAME( 0x02, 0x02, "Upright Controls" )		PORT_DIPLOCATION("SW3:2")
 	PORT_DIPSETTING(    0x02, DEF_STR( Single ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Dual ) )
-	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
-	PORT_BIT( 0xf8, IP_ACTIVE_LOW, IPT_UNUSED )
-
-	PORT_START("DSW3")
-	KONAMI_COINAGE(DEF_STR( Free_Play ), "Invalid")
-	/* "Invalid" = both coin slots disabled */
+	PORT_SERVICE_DIPLOC( 0x04, IP_ACTIVE_LOW, "SW3:3" )
+	PORT_DIPUNUSED_DIPLOC( 0x08, IP_ACTIVE_LOW, "SW3:4" )
+	PORT_BIT( 0xf0, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
 
@@ -244,16 +253,16 @@ GFXDECODE_END
 
 static MACHINE_START( yiear )
 {
-	yiear_state *state = machine->driver_data<yiear_state>();
+	yiear_state *state = machine.driver_data<yiear_state>();
 
-	state_save_register_global(machine, state->yiear_nmi_enable);
+	state->save_item(NAME(state->m_yiear_nmi_enable));
 }
 
 static MACHINE_RESET( yiear )
 {
-	yiear_state *state = machine->driver_data<yiear_state>();
+	yiear_state *state = machine.driver_data<yiear_state>();
 
-	state->yiear_nmi_enable = 0;
+	state->m_yiear_nmi_enable = 0;
 }
 
 static MACHINE_CONFIG_START( yiear, yiear_state )
@@ -261,7 +270,7 @@ static MACHINE_CONFIG_START( yiear, yiear_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6809,XTAL_18_432MHz/12)   /* verified on pcb */
 	MCFG_CPU_PROGRAM_MAP(main_map)
-	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_VBLANK_INT("screen", yiear_vblank_interrupt)
 	MCFG_CPU_PERIODIC_INT(yiear_nmi_interrupt,480)	/* music tempo (correct frequency unknown) */
 
 	MCFG_MACHINE_START(yiear)
@@ -271,16 +280,15 @@ static MACHINE_CONFIG_START( yiear, yiear_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60.58)   /* verified on pcb */
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE_STATIC(yiear)
 
 	MCFG_GFXDECODE(yiear)
 	MCFG_PALETTE_LENGTH(32)
 
 	MCFG_PALETTE_INIT(yiear)
 	MCFG_VIDEO_START(yiear)
-	MCFG_VIDEO_UPDATE(yiear)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
