@@ -42,4 +42,4 @@ void _88games_sprite_callback(running_machine &machine, int *code, int *color, i
 void _88games_tile_callback(running_machine &machine, int layer, int bank, int *code, int *color, int *flags, int *priority);
 void _88games_zoom_callback(running_machine &machine, int *code, int *color, int *flags);
 
-SCREEN_UPDATE( 88games );
+SCREEN_UPDATE_IND16( 88games );
