@@ -9,24 +9,24 @@
 class arabian_state : public driver_device
 {
 public:
-	arabian_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	arabian_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *  blitter;
-	UINT8 *  custom_cpu_ram;
+	UINT8 *  m_blitter;
+	UINT8 *  m_custom_cpu_ram;
 
-	UINT8 *  main_bitmap;
-	UINT8 *  converted_gfx;
+	UINT8 *  m_main_bitmap;
+	UINT8 *  m_converted_gfx;
 
 	/* video-related */
-	UINT8    video_control;
-	UINT8    flip_screen;
+	UINT8    m_video_control;
+	UINT8    m_flip_screen;
 
 	/* MCU */
-	UINT8    mcu_port_o;
-	UINT8    mcu_port_p;
-	UINT8    mcu_port_r[4];
+	UINT8    m_mcu_port_o;
+	UINT8    m_mcu_port_p;
+	UINT8    m_mcu_port_r[4];
 };
 
 
@@ -37,4 +37,4 @@ WRITE8_HANDLER( arabian_videoram_w );
 
 PALETTE_INIT( arabian );
 VIDEO_START( arabian );
-VIDEO_UPDATE( arabian );
+SCREEN_UPDATE_IND16( arabian );
