@@ -22,16 +22,18 @@ extern const pia6821_interface atarixl_pia_interface;
 READ8_DEVICE_HANDLER(atari_pia_pa_r);
 READ8_DEVICE_HANDLER(atari_pia_pb_r);
 WRITE8_DEVICE_HANDLER(a600xl_pia_pb_w);
+WRITE_LINE_DEVICE_HANDLER(atari_pia_cb2_w);
+
 
 /* This is needed in MESS as well for Atari 8bit drivers */
-void atari_machine_start(running_machine *machine);
+void atari_machine_start(running_machine &machine);
 
 MACHINE_START( atarixl );
 
 void atari_interrupt_cb(device_t *device, int mask);
 
-void a800_handle_keyboard(running_machine *machine);
-void a5200_handle_keypads(running_machine *machine);
+void a800_handle_keyboard(running_machine &machine);
+void a5200_handle_keypads(running_machine &machine);
 
 /* video */
 
@@ -257,6 +259,7 @@ typedef struct {
 	UINT8   *uc_g1;				/* used colors for gfx GTIA 1 */
 	UINT8   *uc_g2;				/* used colors for gfx GTIA 2 */
 	UINT8   *uc_g3;				/* used colors for gfx GTIA 3 */
+	bitmap_ind16 *bitmap;
 }   ANTIC;
 
 #define RDANTIC(space)		space->read_byte(antic.dpage+antic.doffs)
@@ -586,18 +589,14 @@ extern char atari_frame_message[64+1];
 extern int atari_frame_counter;
 
 extern VIDEO_START( atari );
-extern VIDEO_UPDATE( atari );
+extern SCREEN_UPDATE_IND16( atari );
 
-INTERRUPT_GEN( a400_interrupt );
-INTERRUPT_GEN( a800_interrupt );
-INTERRUPT_GEN( a800xl_interrupt );
-INTERRUPT_GEN( a5200_interrupt );
+TIMER_DEVICE_CALLBACK( a400_interrupt );
+TIMER_DEVICE_CALLBACK( a800_interrupt );
+TIMER_DEVICE_CALLBACK( a800xl_interrupt );
+TIMER_DEVICE_CALLBACK( a5200_interrupt );
 
 extern PALETTE_INIT( atari );
 
-/*----------- defined in drivers/maxaflex.c -----------*/
-
-int atari_input_disabled(void);
-
 #endif /* ATARI_H */
 
