@@ -19,6 +19,8 @@ public:
 	tilemap_t *m_cj_tilemap;
 	UINT8   m_flipscreen;
 	UINT16  m_bgcolor;
+
+	UINT8	m_nmi_mask;
 };
 
 
@@ -32,6 +34,6 @@ WRITE8_HANDLER( carjmbre_videoram_w );
 
 PALETTE_INIT( carjmbre );
 VIDEO_START( carjmbre );
-SCREEN_UPDATE( carjmbre );
+SCREEN_UPDATE_IND16( carjmbre );
 
 
