@@ -44,4 +44,4 @@ WRITE8_HANDLER( cbasebal_scrollx_w );
 WRITE8_HANDLER( cbasebal_scrolly_w );
 
 VIDEO_START( cbasebal );
-SCREEN_UPDATE( cbasebal );
+SCREEN_UPDATE_IND16( cbasebal );
