@@ -7,17 +7,26 @@
 class centiped_state : public driver_device
 {
 public:
-	centiped_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	centiped_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT8 *videoram;
+	UINT8 *m_videoram;
+	UINT8 m_oldpos[4];
+	UINT8 m_sign[4];
+	UINT8 m_dsw_select;
+	UINT8 m_control_select;
+	UINT8 *m_rambase;
+	UINT8 m_flipscreen;
+	UINT8 *m_bullsdrt_tiles_bankram;
+	tilemap_t *m_bg_tilemap;
+	UINT8 m_bullsdrt_sprites_bank;
+	UINT8 m_penmask[64];
+	UINT8 *m_spriteram;
 };
 
 
 /*----------- defined in video/centiped.c -----------*/
 
-extern UINT8 centiped_flipscreen, *bullsdrt_tiles_bankram;
-
 PALETTE_INIT( warlords );
 
 VIDEO_START( centiped );
@@ -25,10 +34,10 @@ VIDEO_START( milliped );
 VIDEO_START( warlords );
 VIDEO_START( bullsdrt );
 
-VIDEO_UPDATE( centiped );
-VIDEO_UPDATE( milliped );
-VIDEO_UPDATE( warlords );
-VIDEO_UPDATE( bullsdrt );
+SCREEN_UPDATE_IND16( centiped );
+SCREEN_UPDATE_IND16( milliped );
+SCREEN_UPDATE_IND16( warlords );
+SCREEN_UPDATE_IND16( bullsdrt );
 
 WRITE8_HANDLER( centiped_paletteram_w );
 WRITE8_HANDLER( milliped_paletteram_w );
@@ -39,4 +48,3 @@ WRITE8_HANDLER( bullsdrt_tilesbank_w );
 WRITE8_HANDLER( bullsdrt_sprites_bank_w );
 
 WRITE8_HANDLER( mazeinv_paletteram_w );
-
