@@ -32,6 +32,8 @@ public:
 	device_t *m_maincpu;
 	device_t *m_audiocpu;
 	device_t *m_mcu;
+
+	UINT8          m_irq_mask;
 };
 
 
@@ -46,7 +48,7 @@ PALETTE_INIT( champbas );
 PALETTE_INIT( exctsccr );
 VIDEO_START( champbas );
 VIDEO_START( exctsccr );
-SCREEN_UPDATE( champbas );
-SCREEN_UPDATE( exctsccr );
+SCREEN_UPDATE_IND16( champbas );
+SCREEN_UPDATE_IND16( exctsccr );
 
 
