@@ -7,23 +7,24 @@
 class citycon_state : public driver_device
 {
 public:
-	citycon_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	citycon_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *        videoram;
-	UINT8 *        linecolor;
-	UINT8 *        scroll;
-	UINT8 *        spriteram;
-//  UINT8 *        paletteram;  // currently this uses generic palette handling
-	size_t         spriteram_size;
+	UINT8 *        m_videoram;
+	UINT8 *        m_linecolor;
+	UINT8 *        m_scroll;
+	UINT8 *        m_spriteram;
+//  UINT8 *        m_paletteram;  // currently this uses generic palette handling
+	size_t         m_spriteram_size;
 
 	/* video-related */
-	tilemap_t        *bg_tilemap,*fg_tilemap;
-	int            bg_image;
+	tilemap_t        *m_bg_tilemap;
+	tilemap_t        *m_fg_tilemap;
+	int            m_bg_image;
 
 	/* devices */
-	device_t *maincpu;
+	device_t *m_maincpu;
 };
 
 
@@ -33,5 +34,5 @@ WRITE8_HANDLER( citycon_videoram_w );
 WRITE8_HANDLER( citycon_linecolor_w );
 WRITE8_HANDLER( citycon_background_w );
 
-VIDEO_UPDATE( citycon );
+SCREEN_UPDATE_IND16( citycon );
 VIDEO_START( citycon );
