@@ -40,5 +40,5 @@ WRITE8_HANDLER( commando_scrolly_w );
 WRITE8_HANDLER( commando_c804_w );
 
 VIDEO_START( commando );
-SCREEN_UPDATE( commando );
-SCREEN_EOF( commando );
+SCREEN_UPDATE_IND16( commando );
+SCREEN_VBLANK( commando );
