@@ -2,5 +2,7 @@
 
 void eolith_speedup_read(address_space *space);
 void init_eolith_speedup(running_machine &machine);
-INTERRUPT_GEN( eolith_speedup );
+TIMER_DEVICE_CALLBACK( eolith_speedup );
 CUSTOM_INPUT( eolith_speedup_getvblank );
+CUSTOM_INPUT( stealsee_speedup_getvblank );
+
