@@ -54,6 +54,6 @@ WRITE16_HANDLER( f1gp2_gfxctrl_w );
 VIDEO_START( f1gp );
 VIDEO_START( f1gpb );
 VIDEO_START( f1gp2 );
-SCREEN_UPDATE( f1gp );
-SCREEN_UPDATE( f1gpb );
-SCREEN_UPDATE( f1gp2 );
+SCREEN_UPDATE_IND16( f1gp );
+SCREEN_UPDATE_IND16( f1gpb );
+SCREEN_UPDATE_IND16( f1gp2 );
