@@ -19,6 +19,9 @@ public:
 	UINT8 m_starfield_control[4];
 	int m_total_stars;
 	struct star m_stars[MAX_STARS];
+	UINT8 m_main_irq_mask;
+	UINT8 m_sub_irq_mask;
+	UINT8 m_sub2_irq_mask;
 };
 
 
@@ -35,5 +38,5 @@ WRITE8_HANDLER( gaplus_videoram_w );
 WRITE8_HANDLER( gaplus_starfield_control_w );
 VIDEO_START( gaplus );
 PALETTE_INIT( gaplus );
-SCREEN_UPDATE( gaplus );
-SCREEN_EOF( gaplus );	/* update starfields */
+SCREEN_UPDATE_IND16( gaplus );
+SCREEN_VBLANK( gaplus );	/* update starfields */
