@@ -66,8 +66,8 @@ VIDEO_START( reikaids );
 VIDEO_START( pteacher );
 VIDEO_START( lemnangl );
 VIDEO_START( mirderby );
-SCREEN_UPDATE( mrokumei );
-SCREEN_UPDATE( reikaids );
-SCREEN_UPDATE( pteacher );
-SCREEN_UPDATE( mirderby );
-SCREEN_EOF( homedata );
+SCREEN_UPDATE_IND16( mrokumei );
+SCREEN_UPDATE_IND16( reikaids );
+SCREEN_UPDATE_IND16( pteacher );
+SCREEN_UPDATE_IND16( mirderby );
+SCREEN_VBLANK( homedata );
