@@ -67,14 +67,14 @@ VIDEO_START( spelunkr );
 VIDEO_START( spelunk2 );
 VIDEO_START( youjyudn );
 
-SCREEN_UPDATE( battroad );
-SCREEN_UPDATE( horizon );
-SCREEN_UPDATE( kidniki );
-SCREEN_UPDATE( kungfum );
-SCREEN_UPDATE( ldrun );
-SCREEN_UPDATE( ldrun3 );
-SCREEN_UPDATE( ldrun4 );
-SCREEN_UPDATE( lotlot );
-SCREEN_UPDATE( spelunkr );
-SCREEN_UPDATE( spelunk2 );
-SCREEN_UPDATE( youjyudn );
+SCREEN_UPDATE_IND16( battroad );
+SCREEN_UPDATE_IND16( horizon );
+SCREEN_UPDATE_IND16( kidniki );
+SCREEN_UPDATE_IND16( kungfum );
+SCREEN_UPDATE_IND16( ldrun );
+SCREEN_UPDATE_IND16( ldrun3 );
+SCREEN_UPDATE_IND16( ldrun4 );
+SCREEN_UPDATE_IND16( lotlot );
+SCREEN_UPDATE_IND16( spelunkr );
+SCREEN_UPDATE_IND16( spelunk2 );
+SCREEN_UPDATE_IND16( youjyudn );
