@@ -7,10 +7,14 @@ public:
 	UINT8 *m_videoram;
 	UINT8 *m_spriteram;
 	tilemap_t *m_bg_tilemap;
-	bitmap_t *m_sprite_bitmap;
+	bitmap_ind16 m_sprite_bitmap;
 
 	UINT8 m_scroll;
 	int m_mux;
+
+	UINT8 m_main_irq_mask;
+	UINT8 m_sub_irq_mask;
+	UINT8 m_sub2_irq_mask;
 };
 
 
@@ -18,14 +22,14 @@ public:
 
 VIDEO_START( phozon );
 PALETTE_INIT( phozon );
-SCREEN_UPDATE( phozon );
+SCREEN_UPDATE_IND16( phozon );
 
 PALETTE_INIT( superpac );
 PALETTE_INIT( mappy );
 VIDEO_START( superpac );
 VIDEO_START( mappy );
-SCREEN_UPDATE( superpac );
-SCREEN_UPDATE( mappy );
+SCREEN_UPDATE_IND16( superpac );
+SCREEN_UPDATE_IND16( mappy );
 WRITE8_HANDLER( superpac_videoram_w );
 WRITE8_HANDLER( mappy_videoram_w );
 WRITE8_HANDLER( mappy_scroll_w );
