@@ -2,32 +2,43 @@
 class mexico86_state : public driver_device
 {
 public:
-	mexico86_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	mexico86_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *     protection_ram;
-	UINT8 *     videoram;
-	UINT8 *     objectram;
-	size_t      objectram_size;
+	UINT8 *     m_protection_ram;
+	UINT8 *     m_videoram;
+	UINT8 *     m_objectram;
+	size_t      m_objectram_size;
 
 	/* video-related */
-	int      charbank;
+	int      m_charbank;
 
 	/* mcu */
 	/* mexico86 68705 protection */
-	UINT8    port_a_in, port_a_out, ddr_a;
-	UINT8    port_b_in, port_b_out, ddr_b;
-	int      address, latch;
+	UINT8    m_port_a_in;
+	UINT8    m_port_a_out;
+	UINT8    m_ddr_a;
+	UINT8    m_port_b_in;
+	UINT8    m_port_b_out;
+	UINT8    m_ddr_b;
+	int      m_address;
+	int      m_latch;
 	/* kikikai mcu simulation */
-	int      mcu_running, mcu_initialised;
-	int      coin_last;
+	int      m_mcu_running;
+	int      m_mcu_initialised;
+	int      m_coin_last;
 
 	/* devices */
-	device_t *maincpu;
-	device_t *audiocpu;
-	device_t *subcpu;
-	device_t *mcu;
+	device_t *m_maincpu;
+	device_t *m_audiocpu;
+	device_t *m_subcpu;
+	device_t *m_mcu;
+
+	/* queue */
+	UINT8 m_queue[64];
+	int m_qfront;
+	int m_qstate;
 };
 
 
@@ -48,5 +59,5 @@ WRITE8_HANDLER( mexico86_68705_ddr_b_w );
 
 WRITE8_HANDLER( mexico86_bankswitch_w );
 
-VIDEO_UPDATE( mexico86 );
-VIDEO_UPDATE( kikikai );
+SCREEN_UPDATE_IND16( mexico86 );
+SCREEN_UPDATE_IND16( kikikai );
