@@ -22,7 +22,7 @@ public:
 extern UINT32 *zeusbase;
 
 VIDEO_START( midzeus );
-SCREEN_UPDATE( midzeus );
+SCREEN_UPDATE_IND16( midzeus );
 
 READ32_HANDLER( zeus_r );
 WRITE32_HANDLER( zeus_w );
@@ -30,7 +30,7 @@ WRITE32_HANDLER( zeus_w );
 /*----------- defined in video/midzeus2.c -----------*/
 
 VIDEO_START( midzeus2 );
-SCREEN_UPDATE( midzeus2 );
+SCREEN_UPDATE_RGB32( midzeus2 );
 
 READ32_HANDLER( zeus2_r );
 WRITE32_HANDLER( zeus2_w );
