@@ -36,4 +36,4 @@ WRITE16_HANDLER( ohmygod_scrollx_w );
 WRITE16_HANDLER( ohmygod_scrolly_w );
 
 VIDEO_START( ohmygod );
-SCREEN_UPDATE( ohmygod );
+SCREEN_UPDATE_IND16( ohmygod );
