@@ -37,5 +37,5 @@ WRITE16_HANDLER( othldrby_vreg_addr_w );
 WRITE16_HANDLER( othldrby_vreg_w );
 
 VIDEO_START( othldrby );
-SCREEN_EOF( othldrby );
-SCREEN_UPDATE( othldrby );
+SCREEN_VBLANK( othldrby );
+SCREEN_UPDATE_IND16( othldrby );
