@@ -39,4 +39,4 @@ extern void overdriv_sprite_callback(running_machine &machine, int *code,int *co
 extern void overdriv_zoom_callback_0(running_machine &machine, int *code,int *color,int *flags);
 extern void overdriv_zoom_callback_1(running_machine &machine, int *code,int *color,int *flags);
 
-SCREEN_UPDATE( overdriv );
+SCREEN_UPDATE_IND16( overdriv );
