@@ -3,7 +3,10 @@ class pgm_state : public driver_device
 {
 public:
 	pgm_state(const machine_config &mconfig, device_type type, const char *tag)
-		: driver_device(mconfig, type, tag) { }
+		: driver_device(mconfig, type, tag)
+		{
+			m_irq4_disabled = 0;
+		}
 
 	/* memory pointers */
 //  UINT16 *      m_mainram;  // currently this is also used by nvram handler
@@ -25,9 +28,31 @@ public:
 	tilemap_t       *m_bg_tilemap;
 	tilemap_t     *m_tx_tilemap;
 	UINT16        *m_sprite_temp_render;
-	bitmap_t      *m_tmppgmbitmap;
+	bitmap_rgb32      m_tmppgmbitmap;
 
-	/* misc */
+	/* devices */
+	cpu_device *m_maincpu;
+	cpu_device *m_soundcpu;
+	cpu_device *m_prot;
+	device_t *m_ics;
+
+	/* used by rendering */
+	UINT8 *m_bdata;
+	size_t  m_bdatasize;
+	int m_aoffset;
+	int m_boffset;
+
+	/* hack */
+	int m_irq4_disabled;
+
+	/* calendar */
+	UINT8        m_cal_val;
+	UINT8        m_cal_mask;
+	UINT8        m_cal_com;
+	UINT8        m_cal_cnt;
+	system_time  m_systime;
+
+	/* protection handling */
 	// kov2
 	UINT32        m_kov2_latchdata_68k_w;
 	UINT32        m_kov2_latchdata_arm_w;
@@ -71,20 +96,20 @@ public:
 	UINT16        m_asic_params[256];
 	UINT16        m_asic28_rcnt;
 	UINT32        m_eoregs[16];
+	// Oldsplus simulation
+	UINT16        m_oldsplus_key;
+	UINT16        m_oldsplus_int[2];
+	UINT32        m_oldsplus_val;
+	UINT16        m_oldsplus_ram[0x100];
+	UINT32        m_oldsplus_regs[0x100];
 
-	/* calendar */
-	UINT8        m_cal_val;
-	UINT8        m_cal_mask;
-	UINT8        m_cal_com;
-	UINT8        m_cal_cnt;
-	system_time  m_systime;
 
-	/* devices */
-	cpu_device *m_soundcpu;
-	cpu_device *m_prot;
-	device_t *m_ics;
 };
 
+
+
+
+
 extern UINT16 *pgm_mainram;	// used by nvram handler, we cannot move it to driver data struct
 
 /*----------- defined in machine/pgmcrypt.c -----------*/
@@ -128,11 +153,18 @@ WRITE16_HANDLER( asic28_w );
 READ16_HANDLER( dw2_d80000_r );
 
 
+READ16_HANDLER( oldsplus_protram_r );
+READ16_HANDLER( oldsplus_r );
+WRITE16_HANDLER( oldsplus_w );
+
+MACHINE_RESET( kov );
+void install_protection_asic_sim_kov(running_machine &machine);
+
 /*----------- defined in video/pgm.c -----------*/
 
 WRITE16_HANDLER( pgm_tx_videoram_w );
 WRITE16_HANDLER( pgm_bg_videoram_w );
 
 VIDEO_START( pgm );
-SCREEN_EOF( pgm );
-SCREEN_UPDATE( pgm );
+SCREEN_VBLANK( pgm );
+SCREEN_UPDATE_IND16( pgm );
