@@ -1,10 +1,30 @@
 class pitnrun_state : public driver_device
 {
 public:
-	pitnrun_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	pitnrun_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT8 *videoram;
+	UINT8 *m_videoram;
+	int m_nmi;
+	UINT8* m_videoram2;
+	UINT8 m_fromz80;
+	UINT8 m_toz80;
+	int m_zaccept;
+	int m_zready;
+	UINT8 m_portA_in;
+	UINT8 m_portA_out;
+	int m_address;
+	int m_h_heed;
+	int m_v_heed;
+	int m_ha;
+	int m_scroll;
+	int m_char_bank;
+	int m_color_select;
+	bitmap_ind16 *m_tmp_bitmap[4];
+	tilemap_t *m_bg;
+	tilemap_t *m_fg;
+	UINT8 *m_spriteram;
+	size_t m_spriteram_size;
 };
 
 
@@ -26,8 +46,6 @@ WRITE8_HANDLER( pitnrun_mcu_data_w );
 
 /*----------- defined in video/pitnrun.c -----------*/
 
-extern UINT8* pitnrun_videoram2;
-
 WRITE8_HANDLER( pitnrun_videoram_w );
 WRITE8_HANDLER( pitnrun_videoram2_w );
 WRITE8_HANDLER(pitnrun_ha_w);
@@ -39,4 +57,4 @@ WRITE8_HANDLER( pitnrun_scroll_w );
 
 PALETTE_INIT(pitnrun);
 VIDEO_START(pitnrun);
-VIDEO_UPDATE(pitnrun);
+SCREEN_UPDATE_IND16(pitnrun);
