@@ -3,8 +3,11 @@ class qdrmfgp_state : public driver_device
 public:
 	qdrmfgp_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag),
-		  m_nvram(*this, "nvram") { }
+		m_maincpu(*this, "maincpu"),
+		m_nvram(*this, "nvram")
+		{ }
 
+	required_device<cpu_device> m_maincpu;
 	required_shared_ptr<UINT8>	m_nvram;
 	UINT8 *m_sndram;
 	UINT16 *m_workram;
@@ -17,7 +20,7 @@ public:
 
 VIDEO_START( qdrmfgp );
 VIDEO_START( qdrmfgp2 );
-SCREEN_UPDATE( qdrmfgp );
+SCREEN_UPDATE_IND16( qdrmfgp );
 
 void qdrmfgp_tile_callback(running_machine &machine, int layer, int *code, int *color, int *flags);
 void qdrmfgp2_tile_callback(running_machine &machine, int layer, int *code, int *color, int *flags);
