@@ -42,7 +42,7 @@ MACHINE_START( simpsons );
 /*----------- defined in video/simpsons.c -----------*/
 
 void simpsons_video_banking( running_machine &machine, int select );
-SCREEN_UPDATE( simpsons );
+SCREEN_UPDATE_IND16( simpsons );
 
 extern void simpsons_tile_callback(running_machine &machine, int layer,int bank,int *code,int *color,int *flags,int *priority);
 extern void simpsons_sprite_callback(running_machine &machine, int *code,int *color,int *priority_mask);
