@@ -1,20 +1,20 @@
 class snk68_state : public driver_device
 {
 public:
-	snk68_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	snk68_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	int invert_controls;
-	int sound_status;
+	int m_invert_controls;
+	int m_sound_status;
 
-	UINT16* pow_fg_videoram;
+	UINT16* m_pow_fg_videoram;
 
-	UINT16 *spriteram;
-	UINT16 *paletteram;
-	int sprite_flip_axis;
-	tilemap_t *fg_tilemap;
-	int flipscreen;
-	UINT32 fg_tile_offset;
+	UINT16 *m_spriteram;
+	UINT16 *m_paletteram;
+	int m_sprite_flip_axis;
+	tilemap_t *m_fg_tilemap;
+	int m_flipscreen;
+	UINT32 m_fg_tile_offset;
 };
 
 
@@ -22,7 +22,7 @@ public:
 
 VIDEO_START( pow );
 VIDEO_START( searchar );
-VIDEO_UPDATE( pow );
+SCREEN_UPDATE_IND16( pow );
 WRITE16_HANDLER( pow_paletteram16_word_w );
 WRITE16_HANDLER( pow_flipscreen16_w );
 WRITE16_HANDLER( searchar_flipscreen16_w );
