@@ -2,7 +2,9 @@ class spdodgeb_state : public driver_device
 {
 public:
 	spdodgeb_state(const machine_config &mconfig, device_type type, const char *tag)
-		: driver_device(mconfig, type, tag) { }
+		: driver_device(mconfig, type, tag),
+		m_maincpu(*this,"maincpu")
+		{ }
 
 	int m_toggle;
 	int m_adpcm_pos[2];
@@ -29,6 +31,8 @@ public:
 	int m_lastscroll;
 	UINT8 *m_spriteram;
 	size_t m_spriteram_size;
+
+	required_device<cpu_device> m_maincpu;
 };
 
 
@@ -36,8 +40,8 @@ public:
 
 PALETTE_INIT( spdodgeb );
 VIDEO_START( spdodgeb );
-SCREEN_UPDATE( spdodgeb );
-INTERRUPT_GEN( spdodgeb_interrupt );
+SCREEN_UPDATE_IND16( spdodgeb );
+TIMER_DEVICE_CALLBACK( spdodgeb_interrupt );
 WRITE8_HANDLER( spdodgeb_scrollx_lo_w );
 WRITE8_HANDLER( spdodgeb_ctrl_w );
 WRITE8_HANDLER( spdodgeb_videoram_w );
