@@ -13,6 +13,7 @@ public:
 	UINT8 *m_vram3;
 	UINT8 *m_vram4;
 	UINT8 *m_scrollram;
+	UINT8 *m_buffer_spriteram;
 };
 
 
@@ -23,5 +24,6 @@ WRITE8_HANDLER(ssrj_vram2_w);
 WRITE8_HANDLER(ssrj_vram4_w);
 
 VIDEO_START( ssrj );
-SCREEN_UPDATE( ssrj );
+SCREEN_UPDATE_IND16( ssrj );
+SCREEN_VBLANK( ssrj );
 PALETTE_INIT( ssrj );
