@@ -34,4 +34,4 @@ public:
 extern void surpratk_tile_callback(running_machine &machine, int layer,int bank,int *code,int *color,int *flags,int *priority);
 extern void surpratk_sprite_callback(running_machine &machine, int *code,int *color,int *priority_mask);
 
-SCREEN_UPDATE( surpratk );
+SCREEN_UPDATE_IND16( surpratk );
