@@ -17,13 +17,15 @@ public:
 	UINT8 m_yscroll[2];
 	UINT8 *m_spriteram;
 	size_t m_spriteram_size;
+
+	UINT8 m_irq_mask;
 };
 
 
 /*----------- defined in video/tankbust.c -----------*/
 
 VIDEO_START( tankbust );
-SCREEN_UPDATE( tankbust );
+SCREEN_UPDATE_IND16( tankbust );
 
 WRITE8_HANDLER( tankbust_background_videoram_w );
 READ8_HANDLER( tankbust_background_videoram_r );
