@@ -37,4 +37,4 @@ WRITE8_HANDLER( timeplt_flipscreen_w );
 PALETTE_INIT( timeplt );
 VIDEO_START( timeplt );
 VIDEO_START( chkun );
-SCREEN_UPDATE( timeplt );
+SCREEN_UPDATE_IND16( timeplt );
