@@ -16,4 +16,4 @@ WRITE8_HANDLER( usgames_videoram_w );
 WRITE8_HANDLER( usgames_charram_w );
 VIDEO_START( usgames );
 PALETTE_INIT( usgames );
-SCREEN_UPDATE( usgames );
+SCREEN_UPDATE_IND16( usgames );
