@@ -14,17 +14,17 @@ public:
 	int        m_layerpri[3];
 
 	/* for xmen6p */
-	bitmap_t   *m_screen_right;
-	bitmap_t   *m_screen_left;
+	bitmap_ind16   *m_screen_right;
+	bitmap_ind16   *m_screen_left;
 	UINT16 *   m_xmen6p_spriteramleft;
 	UINT16 *   m_xmen6p_spriteramright;
 	UINT16 *   m_xmen6p_tilemapleft;
 	UINT16 *   m_xmen6p_tilemapright;
 	UINT16 *   m_k053247_ram;
-	UINT16     m_current_frame;
 
 	/* misc */
 	UINT8       m_sound_curbank;
+	UINT8       m_vblank_irq_mask;
 
 	/* devices */
 	device_t *m_maincpu;
@@ -43,6 +43,7 @@ void xmen_tile_callback(running_machine &machine, int layer,int bank,int *code,i
 void xmen_sprite_callback(running_machine &machine, int *code,int *color,int *priority_mask);
 
 VIDEO_START( xmen6p );
-SCREEN_UPDATE( xmen );
-SCREEN_UPDATE( xmen6p );
-SCREEN_EOF( xmen6p );
+SCREEN_UPDATE_IND16( xmen );
+SCREEN_UPDATE_IND16( xmen6p_left );
+SCREEN_UPDATE_IND16( xmen6p_right );
+SCREEN_VBLANK( xmen6p );
