@@ -9,7 +9,6 @@
 #include "includes/dc.h"
 #include "cpu/sh4/sh4.h"
 #include "sound/aica.h"
-#include "includes/naomibd.h"
 #include "includes/naomi.h"
 #include "machine/mie.h"
 
@@ -21,8 +20,6 @@
 #define DEBUG_AICA_DMA (0)
 #define DEBUG_PVRCTRL	(0)
 
-static UINT8 mp_mux_data;
-
 #if DEBUG_SYSCTRL
 static const char *const sysctrl_names[] =
 {
@@ -79,81 +76,65 @@ static const char *const sysctrl_names[] =
 
 #endif
 
-UINT32 dc_sysctrl_regs[0x200/4];
-static UINT32 dc_rtcregister[4];
-UINT32 g1bus_regs[0x100/4];
-static UINT32 g2bus_regs[0x100/4];
-static emu_timer *dc_rtc_timer;
-
-static struct {
-	UINT32 aica_addr;
-	UINT32 root_addr;
-	UINT32 size;
-	UINT8 dir;
-	UINT8 flag;
-	UINT8 indirect;
-	UINT8 start;
-	UINT8 sel;
-}wave_dma;
-
-static struct {
-	UINT32 pvr_addr;
-	UINT32 sys_addr;
-	UINT32 size;
-	UINT8 sel;
-	UINT8 dir;
-	UINT8 flag;
-	UINT8 start;
-}pvr_dma;
-
 static TIMER_CALLBACK( aica_dma_irq )
 {
-	wave_dma.start = g2bus_regs[SB_ADST] = 0;
-	dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_AICA;
+	dc_state *state = machine.driver_data<dc_state>();
+
+	state->m_wave_dma.start = state->g2bus_regs[SB_ADST] = 0;
+	state->dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_AICA;
 	dc_update_interrupt_status(machine);
 }
 
 static TIMER_CALLBACK( pvr_dma_irq )
 {
-	pvr_dma.start = pvrctrl_regs[SB_PDST] = 0;
-	dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_PVR;
+	dc_state *state = machine.driver_data<dc_state>();
+
+	state->m_pvr_dma.start = state->pvrctrl_regs[SB_PDST] = 0;
+	state->dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_PVR;
 	dc_update_interrupt_status(machine);
 }
 
-static TIMER_CALLBACK( gdrom_dma_irq )
+void naomi_g1_irq(running_machine &machine)
 {
-	g1bus_regs[SB_GDST] = 0;
-	dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_GDROM;
+	dc_state *state = machine.driver_data<dc_state>();
+
+	state->dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_GDROM;
 	dc_update_interrupt_status(machine);
 }
 
 static TIMER_CALLBACK( ch2_dma_irq )
 {
-	dc_sysctrl_regs[SB_C2DLEN]=0;
-	dc_sysctrl_regs[SB_C2DST]=0;
-	dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_CH2;
+	dc_state *state = machine.driver_data<dc_state>();
+
+	state->dc_sysctrl_regs[SB_C2DLEN]=0;
+	state->dc_sysctrl_regs[SB_C2DST]=0;
+	state->dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_CH2;
 	dc_update_interrupt_status(machine);
 }
 
 static TIMER_CALLBACK( yuv_fifo_irq )
 {
-	dc_sysctrl_regs[SB_ISTNRM] |= IST_EOXFER_YUV;
+	dc_state *state = machine.driver_data<dc_state>();
+
+	state->dc_sysctrl_regs[SB_ISTNRM] |= IST_EOXFER_YUV;
 	dc_update_interrupt_status(machine);
 }
 
 static void wave_dma_execute(address_space *space)
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
+
 	UINT32 src,dst,size;
-	dst = wave_dma.aica_addr;
-	src = wave_dma.root_addr;
+	dst = state->m_wave_dma.aica_addr;
+	src = state->m_wave_dma.root_addr;
 	size = 0;
 
 	/* 0 rounding size = 32 Mbytes */
-	if(wave_dma.size == 0) { wave_dma.size = 0x200000; }
+	if(state->m_wave_dma.size == 0) { state->m_wave_dma.size = 0x200000; }
 
-	if(wave_dma.dir == 0)
+	if(state->m_wave_dma.dir == 0)
 	{
-		for(;size<wave_dma.size;size+=4)
+		for(;size<state->m_wave_dma.size;size+=4)
 		{
 			space->write_dword(dst,space->read_dword(src));
 			src+=4;
@@ -162,7 +143,7 @@ static void wave_dma_execute(address_space *space)
 	}
 	else
 	{
-		for(;size<wave_dma.size;size+=4)
+		for(;size<state->m_wave_dma.size;size+=4)
 		{
 			space->write_dword(src,space->read_dword(dst));
 			src+=4;
@@ -171,10 +152,10 @@ static void wave_dma_execute(address_space *space)
 	}
 
 	/* update the params*/
-	wave_dma.aica_addr = g2bus_regs[SB_ADSTAG] = dst;
-	wave_dma.root_addr = g2bus_regs[SB_ADSTAR] = src;
-	wave_dma.size = g2bus_regs[SB_ADLEN] = 0;
-	wave_dma.flag = (wave_dma.indirect & 1) ? 1 : 0;
+	state->m_wave_dma.aica_addr = state->g2bus_regs[SB_ADSTAG] = dst;
+	state->m_wave_dma.root_addr = state->g2bus_regs[SB_ADSTAR] = src;
+	state->m_wave_dma.size = state->g2bus_regs[SB_ADLEN] = 0;
+	state->m_wave_dma.flag = (state->m_wave_dma.indirect & 1) ? 1 : 0;
 	/* Note: if you trigger an instant DMA IRQ trigger, sfz3upper doesn't play any bgm. */
 	/* TODO: timing of this */
 	space->machine().scheduler().timer_set(attotime::from_usec(300), FUNC(aica_dma_irq));
@@ -182,22 +163,24 @@ static void wave_dma_execute(address_space *space)
 
 static void pvr_dma_execute(address_space *space)
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
+
 	UINT32 src,dst,size;
-	dst = pvr_dma.pvr_addr;
-	src = pvr_dma.sys_addr;
+	dst = state->m_pvr_dma.pvr_addr;
+	src = state->m_pvr_dma.sys_addr;
 	size = 0;
 
 	/* used so far by usagui and sprtjam*/
 	//printf("PVR-DMA start\n");
-	//printf("%08x %08x %08x\n",pvr_dma.pvr_addr,pvr_dma.sys_addr,pvr_dma.size);
-	//printf("src %s dst %08x\n",pvr_dma.dir ? "->" : "<-",pvr_dma.sel);
+	//printf("%08x %08x %08x\n",state->m_pvr_dma.pvr_addr,state->m_pvr_dma.sys_addr,state->m_pvr_dma.size);
+	//printf("src %s dst %08x\n",state->m_pvr_dma.dir ? "->" : "<-",state->m_pvr_dma.sel);
 
 	/* 0 rounding size = 16 Mbytes */
-	if(pvr_dma.size == 0) { pvr_dma.size = 0x100000; }
+	if(state->m_pvr_dma.size == 0) { state->m_pvr_dma.size = 0x100000; }
 
-	if(pvr_dma.dir == 0)
+	if(state->m_pvr_dma.dir == 0)
 	{
-		for(;size<pvr_dma.size;size+=4)
+		for(;size<state->m_pvr_dma.size;size+=4)
 		{
 			space->write_dword(dst,space->read_dword(src));
 			src+=4;
@@ -206,7 +189,7 @@ static void pvr_dma_execute(address_space *space)
 	}
 	else
 	{
-		for(;size<pvr_dma.size;size+=4)
+		for(;size<state->m_pvr_dma.size;size+=4)
 		{
 			space->write_dword(src,space->read_dword(dst));
 			src+=4;
@@ -269,27 +252,28 @@ INLINE int decode_reg3216_64(running_machine &machine, UINT32 offset, UINT64 mem
 
 int dc_compute_interrupt_level(running_machine &machine)
 {
+	dc_state *state = machine.driver_data<dc_state>();
 	UINT32 ln,lx,le;
 
-	ln=dc_sysctrl_regs[SB_ISTNRM] & dc_sysctrl_regs[SB_IML6NRM];
-	lx=dc_sysctrl_regs[SB_ISTEXT] & dc_sysctrl_regs[SB_IML6EXT];
-	le=dc_sysctrl_regs[SB_ISTERR] & dc_sysctrl_regs[SB_IML6ERR];
+	ln=state->dc_sysctrl_regs[SB_ISTNRM] & state->dc_sysctrl_regs[SB_IML6NRM];
+	lx=state->dc_sysctrl_regs[SB_ISTEXT] & state->dc_sysctrl_regs[SB_IML6EXT];
+	le=state->dc_sysctrl_regs[SB_ISTERR] & state->dc_sysctrl_regs[SB_IML6ERR];
 	if (ln | lx | le)
 	{
 		return 6;
 	}
 
-	ln=dc_sysctrl_regs[SB_ISTNRM] & dc_sysctrl_regs[SB_IML4NRM];
-	lx=dc_sysctrl_regs[SB_ISTEXT] & dc_sysctrl_regs[SB_IML4EXT];
-	le=dc_sysctrl_regs[SB_ISTERR] & dc_sysctrl_regs[SB_IML4ERR];
+	ln=state->dc_sysctrl_regs[SB_ISTNRM] & state->dc_sysctrl_regs[SB_IML4NRM];
+	lx=state->dc_sysctrl_regs[SB_ISTEXT] & state->dc_sysctrl_regs[SB_IML4EXT];
+	le=state->dc_sysctrl_regs[SB_ISTERR] & state->dc_sysctrl_regs[SB_IML4ERR];
 	if (ln | lx | le)
 	{
 		return 4;
 	}
 
-	ln=dc_sysctrl_regs[SB_ISTNRM] & dc_sysctrl_regs[SB_IML2NRM];
-	lx=dc_sysctrl_regs[SB_ISTEXT] & dc_sysctrl_regs[SB_IML2EXT];
-	le=dc_sysctrl_regs[SB_ISTERR] & dc_sysctrl_regs[SB_IML2ERR];
+	ln=state->dc_sysctrl_regs[SB_ISTNRM] & state->dc_sysctrl_regs[SB_IML2NRM];
+	lx=state->dc_sysctrl_regs[SB_ISTEXT] & state->dc_sysctrl_regs[SB_IML2EXT];
+	le=state->dc_sysctrl_regs[SB_ISTERR] & state->dc_sysctrl_regs[SB_IML2ERR];
 	if (ln | lx | le)
 	{
 		return 2;
@@ -300,33 +284,34 @@ int dc_compute_interrupt_level(running_machine &machine)
 
 void dc_update_interrupt_status(running_machine &machine)
 {
+	dc_state *state = machine.driver_data<dc_state>();
 	int level;
 
-	if (dc_sysctrl_regs[SB_ISTERR])
+	if (state->dc_sysctrl_regs[SB_ISTERR])
 	{
-		dc_sysctrl_regs[SB_ISTNRM] |= IST_ERROR;
+		state->dc_sysctrl_regs[SB_ISTNRM] |= IST_ERROR;
 	}
 	else
 	{
-		dc_sysctrl_regs[SB_ISTNRM] &= ~IST_ERROR;
+		state->dc_sysctrl_regs[SB_ISTNRM] &= ~IST_ERROR;
 	}
 
-	if (dc_sysctrl_regs[SB_ISTEXT])
+	if (state->dc_sysctrl_regs[SB_ISTEXT])
 	{
-		dc_sysctrl_regs[SB_ISTNRM] |= IST_G1G2EXTSTAT;
+		state->dc_sysctrl_regs[SB_ISTNRM] |= IST_G1G2EXTSTAT;
 	}
 	else
 	{
-		dc_sysctrl_regs[SB_ISTNRM] &= ~IST_G1G2EXTSTAT;
+		state->dc_sysctrl_regs[SB_ISTNRM] &= ~IST_G1G2EXTSTAT;
 	}
 
 	level=dc_compute_interrupt_level(machine);
 	sh4_set_irln_input(machine.device("maincpu"), 15-level);
 
 	/* Wave DMA HW trigger */
-	if(wave_dma.flag && ((wave_dma.sel & 2) == 2))
+	if(state->m_wave_dma.flag && ((state->m_wave_dma.sel & 2) == 2))
 	{
-		if((dc_sysctrl_regs[SB_G2DTNRM] & dc_sysctrl_regs[SB_ISTNRM]) || (dc_sysctrl_regs[SB_G2DTEXT] & dc_sysctrl_regs[SB_ISTEXT]))
+		if((state->dc_sysctrl_regs[SB_G2DTNRM] & state->dc_sysctrl_regs[SB_ISTNRM]) || (state->dc_sysctrl_regs[SB_G2DTEXT] & state->dc_sysctrl_regs[SB_ISTEXT]))
 		{
 			address_space *space = machine.device("maincpu")->memory().space(AS_PROGRAM);
 
@@ -336,9 +321,9 @@ void dc_update_interrupt_status(running_machine &machine)
 	}
 
 	/* PVR-DMA HW trigger */
-	if(pvr_dma.flag && ((pvr_dma.sel & 1) == 1))
+	if(state->m_pvr_dma.flag && ((state->m_pvr_dma.sel & 1) == 1))
 	{
-		if((dc_sysctrl_regs[SB_PDTNRM] & dc_sysctrl_regs[SB_ISTNRM]) || (dc_sysctrl_regs[SB_PDTEXT] & dc_sysctrl_regs[SB_ISTEXT]))
+		if((state->dc_sysctrl_regs[SB_PDTNRM] & state->dc_sysctrl_regs[SB_ISTNRM]) || (state->dc_sysctrl_regs[SB_PDTEXT] & state->dc_sysctrl_regs[SB_ISTEXT]))
 		{
 			address_space *space = machine.device("maincpu")->memory().space(AS_PROGRAM);
 
@@ -350,6 +335,8 @@ void dc_update_interrupt_status(running_machine &machine)
 
 READ64_HANDLER( dc_sysctrl_r )
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
+
 	int reg;
 	UINT64 shift;
 
@@ -358,15 +345,17 @@ READ64_HANDLER( dc_sysctrl_r )
 	#if DEBUG_SYSCTRL
 	if ((reg != 0x40) && (reg != 0x41) && (reg != 0x42) && (reg != 0x23) && (reg > 2))	// filter out IRQ status reads
 	{
-		mame_printf_verbose("SYSCTRL: [%08x] read %x @ %x (reg %x: %s), mask %" I64FMT "x (PC=%x)\n", 0x5f6800+reg*4, dc_sysctrl_regs[reg], offset, reg, sysctrl_names[reg], mem_mask, cpu_get_pc(&space->device()));
+		mame_printf_verbose("SYSCTRL: [%08x] read %x @ %x (reg %x: %s), mask %" I64FMT "x (PC=%x)\n", 0x5f6800+reg*4, state->dc_sysctrl_regs[reg], offset, reg, sysctrl_names[reg], mem_mask, cpu_get_pc(&space->device()));
 	}
 	#endif
 
-	return (UINT64)dc_sysctrl_regs[reg] << shift;
+	return (UINT64)state->dc_sysctrl_regs[reg] << shift;
 }
 
 WRITE64_HANDLER( dc_sysctrl_w )
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
+
 	int reg;
 	UINT64 shift;
 	UINT32 old,dat;
@@ -375,23 +364,23 @@ WRITE64_HANDLER( dc_sysctrl_w )
 
 	reg = decode_reg32_64(space->machine(), offset, mem_mask, &shift);
 	dat = (UINT32)(data >> shift);
-	old = dc_sysctrl_regs[reg];
-	dc_sysctrl_regs[reg] = dat; // 5f6800+off*4=dat
+	old = state->dc_sysctrl_regs[reg];
+	state->dc_sysctrl_regs[reg] = dat; // 5f6800+off*4=dat
 	switch (reg)
 	{
 		case SB_C2DST:
 			if(((old & 1) == 0) && (dat & 1)) // 0 -> 1
 			{
-				address=(dc_sysctrl_regs[SB_C2DSTAT] & 0x03ffffe0) | 0x10000000;
-				if(dc_sysctrl_regs[SB_C2DSTAT] & 0x1f)
-					printf("C2DSTAT just used to reserved bits %02x\n",dc_sysctrl_regs[SB_C2DSTAT] & 0x1f);
+				address=(state->dc_sysctrl_regs[SB_C2DSTAT] & 0x03ffffe0) | 0x10000000;
+				if(state->dc_sysctrl_regs[SB_C2DSTAT] & 0x1f)
+					printf("C2DSTAT just used to reserved bits %02x\n",state->dc_sysctrl_regs[SB_C2DSTAT] & 0x1f);
 
 				ddtdata.destination=address;
 				/* 0 rounding size = 16 Mbytes */
-				if(dc_sysctrl_regs[SB_C2DLEN] == 0)
+				if(state->dc_sysctrl_regs[SB_C2DLEN] == 0)
 					ddtdata.length = 0x1000000;
 				else
-					ddtdata.length = dc_sysctrl_regs[SB_C2DLEN];
+					ddtdata.length = state->dc_sysctrl_regs[SB_C2DLEN];
 				ddtdata.size=1;
 				ddtdata.direction=0;
 				ddtdata.channel=2;
@@ -399,27 +388,27 @@ WRITE64_HANDLER( dc_sysctrl_w )
 				sh4_dma_ddt(space->machine().device("maincpu"),&ddtdata);
 				#if DEBUG_SYSCTRL
 				if ((address >= 0x11000000) && (address <= 0x11FFFFFF))
-					if (dc_sysctrl_regs[SB_LMMODE0])
-						printf("SYSCTRL: Ch2 direct display lists dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, dc_sysctrl_regs[SB_C2DSTAT],dc_sysctrl_regs[SB_LMMODE0],dc_sysctrl_regs[SB_LMMODE1]); // 1
+					if (state->dc_sysctrl_regs[SB_LMMODE0])
+						printf("SYSCTRL: Ch2 direct display lists dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", state->dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, state->dc_sysctrl_regs[SB_C2DSTAT],state->dc_sysctrl_regs[SB_LMMODE0],state->dc_sysctrl_regs[SB_LMMODE1]); // 1
 					else
-						mame_printf_verbose("SYSCTRL: Ch2 direct textures dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, dc_sysctrl_regs[SB_C2DSTAT],dc_sysctrl_regs[SB_LMMODE0],dc_sysctrl_regs[SB_LMMODE1]); // 0
+						mame_printf_verbose("SYSCTRL: Ch2 direct textures dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", state->dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, state->dc_sysctrl_regs[SB_C2DSTAT],state->dc_sysctrl_regs[SB_LMMODE0],state->dc_sysctrl_regs[SB_LMMODE1]); // 0
 				else if ((address >= 0x13000000) && (address <= 0x13FFFFFF))
-					if (dc_sysctrl_regs[SB_LMMODE1])
-						printf("SYSCTRL: Ch2 direct display lists dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, dc_sysctrl_regs[SB_C2DSTAT],dc_sysctrl_regs[SB_LMMODE0],dc_sysctrl_regs[SB_LMMODE1]); // 1
+					if (state->dc_sysctrl_regs[SB_LMMODE1])
+						printf("SYSCTRL: Ch2 direct display lists dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", state->dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, state->dc_sysctrl_regs[SB_C2DSTAT],state->dc_sysctrl_regs[SB_LMMODE0],state->dc_sysctrl_regs[SB_LMMODE1]); // 1
 					else
-						mame_printf_verbose("SYSCTRL: Ch2 direct textures dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, dc_sysctrl_regs[SB_C2DSTAT],dc_sysctrl_regs[SB_LMMODE0],dc_sysctrl_regs[SB_LMMODE1]); // 0
+						mame_printf_verbose("SYSCTRL: Ch2 direct textures dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", state->dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, state->dc_sysctrl_regs[SB_C2DSTAT],state->dc_sysctrl_regs[SB_LMMODE0],state->dc_sysctrl_regs[SB_LMMODE1]); // 0
 				else if ((address >= 0x10800000) && (address <= 0x10ffffff))
-					printf("SYSCTRL: Ch2 YUV dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, dc_sysctrl_regs[SB_C2DSTAT],dc_sysctrl_regs[SB_LMMODE0],dc_sysctrl_regs[SB_LMMODE1]);
+					printf("SYSCTRL: Ch2 YUV dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", state->dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, state->dc_sysctrl_regs[SB_C2DSTAT],state->dc_sysctrl_regs[SB_LMMODE0],state->dc_sysctrl_regs[SB_LMMODE1]);
 				else if ((address >= 0x10000000) && (address <= 0x107fffff))
-					mame_printf_verbose("SYSCTRL: Ch2 TA Display List dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, dc_sysctrl_regs[SB_C2DSTAT],dc_sysctrl_regs[SB_LMMODE0],dc_sysctrl_regs[SB_LMMODE1]);
+					mame_printf_verbose("SYSCTRL: Ch2 TA Display List dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", state->dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, state->dc_sysctrl_regs[SB_C2DSTAT],state->dc_sysctrl_regs[SB_LMMODE0],state->dc_sysctrl_regs[SB_LMMODE1]);
 				else
-					mame_printf_verbose("SYSCTRL: Ch2 unknown dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, dc_sysctrl_regs[SB_C2DSTAT],dc_sysctrl_regs[SB_LMMODE0],dc_sysctrl_regs[SB_LMMODE1]);
+					mame_printf_verbose("SYSCTRL: Ch2 unknown dma %x from %08x to %08x (lmmode0=%d lmmode1=%d)\n", state->dc_sysctrl_regs[SB_C2DLEN], ddtdata.source-ddtdata.length, state->dc_sysctrl_regs[SB_C2DSTAT],state->dc_sysctrl_regs[SB_LMMODE0],state->dc_sysctrl_regs[SB_LMMODE1]);
 				#endif
 
 				if ((!(address & 0x01000000)))
-					dc_sysctrl_regs[SB_C2DSTAT]=address;
+					state->dc_sysctrl_regs[SB_C2DSTAT]=address;
 				else //direct texture path
-					dc_sysctrl_regs[SB_C2DSTAT]=address+ddtdata.length;
+					state->dc_sysctrl_regs[SB_C2DSTAT]=address+ddtdata.length;
 
 				/* 200 usecs breaks sfz3upper */
 				space->machine().scheduler().timer_set(attotime::from_usec(50), FUNC(ch2_dma_irq));
@@ -430,17 +419,17 @@ WRITE64_HANDLER( dc_sysctrl_w )
 			break;
 
 		case SB_ISTNRM:
-			dc_sysctrl_regs[SB_ISTNRM] = old & ~(dat | 0xC0000000); // bits 31,30 ro
+			state->dc_sysctrl_regs[SB_ISTNRM] = old & ~(dat | 0xC0000000); // bits 31,30 ro
 			dc_update_interrupt_status(space->machine());
 			break;
 
 		case SB_ISTEXT:
-			dc_sysctrl_regs[SB_ISTEXT] = old;
+			state->dc_sysctrl_regs[SB_ISTEXT] = old;
 			dc_update_interrupt_status(space->machine());
 			break;
 
 		case SB_ISTERR:
-			dc_sysctrl_regs[SB_ISTERR] = old & ~dat;
+			state->dc_sysctrl_regs[SB_ISTERR] = old & ~dat;
 			dc_update_interrupt_status(space->machine());
 			break;
 		case SB_SDST:
@@ -449,8 +438,8 @@ WRITE64_HANDLER( dc_sysctrl_w )
 				// TODO: Sort-DMA routine goes here
 				printf("Sort-DMA irq\n");
 
-				dc_sysctrl_regs[SB_SDST] = 0;
-				dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_SORT;
+				state->dc_sysctrl_regs[SB_SDST] = 0;
+				state->dc_sysctrl_regs[SB_ISTNRM] |= IST_DMA_SORT;
 				dc_update_interrupt_status(space->machine());
 			}
 			break;
@@ -466,6 +455,8 @@ WRITE64_HANDLER( dc_sysctrl_w )
 
 READ64_HANDLER( dc_gdrom_r )
 {
+//  dc_state *state = space->machine().driver_data<dc_state>();
+
 	UINT32 off;
 
 	if ((int)~mem_mask & 1)
@@ -487,6 +478,7 @@ READ64_HANDLER( dc_gdrom_r )
 
 WRITE64_HANDLER( dc_gdrom_w )
 {
+//  dc_state *state = space->machine().driver_data<dc_state>();
 	UINT32 dat,off;
 
 	if ((int)~mem_mask & 1)
@@ -503,79 +495,20 @@ WRITE64_HANDLER( dc_gdrom_w )
 	mame_printf_verbose("GDROM: [%08x=%x]write %" I64FMT "x to %x, mask %" I64FMT "x\n", 0x5f7000+off*4, dat, data, offset, mem_mask);
 }
 
-READ64_HANDLER( dc_g1_ctrl_r )
-{
-	int reg;
-	UINT64 shift;
-
-	reg = decode_reg32_64(space->machine(), offset, mem_mask, &shift);
-	mame_printf_verbose("G1CTRL:  Unmapped read %08x\n", 0x5f7400+reg*4);
-	return (UINT64)g1bus_regs[reg] << shift;
-}
-
-WRITE64_HANDLER( dc_g1_ctrl_w )
-{
-	int reg;
-	UINT64 shift;
-	UINT32 old,dat;
-	struct sh4_ddt_dma ddtdata;
-	UINT8 *ROM;
-	UINT32 dmaoffset;
-
-	reg = decode_reg32_64(space->machine(), offset, mem_mask, &shift);
-	dat = (UINT32)(data >> shift);
-	old = g1bus_regs[reg];
-
-	g1bus_regs[reg] = dat; // 5f7400+reg*4=dat
-	mame_printf_verbose("G1CTRL: [%08x=%x] write %" I64FMT "x to %x, mask %" I64FMT "x\n", 0x5f7400+reg*4, dat, data, offset, mem_mask);
-	switch (reg)
-	{
-	case SB_GDST:
-		g1bus_regs[SB_GDST] = old;
-		if (((old & 1) == 0) && (dat & 1) && g1bus_regs[SB_GDEN] == 1) // 0 -> 1
-		{
-			if (g1bus_regs[SB_GDDIR] == 0)
-			{
-				printf("G1CTRL: unsupported transfer\n");
-				return;
-			}
-			g1bus_regs[SB_GDST] = dat & 1;
-//          printf("ROM board DMA to %x len %x (PC %x)\n", g1bus_regs[SB_GDSTAR], g1bus_regs[SB_GDLEN], cpu_get_pc(&space->device()));
-			ROM = (UINT8 *)naomibd_get_memory(space->machine().device("rom_board"));
-			dmaoffset = naomibd_get_dmaoffset(space->machine().device("rom_board"));
-			ddtdata.destination=g1bus_regs[SB_GDSTAR];		// destination address
-			ddtdata.length=g1bus_regs[SB_GDLEN] >> 5;		// words to transfer
-			/* data in the lower 5 bits makes the length size to round by 32 bytes, this'll be needed by Virtua Tennis to boot (according to Deunan) */
-			if(g1bus_regs[SB_GDLEN] & 0x1c)
-				ddtdata.length++;
-
-			ddtdata.size=32;			// bytes per word
-			ddtdata.buffer=ROM+dmaoffset;	// buffer address
-			ddtdata.direction=1;	// 0 source to buffer, 1 buffer to destination
-			ddtdata.channel= -1;	// not used
-			ddtdata.mode= -1;		// copy from/to buffer
-			mame_printf_verbose("G1CTRL: transfer %x from ROM %08x to sdram %08x\n", g1bus_regs[SB_GDLEN], dmaoffset, g1bus_regs[SB_GDSTAR]);
-			sh4_dma_ddt(space->machine().device("maincpu"), &ddtdata);
-			/* Note: KOF Neowave definitely wants this to be delayed (!) */
-			/* FIXME: timing of this */
-			space->machine().scheduler().timer_set(attotime::from_usec(500), FUNC(gdrom_dma_irq));
-		}
-		break;
-	}
-}
-
 READ64_HANDLER( dc_g2_ctrl_r )
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
 	int reg;
 	UINT64 shift;
 
 	reg = decode_reg32_64(space->machine(), offset, mem_mask, &shift);
 	mame_printf_verbose("G2CTRL:  Unmapped read %08x\n", 0x5f7800+reg*4);
-	return (UINT64)g2bus_regs[reg] << shift;
+	return (UINT64)state->g2bus_regs[reg] << shift;
 }
 
 WRITE64_HANDLER( dc_g2_ctrl_w )
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
 	int reg;
 	UINT64 shift;
 	UINT32 dat;
@@ -584,41 +517,41 @@ WRITE64_HANDLER( dc_g2_ctrl_w )
 	reg = decode_reg32_64(space->machine(), offset, mem_mask, &shift);
 	dat = (UINT32)(data >> shift);
 
-	g2bus_regs[reg] = dat; // 5f7800+reg*4=dat
+	state->g2bus_regs[reg] = dat; // 5f7800+reg*4=dat
 
 	switch (reg)
 	{
 		/*AICA Address register*/
-		case SB_ADSTAG: wave_dma.aica_addr = dat; break;
+		case SB_ADSTAG: state->m_wave_dma.aica_addr = dat; break;
 		/*Root address (work ram)*/
-		case SB_ADSTAR:	wave_dma.root_addr = dat; break;
+		case SB_ADSTAR:	state->m_wave_dma.root_addr = dat; break;
 		/*DMA size (in dword units, bit 31 is "set dma initiation enable setting to 0"*/
 		case SB_ADLEN:
-			wave_dma.size = dat & 0x7fffffff;
-			wave_dma.indirect = (dat & 0x80000000)>>31;
+			state->m_wave_dma.size = dat & 0x7fffffff;
+			state->m_wave_dma.indirect = (dat & 0x80000000)>>31;
 			break;
 		/*0 = root memory to aica / 1 = aica to root memory*/
-		case SB_ADDIR: wave_dma.dir = (dat & 1); break;
+		case SB_ADDIR: state->m_wave_dma.dir = (dat & 1); break;
 		/*dma flag (active HIGH, bug in docs)*/
-		case SB_ADEN: wave_dma.flag = (dat & 1); break;
+		case SB_ADEN: state->m_wave_dma.flag = (dat & 1); break;
 		/*
         SB_ADTSEL
-        bit 1: (0) Wave DMA thru SB_ADST flag (1) Wave DMA thru irq trigger, defined by SB_G2DTNRM / SB_G2DTEXT
+        bit 1: (0) Wave DMA through SB_ADST flag (1) Wave DMA through irq trigger, defined by SB_G2DTNRM / SB_G2DTEXT
         */
-		case SB_ADTSEL: wave_dma.sel = dat & 7; break;
+		case SB_ADTSEL: state->m_wave_dma.sel = dat & 7; break;
 		/*ready for dma'ing*/
 		case SB_ADST:
-			old = wave_dma.start & 1;
-			wave_dma.start = dat & 1;
+			old = state->m_wave_dma.start & 1;
+			state->m_wave_dma.start = dat & 1;
 
 			#if DEBUG_AICA_DMA
 			printf("AICA: G2-DMA start \n");
-			printf("DST %08x SRC %08x SIZE %08x IND %02x\n",wave_dma.aica_addr,wave_dma.root_addr,wave_dma.size,wave_dma.indirect);
-			printf("SEL %08x ST  %08x FLAG %08x DIR %02x\n",wave_dma.sel,wave_dma.start,wave_dma.flag,wave_dma.dir);
+			printf("DST %08x SRC %08x SIZE %08x IND %02x\n",state->m_wave_dma.aica_addr,state->m_wave_dma.root_addr,state->m_wave_dma.size,state->m_wave_dma.indirect);
+			printf("SEL %08x ST  %08x FLAG %08x DIR %02x\n",state->m_wave_dma.sel,state->m_wave_dma.start,state->m_wave_dma.flag,state->m_wave_dma.dir);
 			#endif
 
 			//mame_printf_verbose("SB_ADST data %08x\n",dat);
-			if(((old & 1) == 0) && wave_dma.flag && wave_dma.start && ((wave_dma.sel & 2) == 0)) // 0 -> 1
+			if(((old & 1) == 0) && state->m_wave_dma.flag && state->m_wave_dma.start && ((state->m_wave_dma.sel & 2) == 0)) // 0 -> 1
 				wave_dma_execute(space);
 			break;
 
@@ -667,20 +600,22 @@ INLINE int decode_reg_64(UINT32 offset, UINT64 mem_mask, UINT64 *shift)
 
 READ64_HANDLER( pvr_ctrl_r )
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
 	int reg;
 	UINT64 shift;
 
 	reg = decode_reg_64(offset, mem_mask, &shift);
 
 	#if DEBUG_PVRCTRL
-	mame_printf_verbose("PVRCTRL: [%08x] read %x @ %x (reg %x), mask %" I64FMT "x (PC=%x)\n", 0x5f7c00+reg*4, pvrctrl_regs[reg], offset, reg, mem_mask, cpu_get_pc(&space->device()));
+	mame_printf_verbose("PVRCTRL: [%08x] read %x @ %x (reg %x), mask %" I64FMT "x (PC=%x)\n", 0x5f7c00+reg*4, state->pvrctrl_regs[reg], offset, reg, mem_mask, cpu_get_pc(&space->device()));
 	#endif
 
-	return (UINT64)pvrctrl_regs[reg] << shift;
+	return (UINT64)state->pvrctrl_regs[reg] << shift;
 }
 
 WRITE64_HANDLER( pvr_ctrl_w )
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
 	int reg;
 	UINT64 shift;
 	UINT32 dat;
@@ -691,21 +626,21 @@ WRITE64_HANDLER( pvr_ctrl_w )
 
 	switch (reg)
 	{
-		case SB_PDSTAP: pvr_dma.pvr_addr = dat; break;
-		case SB_PDSTAR: pvr_dma.sys_addr = dat; break;
-		case SB_PDLEN: pvr_dma.size = dat; break;
-		case SB_PDDIR: pvr_dma.dir = dat & 1; break;
+		case SB_PDSTAP: state->m_pvr_dma.pvr_addr = dat; break;
+		case SB_PDSTAR: state->m_pvr_dma.sys_addr = dat; break;
+		case SB_PDLEN: state->m_pvr_dma.size = dat; break;
+		case SB_PDDIR: state->m_pvr_dma.dir = dat & 1; break;
 		case SB_PDTSEL:
-			pvr_dma.sel = dat & 1;
-			//if(pvr_dma.sel & 1)
+			state->m_pvr_dma.sel = dat & 1;
+			//if(state->m_pvr_dma.sel & 1)
 			//  printf("Warning: Unsupported irq mode trigger PVR-DMA\n");
 			break;
-		case SB_PDEN: pvr_dma.flag = dat & 1; break;
+		case SB_PDEN: state->m_pvr_dma.flag = dat & 1; break;
 		case SB_PDST:
-			old = pvr_dma.start & 1;
-			pvr_dma.start = dat & 1;
+			old = state->m_pvr_dma.start & 1;
+			state->m_pvr_dma.start = dat & 1;
 
-			if(((old & 1) == 0) && pvr_dma.flag && pvr_dma.start && ((pvr_dma.sel & 1) == 0)) // 0 -> 1
+			if(((old & 1) == 0) && state->m_pvr_dma.flag && state->m_pvr_dma.start && ((state->m_pvr_dma.sel & 1) == 0)) // 0 -> 1
 				pvr_dma_execute(space);
 			break;
 	}
@@ -714,13 +649,14 @@ WRITE64_HANDLER( pvr_ctrl_w )
 	mame_printf_verbose("PVRCTRL: [%08x=%x] write %" I64FMT "x to %x (reg %x), mask %" I64FMT "x\n", 0x5f7c00+reg*4, dat, data>>shift, offset, reg, mem_mask);
 	#endif
 
-//  pvrctrl_regs[reg] |= dat;
-	pvrctrl_regs[reg] = dat;
+//  state->pvrctrl_regs[reg] |= dat;
+	state->pvrctrl_regs[reg] = dat;
 
 }
 
 READ64_HANDLER( dc_modem_r )
 {
+//  dc_state *state = space->machine().driver_data<dc_state>();
 	int reg;
 	UINT64 shift;
 
@@ -739,6 +675,7 @@ READ64_HANDLER( dc_modem_r )
 
 WRITE64_HANDLER( dc_modem_w )
 {
+//  dc_state *state = space->machine().driver_data<dc_state>();
 	int reg;
 	UINT64 shift;
 	UINT32 dat;
@@ -750,41 +687,43 @@ WRITE64_HANDLER( dc_modem_w )
 
 READ64_HANDLER( dc_rtc_r )
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
 	int reg;
 	UINT64 shift;
 
 	reg = decode_reg3216_64(space->machine(), offset, mem_mask, &shift);
 	mame_printf_verbose("RTC:  Unmapped read %08x\n", 0x710000+reg*4);
 
-	return (UINT64)dc_rtcregister[reg] << shift;
+	return (UINT64)state->dc_rtcregister[reg] << shift;
 }
 
 WRITE64_HANDLER( dc_rtc_w )
 {
+	dc_state *state = space->machine().driver_data<dc_state>();
 	int reg;
 	UINT64 shift;
 	UINT32 old,dat;
 
 	reg = decode_reg3216_64(space->machine(), offset, mem_mask, &shift);
 	dat = (UINT32)(data >> shift);
-	old = dc_rtcregister[reg];
-	dc_rtcregister[reg] = dat & 0xFFFF; // 5f6c00+off*4=dat
+	old = state->dc_rtcregister[reg];
+	state->dc_rtcregister[reg] = dat & 0xFFFF; // 5f6c00+off*4=dat
 	switch (reg)
 	{
 	case RTC1:
-		if (dc_rtcregister[RTC3])
-			dc_rtcregister[RTC3] = 0;
+		if (state->dc_rtcregister[RTC3])
+			state->dc_rtcregister[RTC3] = 0;
 		else
-			dc_rtcregister[reg] = old;
+			state->dc_rtcregister[reg] = old;
 		break;
 	case RTC2:
-		if (dc_rtcregister[RTC3] == 0)
-			dc_rtcregister[reg] = old;
+		if (state->dc_rtcregister[RTC3] == 0)
+			state->dc_rtcregister[reg] = old;
 		else
-			dc_rtc_timer->adjust(attotime::zero, 0, attotime::from_seconds(1));
+			state->dc_rtc_timer->adjust(attotime::zero, 0, attotime::from_seconds(1));
 		break;
 	case RTC3:
-		dc_rtcregister[RTC3] &= 1;
+		state->dc_rtcregister[RTC3] &= 1;
 		break;
 	}
 	mame_printf_verbose("RTC: [%08x=%x] write %" I64FMT "x to %x, mask %" I64FMT "x\n", 0x710000 + reg*4, dat, data, offset, mem_mask);
@@ -792,21 +731,24 @@ WRITE64_HANDLER( dc_rtc_w )
 
 static TIMER_CALLBACK(dc_rtc_increment)
 {
-    dc_rtcregister[RTC2] = (dc_rtcregister[RTC2] + 1) & 0xFFFF;
-    if (dc_rtcregister[RTC2] == 0)
-        dc_rtcregister[RTC1] = (dc_rtcregister[RTC1] + 1) & 0xFFFF;
+	dc_state *state = machine.driver_data<dc_state>();
+
+    state->dc_rtcregister[RTC2] = (state->dc_rtcregister[RTC2] + 1) & 0xFFFF;
+    if (state->dc_rtcregister[RTC2] == 0)
+        state->dc_rtcregister[RTC1] = (state->dc_rtcregister[RTC1] + 1) & 0xFFFF;
 }
 
 /* fill the RTC registers with the proper start-up values */
 static void rtc_initial_setup(running_machine &machine)
 {
+	dc_state *state = machine.driver_data<dc_state>();
 	static UINT32 current_time;
 	static int year_count,cur_year,i;
 	static const int month_to_day_conversion[12] = { 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334 };
 	system_time systime;
 	machine.base_datetime(systime);
 
-	memset(dc_rtcregister, 0, sizeof(dc_rtcregister));
+	memset(state->dc_rtcregister, 0, sizeof(state->dc_rtcregister));
 
 	/* put the seconds */
 	current_time = systime.local_time.second;
@@ -831,33 +773,63 @@ static void rtc_initial_setup(running_machine &machine)
 	for(i=0;i<year_count-1;i++)
 		current_time += (((((i+1950) % 4) == 0) && (((i+1950) % 100) != 0)) || (((i+1950) % 400) == 0)) ? 60*60*24*366 : 60*60*24*365;
 
-	dc_rtcregister[RTC2] = current_time & 0x0000ffff;
-	dc_rtcregister[RTC1] = (current_time & 0xffff0000) >> 16;
+	state->dc_rtcregister[RTC2] = current_time & 0x0000ffff;
+	state->dc_rtcregister[RTC1] = (current_time & 0xffff0000) >> 16;
 
-	dc_rtc_timer = machine.scheduler().timer_alloc(FUNC(dc_rtc_increment));
+	state->dc_rtc_timer = machine.scheduler().timer_alloc(FUNC(dc_rtc_increment));
 }
 
 MACHINE_START( dc )
 {
+	dc_state *state = machine.driver_data<dc_state>();
+
 	rtc_initial_setup(machine);
+
+	// save states
+	state_save_register_global_pointer(machine, state->dc_rtcregister, 4);
+	state_save_register_global_pointer(machine, state->dc_sysctrl_regs, 0x200/4);
+	state_save_register_global_pointer(machine, state->g2bus_regs, 0x100/4);
+	state_save_register_global(machine, state->m_wave_dma.aica_addr);
+	state_save_register_global(machine, state->m_wave_dma.root_addr);
+	state_save_register_global(machine, state->m_wave_dma.size);
+	state_save_register_global(machine, state->m_wave_dma.dir);
+	state_save_register_global(machine, state->m_wave_dma.flag);
+	state_save_register_global(machine, state->m_wave_dma.indirect);
+	state_save_register_global(machine, state->m_wave_dma.start);
+	state_save_register_global(machine, state->m_wave_dma.sel);
+	state_save_register_global(machine, state->m_pvr_dma.pvr_addr);
+	state_save_register_global(machine, state->m_pvr_dma.sys_addr);
+	state_save_register_global(machine, state->m_pvr_dma.size);
+	state_save_register_global(machine, state->m_pvr_dma.sel);
+	state_save_register_global(machine, state->m_pvr_dma.dir);
+	state_save_register_global(machine, state->m_pvr_dma.flag);
+	state_save_register_global(machine, state->m_pvr_dma.start);
+	state_save_register_global_pointer(machine,state->pvrta_regs,0x2000/4);
+	state_save_register_global_pointer(machine,state->pvrctrl_regs,0x100/4);
+	state_save_register_global(machine, state->debug_dip_status);
+	state_save_register_global_pointer(machine,state->tafifo_buff,32);
+	state_save_register_global(machine, state->scanline);
+	state_save_register_global(machine, state->next_y);
+	state_save_register_global_pointer(machine,state->dc_sound_ram,sizeof(state->dc_sound_ram));
 }
 
 MACHINE_RESET( dc )
 {
+	dc_state *state = machine.driver_data<dc_state>();
+
 	/* halt the ARM7 */
 	cputag_set_input_line(machine, "soundcpu", INPUT_LINE_RESET, ASSERT_LINE);
 
-	memset(dc_sysctrl_regs, 0, sizeof(dc_sysctrl_regs));
+	memset(state->dc_sysctrl_regs, 0, sizeof(state->dc_sysctrl_regs));
 
-	dc_rtc_timer->adjust(attotime::zero, 0, attotime::from_seconds(1));
+	state->dc_rtc_timer->adjust(attotime::zero, 0, attotime::from_seconds(1));
 
-	dc_sysctrl_regs[SB_SBREV] = 0x0b;
-
-	mp_mux_data = 0;
+	state->dc_sysctrl_regs[SB_SBREV] = 0x0b;
 }
 
 READ64_DEVICE_HANDLER( dc_aica_reg_r )
 {
+	//  dc_state *state = device->machine().driver_data<dc_state>();
 	//int reg;
 	UINT64 shift;
 
@@ -870,6 +842,7 @@ READ64_DEVICE_HANDLER( dc_aica_reg_r )
 
 WRITE64_DEVICE_HANDLER( dc_aica_reg_w )
 {
+	//  dc_state *state = device->machine().driver_data<dc_state>();
 	int reg;
 	UINT64 shift;
 	UINT32 dat;
