@@ -91,7 +91,7 @@ enum
 	POKEMON,                     /* Pocket Monster */
 	POKEMON2,                    /* Pocket Monster 2 */
 	KAIJU,                       /* Pokemon Stadium */
-	RADICA,                      /* Radica TV games.. these probably should be a seperate driver since they are a seperate 'console' */
+	RADICA,                      /* Radica TV games.. these probably should be a separate driver since they are a separate 'console' */
 	REALTEC,                     /* Whac a Critter/Mallet legend, Defend the Earth, Funnyworld/Ballonboy */
 	REDCLIFF,                    /* Romance of the Three Kingdoms - Battle of Red Cliffs, already decoded from .mdx format */
 	REDCL_EN,                    /* The encoded version... */
@@ -1558,6 +1558,7 @@ static int megadrive_load_nonlist(device_image_interface &image)
 	/* is this a SMD file? */
 	if (genesis_is_SMD(&rawROM[0x2200], (unsigned)length))
 	{
+//      printf("SMD!\n");
 		tmpROMnew = ROM;
 		tmpROM = ROM + 0x2000 + 512;
 
@@ -1589,6 +1590,7 @@ static int megadrive_load_nonlist(device_image_interface &image)
 	else if ((rawROM[0x2080] == 'E') && (rawROM[0x2081] == 'A') &&
 			 (rawROM[0x2082] == 'M' || rawROM[0x2082] == 'G'))
 	{
+//      printf("MD!\n");
 		tmpROMnew = global_alloc_array(unsigned char, length);
 		secondhalf = &tmpROMnew[length >> 1];
 
