@@ -159,7 +159,7 @@ MACHINE_CONFIG_END
 
 
 ROM_START( namco_53xx )
-	ROM_REGION( 0x400, "mcu", ROMREGION_LOADBYNAME )
+	ROM_REGION( 0x400, "mcu", 0 )
 	ROM_LOAD( "53xx.bin",     0x0000, 0x0400, CRC(b326fecb) SHA1(758d8583d658e4f1df93184009d86c3eb8713899) )
 ROM_END
 
