@@ -73,16 +73,16 @@ static void get_pens(running_machine &machine, const _20pacgal_state *state, pen
 }
 
 
-static void do_pen_lookup(running_machine &machine, const _20pacgal_state *state, bitmap_t *bitmap, const rectangle *cliprect)
+static void do_pen_lookup(running_machine &machine, const _20pacgal_state *state, bitmap_rgb32 &bitmap, const rectangle &cliprect)
 {
 	int y, x;
 	pen_t pens[NUM_PENS + NUM_STAR_PENS];
 
 	get_pens(machine, state, pens);
 
-	for (y = cliprect->min_y; y <= cliprect->max_y; y++)
-		for(x = cliprect->min_x; x <= cliprect->max_x; x++)
-			*BITMAP_ADDR32(bitmap, y, x) = pens[*BITMAP_ADDR32(bitmap, y, x)];
+	for (y = cliprect.min_y; y <= cliprect.max_y; y++)
+		for(x = cliprect.min_x; x <= cliprect.max_x; x++)
+			bitmap.pix32(y, x) = pens[bitmap.pix32(y, x)];
 }
 
 
@@ -93,7 +93,7 @@ static void do_pen_lookup(running_machine &machine, const _20pacgal_state *state
  *
  *************************************/
 
-static void draw_sprite(running_machine& machine, const _20pacgal_state *state, bitmap_t *bitmap, int y, int x,
+static void draw_sprite(running_machine& machine, const _20pacgal_state *state, bitmap_rgb32 &bitmap, int y, int x,
 						UINT8 code, UINT8 color, int flip_y, int flip_x)
 {
 	int sy;
@@ -139,7 +139,7 @@ static void draw_sprite(running_machine& machine, const _20pacgal_state *state,
 
 					/* pen bits A0-A3 */
 					if (col)
-						*BITMAP_ADDR32(bitmap, y, x) = (*BITMAP_ADDR32(bitmap, y, x) & 0xff0) | col;
+						bitmap.pix32(y, x) = (bitmap.pix32(y, x) & 0xff0) | col;
 				}
 
 				/* next pixel */
@@ -163,7 +163,7 @@ static void draw_sprite(running_machine& machine, const _20pacgal_state *state,
 }
 
 
-static void draw_sprites(running_machine& machine,const _20pacgal_state *state, bitmap_t *bitmap)
+static void draw_sprites(running_machine& machine,const _20pacgal_state *state, bitmap_rgb32 &bitmap)
 {
 	int offs;
 
@@ -215,7 +215,7 @@ static void draw_sprites(running_machine& machine,const _20pacgal_state *state,
  *
  *************************************/
 
-static void draw_chars(const _20pacgal_state *state, bitmap_t *bitmap)
+static void draw_chars(const _20pacgal_state *state, bitmap_rgb32 &bitmap)
 {
 	offs_t offs;
 
@@ -274,7 +274,7 @@ static void draw_chars(const _20pacgal_state *state, bitmap_t *bitmap)
 
 				/* pen bits A4-A11 */
 				if ( col != 0 )
-					*BITMAP_ADDR32(bitmap, y, x) = (color_base | col) << 4;
+					bitmap.pix32(y, x) = (color_base | col) << 4;
 
 				/* next pixel */
 				if (flip)
@@ -349,7 +349,7 @@ static void draw_chars(const _20pacgal_state *state, bitmap_t *bitmap)
  *
  */
 
-static void draw_stars(_20pacgal_state *state, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_stars(_20pacgal_state *state, bitmap_rgb32 &bitmap, const rectangle &cliprect )
 {
 	if ( (state->m_stars_ctrl[0] >> 5) & 1 )
 	{
@@ -391,8 +391,8 @@ static void draw_stars(_20pacgal_state *state, bitmap_t *bitmap, const rectangle
 
 			if (((lfsr & 0xffc0) == star_seta) || ((lfsr & 0xffc0) == star_setb))
 			{
-				if (y >= cliprect->min_y && y <= cliprect->max_y)
-					*BITMAP_ADDR32(bitmap, y, x) = NUM_PENS + (lfsr & 0x3f);
+				if (y >= cliprect.min_y && y <= cliprect.max_y)
+					bitmap.pix32(y, x) = NUM_PENS + (lfsr & 0x3f);
 				cnt++;
 			}
 		}
@@ -406,15 +406,15 @@ static void draw_stars(_20pacgal_state *state, bitmap_t *bitmap, const rectangle
  *
  *************************************/
 
-static SCREEN_UPDATE( 20pacgal )
+static SCREEN_UPDATE_RGB32( 20pacgal )
 {
-	_20pacgal_state *state = screen->machine().driver_data<_20pacgal_state>();
+	_20pacgal_state *state = screen.machine().driver_data<_20pacgal_state>();
 
-	bitmap_fill(bitmap,cliprect,0);
+	bitmap.fill(0, cliprect);
 	draw_stars(state, bitmap,cliprect);
 	draw_chars(state, bitmap);
-	draw_sprites(screen->machine(),state, bitmap);
-	do_pen_lookup(screen->machine(), state, bitmap, cliprect);
+	draw_sprites(screen.machine(),state, bitmap);
+	do_pen_lookup(screen.machine(), state, bitmap, cliprect);
 
 	return 0;
 }
@@ -431,8 +431,7 @@ MACHINE_CONFIG_FRAGMENT( 20pacgal_video )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(SCREEN_WIDTH, SCREEN_HEIGHT)
 	MCFG_SCREEN_VISIBLE_AREA(0, SCREEN_WIDTH - 1, 0, SCREEN_HEIGHT - 1)
-	MCFG_SCREEN_UPDATE(20pacgal)
+	MCFG_SCREEN_UPDATE_STATIC(20pacgal)
 MACHINE_CONFIG_END
