@@ -11,9 +11,9 @@
 
 static TILE_GET_INFO( get_back_tile_info )
 {
-	cabal_state *state = machine->driver_data<cabal_state>();
+	cabal_state *state = machine.driver_data<cabal_state>();
 
-	int tile = state->videoram[tile_index];
+	int tile = state->m_videoram[tile_index];
 	int color = (tile>>12)&0xf;
 
 	tile &= 0xfff;
@@ -27,9 +27,9 @@ static TILE_GET_INFO( get_back_tile_info )
 
 static TILE_GET_INFO( get_text_tile_info )
 {
-	cabal_state *state = machine->driver_data<cabal_state>();
+	cabal_state *state = machine.driver_data<cabal_state>();
 
-	int tile = state->colorram[tile_index];
+	int tile = state->m_colorram[tile_index];
 	int color = (tile>>10);
 
 	tile &= 0x3ff;
@@ -44,13 +44,13 @@ static TILE_GET_INFO( get_text_tile_info )
 
 VIDEO_START( cabal )
 {
-	cabal_state *state = machine->driver_data<cabal_state>();
+	cabal_state *state = machine.driver_data<cabal_state>();
 
-	state->background_layer = tilemap_create(machine, get_back_tile_info,tilemap_scan_rows,16,16,16,16);
-	state->text_layer       = tilemap_create(machine, get_text_tile_info,tilemap_scan_rows,  8,8,32,32);
+	state->m_background_layer = tilemap_create(machine, get_back_tile_info,tilemap_scan_rows,16,16,16,16);
+	state->m_text_layer       = tilemap_create(machine, get_text_tile_info,tilemap_scan_rows,  8,8,32,32);
 
-	tilemap_set_transparent_pen(state->text_layer,3);
-	tilemap_set_transparent_pen(state->background_layer,15);
+	state->m_text_layer->set_transparent_pen(3);
+	state->m_background_layer->set_transparent_pen(15);
 }
 
 
@@ -60,27 +60,27 @@ WRITE16_HANDLER( cabal_flipscreen_w )
 {
 	if (ACCESSING_BITS_0_7)
 	{
-		cabal_state *state = space->machine->driver_data<cabal_state>();
+		cabal_state *state = space->machine().driver_data<cabal_state>();
 		int flip = (data & 0x20) ? (TILEMAP_FLIPX | TILEMAP_FLIPY) : 0;
-		tilemap_set_flip(state->background_layer,flip);
-		tilemap_set_flip(state->text_layer,flip);
+		state->m_background_layer->set_flip(flip);
+		state->m_text_layer->set_flip(flip);
 
-		flip_screen_set(space->machine, data & 0x20);
+		flip_screen_set(space->machine(), data & 0x20);
 	}
 }
 
 WRITE16_HANDLER( cabal_background_videoram16_w )
 {
-	cabal_state *state = space->machine->driver_data<cabal_state>();
-	COMBINE_DATA(&state->videoram[offset]);
-	tilemap_mark_tile_dirty(state->background_layer,offset);
+	cabal_state *state = space->machine().driver_data<cabal_state>();
+	COMBINE_DATA(&state->m_videoram[offset]);
+	state->m_background_layer->mark_tile_dirty(offset);
 }
 
 WRITE16_HANDLER( cabal_text_videoram16_w )
 {
-	cabal_state *state = space->machine->driver_data<cabal_state>();
-	COMBINE_DATA(&state->colorram[offset]);
-	tilemap_mark_tile_dirty(state->text_layer,offset);
+	cabal_state *state = space->machine().driver_data<cabal_state>();
+	COMBINE_DATA(&state->m_colorram[offset]);
+	state->m_text_layer->mark_tile_dirty(offset);
 }
 
 
@@ -105,13 +105,13 @@ WRITE16_HANDLER( cabal_text_videoram16_w )
 
 ********************************************************************/
 
-static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
-	cabal_state *state = machine->driver_data<cabal_state>();
+	cabal_state *state = machine.driver_data<cabal_state>();
 	int offs,data0,data1,data2;
-	UINT16 *spriteram16 = state->spriteram;
+	UINT16 *spriteram16 = state->m_spriteram;
 
-	for( offs = state->spriteram_size/2 - 4; offs >= 0; offs -= 4 )
+	for( offs = state->m_spriteram_size/2 - 4; offs >= 0; offs -= 4 )
 	{
 		data0 = spriteram16[offs];
 		data1 = spriteram16[offs+1];
@@ -136,7 +136,7 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 				flipy = !flipy;
 			}
 
-			drawgfx_transpen( bitmap,cliprect,machine->gfx[2],
+			drawgfx_transpen( bitmap,cliprect,machine.gfx[2],
 				tile_number,
 				color,
 				flipx,flipy,
@@ -146,12 +146,12 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 }
 
 
-VIDEO_UPDATE( cabal )
+SCREEN_UPDATE_IND16( cabal )
 {
-	cabal_state *state = screen->machine->driver_data<cabal_state>();
-	tilemap_draw(bitmap,cliprect,state->background_layer,TILEMAP_DRAW_OPAQUE,0);
-	draw_sprites(screen->machine,bitmap,cliprect);
-	tilemap_draw(bitmap,cliprect,state->text_layer,0,0);
+	cabal_state *state = screen.machine().driver_data<cabal_state>();
+	state->m_background_layer->draw(bitmap, cliprect, TILEMAP_DRAW_OPAQUE,0);
+	draw_sprites(screen.machine(),bitmap,cliprect);
+	state->m_text_layer->draw(bitmap, cliprect, 0,0);
 	return 0;
 }
 
