@@ -143,15 +143,14 @@ PALETTE_INIT( carpolo )
 VIDEO_START( carpolo )
 {
 	carpolo_state *state = machine.driver_data<carpolo_state>();
-	bitmap_format format = machine.primary_screen->format();
 
-	state->m_sprite_sprite_collision_bitmap1 = auto_bitmap_alloc(machine, SPRITE_WIDTH*2, SPRITE_HEIGHT*2, format);
-	state->m_sprite_sprite_collision_bitmap2 = auto_bitmap_alloc(machine, SPRITE_WIDTH*2, SPRITE_HEIGHT*2, format);
+	state->m_sprite_sprite_collision_bitmap1 = auto_bitmap_ind16_alloc(machine, SPRITE_WIDTH*2, SPRITE_HEIGHT*2);
+	state->m_sprite_sprite_collision_bitmap2 = auto_bitmap_ind16_alloc(machine, SPRITE_WIDTH*2, SPRITE_HEIGHT*2);
 
-	state->m_sprite_goal_collision_bitmap1 = auto_bitmap_alloc(machine, SPRITE_WIDTH+GOAL_WIDTH, SPRITE_HEIGHT+GOAL_HEIGHT, format);
-	state->m_sprite_goal_collision_bitmap2 = auto_bitmap_alloc(machine, SPRITE_WIDTH+GOAL_WIDTH, SPRITE_HEIGHT+GOAL_HEIGHT, format);
+	state->m_sprite_goal_collision_bitmap1 = auto_bitmap_ind16_alloc(machine, SPRITE_WIDTH+GOAL_WIDTH, SPRITE_HEIGHT+GOAL_HEIGHT);
+	state->m_sprite_goal_collision_bitmap2 = auto_bitmap_ind16_alloc(machine, SPRITE_WIDTH+GOAL_WIDTH, SPRITE_HEIGHT+GOAL_HEIGHT);
 
-	state->m_sprite_border_collision_bitmap = auto_bitmap_alloc(machine, SPRITE_WIDTH, SPRITE_HEIGHT, format);
+	state->m_sprite_border_collision_bitmap = auto_bitmap_ind16_alloc(machine, SPRITE_WIDTH, SPRITE_HEIGHT);
 
     state_save_register_global_bitmap(machine, state->m_sprite_sprite_collision_bitmap1);
     state_save_register_global_bitmap(machine, state->m_sprite_sprite_collision_bitmap2);
@@ -167,7 +166,7 @@ VIDEO_START( carpolo )
  *
  *************************************/
 
-static void draw_alpha_line(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect,
+static void draw_alpha_line(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect,
 							int alpha_line, int video_line)
 {
 	carpolo_state *state = machine.driver_data<carpolo_state>();
@@ -198,7 +197,7 @@ static void remap_sprite_code(running_machine &machine, int bank, int code, int
 }
 
 
-static void draw_sprite(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect,
+static void draw_sprite(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect,
 						UINT8 x, UINT8 y, int bank, int code, int col)
 {
 	int remapped_code, flipy;
@@ -221,58 +220,58 @@ static void draw_sprite(running_machine &machine, bitmap_t *bitmap, const rectan
 }
 
 
-SCREEN_UPDATE( carpolo )
+SCREEN_UPDATE_IND16( carpolo )
 {
-	carpolo_state *state = screen->machine().driver_data<carpolo_state>();
+	carpolo_state *state = screen.machine().driver_data<carpolo_state>();
 	/* draw the playfield elements in the correct priority order */
 
 	/* score area - position determined by bit 4 of the vertical timing PROM */
-	plot_box(bitmap,0,0,RIGHT_BORDER+1,TOP_BORDER,BACKGROUND_PEN);
+	bitmap.plot_box(0,0,RIGHT_BORDER+1,TOP_BORDER,BACKGROUND_PEN);
 
 	/* field */
-	plot_box(bitmap,0,TOP_BORDER,RIGHT_BORDER+1,BOTTOM_BORDER-TOP_BORDER+1,FIELD_PEN);
+	bitmap.plot_box(0,TOP_BORDER,RIGHT_BORDER+1,BOTTOM_BORDER-TOP_BORDER+1,FIELD_PEN);
 
 	/* car 1 */
-	draw_sprite(screen->machine(), bitmap, cliprect,
+	draw_sprite(screen.machine(), bitmap, cliprect,
 				state->m_spriteram[0x00], state->m_spriteram[0x01],
 				0, state->m_spriteram[0x0c] & 0x0f, CAR1_COLOR);
 
 	/* border - position determined by bit 4 and 7 of the vertical timing PROM */
-	plot_box(bitmap,0,TOP_BORDER,   RIGHT_BORDER+1,1,LINE_PEN);
-	plot_box(bitmap,0,BOTTOM_BORDER,RIGHT_BORDER+1,1,LINE_PEN);
-	plot_box(bitmap,LEFT_BORDER,TOP_BORDER, 1,BOTTOM_BORDER-TOP_BORDER+1,LINE_PEN);
-	plot_box(bitmap,RIGHT_BORDER,TOP_BORDER,1,BOTTOM_BORDER-TOP_BORDER+1,LINE_PEN);
+	bitmap.plot_box(0,TOP_BORDER,   RIGHT_BORDER+1,1,LINE_PEN);
+	bitmap.plot_box(0,BOTTOM_BORDER,RIGHT_BORDER+1,1,LINE_PEN);
+	bitmap.plot_box(LEFT_BORDER,TOP_BORDER, 1,BOTTOM_BORDER-TOP_BORDER+1,LINE_PEN);
+	bitmap.plot_box(RIGHT_BORDER,TOP_BORDER,1,BOTTOM_BORDER-TOP_BORDER+1,LINE_PEN);
 
 	/* car 4 */
-	draw_sprite(screen->machine(), bitmap, cliprect,
+	draw_sprite(screen.machine(), bitmap, cliprect,
 				state->m_spriteram[0x06], state->m_spriteram[0x07],
 				0, state->m_spriteram[0x0d] >> 4, CAR4_COLOR);
 
 	/* car 3 */
-	draw_sprite(screen->machine(), bitmap, cliprect,
+	draw_sprite(screen.machine(), bitmap, cliprect,
 				state->m_spriteram[0x04], state->m_spriteram[0x05],
 				0, state->m_spriteram[0x0d] & 0x0f, CAR3_COLOR);
 
 	/* car 2 */
-	draw_sprite(screen->machine(), bitmap, cliprect,
+	draw_sprite(screen.machine(), bitmap, cliprect,
 				state->m_spriteram[0x02], state->m_spriteram[0x03],
 				0, state->m_spriteram[0x0c] >> 4, CAR2_COLOR);
 
 	/* ball */
-	draw_sprite(screen->machine(), bitmap, cliprect,
+	draw_sprite(screen.machine(), bitmap, cliprect,
 				state->m_spriteram[0x08], state->m_spriteram[0x09],
 				1, state->m_spriteram[0x0e] & 0x0f, BALL_COLOR);
 
 	/* left goal - position determined by bit 6 of the
        horizontal and vertical timing PROMs */
-	drawgfxzoom_transpen(bitmap,cliprect,screen->machine().gfx[1],
+	drawgfxzoom_transpen(bitmap,cliprect,screen.machine().gfx[1],
 				0,0,
 				0,0,
 				LEFT_GOAL_X,GOAL_Y,
 				0x20000,0x20000,0);
 
 	/* right goal */
-	drawgfxzoom_transpen(bitmap,cliprect,screen->machine().gfx[1],
+	drawgfxzoom_transpen(bitmap,cliprect,screen.machine().gfx[1],
 				0,1,
 				1,0,
 				RIGHT_GOAL_X,GOAL_Y,
@@ -284,7 +283,7 @@ SCREEN_UPDATE( carpolo )
 		popmessage("WIDE!\n");
 
 	if (state->m_spriteram[0x0f] & 0x01)
-		draw_sprite(screen->machine(), bitmap, cliprect,
+		draw_sprite(screen.machine(), bitmap, cliprect,
 					state->m_spriteram[0x0a], state->m_spriteram[0x0b],
 					1, state->m_spriteram[0x0e] >> 4, SPECIAL_CHAR_COLOR);
 
@@ -295,14 +294,14 @@ SCREEN_UPDATE( carpolo )
        and bit 3 of the vertical timing PROM controls in
        which quadrant the line will actually appear */
 
-	draw_alpha_line(screen->machine(), bitmap, cliprect, 0, (0*4+0)*2  );
-	draw_alpha_line(screen->machine(), bitmap, cliprect, 1, (0*4+0)*2+1);
-	draw_alpha_line(screen->machine(), bitmap, cliprect, 2, (3*4+1)*2  );
-	draw_alpha_line(screen->machine(), bitmap, cliprect, 3, (3*4+1)*2+1);
-	draw_alpha_line(screen->machine(), bitmap, cliprect, 4, (1*4+2)*2  );
-	draw_alpha_line(screen->machine(), bitmap, cliprect, 5, (1*4+2)*2+1);
-	draw_alpha_line(screen->machine(), bitmap, cliprect, 6, (0*4+3)*2  );
-	draw_alpha_line(screen->machine(), bitmap, cliprect, 7, (0*4+3)*2+1);
+	draw_alpha_line(screen.machine(), bitmap, cliprect, 0, (0*4+0)*2  );
+	draw_alpha_line(screen.machine(), bitmap, cliprect, 1, (0*4+0)*2+1);
+	draw_alpha_line(screen.machine(), bitmap, cliprect, 2, (3*4+1)*2  );
+	draw_alpha_line(screen.machine(), bitmap, cliprect, 3, (3*4+1)*2+1);
+	draw_alpha_line(screen.machine(), bitmap, cliprect, 4, (1*4+2)*2  );
+	draw_alpha_line(screen.machine(), bitmap, cliprect, 5, (1*4+2)*2+1);
+	draw_alpha_line(screen.machine(), bitmap, cliprect, 6, (0*4+3)*2  );
+	draw_alpha_line(screen.machine(), bitmap, cliprect, 7, (0*4+3)*2+1);
 
 	return 0;
 }
@@ -360,23 +359,23 @@ static int check_sprite_sprite_collision(running_machine &machine,
 
 		normalize_coordinates(&x1, &y1, &x2, &y2);
 
-		bitmap_fill(state->m_sprite_sprite_collision_bitmap1, 0, 0);
-		bitmap_fill(state->m_sprite_sprite_collision_bitmap2, 0, 0);
+		state->m_sprite_sprite_collision_bitmap1->fill(0);
+		state->m_sprite_sprite_collision_bitmap2->fill(0);
 
-		drawgfx_opaque(state->m_sprite_sprite_collision_bitmap1,0,machine.gfx[0],
+		drawgfx_opaque(*state->m_sprite_sprite_collision_bitmap1,state->m_sprite_sprite_collision_bitmap1->cliprect(),machine.gfx[0],
 				code1,0,
 				0,flipy1,
 				x1,y1);
 
-		drawgfx_opaque(state->m_sprite_sprite_collision_bitmap2,0,machine.gfx[0],
+		drawgfx_opaque(*state->m_sprite_sprite_collision_bitmap2,state->m_sprite_sprite_collision_bitmap2->cliprect(),machine.gfx[0],
 				code2,0,
 				0,flipy2,
 				x2,y2);
 
 		for (x = x1; x < x1 + SPRITE_WIDTH; x++)
 			for (y = y1; y < y1 + SPRITE_HEIGHT; y++)
-				if ((*BITMAP_ADDR16(state->m_sprite_sprite_collision_bitmap1, y, x) == 1) &&
-				    (*BITMAP_ADDR16(state->m_sprite_sprite_collision_bitmap2, y, x) == 1))
+				if ((state->m_sprite_sprite_collision_bitmap1->pix16(y, x) == 1) &&
+				    (state->m_sprite_sprite_collision_bitmap2->pix16(y, x) == 1))
 				{
 					*col_x = (x1 + x) & 0x0f;
 					*col_y = (y1 + y) & 0x0f;
@@ -414,15 +413,15 @@ static int check_sprite_left_goal_collision(running_machine &machine, int x1, in
 
 		normalize_coordinates(&x1, &y1, &x2, &y2);
 
-		bitmap_fill(state->m_sprite_goal_collision_bitmap1, 0, 0);
-		bitmap_fill(state->m_sprite_goal_collision_bitmap2, 0, 0);
+		state->m_sprite_goal_collision_bitmap1->fill(0);
+		state->m_sprite_goal_collision_bitmap2->fill(0);
 
-		drawgfx_opaque(state->m_sprite_goal_collision_bitmap1,0,machine.gfx[0],
+		drawgfx_opaque(*state->m_sprite_goal_collision_bitmap1,state->m_sprite_goal_collision_bitmap1->cliprect(),machine.gfx[0],
 				code1,0,
 				0,flipy1,
 				x1,y1);
 
-		drawgfxzoom_transpen(state->m_sprite_goal_collision_bitmap2,0,machine.gfx[1],
+		drawgfxzoom_transpen(*state->m_sprite_goal_collision_bitmap2,state->m_sprite_goal_collision_bitmap2->cliprect(),machine.gfx[1],
 					0,0,
 					0,0,
 					x2,y2,
@@ -430,9 +429,9 @@ static int check_sprite_left_goal_collision(running_machine &machine, int x1, in
 
 		for (x = x1; x < x1 + SPRITE_WIDTH; x++)
 			for (y = y1; y < y1 + SPRITE_HEIGHT; y++)
-				if ((*BITMAP_ADDR16(state->m_sprite_goal_collision_bitmap1, y, x) == 1))
+				if ((state->m_sprite_goal_collision_bitmap1->pix16(y, x) == 1))
 				{
-					pen_t pix = *BITMAP_ADDR16(state->m_sprite_goal_collision_bitmap2, y, x);
+					pen_t pix = state->m_sprite_goal_collision_bitmap2->pix16(y, x);
 
 					if (pix == LEFT_GOAL_PEN)
 					{
@@ -472,15 +471,15 @@ static int check_sprite_right_goal_collision(running_machine &machine, int x1, i
 
 		normalize_coordinates(&x1, &y1, &x2, &y2);
 
-		bitmap_fill(state->m_sprite_goal_collision_bitmap1, 0, 0);
-		bitmap_fill(state->m_sprite_goal_collision_bitmap2, 0, 0);
+		state->m_sprite_goal_collision_bitmap1->fill(0);
+		state->m_sprite_goal_collision_bitmap2->fill(0);
 
-		drawgfx_opaque(state->m_sprite_goal_collision_bitmap1,0,machine.gfx[0],
+		drawgfx_opaque(*state->m_sprite_goal_collision_bitmap1,state->m_sprite_goal_collision_bitmap1->cliprect(),machine.gfx[0],
 				code1,0,
 				0,flipy1,
 				x1,y1);
 
-		drawgfxzoom_transpen(state->m_sprite_goal_collision_bitmap2,0,machine.gfx[1],
+		drawgfxzoom_transpen(*state->m_sprite_goal_collision_bitmap2,state->m_sprite_goal_collision_bitmap2->cliprect(),machine.gfx[1],
 					0,1,
 					1,0,
 					x2,y2,
@@ -488,9 +487,9 @@ static int check_sprite_right_goal_collision(running_machine &machine, int x1, i
 
 		for (x = x1; x < x1 + SPRITE_WIDTH; x++)
 			for (y = y1; y < y1 + SPRITE_HEIGHT; y++)
-				if ((*BITMAP_ADDR16(state->m_sprite_goal_collision_bitmap1, y, x) == 1))
+				if ((state->m_sprite_goal_collision_bitmap1->pix16(y, x) == 1))
 				{
-					pen_t pix = *BITMAP_ADDR16(state->m_sprite_goal_collision_bitmap2, y, x);
+					pen_t pix = state->m_sprite_goal_collision_bitmap2->pix16(y, x);
 
 					if (pix == RIGHT_GOAL_PEN)
 					{
@@ -521,14 +520,14 @@ static int check_sprite_border_collision(running_machine &machine, UINT8 x1, UIN
 	x1 = 240 - x1;
 	y1 = 240 - y1;
 
-	drawgfx_opaque(state->m_sprite_border_collision_bitmap,0,machine.gfx[0],
+	drawgfx_opaque(*state->m_sprite_border_collision_bitmap,state->m_sprite_border_collision_bitmap->cliprect(),machine.gfx[0],
 			code1,0,
 			0,flipy1,
 			0,0);
 
 	for (x = 0; x < SPRITE_WIDTH; x++)
 		for (y = 0; y < SPRITE_HEIGHT; y++)
-			if ((*BITMAP_ADDR16(state->m_sprite_border_collision_bitmap, y, x) == 1))
+			if ((state->m_sprite_border_collision_bitmap->pix16(y, x) == 1))
 			{
 				if (((UINT8)(x1 + x) == LEFT_BORDER) ||
 					((UINT8)(x1 + x) == RIGHT_BORDER))
@@ -549,182 +548,186 @@ static int check_sprite_border_collision(running_machine &machine, UINT8 x1, UIN
 }
 
 
-SCREEN_EOF( carpolo )
+SCREEN_VBLANK( carpolo )
 {
-	carpolo_state *state = machine.driver_data<carpolo_state>();
-	int col_x, col_y;
-	int car1_x, car2_x, car3_x, car4_x, ball_x;
-	int car1_y, car2_y, car3_y, car4_y, ball_y;
-	int car1_code, car2_code, car3_code, car4_code, ball_code;
-	int car1_flipy, car2_flipy, car3_flipy, car4_flipy, ball_flipy;
-
-
-	/* check car-car collision first */
-
-	car1_x = state->m_spriteram[0x00];
-	car1_y = state->m_spriteram[0x01];
-	remap_sprite_code(machine, 0, state->m_spriteram[0x0c] & 0x0f, &car1_code, &car1_flipy);
-
-	car2_x = state->m_spriteram[0x02];
-	car2_y = state->m_spriteram[0x03];
-	remap_sprite_code(machine, 0, state->m_spriteram[0x0c] >> 4,   &car2_code, &car2_flipy);
-
-	car3_x = state->m_spriteram[0x04];
-	car3_y = state->m_spriteram[0x05];
-	remap_sprite_code(machine, 0, state->m_spriteram[0x0d] & 0x0f, &car3_code, &car3_flipy);
-
-	car4_x = state->m_spriteram[0x06];
-	car4_y = state->m_spriteram[0x07];
-	remap_sprite_code(machine, 0, state->m_spriteram[0x0d] >> 4,   &car4_code, &car4_flipy);
-
-	ball_x = state->m_spriteram[0x08];
-	ball_y = state->m_spriteram[0x09];
-	remap_sprite_code(machine, 1, state->m_spriteram[0x0e] & 0x0f, &ball_code, &ball_flipy);
-
-
-	/* cars 1 and 2 */
-	if (check_sprite_sprite_collision(machine,
-									  car1_x, car1_y, car1_code, car1_flipy,
-									  car2_x, car2_y, car2_code, car2_flipy,
-									  &col_x, &col_y))
-		carpolo_generate_car_car_interrupt(machine, 0, 1);
-
-	/* cars 1 and 3 */
-	else if (check_sprite_sprite_collision(machine,
-										   car1_x, car1_y, car1_code, car1_flipy,
-										   car3_x, car3_y, car3_code, car3_flipy,
-										   &col_x, &col_y))
-		carpolo_generate_car_car_interrupt(machine, 0, 2);
-
-	/* cars 1 and 4 */
-	else if (check_sprite_sprite_collision(machine,
-										   car1_x, car1_y, car1_code, car1_flipy,
-										   car4_x, car4_y, car4_code, car4_flipy,
-										   &col_x, &col_y))
-		carpolo_generate_car_car_interrupt(machine, 0, 3);
-
-	/* cars 2 and 3 */
-	else if (check_sprite_sprite_collision(machine,
-										   car2_x, car2_y, car2_code, car2_flipy,
-										   car3_x, car3_y, car3_code, car3_flipy,
-										   &col_x, &col_y))
-		carpolo_generate_car_car_interrupt(machine, 1, 2);
-
-	/* cars 2 and 4 */
-	else if (check_sprite_sprite_collision(machine,
-										   car2_x, car2_y, car2_code, car2_flipy,
-										   car4_x, car4_y, car4_code, car4_flipy,
-										   &col_x, &col_y))
-		carpolo_generate_car_car_interrupt(machine, 1, 3);
-
-	/* cars 3 and 4 */
-	else if (check_sprite_sprite_collision(machine,
-										   car3_x, car3_y, car3_code, car3_flipy,
-										   car4_x, car4_y, car4_code, car4_flipy,
-										   &col_x, &col_y))
-		carpolo_generate_car_car_interrupt(machine, 2, 3);
-
-
-
-	/* check car-ball collision */
-	if (check_sprite_sprite_collision(machine,
-									  car1_x, car1_y, car1_code, car1_flipy,
-									  ball_x, ball_y, ball_code, ball_flipy,
-									  &col_x, &col_y))
-		carpolo_generate_car_ball_interrupt(machine, 0, col_x, col_y);
-
-	else if (check_sprite_sprite_collision(machine,
-										   car2_x, car2_y, car2_code, car2_flipy,
-										   ball_x, ball_y, ball_code, ball_flipy,
-										   &col_x, &col_y))
-		carpolo_generate_car_ball_interrupt(machine, 1, col_x, col_y);
-
-	else if (check_sprite_sprite_collision(machine,
-										   car3_x, car3_y, car3_code, car3_flipy,
-										   ball_x, ball_y, ball_code, ball_flipy,
-										   &col_x, &col_y))
-		carpolo_generate_car_ball_interrupt(machine, 2, col_x, col_y);
-
-	else if (check_sprite_sprite_collision(machine,
-										   car4_x, car4_y, car4_code, car4_flipy,
-										   ball_x, ball_y, ball_code, ball_flipy,
-										   &col_x, &col_y))
-		carpolo_generate_car_ball_interrupt(machine, 3, col_x, col_y);
-
-
-	/* check car-goal collision */
-	if (check_sprite_left_goal_collision(machine, car1_x, car1_y, car1_code, car1_flipy, 1))
-		carpolo_generate_car_goal_interrupt(machine, 0, 0);
-
-	else if (check_sprite_right_goal_collision(machine, car1_x, car1_y, car1_code, car1_flipy, 1))
-		carpolo_generate_car_goal_interrupt(machine, 0, 1);
-
-	else if (check_sprite_left_goal_collision(machine, car2_x, car2_y, car2_code, car2_flipy, 1))
-		carpolo_generate_car_goal_interrupt(machine, 1, 0);
-
-	else if (check_sprite_right_goal_collision(machine, car2_x, car2_y, car2_code, car2_flipy, 1))
-		carpolo_generate_car_goal_interrupt(machine, 1, 1);
-
-	else if (check_sprite_left_goal_collision(machine, car3_x, car3_y, car3_code, car3_flipy, 1))
-		carpolo_generate_car_goal_interrupt(machine, 2, 0);
-
-	else if (check_sprite_right_goal_collision(machine, car3_x, car3_y, car3_code, car3_flipy, 1))
-		carpolo_generate_car_goal_interrupt(machine, 2, 1);
-
-	else if (check_sprite_left_goal_collision(machine, car4_x, car4_y, car4_code, car4_flipy, 1))
-		carpolo_generate_car_goal_interrupt(machine, 3, 0);
-
-	else if (check_sprite_right_goal_collision(machine, car4_x, car4_y, car4_code, car4_flipy, 1))
-		carpolo_generate_car_goal_interrupt(machine, 3, 1);
-
-
-	/* check ball collision with static screen elements */
+	// rising edge
+	if (vblank_on)
 	{
-		int col;
-
-		col = check_sprite_left_goal_collision(machine, ball_x, ball_y, ball_code, ball_flipy, 0);
-
-		if (col == 1)  carpolo_generate_ball_screen_interrupt(machine, 0x05);
-		if (col == 2)  carpolo_generate_ball_screen_interrupt(machine, 0x03);
+		carpolo_state *state = screen.machine().driver_data<carpolo_state>();
+		int col_x, col_y;
+		int car1_x, car2_x, car3_x, car4_x, ball_x;
+		int car1_y, car2_y, car3_y, car4_y, ball_y;
+		int car1_code, car2_code, car3_code, car4_code, ball_code;
+		int car1_flipy, car2_flipy, car3_flipy, car4_flipy, ball_flipy;
 
 
-		col = check_sprite_right_goal_collision(machine, ball_x, ball_y, ball_code, ball_flipy, 0);
+		/* check car-car collision first */
 
-		if (col == 1)  carpolo_generate_ball_screen_interrupt(machine, 0x05 | 0x08);
-		if (col == 2)  carpolo_generate_ball_screen_interrupt(machine, 0x03 | 0x08);
+		car1_x = state->m_spriteram[0x00];
+		car1_y = state->m_spriteram[0x01];
+		remap_sprite_code(screen.machine(), 0, state->m_spriteram[0x0c] & 0x0f, &car1_code, &car1_flipy);
+
+		car2_x = state->m_spriteram[0x02];
+		car2_y = state->m_spriteram[0x03];
+		remap_sprite_code(screen.machine(), 0, state->m_spriteram[0x0c] >> 4,   &car2_code, &car2_flipy);
+
+		car3_x = state->m_spriteram[0x04];
+		car3_y = state->m_spriteram[0x05];
+		remap_sprite_code(screen.machine(), 0, state->m_spriteram[0x0d] & 0x0f, &car3_code, &car3_flipy);
+
+		car4_x = state->m_spriteram[0x06];
+		car4_y = state->m_spriteram[0x07];
+		remap_sprite_code(screen.machine(), 0, state->m_spriteram[0x0d] >> 4,   &car4_code, &car4_flipy);
+
+		ball_x = state->m_spriteram[0x08];
+		ball_y = state->m_spriteram[0x09];
+		remap_sprite_code(screen.machine(), 1, state->m_spriteram[0x0e] & 0x0f, &ball_code, &ball_flipy);
 
 
-		if (check_sprite_border_collision(machine, ball_x, ball_y, ball_code, ball_flipy))
-			carpolo_generate_ball_screen_interrupt(machine, 0x06);
-	}
+		/* cars 1 and 2 */
+		if (check_sprite_sprite_collision(screen.machine(),
+										  car1_x, car1_y, car1_code, car1_flipy,
+										  car2_x, car2_y, car2_code, car2_flipy,
+										  &col_x, &col_y))
+			carpolo_generate_car_car_interrupt(screen.machine(), 0, 1);
+
+		/* cars 1 and 3 */
+		else if (check_sprite_sprite_collision(screen.machine(),
+											   car1_x, car1_y, car1_code, car1_flipy,
+											   car3_x, car3_y, car3_code, car3_flipy,
+											   &col_x, &col_y))
+			carpolo_generate_car_car_interrupt(screen.machine(), 0, 2);
+
+		/* cars 1 and 4 */
+		else if (check_sprite_sprite_collision(screen.machine(),
+											   car1_x, car1_y, car1_code, car1_flipy,
+											   car4_x, car4_y, car4_code, car4_flipy,
+											   &col_x, &col_y))
+			carpolo_generate_car_car_interrupt(screen.machine(), 0, 3);
+
+		/* cars 2 and 3 */
+		else if (check_sprite_sprite_collision(screen.machine(),
+											   car2_x, car2_y, car2_code, car2_flipy,
+											   car3_x, car3_y, car3_code, car3_flipy,
+											   &col_x, &col_y))
+			carpolo_generate_car_car_interrupt(screen.machine(), 1, 2);
+
+		/* cars 2 and 4 */
+		else if (check_sprite_sprite_collision(screen.machine(),
+											   car2_x, car2_y, car2_code, car2_flipy,
+											   car4_x, car4_y, car4_code, car4_flipy,
+											   &col_x, &col_y))
+			carpolo_generate_car_car_interrupt(screen.machine(), 1, 3);
+
+		/* cars 3 and 4 */
+		else if (check_sprite_sprite_collision(screen.machine(),
+											   car3_x, car3_y, car3_code, car3_flipy,
+											   car4_x, car4_y, car4_code, car4_flipy,
+											   &col_x, &col_y))
+			carpolo_generate_car_car_interrupt(screen.machine(), 2, 3);
 
 
-	/* check car-border collision */
-	{
-		int col;
 
-		col = check_sprite_border_collision(machine, car1_x, car1_y, car1_code, car1_flipy);
+		/* check car-ball collision */
+		if (check_sprite_sprite_collision(screen.machine(),
+										  car1_x, car1_y, car1_code, car1_flipy,
+										  ball_x, ball_y, ball_code, ball_flipy,
+										  &col_x, &col_y))
+			carpolo_generate_car_ball_interrupt(screen.machine(), 0, col_x, col_y);
 
-		if (col)
-			carpolo_generate_car_border_interrupt(machine, 0, (col == 2));
-		else
+		else if (check_sprite_sprite_collision(screen.machine(),
+											   car2_x, car2_y, car2_code, car2_flipy,
+											   ball_x, ball_y, ball_code, ball_flipy,
+											   &col_x, &col_y))
+			carpolo_generate_car_ball_interrupt(screen.machine(), 1, col_x, col_y);
+
+		else if (check_sprite_sprite_collision(screen.machine(),
+											   car3_x, car3_y, car3_code, car3_flipy,
+											   ball_x, ball_y, ball_code, ball_flipy,
+											   &col_x, &col_y))
+			carpolo_generate_car_ball_interrupt(screen.machine(), 2, col_x, col_y);
+
+		else if (check_sprite_sprite_collision(screen.machine(),
+											   car4_x, car4_y, car4_code, car4_flipy,
+											   ball_x, ball_y, ball_code, ball_flipy,
+											   &col_x, &col_y))
+			carpolo_generate_car_ball_interrupt(screen.machine(), 3, col_x, col_y);
+
+
+		/* check car-goal collision */
+		if (check_sprite_left_goal_collision(screen.machine(), car1_x, car1_y, car1_code, car1_flipy, 1))
+			carpolo_generate_car_goal_interrupt(screen.machine(), 0, 0);
+
+		else if (check_sprite_right_goal_collision(screen.machine(), car1_x, car1_y, car1_code, car1_flipy, 1))
+			carpolo_generate_car_goal_interrupt(screen.machine(), 0, 1);
+
+		else if (check_sprite_left_goal_collision(screen.machine(), car2_x, car2_y, car2_code, car2_flipy, 1))
+			carpolo_generate_car_goal_interrupt(screen.machine(), 1, 0);
+
+		else if (check_sprite_right_goal_collision(screen.machine(), car2_x, car2_y, car2_code, car2_flipy, 1))
+			carpolo_generate_car_goal_interrupt(screen.machine(), 1, 1);
+
+		else if (check_sprite_left_goal_collision(screen.machine(), car3_x, car3_y, car3_code, car3_flipy, 1))
+			carpolo_generate_car_goal_interrupt(screen.machine(), 2, 0);
+
+		else if (check_sprite_right_goal_collision(screen.machine(), car3_x, car3_y, car3_code, car3_flipy, 1))
+			carpolo_generate_car_goal_interrupt(screen.machine(), 2, 1);
+
+		else if (check_sprite_left_goal_collision(screen.machine(), car4_x, car4_y, car4_code, car4_flipy, 1))
+			carpolo_generate_car_goal_interrupt(screen.machine(), 3, 0);
+
+		else if (check_sprite_right_goal_collision(screen.machine(), car4_x, car4_y, car4_code, car4_flipy, 1))
+			carpolo_generate_car_goal_interrupt(screen.machine(), 3, 1);
+
+
+		/* check ball collision with static screen elements */
 		{
-			col = check_sprite_border_collision(machine, car2_x, car2_y, car2_code, car2_flipy);
+			int col;
+
+			col = check_sprite_left_goal_collision(screen.machine(), ball_x, ball_y, ball_code, ball_flipy, 0);
+
+			if (col == 1)  carpolo_generate_ball_screen_interrupt(screen.machine(), 0x05);
+			if (col == 2)  carpolo_generate_ball_screen_interrupt(screen.machine(), 0x03);
+
+
+			col = check_sprite_right_goal_collision(screen.machine(), ball_x, ball_y, ball_code, ball_flipy, 0);
+
+			if (col == 1)  carpolo_generate_ball_screen_interrupt(screen.machine(), 0x05 | 0x08);
+			if (col == 2)  carpolo_generate_ball_screen_interrupt(screen.machine(), 0x03 | 0x08);
+
+
+			if (check_sprite_border_collision(screen.machine(), ball_x, ball_y, ball_code, ball_flipy))
+				carpolo_generate_ball_screen_interrupt(screen.machine(), 0x06);
+		}
+
+
+		/* check car-border collision */
+		{
+			int col;
+
+			col = check_sprite_border_collision(screen.machine(), car1_x, car1_y, car1_code, car1_flipy);
 
 			if (col)
-				carpolo_generate_car_border_interrupt(machine, 1, (col == 2));
+				carpolo_generate_car_border_interrupt(screen.machine(), 0, (col == 2));
 			else
 			{
-				col = check_sprite_border_collision(machine, car3_x, car3_y, car3_code, car3_flipy);
+				col = check_sprite_border_collision(screen.machine(), car2_x, car2_y, car2_code, car2_flipy);
 
 				if (col)
-					carpolo_generate_car_border_interrupt(machine, 2, (col == 2));
+					carpolo_generate_car_border_interrupt(screen.machine(), 1, (col == 2));
 				else
 				{
-					col = check_sprite_border_collision(machine, car4_x, car4_y, car4_code, car4_flipy);
+					col = check_sprite_border_collision(screen.machine(), car3_x, car3_y, car3_code, car3_flipy);
 
 					if (col)
-						carpolo_generate_car_border_interrupt(machine, 3, (col == 2));
+						carpolo_generate_car_border_interrupt(screen.machine(), 2, (col == 2));
+					else
+					{
+						col = check_sprite_border_collision(screen.machine(), car4_x, car4_y, car4_code, car4_flipy);
+
+						if (col)
+							carpolo_generate_car_border_interrupt(screen.machine(), 3, (col == 2));
+					}
 				}
 			}
 		}
