@@ -400,7 +400,7 @@ static TILE_GET_INFO( cclimber_get_bs_tile_info )
 	int code, color;
 
 	/* only the lower right is visible */
-	tileinfo->group = ((tile_index & 0x210) == 0x210) ? 0 : 1;
+	tileinfo.group = ((tile_index & 0x210) == 0x210) ? 0 : 1;
 
 	/* the address doesn't use A4 of the coordinates, giving a 16x16 map */
 	tile_index = ((tile_index & 0x1e0) >> 1) | (tile_index & 0x0f);
@@ -418,7 +418,7 @@ static TILE_GET_INFO( toprollr_get_bs_tile_info )
 	int code, color;
 
 	/* only the lower right is visible */
-	tileinfo->group = ((tile_index & 0x210) == 0x210) ? 0 : 1;
+	tileinfo.group = ((tile_index & 0x210) == 0x210) ? 0 : 1;
 
 	/* the address doesn't use A4 of the coordinates, giving a 16x16 map */
 	tile_index = ((tile_index & 0x1e0) >> 1) | (tile_index & 0x0f);
@@ -444,14 +444,14 @@ VIDEO_START( cclimber )
 {
 	cclimber_state *state = machine.driver_data<cclimber_state>();
 	state->m_pf_tilemap = tilemap_create(machine, cclimber_get_pf_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
-	tilemap_set_transparent_pen(state->m_pf_tilemap, 0);
-	tilemap_set_scroll_cols(state->m_pf_tilemap, 32);
+	state->m_pf_tilemap->set_transparent_pen(0);
+	state->m_pf_tilemap->set_scroll_cols(32);
 
 	state->m_bs_tilemap = tilemap_create(machine, cclimber_get_bs_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
-	tilemap_set_scroll_cols(state->m_bs_tilemap, 1);
-	tilemap_set_scroll_rows(state->m_bs_tilemap, 1);
-	tilemap_set_transmask(state->m_bs_tilemap, 0, 0x01, 0);	/* pen 0 is transaprent */
-	tilemap_set_transmask(state->m_bs_tilemap, 1, 0x0f, 0);  /* all 4 pens are transparent */
+	state->m_bs_tilemap->set_scroll_cols(1);
+	state->m_bs_tilemap->set_scroll_rows(1);
+	state->m_bs_tilemap->set_transmask(0, 0x01, 0);	/* pen 0 is transaprent */
+	state->m_bs_tilemap->set_transmask(1, 0x0f, 0);  /* all 4 pens are transparent */
 }
 
 
@@ -459,14 +459,14 @@ VIDEO_START( swimmer )
 {
 	cclimber_state *state = machine.driver_data<cclimber_state>();
 	state->m_pf_tilemap = tilemap_create(machine, swimmer_get_pf_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
-	tilemap_set_transparent_pen(state->m_pf_tilemap, 0);
-	tilemap_set_scroll_cols(state->m_pf_tilemap, 32);
+	state->m_pf_tilemap->set_transparent_pen(0);
+	state->m_pf_tilemap->set_scroll_cols(32);
 
 	state->m_bs_tilemap = tilemap_create(machine, cclimber_get_bs_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
-	tilemap_set_scroll_cols(state->m_bs_tilemap, 1);
-	tilemap_set_scroll_rows(state->m_bs_tilemap, 1);
-	tilemap_set_transmask(state->m_bs_tilemap, 0, 0x01, 0);	/* pen 0 is transaprent */
-	tilemap_set_transmask(state->m_bs_tilemap, 1, 0xff, 0);  /* all 8 pens are transparent */
+	state->m_bs_tilemap->set_scroll_cols(1);
+	state->m_bs_tilemap->set_scroll_rows(1);
+	state->m_bs_tilemap->set_transmask(0, 0x01, 0);	/* pen 0 is transaprent */
+	state->m_bs_tilemap->set_transmask(1, 0xff, 0);  /* all 8 pens are transparent */
 }
 
 
@@ -474,35 +474,35 @@ VIDEO_START( toprollr )
 {
 	cclimber_state *state = machine.driver_data<cclimber_state>();
 	state->m_pf_tilemap = tilemap_create(machine, toprollr_get_pf_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
-	tilemap_set_transparent_pen(state->m_pf_tilemap, 0);
+	state->m_pf_tilemap->set_transparent_pen(0);
 
 	state->m_toproller_bg_tilemap = tilemap_create(machine, toproller_get_bg_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
-	tilemap_set_scroll_rows(state->m_toproller_bg_tilemap, 1);
+	state->m_toproller_bg_tilemap->set_scroll_rows(1);
 
 	state->m_bs_tilemap = tilemap_create(machine, toprollr_get_bs_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
-	tilemap_set_scroll_cols(state->m_bs_tilemap, 1);
-	tilemap_set_scroll_rows(state->m_bs_tilemap, 1);
-	tilemap_set_transmask(state->m_bs_tilemap, 0, 0x01, 0);	/* pen 0 is transaprent */
-	tilemap_set_transmask(state->m_bs_tilemap, 1, 0x0f, 0);  /* all 4 pens are transparent */
+	state->m_bs_tilemap->set_scroll_cols(1);
+	state->m_bs_tilemap->set_scroll_rows(1);
+	state->m_bs_tilemap->set_transmask(0, 0x01, 0);	/* pen 0 is transaprent */
+	state->m_bs_tilemap->set_transmask(1, 0x0f, 0);  /* all 4 pens are transparent */
 }
 
 
-static void draw_playfield(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void draw_playfield(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	cclimber_state *state = machine.driver_data<cclimber_state>();
 	int i;
 
-	tilemap_mark_all_tiles_dirty(state->m_pf_tilemap);
-	tilemap_set_flip(state->m_pf_tilemap, (CCLIMBER_FLIP_X ? TILEMAP_FLIPX : 0) |
+	state->m_pf_tilemap->mark_all_dirty();
+	state->m_pf_tilemap->set_flip((CCLIMBER_FLIP_X ? TILEMAP_FLIPX : 0) |
 								 (CCLIMBER_FLIP_Y ? TILEMAP_FLIPY : 0));
 	for (i = 0; i < 32; i++)
-		tilemap_set_scrolly(state->m_pf_tilemap, i, state->m_column_scroll[i]);
+		state->m_pf_tilemap->set_scrolly(i, state->m_column_scroll[i]);
 
-	tilemap_draw(bitmap, cliprect, state->m_pf_tilemap, 0, 0);
+	state->m_pf_tilemap->draw(bitmap, cliprect, 0, 0);
 }
 
 
-static void cclimber_draw_bigsprite(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void cclimber_draw_bigsprite(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	cclimber_state *state = machine.driver_data<cclimber_state>();
 	UINT8 x = state->m_bigsprite_control[3] - 8;
@@ -516,36 +516,36 @@ static void cclimber_draw_bigsprite(running_machine &machine, bitmap_t *bitmap,
 	if (bigsprite_flip_y)
 		y = 0x80 - y;
 
-	tilemap_mark_all_tiles_dirty(state->m_bs_tilemap);
+	state->m_bs_tilemap->mark_all_dirty();
 
-	tilemap_set_flip(state->m_bs_tilemap, (bigsprite_flip_x ? TILEMAP_FLIPX : 0) |
+	state->m_bs_tilemap->set_flip((bigsprite_flip_x ? TILEMAP_FLIPX : 0) |
 								 (CCLIMBER_FLIP_Y ^ bigsprite_flip_y ? TILEMAP_FLIPY : 0));
 
-	tilemap_set_scrollx(state->m_bs_tilemap, 0, x);
-	tilemap_set_scrolly(state->m_bs_tilemap, 0, y);
+	state->m_bs_tilemap->set_scrollx(0, x);
+	state->m_bs_tilemap->set_scrolly(0, y);
 
-	tilemap_draw(bitmap, cliprect, state->m_bs_tilemap, 0, 0);
+	state->m_bs_tilemap->draw(bitmap, cliprect, 0, 0);
 }
 
 
-static void toprollr_draw_bigsprite(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void toprollr_draw_bigsprite(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	cclimber_state *state = machine.driver_data<cclimber_state>();
 	UINT8 x = state->m_bigsprite_control[3] - 8;
 	UINT8 y = state->m_bigsprite_control[2];
 
-	tilemap_mark_all_tiles_dirty(state->m_bs_tilemap);
+	state->m_bs_tilemap->mark_all_dirty();
 
-	tilemap_set_flip(state->m_bs_tilemap, CCLIMBER_FLIP_Y ? TILEMAP_FLIPY : 0);
+	state->m_bs_tilemap->set_flip(CCLIMBER_FLIP_Y ? TILEMAP_FLIPY : 0);
 
-	tilemap_set_scrollx(state->m_bs_tilemap, 0, x);
-	tilemap_set_scrolly(state->m_bs_tilemap, 0, y);
+	state->m_bs_tilemap->set_scrollx(0, x);
+	state->m_bs_tilemap->set_scrolly(0, y);
 
-	tilemap_draw(bitmap, cliprect, state->m_bs_tilemap, 0, 0);
+	state->m_bs_tilemap->draw(bitmap, cliprect, 0, 0);
 }
 
 
-static void cclimber_draw_sprites(bitmap_t *bitmap, const rectangle *cliprect, const gfx_element *gfx)
+static void cclimber_draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect, const gfx_element *gfx)
 {
 	cclimber_state *state = gfx->machine().driver_data<cclimber_state>();
 	int offs;
@@ -586,7 +586,7 @@ static void cclimber_draw_sprites(bitmap_t *bitmap, const rectangle *cliprect, c
 }
 
 
-static void toprollr_draw_sprites(bitmap_t *bitmap, const rectangle *cliprect, const gfx_element *gfx)
+static void toprollr_draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect, const gfx_element *gfx)
 {
 	cclimber_state *state = gfx->machine().driver_data<cclimber_state>();
 	int offs;
@@ -624,7 +624,7 @@ static void toprollr_draw_sprites(bitmap_t *bitmap, const rectangle *cliprect, c
 }
 
 
-static void swimmer_draw_sprites(bitmap_t *bitmap, const rectangle *cliprect, const gfx_element *gfx)
+static void swimmer_draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect, const gfx_element *gfx)
 {
 	cclimber_state *state = gfx->machine().driver_data<cclimber_state>();
 	int offs;
@@ -662,35 +662,35 @@ static void swimmer_draw_sprites(bitmap_t *bitmap, const rectangle *cliprect, co
 }
 
 
-SCREEN_UPDATE( cclimber )
+SCREEN_UPDATE_IND16( cclimber )
 {
-	cclimber_state *state = screen->machine().driver_data<cclimber_state>();
-	bitmap_fill(bitmap, cliprect, CCLIMBER_BG_PEN);
-	draw_playfield(screen->machine(), bitmap, cliprect);
+	cclimber_state *state = screen.machine().driver_data<cclimber_state>();
+	bitmap.fill(CCLIMBER_BG_PEN, cliprect);
+	draw_playfield(screen.machine(), bitmap, cliprect);
 
 	/* draw the "big sprite" under the regular sprites */
 	if ((state->m_bigsprite_control[0] & 0x01))
 	{
-		cclimber_draw_bigsprite(screen->machine(), bitmap, cliprect);
-		cclimber_draw_sprites(bitmap, cliprect, screen->machine().gfx[1]);
+		cclimber_draw_bigsprite(screen.machine(), bitmap, cliprect);
+		cclimber_draw_sprites(bitmap, cliprect, screen.machine().gfx[1]);
 	}
 
 	/* draw the "big sprite" over the regular sprites */
 	else
 	{
-		cclimber_draw_sprites(bitmap, cliprect, screen->machine().gfx[1]);
-		cclimber_draw_bigsprite(screen->machine(), bitmap, cliprect);
+		cclimber_draw_sprites(bitmap, cliprect, screen.machine().gfx[1]);
+		cclimber_draw_bigsprite(screen.machine(), bitmap, cliprect);
 	}
 
 	return 0;
 }
 
 
-SCREEN_UPDATE( yamato )
+SCREEN_UPDATE_IND16( yamato )
 {
-	cclimber_state *state = screen->machine().driver_data<cclimber_state>();
+	cclimber_state *state = screen.machine().driver_data<cclimber_state>();
 	int i;
-	UINT8 *sky_rom = screen->machine().region("user1")->base() + 0x1200;
+	UINT8 *sky_rom = screen.machine().region("user1")->base() + 0x1200;
 
 	for (i = 0; i < 0x100; i++)
 	{
@@ -698,115 +698,115 @@ SCREEN_UPDATE( yamato )
 		pen_t pen = YAMATO_SKY_PEN_BASE + sky_rom[(CCLIMBER_FLIP_X ? 0x80 : 0) + (i >> 1)];
 
 		for (j = 0; j < 0x100; j++)
-			*BITMAP_ADDR16(bitmap, j, (i - 8) & 0xff) = pen;
+			bitmap.pix16(j, (i - 8) & 0xff) = pen;
 	}
 
-	draw_playfield(screen->machine(), bitmap, cliprect);
+	draw_playfield(screen.machine(), bitmap, cliprect);
 
 	/* draw the "big sprite" under the regular sprites */
 	if ((state->m_bigsprite_control[0] & 0x01))
 	{
-		cclimber_draw_bigsprite(screen->machine(), bitmap, cliprect);
-		toprollr_draw_sprites(bitmap, cliprect, screen->machine().gfx[1]);
+		cclimber_draw_bigsprite(screen.machine(), bitmap, cliprect);
+		toprollr_draw_sprites(bitmap, cliprect, screen.machine().gfx[1]);
 	}
 
 	/* draw the "big sprite" over the regular sprites */
 	else
 	{
-		toprollr_draw_sprites(bitmap, cliprect, screen->machine().gfx[1]);
-		cclimber_draw_bigsprite(screen->machine(), bitmap, cliprect);
+		toprollr_draw_sprites(bitmap, cliprect, screen.machine().gfx[1]);
+		cclimber_draw_bigsprite(screen.machine(), bitmap, cliprect);
 	}
 
 	return 0;
 }
 
 
-SCREEN_UPDATE( swimmer )
+SCREEN_UPDATE_IND16( swimmer )
 {
-	cclimber_state *state = screen->machine().driver_data<cclimber_state>();
-	swimmer_set_background_pen(screen->machine());
+	cclimber_state *state = screen.machine().driver_data<cclimber_state>();
+	swimmer_set_background_pen(screen.machine());
 
 	if (*state->m_swimmer_side_background_enabled & 0x01)
 	{
 		if (CCLIMBER_FLIP_X)
 		{
-			rectangle split_rect_left =  { 0, 0xff - SWIMMER_BG_SPLIT, 0, 0xff };
-			rectangle split_rect_right = { 0x100 - SWIMMER_BG_SPLIT, 0xff, 0, 0xff };
+			rectangle split_rect_left(0, 0xff - SWIMMER_BG_SPLIT, 0, 0xff);
+			rectangle split_rect_right(0x100 - SWIMMER_BG_SPLIT, 0xff, 0, 0xff);
 
-			sect_rect(&split_rect_left, cliprect);
-			bitmap_fill(bitmap, &split_rect_left, SWIMMER_SIDE_BG_PEN);
+			split_rect_left &= cliprect;
+			bitmap.fill(SWIMMER_SIDE_BG_PEN, split_rect_left);
 
-			sect_rect(&split_rect_right, cliprect);
-			bitmap_fill(bitmap, &split_rect_right, CCLIMBER_BG_PEN);
+			split_rect_right &= cliprect;
+			bitmap.fill(CCLIMBER_BG_PEN, split_rect_right);
 		}
 		else
 		{
-			rectangle split_rect_left =  { 0, SWIMMER_BG_SPLIT - 1, 0, 0xff };
-			rectangle split_rect_right = { SWIMMER_BG_SPLIT, 0xff, 0, 0xff };
+			rectangle split_rect_left(0, SWIMMER_BG_SPLIT - 1, 0, 0xff);
+			rectangle split_rect_right(SWIMMER_BG_SPLIT, 0xff, 0, 0xff);
 
-			sect_rect(&split_rect_left, cliprect);
-			bitmap_fill(bitmap, &split_rect_left, CCLIMBER_BG_PEN);
+			split_rect_left &= cliprect;
+			bitmap.fill(CCLIMBER_BG_PEN, split_rect_left);
 
-			sect_rect(&split_rect_right, cliprect);
-			bitmap_fill(bitmap, &split_rect_right, SWIMMER_SIDE_BG_PEN);
+			split_rect_right &= cliprect;
+			bitmap.fill(SWIMMER_SIDE_BG_PEN, split_rect_right);
 		}
 	}
 	else
-		bitmap_fill(bitmap, cliprect, CCLIMBER_BG_PEN);
+		bitmap.fill(CCLIMBER_BG_PEN, cliprect);
 
-	draw_playfield(screen->machine(), bitmap, cliprect);
+	draw_playfield(screen.machine(), bitmap, cliprect);
 
 	/* draw the "big sprite" under the regular sprites */
 	if ((state->m_bigsprite_control[0] & 0x01))
 	{
-		cclimber_draw_bigsprite(screen->machine(), bitmap, cliprect);
-		swimmer_draw_sprites(bitmap, cliprect, screen->machine().gfx[1]);
+		cclimber_draw_bigsprite(screen.machine(), bitmap, cliprect);
+		swimmer_draw_sprites(bitmap, cliprect, screen.machine().gfx[1]);
 	}
 
 	/* draw the "big sprite" over the regular sprites */
 	else
 	{
-		swimmer_draw_sprites(bitmap, cliprect, screen->machine().gfx[1]);
-		cclimber_draw_bigsprite(screen->machine(), bitmap, cliprect);
+		swimmer_draw_sprites(bitmap, cliprect, screen.machine().gfx[1]);
+		cclimber_draw_bigsprite(screen.machine(), bitmap, cliprect);
 	}
 
 	return 0;
 }
 
 
-SCREEN_UPDATE( toprollr )
+SCREEN_UPDATE_IND16( toprollr )
 {
-	cclimber_state *state = screen->machine().driver_data<cclimber_state>();
-	rectangle scroll_area_clip = *cliprect;
+	cclimber_state *state = screen.machine().driver_data<cclimber_state>();
+	rectangle scroll_area_clip = cliprect;
 	scroll_area_clip.min_x = 4*8;
 	scroll_area_clip.max_x = 29*8-1;
 
-	bitmap_fill(bitmap, cliprect, CCLIMBER_BG_PEN);
+	bitmap.fill(CCLIMBER_BG_PEN, cliprect);
 
-	tilemap_set_scrollx(state->m_toproller_bg_tilemap, 0, state->m_toprollr_bg_videoram[0]);
-	tilemap_set_flip(state->m_toproller_bg_tilemap, (CCLIMBER_FLIP_X ? TILEMAP_FLIPX : 0) |
+	state->m_toproller_bg_tilemap->set_scrollx(0, state->m_toprollr_bg_videoram[0]);
+	state->m_toproller_bg_tilemap->set_flip((CCLIMBER_FLIP_X ? TILEMAP_FLIPX : 0) |
 										   (CCLIMBER_FLIP_Y ? TILEMAP_FLIPY : 0));
-	tilemap_mark_all_tiles_dirty(state->m_toproller_bg_tilemap);
-	tilemap_draw(bitmap, &scroll_area_clip, state->m_toproller_bg_tilemap, 0, 0);
+	state->m_toproller_bg_tilemap->mark_all_dirty();
+	state->m_toproller_bg_tilemap->draw(bitmap, scroll_area_clip, 0, 0);
 
 	/* draw the "big sprite" over the regular sprites */
 	if ((state->m_bigsprite_control[1] & 0x20))
 	{
-		toprollr_draw_sprites(bitmap, &scroll_area_clip, screen->machine().gfx[1]);
-		toprollr_draw_bigsprite(screen->machine(), bitmap, &scroll_area_clip);
+		toprollr_draw_sprites(bitmap, scroll_area_clip, screen.machine().gfx[1]);
+		toprollr_draw_bigsprite(screen.machine(), bitmap, scroll_area_clip);
 	}
 
 	/* draw the "big sprite" under the regular sprites */
 	else
 	{
-		toprollr_draw_bigsprite(screen->machine(), bitmap, &scroll_area_clip);
-		toprollr_draw_sprites(bitmap, &scroll_area_clip, screen->machine().gfx[1]);
+		toprollr_draw_bigsprite(screen.machine(), bitmap, scroll_area_clip);
+		toprollr_draw_sprites(bitmap, scroll_area_clip, screen.machine().gfx[1]);
 	}
 
-	tilemap_mark_all_tiles_dirty(state->m_pf_tilemap);
-	tilemap_set_flip(state->m_pf_tilemap, (CCLIMBER_FLIP_X ? TILEMAP_FLIPX : 0) |
+	state->m_pf_tilemap->mark_all_dirty();
+	state->m_pf_tilemap->set_flip((CCLIMBER_FLIP_X ? TILEMAP_FLIPX : 0) |
 								 (CCLIMBER_FLIP_Y ? TILEMAP_FLIPY : 0));
-	tilemap_draw(bitmap, cliprect, state->m_pf_tilemap, 0, 0);
+	state->m_pf_tilemap->draw(bitmap, cliprect, 0, 0);
 
 	return 0;
 }
