@@ -63,8 +63,8 @@ static void tx_tilemap_mark_all_dirty( running_machine &machine )
 {
 	chaknpop_state *state = machine.driver_data<chaknpop_state>();
 
-	tilemap_mark_all_tiles_dirty(state->m_tx_tilemap);
-	tilemap_set_flip(state->m_tx_tilemap, state->m_flip_x | state->m_flip_y);
+	state->m_tx_tilemap->mark_all_dirty();
+	state->m_tx_tilemap->set_flip(state->m_flip_x | state->m_flip_y);
 }
 
 READ8_HANDLER( chaknpop_gfxmode_r )
@@ -106,7 +106,7 @@ WRITE8_HANDLER( chaknpop_txram_w )
 	chaknpop_state *state = space->machine().driver_data<chaknpop_state>();
 
 	state->m_tx_ram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_tx_tilemap, offset);
+	state->m_tx_tilemap->mark_tile_dirty(offset);
 }
 
 WRITE8_HANDLER( chaknpop_attrram_w )
@@ -183,7 +183,7 @@ VIDEO_START( chaknpop )
   Screen refresh
 ***************************************************************************/
 
-static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_sprites( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect )
 {
 	chaknpop_state *state = machine.driver_data<chaknpop_state>();
 	int offs;
@@ -218,7 +218,7 @@ static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rect
 	}
 }
 
-static void draw_bitmap( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_bitmap( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect )
 {
 	chaknpop_state *state = machine.driver_data<chaknpop_state>();
 	int dx = state->m_flip_x ? -1 : 1;
@@ -250,20 +250,20 @@ static void draw_bitmap( running_machine &machine, bitmap_t *bitmap, const recta
 
 			if (color)
 			{
-				pen_t pen = *BITMAP_ADDR16(bitmap, y, x);
+				pen_t pen = bitmap.pix16(y, x);
 				pen |= color;
-				*BITMAP_ADDR16(bitmap, y, x) = pen;
+				bitmap.pix16(y, x) = pen;
 			}
 		}
 	}
 }
 
-SCREEN_UPDATE( chaknpop )
+SCREEN_UPDATE_IND16( chaknpop )
 {
-	chaknpop_state *state = screen->machine().driver_data<chaknpop_state>();
+	chaknpop_state *state = screen.machine().driver_data<chaknpop_state>();
 
-	tilemap_draw(bitmap, cliprect, state->m_tx_tilemap, 0, 0);
-	draw_sprites(screen->machine(), bitmap, cliprect);
-	draw_bitmap(screen->machine(), bitmap, cliprect);
+	state->m_tx_tilemap->draw(bitmap, cliprect, 0, 0);
+	draw_sprites(screen.machine(), bitmap, cliprect);
+	draw_bitmap(screen.machine(), bitmap, cliprect);
 	return 0;
 }
