@@ -27,19 +27,6 @@ enum
 
 
 
-/*************************************
- *
- *  Local variables
- *
- *************************************/
-
-static int color_mode;
-static rgb_t vector_color;
-static INT16 lastx, lasty;
-static UINT8 last_control;
-
-
-
 /*************************************
  *
  *  Vector rendering
@@ -48,7 +35,8 @@ static UINT8 last_control;
 
 void cinemat_vector_callback(device_t *device, INT16 sx, INT16 sy, INT16 ex, INT16 ey, UINT8 shift)
 {
-	const rectangle &visarea = device->machine->primary_screen->visible_area();
+	cinemat_state *state = device->machine().driver_data<cinemat_state>();
+	const rectangle &visarea = device->machine().primary_screen->visible_area();
 	int intensity = 0xff;
 
 	/* adjust for slop */
@@ -62,15 +50,15 @@ void cinemat_vector_callback(device_t *device, INT16 sx, INT16 sy, INT16 ex, INT
 		intensity = 0x1ff * shift / 8;
 
 	/* move to the starting position if we're not there already */
-	if (sx != lastx || sy != lasty)
-		vector_add_point(device->machine, sx << 16, sy << 16, 0, 0);
+	if (sx != state->m_lastx || sy != state->m_lasty)
+		vector_add_point(device->machine(), sx << 16, sy << 16, 0, 0);
 
 	/* draw the vector */
-	vector_add_point(device->machine, ex << 16, ey << 16, vector_color, intensity);
+	vector_add_point(device->machine(), ex << 16, ey << 16, state->m_vector_color, intensity);
 
 	/* remember the last point */
-	lastx = ex;
-	lasty = ey;
+	state->m_lastx = ex;
+	state->m_lasty = ey;
 }
 
 
@@ -83,43 +71,44 @@ void cinemat_vector_callback(device_t *device, INT16 sx, INT16 sy, INT16 ex, INT
 
 WRITE8_HANDLER(cinemat_vector_control_w)
 {
+	cinemat_state *state = space->machine().driver_data<cinemat_state>();
 	int r, g, b, i;
-	cpu_device *cpu = space->machine->device<cpu_device>("maincpu");
+	cpu_device *cpu = space->machine().device<cpu_device>("maincpu");
 
-	switch (color_mode)
+	switch (state->m_color_mode)
 	{
 		case COLOR_BILEVEL:
 			/* color is either bright or dim, selected by the value sent to the port */
-			vector_color = (data & 1) ? MAKE_RGB(0x80,0x80,0x80) : MAKE_RGB(0xff,0xff,0xff);
+			state->m_vector_color = (data & 1) ? MAKE_RGB(0x80,0x80,0x80) : MAKE_RGB(0xff,0xff,0xff);
 			break;
 
 		case COLOR_16LEVEL:
 			/* on the rising edge of the data value, latch bits 0-3 of the */
 			/* X register as the intensity */
-			if (data != last_control && data)
+			if (data != state->m_last_control && data)
 			{
 				int xval = cpu->state(CCPU_X) & 0x0f;
 				i = (xval + 1) * 255 / 16;
-				vector_color = MAKE_RGB(i,i,i);
+				state->m_vector_color = MAKE_RGB(i,i,i);
 			}
 			break;
 
 		case COLOR_64LEVEL:
 			/* on the rising edge of the data value, latch bits 2-7 of the */
 			/* X register as the intensity */
-			if (data != last_control && data)
+			if (data != state->m_last_control && data)
 			{
 				int xval = cpu->state(CCPU_X);
 				xval = (~xval >> 2) & 0x3f;
 				i = (xval + 1) * 255 / 64;
-				vector_color = MAKE_RGB(i,i,i);
+				state->m_vector_color = MAKE_RGB(i,i,i);
 			}
 			break;
 
 		case COLOR_RGB:
 			/* on the rising edge of the data value, latch the X register */
 			/* as 4-4-4 BGR values */
-			if (data != last_control && data)
+			if (data != state->m_last_control && data)
 			{
 				int xval = cpu->state(CCPU_X);
 				r = (~xval >> 0) & 0x0f;
@@ -128,27 +117,25 @@ WRITE8_HANDLER(cinemat_vector_control_w)
 				g = g * 255 / 15;
 				b = (~xval >> 8) & 0x0f;
 				b = b * 255 / 15;
-				vector_color = MAKE_RGB(r,g,b);
+				state->m_vector_color = MAKE_RGB(r,g,b);
 			}
 			break;
 
 		case COLOR_QB3:
 			{
-				static int lastx, lasty;
-
 				/* on the falling edge of the data value, remember the original X,Y values */
 				/* they will be restored on the rising edge; this is to simulate the fact */
 				/* that the Rockola color hardware did not overwrite the beam X,Y position */
 				/* on an IV instruction if data == 0 here */
-				if (data != last_control && !data)
+				if (data != state->m_last_control && !data)
 				{
-					lastx = cpu->state(CCPU_X);
-					lasty = cpu->state(CCPU_Y);
+					state->m_qb3_lastx = cpu->state(CCPU_X);
+					state->m_qb3_lasty = cpu->state(CCPU_Y);
 				}
 
 				/* on the rising edge of the data value, latch the Y register */
 				/* as 2-3-3 BGR values */
-				if (data != last_control && data)
+				if (data != state->m_last_control && data)
 				{
 					int yval = cpu->state(CCPU_Y);
 					r = (~yval >> 0) & 0x07;
@@ -157,18 +144,18 @@ WRITE8_HANDLER(cinemat_vector_control_w)
 					g = g * 255 / 7;
 					b = (~yval >> 6) & 0x03;
 					b = b * 255 / 3;
-					vector_color = MAKE_RGB(r,g,b);
+					state->m_vector_color = MAKE_RGB(r,g,b);
 
 					/* restore the original X,Y values */
-					cpu->set_state(CCPU_X, lastx);
-					cpu->set_state(CCPU_Y, lasty);
+					cpu->set_state(CCPU_X, state->m_qb3_lastx);
+					cpu->set_state(CCPU_Y, state->m_qb3_lasty);
 				}
 			}
 			break;
 	}
 
 	/* remember the last value */
-	last_control = data;
+	state->m_last_control = data;
 }
 
 
@@ -181,35 +168,40 @@ WRITE8_HANDLER(cinemat_vector_control_w)
 
 VIDEO_START( cinemat_bilevel )
 {
-	color_mode = COLOR_BILEVEL;
+	cinemat_state *state = machine.driver_data<cinemat_state>();
+	state->m_color_mode = COLOR_BILEVEL;
 	VIDEO_START_CALL(vector);
 }
 
 
 VIDEO_START( cinemat_16level )
 {
-	color_mode = COLOR_16LEVEL;
+	cinemat_state *state = machine.driver_data<cinemat_state>();
+	state->m_color_mode = COLOR_16LEVEL;
 	VIDEO_START_CALL(vector);
 }
 
 
 VIDEO_START( cinemat_64level )
 {
-	color_mode = COLOR_64LEVEL;
+	cinemat_state *state = machine.driver_data<cinemat_state>();
+	state->m_color_mode = COLOR_64LEVEL;
 	VIDEO_START_CALL(vector);
 }
 
 
 VIDEO_START( cinemat_color )
 {
-	color_mode = COLOR_RGB;
+	cinemat_state *state = machine.driver_data<cinemat_state>();
+	state->m_color_mode = COLOR_RGB;
 	VIDEO_START_CALL(vector);
 }
 
 
 VIDEO_START( cinemat_qb3color )
 {
-	color_mode = COLOR_QB3;
+	cinemat_state *state = machine.driver_data<cinemat_state>();
+	state->m_color_mode = COLOR_QB3;
 	VIDEO_START_CALL(vector);
 }
 
@@ -221,12 +213,12 @@ VIDEO_START( cinemat_qb3color )
  *
  *************************************/
 
-VIDEO_UPDATE( cinemat )
+SCREEN_UPDATE_RGB32( cinemat )
 {
-	VIDEO_UPDATE_CALL(vector);
+	SCREEN_UPDATE32_CALL(vector);
 	vector_clear_list();
 
-	ccpu_wdt_timer_trigger(screen->machine->device("maincpu"));
+	ccpu_wdt_timer_trigger(screen.machine().device("maincpu"));
 
 	return 0;
 }
@@ -239,11 +231,11 @@ VIDEO_UPDATE( cinemat )
  *
  *************************************/
 
-VIDEO_UPDATE( spacewar )
+SCREEN_UPDATE_RGB32( spacewar )
 {
-	int sw_option = input_port_read(screen->machine, "INPUTS");
+	int sw_option = input_port_read(screen.machine(), "INPUTS");
 
-	VIDEO_UPDATE_CALL(cinemat);
+	SCREEN_UPDATE32_CALL(cinemat);
 
 	/* set the state of the artwork */
 	output_set_value("pressed3", (~sw_option >> 0) & 1);
