@@ -15,7 +15,7 @@ WRITE8_HANDLER( commando_videoram_w )
 	commando_state *state = space->machine().driver_data<commando_state>();
 
 	state->m_videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
+	state->m_bg_tilemap->mark_tile_dirty(offset);
 }
 
 WRITE8_HANDLER( commando_colorram_w )
@@ -23,7 +23,7 @@ WRITE8_HANDLER( commando_colorram_w )
 	commando_state *state = space->machine().driver_data<commando_state>();
 
 	state->m_colorram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
+	state->m_bg_tilemap->mark_tile_dirty(offset);
 }
 
 WRITE8_HANDLER( commando_videoram2_w )
@@ -31,7 +31,7 @@ WRITE8_HANDLER( commando_videoram2_w )
 	commando_state *state = space->machine().driver_data<commando_state>();
 
 	state->m_videoram2[offset] = data;
-	tilemap_mark_tile_dirty(state->m_fg_tilemap, offset);
+	state->m_fg_tilemap->mark_tile_dirty(offset);
 }
 
 WRITE8_HANDLER( commando_colorram2_w )
@@ -39,7 +39,7 @@ WRITE8_HANDLER( commando_colorram2_w )
 	commando_state *state = space->machine().driver_data<commando_state>();
 
 	state->m_colorram2[offset] = data;
-	tilemap_mark_tile_dirty(state->m_fg_tilemap, offset);
+	state->m_fg_tilemap->mark_tile_dirty(offset);
 }
 
 WRITE8_HANDLER( commando_scrollx_w )
@@ -47,7 +47,7 @@ WRITE8_HANDLER( commando_scrollx_w )
 	commando_state *state = space->machine().driver_data<commando_state>();
 
 	state->m_scroll_x[offset] = data;
-	tilemap_set_scrollx(state->m_bg_tilemap, 0, state->m_scroll_x[0] | (state->m_scroll_x[1] << 8));
+	state->m_bg_tilemap->set_scrollx(0, state->m_scroll_x[0] | (state->m_scroll_x[1] << 8));
 }
 
 WRITE8_HANDLER( commando_scrolly_w )
@@ -55,7 +55,7 @@ WRITE8_HANDLER( commando_scrolly_w )
 	commando_state *state = space->machine().driver_data<commando_state>();
 
 	state->m_scroll_y[offset] = data;
-	tilemap_set_scrolly(state->m_bg_tilemap, 0, state->m_scroll_y[0] | (state->m_scroll_y[1] << 8));
+	state->m_bg_tilemap->set_scrolly(0, state->m_scroll_y[0] | (state->m_scroll_y[1] << 8));
 }
 
 WRITE8_HANDLER( commando_c804_w )
@@ -102,10 +102,10 @@ VIDEO_START( commando )
 	state->m_bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols, 16, 16, 32, 32);
 	state->m_fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
 
-	tilemap_set_transparent_pen(state->m_fg_tilemap, 3);
+	state->m_fg_tilemap->set_transparent_pen(3);
 }
 
-static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_sprites( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect )
 {
 	UINT8 *buffered_spriteram = machine.generic.buffered_spriteram.u8;
 	int offs;
@@ -135,19 +135,23 @@ static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rect
 	}
 }
 
-SCREEN_UPDATE( commando )
+SCREEN_UPDATE_IND16( commando )
 {
-	commando_state *state = screen->machine().driver_data<commando_state>();
+	commando_state *state = screen.machine().driver_data<commando_state>();
 
-	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
-	draw_sprites(screen->machine(), bitmap, cliprect);
-	tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
+	state->m_bg_tilemap->draw(bitmap, cliprect, 0, 0);
+	draw_sprites(screen.machine(), bitmap, cliprect);
+	state->m_fg_tilemap->draw(bitmap, cliprect, 0, 0);
 	return 0;
 }
 
-SCREEN_EOF( commando )
+SCREEN_VBLANK( commando )
 {
-	address_space *space = machine.device("maincpu")->memory().space(AS_PROGRAM);
+	// rising edge
+	if (vblank_on)
+	{
+		address_space *space = screen.machine().device("maincpu")->memory().space(AS_PROGRAM);
 
-	buffer_spriteram_w(space, 0, 0);
+		buffer_spriteram_w(space, 0, 0);
+	}
 }
