@@ -1000,7 +1000,7 @@ VIDEO_START( neruton )
 
 ***************************************************************************/
 
-static void hanamai_copylayer( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, int i )
+static void hanamai_copylayer( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int i )
 {
 	dynax_state *state = machine.driver_data<dynax_state>();
 	int color;
@@ -1036,7 +1036,7 @@ static void hanamai_copylayer( running_machine &machine, bitmap_t *bitmap, const
 		for (dy = 0; dy < 256; dy++)
 		{
 			UINT16 *dst;
-			UINT16 *dstbase = BITMAP_ADDR16(bitmap, (dy - scrolly) & 0xff, 0);
+			UINT16 *dstbase = &bitmap.pix16((dy - scrolly) & 0xff);
 
 			length = scrollx;
 			dst = dstbase + 2 * (256 - length);
@@ -1064,7 +1064,7 @@ static void hanamai_copylayer( running_machine &machine, bitmap_t *bitmap, const
 }
 
 
-static void jantouki_copylayer( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, int i, int y )
+static void jantouki_copylayer( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int i, int y )
 {
 	dynax_state *state = machine.driver_data<dynax_state>();
 	int color, scrollx, scrolly, palettes, palbank;
@@ -1104,9 +1104,9 @@ static void jantouki_copylayer( running_machine &machine, bitmap_t *bitmap, cons
 		{
 			int sy = ((dy - scrolly) & 0xff) + y;
 			UINT16 *dst;
-			UINT16 *dstbase = BITMAP_ADDR16(bitmap, sy, 0);
+			UINT16 *dstbase = &bitmap.pix16(sy);
 
-			if ((sy < cliprect->min_y) || (sy > cliprect->max_y))
+			if ((sy < cliprect.min_y) || (sy > cliprect.max_y))
 			{
 				src1 += 256;
 				src2 += 256;
@@ -1139,7 +1139,7 @@ static void jantouki_copylayer( running_machine &machine, bitmap_t *bitmap, cons
 }
 
 
-static void mjdialq2_copylayer( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, int i )
+static void mjdialq2_copylayer( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int i )
 {
 	dynax_state *state = machine.driver_data<dynax_state>();
 	int color;
@@ -1166,7 +1166,7 @@ static void mjdialq2_copylayer( running_machine &machine, bitmap_t *bitmap, cons
 		for (dy = 0; dy < 256; dy++)
 		{
 			UINT16 *dst;
-			UINT16 *dstbase = BITMAP_ADDR16(bitmap, (dy - scrolly) & 0xff, 0);
+			UINT16 *dstbase = &bitmap.pix16((dy - scrolly) & 0xff);
 
 			length = scrollx;
 			dst = dstbase + 256 - length;
@@ -1227,7 +1227,7 @@ static int debug_mask( running_machine &machine )
     I,O        -  Change palette (-,+)
     J,K & N,M  -  Change "tile"  (-,+, slow & fast)
     R          -  move "tile" to the next 1/8th of the gfx  */
-static int debug_viewer( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect )
+static int debug_viewer( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect )
 {
 
 #ifdef MAME_DEBUG
@@ -1255,13 +1255,13 @@ static int debug_viewer( running_machine &machine, bitmap_t *bitmap, const recta
 		state->m_blit_palettes = (c & 0xf) * 0x111;
 		state->m_blit_palbank  = (c >>  4) & 1;
 
-		bitmap_fill(bitmap, cliprect, 0);
+		bitmap.fill(0, cliprect);
 		memset(state->m_pixmap[0][0], 0, sizeof(UINT8) * 0x100 * 0x100);
 
 		if (state->m_layer_layout != LAYOUT_MJDIALQ2)
 			memset(state->m_pixmap[0][1], 0, sizeof(UINT8) * 0x100 * 0x100);
 		for (state->m_hanamai_layer_half = 0; state->m_hanamai_layer_half < 2; state->m_hanamai_layer_half++)
-			blitter_drawgfx(machine, 0, 1, "gfx1", i, 0, cliprect->min_x, cliprect->min_y, 3, 0);
+			blitter_drawgfx(machine, 0, 1, "gfx1", i, 0, cliprect.min_x, cliprect.min_y, 3, 0);
 
 		if (state->m_layer_layout != LAYOUT_MJDIALQ2)
 			hanamai_copylayer(machine, bitmap, cliprect, 0);
@@ -1278,18 +1278,18 @@ static int debug_viewer( running_machine &machine, bitmap_t *bitmap, const recta
 
 
 
-SCREEN_UPDATE( hanamai )
+SCREEN_UPDATE_IND16( hanamai )
 {
-	dynax_state *state = screen->machine().driver_data<dynax_state>();
+	dynax_state *state = screen.machine().driver_data<dynax_state>();
 	int layers_ctrl = ~state->m_layer_enable;
 	int lay[4];
 
-	if (debug_viewer(screen->machine(), bitmap, cliprect))
+	if (debug_viewer(screen.machine(), bitmap, cliprect))
 		return 0;
 
-	layers_ctrl &= debug_mask(screen->machine());
+	layers_ctrl &= debug_mask(screen.machine());
 
-	bitmap_fill(bitmap, cliprect, (state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 1) * 256);
+	bitmap.fill((state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 1) * 256, cliprect);
 
 	/* bit 4 = display enable? */
 	if (!(state->m_hanamai_priority & 0x10))
@@ -1306,27 +1306,27 @@ SCREEN_UPDATE( hanamai )
 		case 0x15:	lay[0] = 0; lay[1] = 2; lay[2] = 3; lay[3] = 1; break;
 	}
 
-	if (BIT(layers_ctrl, lay[0]))   hanamai_copylayer(screen->machine(), bitmap, cliprect, lay[0]);
-	if (BIT(layers_ctrl, lay[1]))   hanamai_copylayer(screen->machine(), bitmap, cliprect, lay[1]);
-	if (BIT(layers_ctrl, lay[2]))   hanamai_copylayer(screen->machine(), bitmap, cliprect, lay[2]);
-	if (BIT(layers_ctrl, lay[3]))   hanamai_copylayer(screen->machine(), bitmap, cliprect, lay[3]);
+	if (BIT(layers_ctrl, lay[0]))   hanamai_copylayer(screen.machine(), bitmap, cliprect, lay[0]);
+	if (BIT(layers_ctrl, lay[1]))   hanamai_copylayer(screen.machine(), bitmap, cliprect, lay[1]);
+	if (BIT(layers_ctrl, lay[2]))   hanamai_copylayer(screen.machine(), bitmap, cliprect, lay[2]);
+	if (BIT(layers_ctrl, lay[3]))   hanamai_copylayer(screen.machine(), bitmap, cliprect, lay[3]);
 	return 0;
 }
 
 
-SCREEN_UPDATE( hnoridur )
+SCREEN_UPDATE_IND16( hnoridur )
 {
-	dynax_state *state = screen->machine().driver_data<dynax_state>();
+	dynax_state *state = screen.machine().driver_data<dynax_state>();
 	int layers_ctrl = ~BITSWAP8(state->m_hanamai_priority, 7, 6, 5, 4, 0, 1, 2, 3);
 	int lay[4];
 	int pri;
 
-	if (debug_viewer(screen->machine(), bitmap, cliprect))
+	if (debug_viewer(screen.machine(), bitmap, cliprect))
 		return 0;
 
-	layers_ctrl &= debug_mask(screen->machine());
+	layers_ctrl &= debug_mask(screen.machine());
 
-	bitmap_fill(bitmap, cliprect, (state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 0x0f) * 256);
+	bitmap.fill((state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 0x0f) * 256, cliprect);
 
 	pri = state->m_hanamai_priority >> 4;
 
@@ -1342,78 +1342,87 @@ SCREEN_UPDATE( hnoridur )
 	lay[2] = (pri >>  4) & 3;
 	lay[3] = (pri >>  0) & 3;
 
-	if (BIT(layers_ctrl, lay[0]))   hanamai_copylayer(screen->machine(), bitmap, cliprect, lay[0]);
-	if (BIT(layers_ctrl, lay[1]))   hanamai_copylayer(screen->machine(), bitmap, cliprect, lay[1]);
-	if (BIT(layers_ctrl, lay[2]))   hanamai_copylayer(screen->machine(), bitmap, cliprect, lay[2]);
-	if (BIT(layers_ctrl, lay[3]))   hanamai_copylayer(screen->machine(), bitmap, cliprect, lay[3]);
+	if (BIT(layers_ctrl, lay[0]))   hanamai_copylayer(screen.machine(), bitmap, cliprect, lay[0]);
+	if (BIT(layers_ctrl, lay[1]))   hanamai_copylayer(screen.machine(), bitmap, cliprect, lay[1]);
+	if (BIT(layers_ctrl, lay[2]))   hanamai_copylayer(screen.machine(), bitmap, cliprect, lay[2]);
+	if (BIT(layers_ctrl, lay[3]))   hanamai_copylayer(screen.machine(), bitmap, cliprect, lay[3]);
 
 	return 0;
 }
 
 
-SCREEN_UPDATE( sprtmtch )
+SCREEN_UPDATE_IND16( sprtmtch )
 {
-	dynax_state *state = screen->machine().driver_data<dynax_state>();
+	dynax_state *state = screen.machine().driver_data<dynax_state>();
 	int layers_ctrl = ~state->m_layer_enable;
 
-	if (debug_viewer(screen->machine(),bitmap,cliprect))
+	if (debug_viewer(screen.machine(),bitmap,cliprect))
 		return 0;
 
-	layers_ctrl &= debug_mask(screen->machine());
+	layers_ctrl &= debug_mask(screen.machine());
 
-	bitmap_fill(bitmap, cliprect, (state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 1) * 256);
+	bitmap.fill((state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 1) * 256, cliprect);
 
-	if (BIT(layers_ctrl, 0))   hanamai_copylayer(screen->machine(), bitmap, cliprect, 0);
-	if (BIT(layers_ctrl, 1))   hanamai_copylayer(screen->machine(), bitmap, cliprect, 1);
-	if (BIT(layers_ctrl, 2))   hanamai_copylayer(screen->machine(), bitmap, cliprect, 2);
+	if (BIT(layers_ctrl, 0))   hanamai_copylayer(screen.machine(), bitmap, cliprect, 0);
+	if (BIT(layers_ctrl, 1))   hanamai_copylayer(screen.machine(), bitmap, cliprect, 1);
+	if (BIT(layers_ctrl, 2))   hanamai_copylayer(screen.machine(), bitmap, cliprect, 2);
 	return 0;
 }
 
-SCREEN_UPDATE( jantouki )
+SCREEN_UPDATE_IND16( jantouki_top )
 {
-	dynax_state *state = screen->machine().driver_data<dynax_state>();
+	dynax_state *state = screen.machine().driver_data<dynax_state>();
 	int layers_ctrl = state->m_layer_enable;
 
-	if (debug_viewer(screen->machine(), bitmap, cliprect))
+	if (debug_viewer(screen.machine(), bitmap, cliprect))
 		return 0;
 
-	layers_ctrl &= debug_mask(screen->machine());
+	layers_ctrl &= debug_mask(screen.machine());
 
-	bitmap_fill(bitmap, cliprect, (state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 1) * 256);
+	bitmap.fill((state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 1) * 256, cliprect);
 
-	if (screen == state->m_top_scr)
-	{
-	//  if (BIT(layers_ctrl, 0))   jantouki_copylayer(screen->machine(), bitmap, cliprect, 3, 0);
-		if (BIT(layers_ctrl, 1))   jantouki_copylayer(screen->machine(), bitmap, cliprect, 2, 0);
-		if (BIT(layers_ctrl, 2))   jantouki_copylayer(screen->machine(), bitmap, cliprect, 1, 0);
-		if (BIT(layers_ctrl, 3))   jantouki_copylayer(screen->machine(), bitmap, cliprect, 0, 0);
-	}
-	else if (screen == state->m_bot_scr)
-	{
-		if (BIT(layers_ctrl, 0))   jantouki_copylayer(screen->machine(), bitmap, cliprect, 3, 0);
-		if (BIT(layers_ctrl, 4))   jantouki_copylayer(screen->machine(), bitmap, cliprect, 7, 0);
-		if (BIT(layers_ctrl, 5))   jantouki_copylayer(screen->machine(), bitmap, cliprect, 6, 0);
-		if (BIT(layers_ctrl, 6))   jantouki_copylayer(screen->machine(), bitmap, cliprect, 5, 0);
-		if (BIT(layers_ctrl, 7))   jantouki_copylayer(screen->machine(), bitmap, cliprect, 4, 0);
-	}
+//  if (BIT(layers_ctrl, 0))   jantouki_copylayer(screen.machine(), bitmap, cliprect, 3, 0);
+	if (BIT(layers_ctrl, 1))   jantouki_copylayer(screen.machine(), bitmap, cliprect, 2, 0);
+	if (BIT(layers_ctrl, 2))   jantouki_copylayer(screen.machine(), bitmap, cliprect, 1, 0);
+	if (BIT(layers_ctrl, 3))   jantouki_copylayer(screen.machine(), bitmap, cliprect, 0, 0);
+	return 0;
+}
+
+SCREEN_UPDATE_IND16( jantouki_bottom )
+{
+	dynax_state *state = screen.machine().driver_data<dynax_state>();
+	int layers_ctrl = state->m_layer_enable;
+
+	if (debug_viewer(screen.machine(), bitmap, cliprect))
+		return 0;
+
+	layers_ctrl &= debug_mask(screen.machine());
+
+	bitmap.fill((state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 1) * 256, cliprect);
+
+	if (BIT(layers_ctrl, 0))   jantouki_copylayer(screen.machine(), bitmap, cliprect, 3, 0);
+	if (BIT(layers_ctrl, 4))   jantouki_copylayer(screen.machine(), bitmap, cliprect, 7, 0);
+	if (BIT(layers_ctrl, 5))   jantouki_copylayer(screen.machine(), bitmap, cliprect, 6, 0);
+	if (BIT(layers_ctrl, 6))   jantouki_copylayer(screen.machine(), bitmap, cliprect, 5, 0);
+	if (BIT(layers_ctrl, 7))   jantouki_copylayer(screen.machine(), bitmap, cliprect, 4, 0);
 	return 0;
 }
 
 
-SCREEN_UPDATE( mjdialq2 )
+SCREEN_UPDATE_IND16( mjdialq2 )
 {
-	dynax_state *state = screen->machine().driver_data<dynax_state>();
+	dynax_state *state = screen.machine().driver_data<dynax_state>();
 	int layers_ctrl = ~state->m_layer_enable;
 
-	if (debug_viewer(screen->machine(), bitmap, cliprect))
+	if (debug_viewer(screen.machine(), bitmap, cliprect))
 		return 0;
 
-	layers_ctrl &= debug_mask(screen->machine());
+	layers_ctrl &= debug_mask(screen.machine());
 
-	bitmap_fill(bitmap, cliprect, (state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 1) * 256);
+	bitmap.fill((state->m_blit_backpen & 0xff) + (state->m_blit_palbank & 1) * 256, cliprect);
 
-	if (BIT(layers_ctrl, 0))   mjdialq2_copylayer(screen->machine(), bitmap, cliprect, 0);
-	if (BIT(layers_ctrl, 1))   mjdialq2_copylayer(screen->machine(), bitmap, cliprect, 1);
+	if (BIT(layers_ctrl, 0))   mjdialq2_copylayer(screen.machine(), bitmap, cliprect, 0);
+	if (BIT(layers_ctrl, 1))   mjdialq2_copylayer(screen.machine(), bitmap, cliprect, 1);
 	return 0;
 }
 
@@ -1425,22 +1434,22 @@ VIDEO_START(htengoku)
 	VIDEO_START_CALL(hnoridur);
 }
 
-SCREEN_UPDATE(htengoku)
+SCREEN_UPDATE_IND16(htengoku)
 {
-	dynax_state *state = screen->machine().driver_data<dynax_state>();
+	dynax_state *state = screen.machine().driver_data<dynax_state>();
 	int layer, x, y;
 
 	// render the layers, one by one, "dynax.c" style. Then convert the pixmaps to "ddenlovr.c"
-	// format and let SCREEN_UPDATE(ddenlovr) do the final compositing (priorities + palettes)
+	// format and let SCREEN_UPDATE_IND16(ddenlovr) do the final compositing (priorities + palettes)
 	for (layer = 0; layer < 4; layer++)
 	{
-		bitmap_fill(bitmap, cliprect, 0);
-		hanamai_copylayer(screen->machine(), bitmap, cliprect, layer);
+		bitmap.fill(0, cliprect);
+		hanamai_copylayer(screen.machine(), bitmap, cliprect, layer);
 
 		for (y = 0; y < 256; y++)
 			for (x = 0; x < 512; x++)
-				state->m_ddenlovr_pixmap[3 - layer][y * 512 + x] = (UINT8)(*BITMAP_ADDR16(bitmap, y, x));
+				state->m_ddenlovr_pixmap[3 - layer][y * 512 + x] = (UINT8)(bitmap.pix16(y, x));
 	}
 
-	return SCREEN_UPDATE_CALL(ddenlovr);
+	return SCREEN_UPDATE16_CALL(ddenlovr);
 }
