@@ -12,64 +12,63 @@ Functions to emulate the video hardware of the machine.
 #include "includes/exzisus.h"
 
 
-UINT8 *exzisus_videoram0;
-UINT8 *exzisus_videoram1;
-UINT8 *exzisus_objectram0;
-UINT8 *exzisus_objectram1;
-size_t  exzisus_objectram_size0;
-size_t  exzisus_objectram_size1;
-
-
-
 /***************************************************************************
   Memory handlers
 ***************************************************************************/
 
 READ8_HANDLER ( exzisus_videoram_0_r )
 {
-	return exzisus_videoram0[offset];
+	exzisus_state *state = space->machine().driver_data<exzisus_state>();
+	return state->m_videoram0[offset];
 }
 
 
 READ8_HANDLER ( exzisus_videoram_1_r )
 {
-	return exzisus_videoram1[offset];
+	exzisus_state *state = space->machine().driver_data<exzisus_state>();
+	return state->m_videoram1[offset];
 }
 
 
 READ8_HANDLER ( exzisus_objectram_0_r )
 {
-	return exzisus_objectram0[offset];
+	exzisus_state *state = space->machine().driver_data<exzisus_state>();
+	return state->m_objectram0[offset];
 }
 
 
 READ8_HANDLER ( exzisus_objectram_1_r )
 {
-	return exzisus_objectram1[offset];
+	exzisus_state *state = space->machine().driver_data<exzisus_state>();
+	return state->m_objectram1[offset];
 }
 
 
 WRITE8_HANDLER( exzisus_videoram_0_w )
 {
-	exzisus_videoram0[offset] = data;
+	exzisus_state *state = space->machine().driver_data<exzisus_state>();
+	state->m_videoram0[offset] = data;
 }
 
 
 WRITE8_HANDLER( exzisus_videoram_1_w )
 {
-	exzisus_videoram1[offset] = data;
+	exzisus_state *state = space->machine().driver_data<exzisus_state>();
+	state->m_videoram1[offset] = data;
 }
 
 
 WRITE8_HANDLER( exzisus_objectram_0_w )
 {
-	exzisus_objectram0[offset] = data;
+	exzisus_state *state = space->machine().driver_data<exzisus_state>();
+	state->m_objectram0[offset] = data;
 }
 
 
 WRITE8_HANDLER( exzisus_objectram_1_w )
 {
-	exzisus_objectram1[offset] = data;
+	exzisus_state *state = space->machine().driver_data<exzisus_state>();
+	state->m_objectram1[offset] = data;
 }
 
 
@@ -77,36 +76,37 @@ WRITE8_HANDLER( exzisus_objectram_1_w )
   Screen refresh
 ***************************************************************************/
 
-VIDEO_UPDATE( exzisus )
+SCREEN_UPDATE_IND16( exzisus )
 {
+	exzisus_state *state = screen.machine().driver_data<exzisus_state>();
 	int offs;
 	int sx, sy, xc, yc;
 	int gfx_num, gfx_attr, gfx_offs;
 
 	/* Is this correct ? */
-	bitmap_fill(bitmap, cliprect, 1023);
+	bitmap.fill(1023, cliprect);
 
 	/* ---------- 1st TC0010VCU ---------- */
 	sx = 0;
-	for (offs = 0 ; offs < exzisus_objectram_size0 ; offs += 4)
+	for (offs = 0 ; offs < state->m_objectram_size0 ; offs += 4)
     {
 		int height;
 
 		/* Skip empty sprites. */
-		if ( !(*(UINT32 *)(&exzisus_objectram0[offs])) )
+		if ( !(*(UINT32 *)(&state->m_objectram0[offs])) )
 		{
 			continue;
 		}
 
-		gfx_num = exzisus_objectram0[offs + 1];
-		gfx_attr = exzisus_objectram0[offs + 3];
+		gfx_num = state->m_objectram0[offs + 1];
+		gfx_attr = state->m_objectram0[offs + 3];
 
 		if ((gfx_num & 0x80) == 0)	/* 16x16 sprites */
 		{
 			gfx_offs = ((gfx_num & 0x7f) << 3);
 			height = 2;
 
-			sx = exzisus_objectram0[offs + 2];
+			sx = state->m_objectram0[offs + 2];
 			sx |= (gfx_attr & 0x40) << 2;
 		}
 		else	/* tilemaps (each sprite is a 16x256 column) */
@@ -120,12 +120,12 @@ VIDEO_UPDATE( exzisus )
 			}
 			else
 			{
-				sx = exzisus_objectram0[offs + 2];
+				sx = state->m_objectram0[offs + 2];
 				sx |= (gfx_attr & 0x40) << 2;
 			}
 		}
 
-		sy = 256 - (height << 3) - (exzisus_objectram0[offs]);
+		sy = 256 - (height << 3) - (state->m_objectram0[offs]);
 
 		for (xc = 0 ; xc < 2 ; xc++)
 		{
@@ -134,21 +134,21 @@ VIDEO_UPDATE( exzisus )
 			{
 				int code, color, x, y;
 
-				code  = (exzisus_videoram0[goffs + 1] << 8) | exzisus_videoram0[goffs];
-				color = (exzisus_videoram0[goffs + 1] >> 6) | (gfx_attr & 0x0f);
+				code  = (state->m_videoram0[goffs + 1] << 8) | state->m_videoram0[goffs];
+				color = (state->m_videoram0[goffs + 1] >> 6) | (gfx_attr & 0x0f);
 				x = (sx + (xc << 3)) & 0xff;
 				y = (sy + (yc << 3)) & 0xff;
 
-				if (flip_screen_get(screen->machine))
+				if (flip_screen_get(screen.machine()))
 				{
 					x = 248 - x;
 					y = 248 - y;
 				}
 
-				drawgfx_transpen(bitmap, cliprect, screen->machine->gfx[0],
+				drawgfx_transpen(bitmap, cliprect, screen.machine().gfx[0],
 						code & 0x3fff,
 						color,
-						flip_screen_get(screen->machine), flip_screen_get(screen->machine),
+						flip_screen_get(screen.machine()), flip_screen_get(screen.machine()),
 						x, y, 15);
 				goffs += 2;
 			}
@@ -158,25 +158,25 @@ VIDEO_UPDATE( exzisus )
 
 	/* ---------- 2nd TC0010VCU ---------- */
 	sx = 0;
-	for (offs = 0 ; offs < exzisus_objectram_size1 ; offs += 4)
+	for (offs = 0 ; offs < state->m_objectram_size1 ; offs += 4)
     {
 		int height;
 
 		/* Skip empty sprites. */
-		if ( !(*(UINT32 *)(&exzisus_objectram1[offs])) )
+		if ( !(*(UINT32 *)(&state->m_objectram1[offs])) )
 		{
 			continue;
 		}
 
-		gfx_num = exzisus_objectram1[offs + 1];
-		gfx_attr = exzisus_objectram1[offs + 3];
+		gfx_num = state->m_objectram1[offs + 1];
+		gfx_attr = state->m_objectram1[offs + 3];
 
 		if ((gfx_num & 0x80) == 0)	/* 16x16 sprites */
 		{
 			gfx_offs = ((gfx_num & 0x7f) << 3);
 			height = 2;
 
-			sx = exzisus_objectram1[offs + 2];
+			sx = state->m_objectram1[offs + 2];
 			sx |= (gfx_attr & 0x40) << 2;
 		}
 		else	/* tilemaps (each sprite is a 16x256 column) */
@@ -190,11 +190,11 @@ VIDEO_UPDATE( exzisus )
 			}
 			else
 			{
-				sx = exzisus_objectram1[offs + 2];
+				sx = state->m_objectram1[offs + 2];
 				sx |= (gfx_attr & 0x40) << 2;
 			}
 		}
-		sy = 256 - (height << 3) - (exzisus_objectram1[offs]);
+		sy = 256 - (height << 3) - (state->m_objectram1[offs]);
 
 		for (xc = 0 ; xc < 2 ; xc++)
 		{
@@ -203,21 +203,21 @@ VIDEO_UPDATE( exzisus )
 			{
 				int code, color, x, y;
 
-				code  = (exzisus_videoram1[goffs + 1] << 8) | exzisus_videoram1[goffs];
-				color = (exzisus_videoram1[goffs + 1] >> 6) | (gfx_attr & 0x0f);
+				code  = (state->m_videoram1[goffs + 1] << 8) | state->m_videoram1[goffs];
+				color = (state->m_videoram1[goffs + 1] >> 6) | (gfx_attr & 0x0f);
 				x = (sx + (xc << 3)) & 0xff;
 				y = (sy + (yc << 3)) & 0xff;
 
-				if (flip_screen_get(screen->machine))
+				if (flip_screen_get(screen.machine()))
 				{
 					x = 248 - x;
 					y = 248 - y;
 				}
 
-				drawgfx_transpen(bitmap, cliprect, screen->machine->gfx[1],
+				drawgfx_transpen(bitmap, cliprect, screen.machine().gfx[1],
 						code & 0x3fff,
 						color,
-						flip_screen_get(screen->machine), flip_screen_get(screen->machine),
+						flip_screen_get(screen.machine()), flip_screen_get(screen.machine()),
 						x, y, 15);
 				goffs += 2;
 			}
