@@ -85,21 +85,21 @@ WRITE8_HANDLER( finalizr_videoctrl_w )
 
 
 
-SCREEN_UPDATE( finalizr )
+SCREEN_UPDATE_IND16( finalizr )
 {
-	finalizr_state *state = screen->machine().driver_data<finalizr_state>();
+	finalizr_state *state = screen.machine().driver_data<finalizr_state>();
 	int offs;
 
-	tilemap_mark_all_tiles_dirty(state->m_bg_tilemap);
-	tilemap_mark_all_tiles_dirty(state->m_fg_tilemap);
+	state->m_bg_tilemap->mark_all_dirty();
+	state->m_fg_tilemap->mark_all_dirty();
 
-	tilemap_set_scrollx(state->m_bg_tilemap, 0, *state->m_scroll - 32);
-	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
+	state->m_bg_tilemap->set_scrollx(0, *state->m_scroll - 32);
+	state->m_bg_tilemap->draw(bitmap, cliprect, 0, 0);
 
 	/* Draw the sprites. */
 	{
-		const gfx_element *gfx1 = screen->machine().gfx[1];
-		const gfx_element *gfx2 = screen->machine().gfx[2];
+		const gfx_element *gfx1 = screen.machine().gfx[1];
+		const gfx_element *gfx2 = screen.machine().gfx[2];
 
 		UINT8 *sr = state->m_spriterambank ? state->m_spriteram_2 : state->m_spriteram;
 
@@ -122,7 +122,7 @@ SCREEN_UPDATE( finalizr )
 
 			if (size >= 0x10)	/* 32x32 */
 			{
-				if (flip_screen_get(screen->machine()))
+				if (flip_screen_get(screen.machine()))
 				{
 					sx = 256 - sx;
 					sy = 224 - sy;
@@ -153,7 +153,7 @@ SCREEN_UPDATE( finalizr )
 			}
 			else
 			{
-				if (flip_screen_get(screen->machine()))
+				if (flip_screen_get(screen.machine()))
 				{
 					sx = ((size & 0x08) ? 280:272) - sx;
 					sy = ((size & 0x04) ? 248:240) - sy;
@@ -213,14 +213,14 @@ SCREEN_UPDATE( finalizr )
 	}
 
 	{
-		const rectangle &visarea = screen->visible_area();
-		rectangle clip = *cliprect;
+		const rectangle &visarea = screen.visible_area();
+		rectangle clip = cliprect;
 
 		/* draw top status region */
 		clip.min_x = visarea.min_x;
 		clip.max_x = visarea.min_x + 31;
-		tilemap_set_scrolldx(state->m_fg_tilemap,  0,-32);
-		tilemap_draw(bitmap, &clip, state->m_fg_tilemap, 0, 0);
+		state->m_fg_tilemap->set_scrolldx(0,-32);
+		state->m_fg_tilemap->draw(bitmap, clip, 0, 0);
 	}
 	return 0;
 }
