@@ -28,7 +28,7 @@ VIDEO_START(funybubl)
 {
 }
 
-static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_sprites( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect )
 {
 	funybubl_state *state = machine.driver_data<funybubl_state>();
 	UINT8 *source = &state->m_banked_vram[0x2000 - 0x20];
@@ -73,13 +73,13 @@ static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rect
 }
 
 
-SCREEN_UPDATE(funybubl)
+SCREEN_UPDATE_IND16(funybubl)
 {
-	funybubl_state *state = screen->machine().driver_data<funybubl_state>();
+	funybubl_state *state = screen.machine().driver_data<funybubl_state>();
 	int x, y, offs;
 	offs = 0;
 
-	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine()));
+	bitmap.fill(get_black_pen(screen.machine()), cliprect);
 
 	/* tilemap .. convert it .. banking makes it slightly more annoying but still easy */
 	for (y = 0; y < 32; y++)
@@ -89,15 +89,15 @@ SCREEN_UPDATE(funybubl)
 			int data;
 
 			data = state->m_banked_vram[offs] | (state->m_banked_vram[offs + 1] << 8);
-			drawgfx_transpen(bitmap, cliprect, screen->machine().gfx[0], data & 0x7fff, (data & 0x8000) ? 2 : 1, 0, 0, x*8, y*8, 0);
+			drawgfx_transpen(bitmap, cliprect, screen.machine().gfx[0], data & 0x7fff, (data & 0x8000) ? 2 : 1, 0, 0, x*8, y*8, 0);
 			offs += 2;
 		}
 	}
 
-	draw_sprites(screen->machine(), bitmap, cliprect);
+	draw_sprites(screen.machine(), bitmap, cliprect);
 
 #if 0
-	if ( screen->machine().input().code_pressed_once(KEYCODE_W) )
+	if ( screen.machine().input().code_pressed_once(KEYCODE_W) )
 	{
 		FILE *fp;
 
