@@ -9,7 +9,7 @@
 typedef struct _poly_extra_data poly_extra_data;
 struct _poly_extra_data
 {
-	bitmap_t *texbase;
+	bitmap_ind16 *texbase;
 };
 
 typedef struct _polygon polygon;
@@ -33,8 +33,8 @@ VIDEO_START( galastrm )
 	galastrm_state *state = machine.driver_data<galastrm_state>();
 	state->m_spritelist = auto_alloc_array(machine, struct tempsprite, 0x4000);
 
-	state->m_tmpbitmaps = machine.primary_screen->alloc_compatible_bitmap();
-	state->m_polybitmap = machine.primary_screen->alloc_compatible_bitmap();
+	machine.primary_screen->register_screen_bitmap(state->m_tmpbitmaps);
+	machine.primary_screen->register_screen_bitmap(state->m_polybitmap);
 
 	state->m_poly = poly_alloc(machine, 16, sizeof(poly_extra_data), POLYFLAG_ALLOW_QUADS);
 	machine.add_notifier(MACHINE_NOTIFY_EXIT, machine_notify_delegate(FUNC(galastrm_exit), &machine));
@@ -193,7 +193,7 @@ logerror("Sprite number %04x had %02x invalid chunks\n",tilenum,bad_chunks);
 	}
 }
 
-static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, const int *primasks, int priority)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, const int *primasks, int priority)
 {
 	galastrm_state *state = machine.driver_data<galastrm_state>();
 	struct tempsprite *sprite_ptr = state->m_sprite_ptr_pre;
@@ -223,9 +223,9 @@ static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const recta
 static void tc0610_draw_scanline(void *dest, INT32 scanline, const poly_extent *extent, const void *extradata, int threadid)
 {
 	const poly_extra_data *extra = (const poly_extra_data *)extradata;
-	bitmap_t *destmap = (bitmap_t *)dest;
-	UINT16 *framebuffer = BITMAP_ADDR16(destmap, scanline, 0);
-	bitmap_t *texbase = extra->texbase;
+	bitmap_ind16 *destmap = (bitmap_ind16 *)dest;
+	UINT16 *framebuffer = &destmap->pix16(scanline);
+	bitmap_ind16 *texbase = extra->texbase;
 	int startx = extent->startx;
 	int stopx = extent->stopx;
 	INT32 u = extent->param[0].start;
@@ -236,13 +236,13 @@ static void tc0610_draw_scanline(void *dest, INT32 scanline, const poly_extent *
 
 	for (x = startx; x < stopx; x++)
 	{
-		framebuffer[x] = *BITMAP_ADDR16(texbase, v >> 16, u >> 16);
+		framebuffer[x] = texbase->pix16(v >> 16, u >> 16);
 		u += dudx;
 		v += dvdx;
 	}
 }
 
-static void tc0610_rotate_draw(running_machine &machine, bitmap_t *bitmap, bitmap_t *srcbitmap, const rectangle *clip)
+static void tc0610_rotate_draw(running_machine &machine, bitmap_ind16 &bitmap, bitmap_ind16 &srcbitmap, const rectangle &clip)
 {
 	galastrm_state *state = machine.driver_data<galastrm_state>();
 	poly_extra_data *extra = (poly_extra_data *)poly_get_extra_data(state->m_poly);
@@ -254,8 +254,8 @@ static void tc0610_rotate_draw(running_machine &machine, bitmap_t *bitmap, bitma
 	const int rzy = state->m_tc0610_ctrl_reg[1][3];
 	const int ryx = state->m_tc0610_ctrl_reg[1][5];
 	const int ryy = state->m_tc0610_ctrl_reg[1][4];
-	const int lx  = srcbitmap->width;
-	const int ly  = srcbitmap->height;
+	const int lx  = srcbitmap.width();
+	const int ly  = srcbitmap.height();
 
 	int yx, /*yy,*/ zx, zy, pxx, pxy, pyx, pyy;
 	float /*ssn, scs, ysn, ycs,*/ zsn, zcs;
@@ -426,31 +426,27 @@ static void tc0610_rotate_draw(running_machine &machine, bitmap_t *bitmap, bitma
 	vert[3].p[0] = (float)(lx - 1) * 65536.0;
 	vert[3].p[1] = 0.0;
 
-	extra->texbase = srcbitmap;
+	extra->texbase = &srcbitmap;
 	callback = tc0610_draw_scanline;
-	poly_render_quad(state->m_poly, bitmap, clip, callback, 2, &vert[0], &vert[1], &vert[2], &vert[3]);
+	poly_render_quad(state->m_poly, &bitmap, clip, callback, 2, &vert[0], &vert[1], &vert[2], &vert[3]);
 }
 
 /**************************************************************
                 SCREEN REFRESH
 **************************************************************/
 
-SCREEN_UPDATE( galastrm )
+SCREEN_UPDATE_IND16( galastrm )
 {
-	galastrm_state *state = screen->machine().driver_data<galastrm_state>();
-	device_t *tc0100scn = screen->machine().device("tc0100scn");
-	device_t *tc0480scp = screen->machine().device("tc0480scp");
+	galastrm_state *state = screen.machine().driver_data<galastrm_state>();
+	device_t *tc0100scn = screen.machine().device("tc0100scn");
+	device_t *tc0480scp = screen.machine().device("tc0480scp");
 	UINT8 layer[5];
 	UINT8 pivlayer[3];
 	UINT16 priority;
 	static const int primasks[4] = {0xfffc, 0xfff0, 0xff00, 0x0};
-	rectangle clip;
-	bitmap_t *priority_bitmap = screen->machine().priority_bitmap;
+	bitmap_ind8 &priority_bitmap = screen.machine().priority_bitmap;
 
-	clip.min_x = 0;
-	clip.min_y = 0;
-	clip.max_x = screen->width() -1;
-	clip.max_y = screen->height() -1;
+	rectangle clip(0, screen.width() -1, 0, screen.height() -1);
 
 	tc0100scn_tilemap_update(tc0100scn);
 	tc0480scp_tilemap_update(tc0480scp);
@@ -466,9 +462,9 @@ SCREEN_UPDATE( galastrm )
 	pivlayer[1] = pivlayer[0] ^ 1;
 	pivlayer[2] = 2;
 
-	bitmap_fill(bitmap, cliprect, 0);
-	bitmap_fill(priority_bitmap, &clip, 0);
-	bitmap_fill(state->m_tmpbitmaps, &clip, 0);
+	bitmap.fill(0, cliprect);
+	priority_bitmap.fill(0, clip);
+	state->m_tmpbitmaps.fill(0, clip);
 
 	tc0100scn_tilemap_draw(tc0100scn, bitmap, cliprect, pivlayer[0], 0, 0);
 	tc0100scn_tilemap_draw(tc0100scn, bitmap, cliprect, pivlayer[1], 0, 0);
@@ -476,17 +472,17 @@ SCREEN_UPDATE( galastrm )
 #if 0
 	if (layer[0]==0 && layer[1]==3 && layer[2]==2 && layer[3]==1)
 	{
-		if (!screen->machine().input().code_pressed(KEYCODE_Z)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[0], 0, 1);
-		if (!screen->machine().input().code_pressed(KEYCODE_X)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[1], 0, 4);
-		if (!screen->machine().input().code_pressed(KEYCODE_C)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[2], 0, 4);
-		if (!screen->machine().input().code_pressed(KEYCODE_V)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[3], 0, 4);
+		if (!screen.machine().input().code_pressed(KEYCODE_Z)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[0], 0, 1);
+		if (!screen.machine().input().code_pressed(KEYCODE_X)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[1], 0, 4);
+		if (!screen.machine().input().code_pressed(KEYCODE_C)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[2], 0, 4);
+		if (!screen.machine().input().code_pressed(KEYCODE_V)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[3], 0, 4);
 	}
 	else
 	{
-		if (!screen->machine().input().code_pressed(KEYCODE_Z)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[0], 0, 1);
-		if (!screen->machine().input().code_pressed(KEYCODE_X)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[1], 0, 2);
-		if (!screen->machine().input().code_pressed(KEYCODE_C)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[2], 0, 4);
-		if (!screen->machine().input().code_pressed(KEYCODE_V)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[3], 0, 8);
+		if (!screen.machine().input().code_pressed(KEYCODE_Z)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[0], 0, 1);
+		if (!screen.machine().input().code_pressed(KEYCODE_X)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[1], 0, 2);
+		if (!screen.machine().input().code_pressed(KEYCODE_C)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[2], 0, 4);
+		if (!screen.machine().input().code_pressed(KEYCODE_V)) tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[3], 0, 8);
 	}
 
 	if (layer[0]==3 && layer[1]==0 && layer[2]==1 && layer[3]==2)
@@ -494,46 +490,46 @@ SCREEN_UPDATE( galastrm )
 		int x,y;
 		UINT8 *pri;
 
-		for (y=0; y < priority_bitmap->height; y++)
+		for (y=0; y < priority_bitmap.height; y++)
 		{
-			for (x=0; x < priority_bitmap->width; x++)
+			for (x=0; x < priority_bitmap.width; x++)
 			{
-				pri = BITMAP_ADDR8(priority_bitmap, y, x);
-				if (!(*pri & 0x02) && *BITMAP_ADDR16(state->m_tmpbitmaps, y, x))
+				pri = &priority_bitmap.pix8(y, x);
+				if (!(*pri & 0x02) && state->m_tmpbitmaps.pix16(y, x))
 					 *pri |= 0x04;
 			}
 		}
 	}
 
-	draw_sprites_pre(screen->machine(), 42-X_OFFSET, -571+Y_OFFSET);
-	draw_sprites(screen->machine(),state->m_tmpbitmaps,&clip,primasks,1);
+	draw_sprites_pre(screen.machine(), 42-X_OFFSET, -571+Y_OFFSET);
+	draw_sprites(screen.machine(),state->m_tmpbitmaps,clip,primasks,1);
 
 	copybitmap_trans(bitmap,state->m_polybitmap,0,0, 0,0,cliprect,0);
-	bitmap_fill(state->m_polybitmap, &clip, 0);
-	tc0610_rotate_draw(screen->machine(),state->m_polybitmap,state->m_tmpbitmaps,cliprect);
+	state->m_polybitmap->fill(0, clip);
+	tc0610_rotate_draw(screen.machine(),state->m_polybitmap,state->m_tmpbitmaps,cliprect);
 
-	bitmap_fill(priority_bitmap, cliprect, 0);
-	draw_sprites(screen->machine(),bitmap,cliprect,primasks,0);
+	priority_bitmap.fill(0, cliprect);
+	draw_sprites(screen.machine(),bitmap,cliprect,primasks,0);
 
-	if (!screen->machine().input().code_pressed(KEYCODE_B)) tc0480scp_tilemap_draw(tc0480scp, bitmap, cliprect, layer[4], 0, 0);
-	if (!screen->machine().input().code_pressed(KEYCODE_M)) tc0100scn_tilemap_draw(tc0100scn, bitmap, cliprect, pivlayer[2], 0, 0);
+	if (!screen.machine().input().code_pressed(KEYCODE_B)) tc0480scp_tilemap_draw(tc0480scp, bitmap, cliprect, layer[4], 0, 0);
+	if (!screen.machine().input().code_pressed(KEYCODE_M)) tc0100scn_tilemap_draw(tc0100scn, bitmap, cliprect, pivlayer[2], 0, 0);
 
 
 
 #else
 	if (layer[0]==0 && layer[1]==3 && layer[2]==2 && layer[3]==1)
 	{
-		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[0], 0, 1);
-		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[1], 0, 4);
-		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[2], 0, 4);
-		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[3], 0, 4);
+		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[0], 0, 1);
+		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[1], 0, 4);
+		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[2], 0, 4);
+		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[3], 0, 4);
 	}
 	else
 	{
-		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[0], 0, 1);
-		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[1], 0, 2);
-		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[2], 0, 4);
-		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, &clip, layer[3], 0, 8);
+		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[0], 0, 1);
+		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[1], 0, 2);
+		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[2], 0, 4);
+		tc0480scp_tilemap_draw(tc0480scp, state->m_tmpbitmaps, clip, layer[3], 0, 8);
 	}
 
 	if (layer[0]==3 && layer[1]==0 && layer[2]==1 && layer[3]==2)
@@ -541,26 +537,26 @@ SCREEN_UPDATE( galastrm )
 		int x,y;
 		UINT8 *pri;
 
-		for (y=0; y < priority_bitmap->height; y++)
+		for (y=0; y < priority_bitmap.height(); y++)
 		{
-			for (x=0; x < priority_bitmap->width; x++)
+			for (x=0; x < priority_bitmap.width(); x++)
 			{
-				pri = BITMAP_ADDR8(priority_bitmap, y, x);
-				if (!(*pri & 0x02) && *BITMAP_ADDR16(state->m_tmpbitmaps, y, x))
+				pri = &priority_bitmap.pix8(y, x);
+				if (!(*pri & 0x02) && state->m_tmpbitmaps.pix16(y, x))
 					 *pri |= 0x04;
 			}
 		}
 	}
 
-	draw_sprites_pre(screen->machine(), 42-X_OFFSET, -571+Y_OFFSET);
-	draw_sprites(screen->machine(),state->m_tmpbitmaps,&clip,primasks,1);
+	draw_sprites_pre(screen.machine(), 42-X_OFFSET, -571+Y_OFFSET);
+	draw_sprites(screen.machine(),state->m_tmpbitmaps,clip,primasks,1);
 
 	copybitmap_trans(bitmap,state->m_polybitmap,0,0, 0,0,cliprect,0);
-	bitmap_fill(state->m_polybitmap, &clip, 0);
-	tc0610_rotate_draw(screen->machine(),state->m_polybitmap,state->m_tmpbitmaps,cliprect);
+	state->m_polybitmap.fill(0, clip);
+	tc0610_rotate_draw(screen.machine(),state->m_polybitmap,state->m_tmpbitmaps,cliprect);
 
-	bitmap_fill(priority_bitmap, cliprect, 0);
-	draw_sprites(screen->machine(),bitmap,cliprect,primasks,0);
+	priority_bitmap.fill(0, cliprect);
+	draw_sprites(screen.machine(),bitmap,cliprect,primasks,0);
 
 	tc0480scp_tilemap_draw(tc0480scp, bitmap, cliprect, layer[4], 0, 0);
 	tc0100scn_tilemap_draw(tc0100scn, bitmap, cliprect, pivlayer[2], 0, 0);
