@@ -53,7 +53,7 @@ VIDEO_START( goindol )
 	state->m_bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
 	state->m_fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
 
-	tilemap_set_transparent_pen(state->m_fg_tilemap, 0);
+	state->m_fg_tilemap->set_transparent_pen(0);
 }
 
 
@@ -67,14 +67,14 @@ WRITE8_HANDLER( goindol_fg_videoram_w )
 {
 	goindol_state *state = space->machine().driver_data<goindol_state>();
 	state->m_fg_videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_fg_tilemap, offset / 2);
+	state->m_fg_tilemap->mark_tile_dirty(offset / 2);
 }
 
 WRITE8_HANDLER( goindol_bg_videoram_w )
 {
 	goindol_state *state = space->machine().driver_data<goindol_state>();
 	state->m_bg_videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset / 2);
+	state->m_bg_tilemap->mark_tile_dirty(offset / 2);
 }
 
 
@@ -85,7 +85,7 @@ WRITE8_HANDLER( goindol_bg_videoram_w )
 
 ***************************************************************************/
 
-static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, int gfxbank, UINT8 *sprite_ram )
+static void draw_sprites( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int gfxbank, UINT8 *sprite_ram )
 {
 	goindol_state *state = machine.driver_data<goindol_state>();
 	int offs, sx, sy, tile, palette;
@@ -123,15 +123,15 @@ static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rect
 	}
 }
 
-SCREEN_UPDATE( goindol )
+SCREEN_UPDATE_IND16( goindol )
 {
-	goindol_state *state = screen->machine().driver_data<goindol_state>();
-	tilemap_set_scrollx(state->m_fg_tilemap, 0, *state->m_fg_scrollx);
-	tilemap_set_scrolly(state->m_fg_tilemap, 0, *state->m_fg_scrolly);
+	goindol_state *state = screen.machine().driver_data<goindol_state>();
+	state->m_fg_tilemap->set_scrollx(0, *state->m_fg_scrollx);
+	state->m_fg_tilemap->set_scrolly(0, *state->m_fg_scrolly);
 
-	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
-	tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
-	draw_sprites(screen->machine(), bitmap, cliprect, 1, state->m_spriteram);
-	draw_sprites(screen->machine(), bitmap, cliprect, 0, state->m_spriteram2);
+	state->m_bg_tilemap->draw(bitmap, cliprect, 0, 0);
+	state->m_fg_tilemap->draw(bitmap, cliprect, 0, 0);
+	draw_sprites(screen.machine(), bitmap, cliprect, 1, state->m_spriteram);
+	draw_sprites(screen.machine(), bitmap, cliprect, 0, state->m_spriteram2);
 	return 0;
 }
