@@ -58,7 +58,7 @@ VIDEO_START( gundealr )
 	state->m_bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols, 8, 8, 32, 32);
 	state->m_fg_tilemap = tilemap_create(machine, get_fg_tile_info, gundealr_scan, 16, 16, 64, 32);
 
-	tilemap_set_transparent_pen(state->m_fg_tilemap, 15);
+	state->m_fg_tilemap->set_transparent_pen(15);
 }
 
 
@@ -73,14 +73,14 @@ WRITE8_HANDLER( gundealr_bg_videoram_w )
 {
 	gundealr_state *state = space->machine().driver_data<gundealr_state>();
 	state->m_bg_videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset / 2);
+	state->m_bg_tilemap->mark_tile_dirty(offset / 2);
 }
 
 WRITE8_HANDLER( gundealr_fg_videoram_w )
 {
 	gundealr_state *state = space->machine().driver_data<gundealr_state>();
 	state->m_fg_videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_fg_tilemap, offset / 2);
+	state->m_fg_tilemap->mark_tile_dirty(offset / 2);
 }
 
 WRITE8_HANDLER( gundealr_paletteram_w )
@@ -105,23 +105,23 @@ WRITE8_HANDLER( gundealr_fg_scroll_w )
 {
 	gundealr_state *state = space->machine().driver_data<gundealr_state>();
 	state->m_scroll[offset] = data;
-	tilemap_set_scrollx(state->m_fg_tilemap, 0, state->m_scroll[1] | ((state->m_scroll[0] & 0x03) << 8));
-	tilemap_set_scrolly(state->m_fg_tilemap, 0, state->m_scroll[3] | ((state->m_scroll[2] & 0x03) << 8));
+	state->m_fg_tilemap->set_scrollx(0, state->m_scroll[1] | ((state->m_scroll[0] & 0x03) << 8));
+	state->m_fg_tilemap->set_scrolly(0, state->m_scroll[3] | ((state->m_scroll[2] & 0x03) << 8));
 }
 
 WRITE8_HANDLER( yamyam_fg_scroll_w )
 {
 	gundealr_state *state = space->machine().driver_data<gundealr_state>();
 	state->m_scroll[offset] = data;
-	tilemap_set_scrollx(state->m_fg_tilemap, 0, state->m_scroll[0] | ((state->m_scroll[1] & 0x03) << 8));
-	tilemap_set_scrolly(state->m_fg_tilemap, 0, state->m_scroll[2] | ((state->m_scroll[3] & 0x03) << 8));
+	state->m_fg_tilemap->set_scrollx(0, state->m_scroll[0] | ((state->m_scroll[1] & 0x03) << 8));
+	state->m_fg_tilemap->set_scrolly(0, state->m_scroll[2] | ((state->m_scroll[3] & 0x03) << 8));
 }
 
 WRITE8_HANDLER( gundealr_flipscreen_w )
 {
 	gundealr_state *state = space->machine().driver_data<gundealr_state>();
 	state->m_flipscreen = data;
-	tilemap_set_flip_all(space->machine(), state->m_flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
+	space->machine().tilemap().set_flip_all(state->m_flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
 }
 
 
@@ -132,10 +132,10 @@ WRITE8_HANDLER( gundealr_flipscreen_w )
 
 ***************************************************************************/
 
-SCREEN_UPDATE( gundealr )
+SCREEN_UPDATE_IND16( gundealr )
 {
-	gundealr_state *state = screen->machine().driver_data<gundealr_state>();
-	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
-	tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
+	gundealr_state *state = screen.machine().driver_data<gundealr_state>();
+	state->m_bg_tilemap->draw(bitmap, cliprect, 0, 0);
+	state->m_fg_tilemap->draw(bitmap, cliprect, 0, 0);
 	return 0;
 }
