@@ -71,13 +71,13 @@ Offset:
 
 ***************************************************************************/
 
-INLINE void get_tile_info(running_machine &machine, tile_data *tileinfo, tilemap_memory_index tile_index, int _N_)
+INLINE void get_tile_info(running_machine &machine, tile_data &tileinfo, tilemap_memory_index tile_index, int _N_)
 {
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
 	UINT16 code_hi = state->m_vram[_N_][ 2 * tile_index + 0];
 	UINT16 code_lo = state->m_vram[_N_][ 2 * tile_index + 1];
 	SET_TILE_INFO(1 + _N_/2, code_lo, (code_hi >> 2) & 0x3f, TILE_FLIPXY( code_hi & 3 ));
-	tileinfo->category	=	(code_hi >> 8) & 7;
+	tileinfo.category	=	(code_hi >> 8) & 7;
 }
 
 static TILE_GET_INFO( get_tile_info_0 ) { get_tile_info(machine, tileinfo, tile_index, 0); }
@@ -89,7 +89,7 @@ INLINE void kaneko16_vram_w(address_space *space, offs_t offset, UINT16 data, UI
 {
 	kaneko16_state *state = space->machine().driver_data<kaneko16_state>();
 	COMBINE_DATA(&state->m_vram[_N_][offset]);
-	tilemap_mark_tile_dirty(state->m_tmap[_N_], offset/2);
+	state->m_tmap[_N_]->mark_tile_dirty(offset/2);
 }
 
 WRITE16_HANDLER( kaneko16_vram_0_w ) { kaneko16_vram_w(space, offset, data, mem_mask, 0); }
@@ -122,7 +122,7 @@ VIDEO_START( kaneko16_1xVIEW2_tilemaps )
 
 	state->m_tmap[3] = 0;
 
-	state->m_sprites_bitmap = machine.primary_screen->alloc_compatible_bitmap();
+	machine.primary_screen->register_screen_bitmap(state->m_sprites_bitmap);
 
 	{
 		int dx, dy;
@@ -143,17 +143,17 @@ VIDEO_START( kaneko16_1xVIEW2_tilemaps )
 			default:		dy = 0;
 		}
 
-		tilemap_set_scrolldx( state->m_tmap[0], -dx,		xdim + dx -1        );
-		tilemap_set_scrolldx( state->m_tmap[1], -(dx+2),	xdim + (dx + 2) - 1 );
+		state->m_tmap[0]->set_scrolldx(-dx,		xdim + dx -1        );
+		state->m_tmap[1]->set_scrolldx(-(dx+2),	xdim + (dx + 2) - 1 );
 
-		tilemap_set_scrolldy( state->m_tmap[0], -dy,		ydim + dy -1 );
-		tilemap_set_scrolldy( state->m_tmap[1], -dy,		ydim + dy -1 );
+		state->m_tmap[0]->set_scrolldy(-dy,		ydim + dy -1 );
+		state->m_tmap[1]->set_scrolldy(-dy,		ydim + dy -1 );
 
-		tilemap_set_transparent_pen(state->m_tmap[0], 0);
-		tilemap_set_transparent_pen(state->m_tmap[1], 0);
+		state->m_tmap[0]->set_transparent_pen(0);
+		state->m_tmap[1]->set_transparent_pen(0);
 
-		tilemap_set_scroll_rows(state->m_tmap[0], 0x200);	// Line Scroll
-		tilemap_set_scroll_rows(state->m_tmap[1], 0x200);
+		state->m_tmap[0]->set_scroll_rows(0x200);	// Line Scroll
+		state->m_tmap[1]->set_scroll_rows(0x200);
 	}
 
 }
@@ -195,17 +195,17 @@ VIDEO_START( kaneko16_2xVIEW2 )
 			default:		dy = 0;
 		}
 
-		tilemap_set_scrolldx( state->m_tmap[2], -dx,		xdim + dx -1        );
-		tilemap_set_scrolldx( state->m_tmap[3], -(dx+2),	xdim + (dx + 2) - 1 );
+		state->m_tmap[2]->set_scrolldx(-dx,		xdim + dx -1        );
+		state->m_tmap[3]->set_scrolldx(-(dx+2),	xdim + (dx + 2) - 1 );
 
-		tilemap_set_scrolldy( state->m_tmap[2], -dy,		ydim + dy -1 );
-		tilemap_set_scrolldy( state->m_tmap[3], -dy,		ydim + dy -1 );
+		state->m_tmap[2]->set_scrolldy(-dy,		ydim + dy -1 );
+		state->m_tmap[3]->set_scrolldy(-dy,		ydim + dy -1 );
 
-		tilemap_set_transparent_pen(state->m_tmap[2], 0);
-		tilemap_set_transparent_pen(state->m_tmap[3], 0);
+		state->m_tmap[2]->set_transparent_pen(0);
+		state->m_tmap[3]->set_transparent_pen(0);
 
-		tilemap_set_scroll_rows(state->m_tmap[2], 0x200);	// Line Scroll
-		tilemap_set_scroll_rows(state->m_tmap[3], 0x200);
+		state->m_tmap[2]->set_scroll_rows(0x200);	// Line Scroll
+		state->m_tmap[3]->set_scroll_rows(0x200);
 	}
 }
 
@@ -214,8 +214,8 @@ VIDEO_START( sandscrp_1xVIEW2 )
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
 	VIDEO_START_CALL(kaneko16_1xVIEW2);
 
-	tilemap_set_scrolldy( state->m_tmap[0], 0, 256 - 1 );
-	tilemap_set_scrolldy( state->m_tmap[1], 0, 256 - 1 );
+	state->m_tmap[0]->set_scrolldy(0, 256 - 1 );
+	state->m_tmap[1]->set_scrolldy(0, 256 - 1 );
 }
 
 
@@ -241,7 +241,7 @@ VIDEO_START( berlwall )
 
 	/* Render the hi-color static backgrounds held in the ROMs */
 
-	state->m_bg15_bitmap = auto_bitmap_alloc(machine, 256 * 32, 256 * 1, BITMAP_FORMAT_INDEXED16);
+	state->m_bg15_bitmap.allocate(256 * 32, 256 * 1);
 
 /*
     8aba is used as background color
@@ -274,7 +274,7 @@ VIDEO_START( berlwall )
 			if ((r & 0x10) && (b & 0x10))
 				g = (g - 1) & 0x1f;		/* decrease with wraparound */
 
-			*BITMAP_ADDR16(state->m_bg15_bitmap, y, sx * 256 + x) = 2048 + ((g << 10) | (r << 5) | b);
+			state->m_bg15_bitmap.pix16(y, sx * 256 + x) = 2048 + ((g << 10) | (r << 5) | b);
 	  }
 
 	VIDEO_START_CALL(kaneko16_1xVIEW2);
@@ -294,7 +294,7 @@ VIDEO_START( galsnew )
 
 	state->m_tmap[3] = 0;
 
-	state->m_sprites_bitmap = machine.primary_screen->alloc_compatible_bitmap();
+	machine.primary_screen->register_screen_bitmap(state->m_sprites_bitmap);
 
 	{
 		int dx = 0x5b, dy = 8;
@@ -302,17 +302,17 @@ VIDEO_START( galsnew )
 		int xdim = machine.primary_screen->width();
 		int ydim = machine.primary_screen->height();
 
-		tilemap_set_scrolldx( state->m_tmap[0], -dx,		xdim + dx -1        );
-		tilemap_set_scrolldx( state->m_tmap[1], -(dx+2),	xdim + (dx + 2) - 1 );
+		state->m_tmap[0]->set_scrolldx(-dx,		xdim + dx -1        );
+		state->m_tmap[1]->set_scrolldx(-(dx+2),	xdim + (dx + 2) - 1 );
 
-		tilemap_set_scrolldy( state->m_tmap[0], -dy,		ydim + dy -1 );
-		tilemap_set_scrolldy( state->m_tmap[1], -dy,		ydim + dy -1 );
+		state->m_tmap[0]->set_scrolldy(-dy,		ydim + dy -1 );
+		state->m_tmap[1]->set_scrolldy(-dy,		ydim + dy -1 );
 
-		tilemap_set_transparent_pen(state->m_tmap[0], 0);
-		tilemap_set_transparent_pen(state->m_tmap[1], 0);
+		state->m_tmap[0]->set_transparent_pen(0);
+		state->m_tmap[1]->set_transparent_pen(0);
 
-		tilemap_set_scroll_rows(state->m_tmap[0], 0x200);	// Line Scroll
-		tilemap_set_scroll_rows(state->m_tmap[1], 0x200);
+		state->m_tmap[0]->set_scroll_rows(0x200);	// Line Scroll
+		state->m_tmap[1]->set_scroll_rows(0x200);
 	}
 }
 
@@ -420,13 +420,13 @@ else
 }
 
 // custom function to draw a single sprite. needed to keep correct sprites - sprites and sprites - tilemaps priorities
-static void kaneko16_draw_sprites_custom(bitmap_t *dest_bmp,const rectangle *clip,const gfx_element *gfx,
+static void kaneko16_draw_sprites_custom(bitmap_ind16 &dest_bmp,const rectangle &clip,const gfx_element *gfx,
 		UINT32 code,UINT32 color,int flipx,int flipy,int sx,int sy,
 		int priority)
 {
 	pen_t pen_base = gfx->color_base + gfx->color_granularity * (color % gfx->total_colors);
 	const UINT8 *source_base = gfx_element_get_data(gfx, code % gfx->total_elements);
-	bitmap_t *priority_bitmap = gfx->machine().priority_bitmap;
+	bitmap_ind8 &priority_bitmap = gfx->machine().priority_bitmap;
 	int sprite_screen_height = ((1<<16)*gfx->height+0x8000)>>16;
 	int sprite_screen_width = ((1<<16)*gfx->width+0x8000)>>16;
 
@@ -462,31 +462,28 @@ static void kaneko16_draw_sprites_custom(bitmap_t *dest_bmp,const rectangle *cli
 			y_index = 0;
 		}
 
-		if( clip )
-		{
-			if( sx < clip->min_x)
-			{ /* clip left */
-				int pixels = clip->min_x-sx;
-				sx += pixels;
-				x_index_base += pixels*dx;
-			}
-			if( sy < clip->min_y )
-			{ /* clip top */
-				int pixels = clip->min_y-sy;
-				sy += pixels;
-				y_index += pixels*dy;
-			}
-			/* NS 980211 - fixed incorrect clipping */
-			if( ex > clip->max_x+1 )
-			{ /* clip right */
-				int pixels = ex-clip->max_x-1;
-				ex -= pixels;
-			}
-			if( ey > clip->max_y+1 )
-			{ /* clip bottom */
-				int pixels = ey-clip->max_y-1;
-				ey -= pixels;
-			}
+		if( sx < clip.min_x)
+		{ /* clip left */
+			int pixels = clip.min_x-sx;
+			sx += pixels;
+			x_index_base += pixels*dx;
+		}
+		if( sy < clip.min_y )
+		{ /* clip top */
+			int pixels = clip.min_y-sy;
+			sy += pixels;
+			y_index += pixels*dy;
+		}
+		/* NS 980211 - fixed incorrect clipping */
+		if( ex > clip.max_x+1 )
+		{ /* clip right */
+			int pixels = ex-clip.max_x-1;
+			ex -= pixels;
+		}
+		if( ey > clip.max_y+1 )
+		{ /* clip bottom */
+			int pixels = ey-clip.max_y-1;
+			ey -= pixels;
 		}
 
 		if( ex>sx )
@@ -496,8 +493,8 @@ static void kaneko16_draw_sprites_custom(bitmap_t *dest_bmp,const rectangle *cli
 			for( y=sy; y<ey; y++ )
 			{
 				const UINT8 *source = source_base + (y_index>>16) * gfx->line_modulo;
-				UINT16 *dest = BITMAP_ADDR16(dest_bmp, y, 0);
-				UINT8 *pri = BITMAP_ADDR8(priority_bitmap, y, 0);
+				UINT16 *dest = &dest_bmp.pix16(y);
+				UINT8 *pri = &priority_bitmap.pix8(y);
 
 				int x, x_index = x_index_base;
 				for( x=sx; x<ex; x++ )
@@ -520,7 +517,7 @@ static void kaneko16_draw_sprites_custom(bitmap_t *dest_bmp,const rectangle *cli
 
 /* Build a list of sprites to display & draw them */
 
-void kaneko16_draw_sprites(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+void kaneko16_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
 	/* Sprites *must* be parsed from the first in RAM to the last,
@@ -855,7 +852,7 @@ WRITE16_HANDLER( kaneko16_bg15_reg_w )
 
 ***************************************************************************/
 
-static void kaneko16_prepare_first_tilemap_chip(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void kaneko16_prepare_first_tilemap_chip(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
 	/* Set Up FIRST Tilemap chip */
@@ -867,13 +864,13 @@ static void kaneko16_prepare_first_tilemap_chip(running_machine &machine, bitmap
 	layers_flip_0 = state->m_layers_0_regs[ 4 ];
 
 	/* Enable layers */
-	tilemap_set_enable(state->m_tmap[0], ~layers_flip_0 & 0x1000);
-	tilemap_set_enable(state->m_tmap[1], ~layers_flip_0 & 0x0010);
+	state->m_tmap[0]->enable(~layers_flip_0 & 0x1000);
+	state->m_tmap[1]->enable(~layers_flip_0 & 0x0010);
 
 	/* Flip layers */
-	tilemap_set_flip(state->m_tmap[0],	((layers_flip_0 & 0x0100) ? TILEMAP_FLIPY : 0) |
+	state->m_tmap[0]->set_flip(	((layers_flip_0 & 0x0100) ? TILEMAP_FLIPY : 0) |
 										((layers_flip_0 & 0x0200) ? TILEMAP_FLIPX : 0) );
-	tilemap_set_flip(state->m_tmap[1],	((layers_flip_0 & 0x0100) ? TILEMAP_FLIPY : 0) |
+	state->m_tmap[1]->set_flip(	((layers_flip_0 & 0x0100) ? TILEMAP_FLIPY : 0) |
 										((layers_flip_0 & 0x0200) ? TILEMAP_FLIPX : 0) );
 
 	/* Scroll layers */
@@ -882,21 +879,21 @@ static void kaneko16_prepare_first_tilemap_chip(running_machine &machine, bitmap
 	layer1_scrollx		=	state->m_layers_0_regs[ 0 ];
 	layer1_scrolly		=	state->m_layers_0_regs[ 1 ] >> 6;
 
-	tilemap_set_scrolly(state->m_tmap[0],0,layer0_scrolly);
-	tilemap_set_scrolly(state->m_tmap[1],0,layer1_scrolly);
+	state->m_tmap[0]->set_scrolly(0,layer0_scrolly);
+	state->m_tmap[1]->set_scrolly(0,layer1_scrolly);
 
 	for (i=0; i<0x200; i++)
 	{
 		UINT16 scroll;
 		scroll = (layers_flip_0 & 0x0800) ? state->m_vscroll[0][i] : 0;
-		tilemap_set_scrollx(state->m_tmap[0],i,(layer0_scrollx + scroll) >> 6 );
+		state->m_tmap[0]->set_scrollx(i,(layer0_scrollx + scroll) >> 6 );
 		scroll = (layers_flip_0 & 0x0008) ? state->m_vscroll[1][i] : 0;
-		tilemap_set_scrollx(state->m_tmap[1],i,(layer1_scrollx + scroll) >> 6 );
+		state->m_tmap[1]->set_scrollx(i,(layer1_scrollx + scroll) >> 6 );
 	}
 
 }
 
-static void kaneko16_prepare_second_tilemap_chip(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void kaneko16_prepare_second_tilemap_chip(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
 	/* Set Up SECOND Tilemap chip */
@@ -909,12 +906,12 @@ static void kaneko16_prepare_second_tilemap_chip(running_machine &machine, bitma
 	{
 		layers_flip_1 = state->m_layers_1_regs[ 4 ];
 
-		tilemap_set_enable(state->m_tmap[2], ~layers_flip_1 & 0x1000);
-		tilemap_set_enable(state->m_tmap[3], ~layers_flip_1 & 0x0010);
+		state->m_tmap[2]->enable(~layers_flip_1 & 0x1000);
+		state->m_tmap[3]->enable(~layers_flip_1 & 0x0010);
 
-		tilemap_set_flip(state->m_tmap[2],	((layers_flip_1 & 0x0100) ? TILEMAP_FLIPY : 0) |
+		state->m_tmap[2]->set_flip(	((layers_flip_1 & 0x0100) ? TILEMAP_FLIPY : 0) |
 											((layers_flip_1 & 0x0200) ? TILEMAP_FLIPX : 0) );
-		tilemap_set_flip(state->m_tmap[3],	((layers_flip_1 & 0x0100) ? TILEMAP_FLIPY : 0) |
+		state->m_tmap[3]->set_flip(	((layers_flip_1 & 0x0100) ? TILEMAP_FLIPY : 0) |
 											((layers_flip_1 & 0x0200) ? TILEMAP_FLIPX : 0) );
 
 		layer0_scrollx		=	state->m_layers_1_regs[ 2 ];
@@ -922,38 +919,38 @@ static void kaneko16_prepare_second_tilemap_chip(running_machine &machine, bitma
 		layer1_scrollx		=	state->m_layers_1_regs[ 0 ];
 		layer1_scrolly		=	state->m_layers_1_regs[ 1 ] >> 6;
 
-		tilemap_set_scrolly(state->m_tmap[2],0,layer0_scrolly);
-		tilemap_set_scrolly(state->m_tmap[3],0,layer1_scrolly);
+		state->m_tmap[2]->set_scrolly(0,layer0_scrolly);
+		state->m_tmap[3]->set_scrolly(0,layer1_scrolly);
 
 		for (i=0; i<0x200; i++)
 		{
 			UINT16 scroll;
 			scroll = (layers_flip_1 & 0x0800) ? state->m_vscroll[2][i] : 0;
-			tilemap_set_scrollx(state->m_tmap[2],i,(layer0_scrollx + scroll) >> 6 );
+			state->m_tmap[2]->set_scrollx(i,(layer0_scrollx + scroll) >> 6 );
 			scroll = (layers_flip_1 & 0x0008) ? state->m_vscroll[3][i] : 0;
-			tilemap_set_scrollx(state->m_tmap[3],i,(layer1_scrollx + scroll) >> 6 );
+			state->m_tmap[3]->set_scrollx(i,(layer1_scrollx + scroll) >> 6 );
 		}
 	}
 }
 
-static void kaneko16_render_first_tilemap_chip(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, int pri)
+static void kaneko16_render_first_tilemap_chip(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int pri)
 {
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
-	tilemap_draw_primask(bitmap,cliprect, state->m_tmap[0], pri, pri, 0);
-	tilemap_draw_primask(bitmap,cliprect, state->m_tmap[1], pri, pri, 0);
+	state->m_tmap[0]->draw(bitmap, cliprect, pri, pri, 0);
+	state->m_tmap[1]->draw(bitmap, cliprect, pri, pri, 0);
 }
 
-static void kaneko16_render_second_tilemap_chip(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, int pri)
+static void kaneko16_render_second_tilemap_chip(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int pri)
 {
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
 	if (state->m_tmap[2])
 	{
-		tilemap_draw_primask(bitmap,cliprect, state->m_tmap[2], pri, state->m_priority.VIEW2_2_pri ? pri : 0, 0);
-		tilemap_draw_primask(bitmap,cliprect, state->m_tmap[3], pri, state->m_priority.VIEW2_2_pri ? pri : 0, 0);
+		state->m_tmap[2]->draw(bitmap, cliprect, pri, state->m_priority.VIEW2_2_pri ? pri : 0, 0);
+		state->m_tmap[3]->draw(bitmap, cliprect, pri, state->m_priority.VIEW2_2_pri ? pri : 0, 0);
 	}
 }
 
-static void kaneko16_render_sprites(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void kaneko16_render_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
 	/* Sprites last (rendered with pdrawgfx, so they can slip
@@ -967,15 +964,15 @@ static void kaneko16_render_sprites(running_machine &machine, bitmap_t *bitmap,
 	}
 	else
 	{
-		bitmap_fill(state->m_sprites_bitmap,cliprect,0);
+		state->m_sprites_bitmap.fill(0, cliprect);
 		kaneko16_draw_sprites(machine,bitmap,cliprect);
 	}
 }
 
-static void kaneko16_render_15bpp_bitmap(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void kaneko16_render_15bpp_bitmap(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
-	if (state->m_bg15_bitmap)
+	if (state->m_bg15_bitmap.valid())
 	{
 		int select	=	state->m_bg15_select[ 0 ];
 //      int reg     =   state->m_bg15_reg[ 0 ];
@@ -993,88 +990,88 @@ static void kaneko16_render_15bpp_bitmap(running_machine &machine, bitmap_t *bit
 	}
 }
 
-static void kaneko16_fill_bitmap(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void kaneko16_fill_bitmap(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	kaneko16_state *state = machine.driver_data<kaneko16_state>();
 	if(state->m_sprite_type == 1)
-		bitmap_fill(bitmap,cliprect,0x7f00);
+		bitmap.fill(0x7f00, cliprect);
 	else
 		/* Fill the bitmap with pen 0. This is wrong, but will work most of
            the times. To do it right, each pixel should be drawn with pen 0
            of the bottomost tile that covers it (which is pretty tricky to do) */
-		bitmap_fill(bitmap,cliprect,0);
+		bitmap.fill(0, cliprect);
 }
 
-static SCREEN_UPDATE( common )
+static SCREEN_UPDATE_IND16( common )
 {
 	int i;
 
-	bitmap_fill(screen->machine().priority_bitmap,cliprect,0);
+	screen.machine().priority_bitmap.fill(0, cliprect);
 
-	kaneko16_prepare_first_tilemap_chip(screen->machine(), bitmap, cliprect);
-	kaneko16_prepare_second_tilemap_chip(screen->machine(), bitmap, cliprect);
+	kaneko16_prepare_first_tilemap_chip(screen.machine(), bitmap, cliprect);
+	kaneko16_prepare_second_tilemap_chip(screen.machine(), bitmap, cliprect);
 
 	for ( i = 0; i < 8; i++ )
 	{
-		kaneko16_render_first_tilemap_chip(screen->machine(),bitmap,cliprect,i);
-		kaneko16_render_second_tilemap_chip(screen->machine(),bitmap,cliprect,i);
+		kaneko16_render_first_tilemap_chip(screen.machine(),bitmap,cliprect,i);
+		kaneko16_render_second_tilemap_chip(screen.machine(),bitmap,cliprect,i);
 	}
 
 	return 0;
 }
 
-SCREEN_UPDATE(berlwall)
+SCREEN_UPDATE_IND16(berlwall)
 {
-	kaneko16_state *state = screen->machine().driver_data<kaneko16_state>();
+	kaneko16_state *state = screen.machine().driver_data<kaneko16_state>();
 	// berlwall uses a 15bpp bitmap as a bg, not a solid fill
-	kaneko16_render_15bpp_bitmap(screen->machine(),bitmap,cliprect);
+	kaneko16_render_15bpp_bitmap(screen.machine(),bitmap,cliprect);
 
 	// if the display is disabled, do nothing?
 	if (!state->m_disp_enable) return 0;
 
-	SCREEN_UPDATE_CALL(common);
-	kaneko16_render_sprites(screen->machine(),bitmap,cliprect);
+	SCREEN_UPDATE16_CALL(common);
+	kaneko16_render_sprites(screen.machine(),bitmap,cliprect);
 	return 0;
 }
 
 
-SCREEN_UPDATE( jchan_view2 )
+SCREEN_UPDATE_IND16( jchan_view2 )
 {
-	kaneko16_state *state = screen->machine().driver_data<kaneko16_state>();
+	kaneko16_state *state = screen.machine().driver_data<kaneko16_state>();
 	int dx,dy;
 
-	SCREEN_UPDATE_CALL(common);
+	SCREEN_UPDATE16_CALL(common);
 
 	/* override the offsets set in common - tuned to char select in jchan2 */
 	dx = 25;dy = 11;
 
-	tilemap_set_scrolldx( state->m_tmap[0], -dx,		320 + dx -1        );
-	tilemap_set_scrolldx( state->m_tmap[1], -(dx+2),	320 + (dx + 2) - 1 );
+	state->m_tmap[0]->set_scrolldx(-dx,		320 + dx -1        );
+	state->m_tmap[1]->set_scrolldx(-(dx+2),	320 + (dx + 2) - 1 );
 
-	tilemap_set_scrolldy( state->m_tmap[0], -dy,		240 + dy -1 );
-	tilemap_set_scrolldy( state->m_tmap[1], -dy,		240 + dy -1 );
+	state->m_tmap[0]->set_scrolldy(-dy,		240 + dy -1 );
+	state->m_tmap[1]->set_scrolldy(-dy,		240 + dy -1 );
 
 	return 0;
 }
 
 
-SCREEN_UPDATE( kaneko16 )
+SCREEN_UPDATE_IND16( kaneko16 )
 {
-	kaneko16_state *state = screen->machine().driver_data<kaneko16_state>();
-	kaneko16_fill_bitmap(screen->machine(),bitmap,cliprect);
+	kaneko16_state *state = screen.machine().driver_data<kaneko16_state>();
+	kaneko16_fill_bitmap(screen.machine(),bitmap,cliprect);
 
 	// if the display is disabled, do nothing?
 	if (!state->m_disp_enable) return 0;
 
-	SCREEN_UPDATE_CALL(common);
-	kaneko16_render_sprites(screen->machine(),bitmap,cliprect);
+	SCREEN_UPDATE16_CALL(common);
+	kaneko16_render_sprites(screen.machine(),bitmap,cliprect);
 	return 0;
 }
 
-SCREEN_UPDATE( galsnew )
+SCREEN_UPDATE_IND16( galsnew )
 {
-	kaneko16_state *state = screen->machine().driver_data<kaneko16_state>();
-//  kaneko16_fill_bitmap(screen->machine(),bitmap,cliprect);
+	kaneko16_state *state = screen.machine().driver_data<kaneko16_state>();
+//  kaneko16_fill_bitmap(screen.machine(),bitmap,cliprect);
 	int y,x;
 	int count;
 
@@ -1082,7 +1079,7 @@ SCREEN_UPDATE( galsnew )
 	count = 0;
 	for (y=0;y<256;y++)
 	{
-		UINT16 *dest = BITMAP_ADDR16(bitmap, y, 0);
+		UINT16 *dest = &bitmap.pix16(y);
 
 		for (x=0;x<256;x++)
 		{
@@ -1096,7 +1093,7 @@ SCREEN_UPDATE( galsnew )
 	count = 0;
 	for (y=0;y<256;y++)
 	{
-		UINT16 *dest = BITMAP_ADDR16(bitmap, y, 0);
+		UINT16 *dest = &bitmap.pix16(y);
 
 		for (x=0;x<256;x++)
 		{
@@ -1113,23 +1110,23 @@ SCREEN_UPDATE( galsnew )
 	// if the display is disabled, do nothing?
 	if (!state->m_disp_enable) return 0;
 
-	SCREEN_UPDATE_CALL(common);
+	SCREEN_UPDATE16_CALL(common);
 
-	kaneko16_render_sprites(screen->machine(),bitmap,cliprect);
+	kaneko16_render_sprites(screen.machine(),bitmap,cliprect);
 	return 0;
 }
 
 
-SCREEN_UPDATE( sandscrp )
+SCREEN_UPDATE_IND16( sandscrp )
 {
-	kaneko16_state *state = screen->machine().driver_data<kaneko16_state>();
-	device_t *pandora = screen->machine().device("pandora");
-	kaneko16_fill_bitmap(screen->machine(),bitmap,cliprect);
+	kaneko16_state *state = screen.machine().driver_data<kaneko16_state>();
+	device_t *pandora = screen.machine().device("pandora");
+	kaneko16_fill_bitmap(screen.machine(),bitmap,cliprect);
 
 	// if the display is disabled, do nothing?
 	if (!state->m_disp_enable) return 0;
 
-	SCREEN_UPDATE_CALL(common);
+	SCREEN_UPDATE16_CALL(common);
 
 	// copy sprite bitmap to screen
 	pandora_update(pandora, bitmap, cliprect);
