@@ -42,15 +42,15 @@ static int gx_specialrozenable; // type 1 roz, with voxel height-map, rendered f
 static int gx_rushingheroes_hack;
 static int gx_le2_textcolour_hack;
 static tilemap_t *gx_psac_tilemap, *gx_psac_tilemap2;
-static bitmap_t* type3_roz_temp_bitmap;
+static bitmap_ind16* type3_roz_temp_bitmap;
 static tilemap_t* gx_psac_tilemap_alt;
 
 static int konamigx_has_dual_screen;
 int konamigx_current_frame;
 INLINE void set_color_555(running_machine &machine, pen_t color, int rshift, int gshift, int bshift, UINT16 data);
 static int konamigx_palformat;
-static bitmap_t* dualscreen_left_tempbitmap;
-static bitmap_t* dualscreen_right_tempbitmap;
+static bitmap_rgb32* dualscreen_left_tempbitmap;
+static bitmap_rgb32* dualscreen_right_tempbitmap;
 
 /* On Type-1 the K053936 output is rendered to these temporary bitmaps as raw data
    the 'voxel' effect to give the pixels height is a post-process operation on the
@@ -69,8 +69,8 @@ static bitmap_t* dualscreen_right_tempbitmap;
 
 
    */
-static bitmap_t *gxtype1_roz_dstbitmap;
-static bitmap_t *gxtype1_roz_dstbitmap2;
+static bitmap_ind16 *gxtype1_roz_dstbitmap;
+static bitmap_ind16 *gxtype1_roz_dstbitmap2;
 static rectangle gxtype1_roz_dstbitmapclip;
 
 static void (*game_tile_callback)(running_machine &machine, int layer, int *code, int *color, int *flags);
@@ -78,7 +78,7 @@ static void (*game_tile_callback)(running_machine &machine, int layer, int *code
 // Localized K053936/ROZ+
 #define K053936_MAX_CHIPS 2
 
-static rectangle K053936_cliprect[K053936_MAX_CHIPS] = {{0,0,0,0},{0,0,0,0}};
+static rectangle K053936_cliprect[K053936_MAX_CHIPS];
 static int K053936_offset[K053936_MAX_CHIPS][2] = {{0,0},{0,0}};
 static int K053936_clip_enabled[K053936_MAX_CHIPS] = {0,0};
 
@@ -89,16 +89,13 @@ void K053936GP_clip_enable(int chip, int status) { K053936_clip_enabled[chip] =
 
 void K053936GP_set_cliprect(int chip, int minx, int maxx, int miny, int maxy)
 {
-	rectangle *cliprect = &K053936_cliprect[chip];
-	cliprect->min_x = minx;
-	cliprect->max_x = maxx;
-	cliprect->min_y = miny;
-	cliprect->max_y = maxy;
+	rectangle &cliprect = K053936_cliprect[chip];
+	cliprect.set(minx, maxx, miny, maxy);
 }
 
 INLINE void K053936GP_copyroz32clip( running_machine &machine,
-		bitmap_t *dst_bitmap, bitmap_t *src_bitmap,
-		const rectangle *dst_cliprect, const rectangle *src_cliprect,
+		bitmap_rgb32 &dst_bitmap, bitmap_ind16 &src_bitmap,
+		const rectangle &dst_cliprect, const rectangle &src_cliprect,
 		UINT32 _startx,UINT32 _starty,int _incxx,int _incxy,int _incyx,int _incyy,
 		int tilebpp, int blend, int alpha, int clip, int pixeldouble_output )
 {
@@ -123,31 +120,28 @@ INLINE void K053936GP_copyroz32clip( running_machine &machine,
 	incxy = _incxy; incxx = _incxx; incyy = _incyy; incyx = _incyx;
 	starty = _starty; startx = _startx;
 
-	if (src_cliprect && clip) // set source clip range to some extreme values when disabled
+	if (clip) // set source clip range to some extreme values when disabled
 	{
-		src_minx = src_cliprect->min_x;
-		src_maxx = src_cliprect->max_x;
-		src_miny = src_cliprect->min_y;
-		src_maxy = src_cliprect->max_y;
+		src_minx = src_cliprect.min_x;
+		src_maxx = src_cliprect.max_x;
+		src_miny = src_cliprect.min_y;
+		src_maxy = src_cliprect.max_y;
 	}
 	// this simply isn't safe to do!
 	else { src_minx = src_miny = -0x10000; src_maxx = src_maxy = 0x10000; }
 
-	if (dst_cliprect) // set target clip range
-	{
-		sx = dst_cliprect->min_x;
-		tx = dst_cliprect->max_x - sx + 1;
-		sy = dst_cliprect->min_y;
-		ty = dst_cliprect->max_y - sy + 1;
+	// set target clip range
+	sx = dst_cliprect.min_x;
+	tx = dst_cliprect.max_x - sx + 1;
+	sy = dst_cliprect.min_y;
+	ty = dst_cliprect.max_y - sy + 1;
 
-		startx += sx * incxx + sy * incyx;
-		starty += sx * incxy + sy * incyy;
-	}
-	else { sx = sy = 0; tx = dst_bitmap->width; ty = dst_bitmap->height; }
+	startx += sx * incxx + sy * incyx;
+	starty += sx * incxy + sy * incyy;
 
 	// adjust entry points and other loop constants
-	dst_pitch = dst_bitmap->rowpixels;
-	dst_base = (UINT32*)dst_bitmap->base;
+	dst_pitch = dst_bitmap.rowpixels();
+	dst_base = &dst_bitmap.pix32(0);
 	dst_base2 = sy * dst_pitch + sx + tx;
 	ecx = tx = -tx;
 
@@ -155,10 +149,10 @@ INLINE void K053936GP_copyroz32clip( running_machine &machine,
 	pal_base = machine.pens;
 	cmask = colormask[tilebpp];
 
-	src_pitch = src_bitmap->rowpixels;
-	src_base = (UINT16 *)src_bitmap->base;
-	src_size = src_bitmap->width * src_bitmap->height;
-	dst_size = dst_bitmap->width * dst_bitmap->height;
+	src_pitch = src_bitmap.rowpixels();
+	src_base = &src_bitmap.pix16(0);
+	src_size = src_bitmap.width() * src_bitmap.height();
+	dst_size = dst_bitmap.width() * dst_bitmap.height();
 	dst_ptr = 0;//dst_base;
 	cy = starty;
 	cx = startx;
@@ -283,27 +277,25 @@ INLINE void K053936GP_copyroz32clip( running_machine &machine,
 // adapted from generic K053936_zoom_draw()
 static void K053936GP_zoom_draw(running_machine &machine,
 		int chip, UINT16 *ctrl, UINT16 *linectrl,
-		bitmap_t *bitmap, const rectangle *cliprect, tilemap_t *tmap,
+		bitmap_rgb32 &bitmap, const rectangle &cliprect, tilemap_t *tmap,
 		int tilebpp, int blend, int alpha, int pixeldouble_output)
 {
-	bitmap_t *src_bitmap;
-	rectangle *src_cliprect;
 	UINT16 *lineaddr;
 
 	rectangle my_clip;
 	UINT32 startx, starty;
 	int incxx, incxy, incyx, incyy, y, maxy, clip;
 
-	src_bitmap = tilemap_get_pixmap(tmap);
-	src_cliprect = &K053936_cliprect[chip];
+	bitmap_ind16 &src_bitmap = tmap->pixmap();
+	rectangle &src_cliprect = K053936_cliprect[chip];
 	clip = K053936_clip_enabled[chip];
 
 	if (ctrl[0x07] & 0x0040)    /* "super" mode */
 	{
-		my_clip.min_x = cliprect->min_x;
-		my_clip.max_x = cliprect->max_x;
-		y = cliprect->min_y;
-		maxy = cliprect->max_y;
+		my_clip.min_x = cliprect.min_x;
+		my_clip.max_x = cliprect.max_x;
+		y = cliprect.min_y;
+		maxy = cliprect.max_y;
 
 		while (y <= maxy)
 		{
@@ -322,7 +314,7 @@ static void K053936GP_zoom_draw(running_machine &machine,
 			starty -= K053936_offset[chip][0] * incxy;
 
 			K053936GP_copyroz32clip(machine,
-					bitmap, src_bitmap, &my_clip, src_cliprect,
+					bitmap, src_bitmap, my_clip, src_cliprect,
 					startx<<5, starty<<5, incxx<<5, incxy<<5, 0, 0,
 					tilebpp, blend, alpha, clip, pixeldouble_output);
 			y++;
@@ -353,13 +345,13 @@ static void K053936GP_zoom_draw(running_machine &machine,
 	}
 }
 
-static void K053936GP_0_zoom_draw(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect,
+static void K053936GP_0_zoom_draw(running_machine &machine, bitmap_rgb32 &bitmap, const rectangle &cliprect,
 		tilemap_t *tmap, int tilebpp, int blend, int alpha, int pixeldouble_output)
 {
 	K053936GP_zoom_draw(machine, 0,K053936_0_ctrl,K053936_0_linectrl,bitmap,cliprect,tmap,tilebpp,blend,alpha, pixeldouble_output);
 }
 
-static void K053936GP_1_zoom_draw(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect,
+static void K053936GP_1_zoom_draw(running_machine &machine, bitmap_rgb32 &bitmap, const rectangle &cliprect,
 		tilemap_t *tmap, int tilebpp, int blend, int alpha, int pixeldouble_output)
 {
 	K053936GP_zoom_draw(machine, 1,K053936_1_ctrl,K053936_1_linectrl,bitmap,cliprect,tmap,tilebpp,blend,alpha, pixeldouble_output);
@@ -385,7 +377,7 @@ static void K053936GP_1_zoom_draw(running_machine &machine, bitmap_t *bitmap, co
 
 
 INLINE void zdrawgfxzoom32GP(
-		bitmap_t *bitmap, const rectangle *cliprect, const gfx_element *gfx,
+		bitmap_rgb32 &bitmap, const rectangle &cliprect, const gfx_element *gfx,
 		UINT32 code, UINT32 color, int flipx, int flipy, int sx, int sy,
 		int scalex, int scaley, int alpha, int drawmode, int zcode, int pri)
 {
@@ -453,12 +445,12 @@ INLINE void zdrawgfxzoom32GP(
 	pal_base  = gfx->machine().pens + gfx->color_base + (color % gfx->total_colors) * granularity;
 	shd_base  = gfx->machine().shadow_table;
 
-	dst_ptr   = (UINT32 *)bitmap->base;
-	dst_pitch = bitmap->rowpixels;
-	dst_minx  = cliprect->min_x;
-	dst_maxx  = cliprect->max_x;
-	dst_miny  = cliprect->min_y;
-	dst_maxy  = cliprect->max_y;
+	dst_ptr   = &bitmap.pix32(0);
+	dst_pitch = bitmap.rowpixels();
+	dst_minx  = cliprect.min_x;
+	dst_maxx  = cliprect.max_x;
+	dst_miny  = cliprect.min_y;
+	dst_maxy  = cliprect.max_y;
 	dst_x     = sx;
 	dst_y     = sy;
 
@@ -510,8 +502,8 @@ INLINE void zdrawgfxzoom32GP(
 
 	// adjust insertion points and pre-entry constants
 	eax = (dst_y - dst_miny) * GX_ZBUFW + (dst_x - dst_minx) + dst_w;
-//  db0 = z8 = (UINT8)zcode;
-//  db1 = p8 = (UINT8)pri;
+	z8 = (UINT8)zcode;
+	p8 = (UINT8)pri;
 	ozbuf_ptr += eax;
 	szbuf_ptr += eax << 1;
 	dst_ptr += dst_y * dst_pitch + dst_x + dst_w;
@@ -1061,8 +1053,8 @@ static void gx_wipezbuf(running_machine &machine, int noshadow)
 {
 	const rectangle &visarea = machine.primary_screen->visible_area();
 
-	int w = visarea.max_x - visarea.min_x + 1;
-	int h = visarea.max_y - visarea.min_y + 1;
+	int w = visarea.width();
+	int h = visarea.height();
 
 	UINT8 *zptr = gx_objzbuf;
 	int ecx = h;
@@ -1134,7 +1126,7 @@ void konamigx_mixer_init(running_machine &machine, int objdma)
 	gx_objdma = 0;
 	gx_primode = 0;
 
-	gx_objzbuf = (UINT8 *)machine.priority_bitmap->base;
+	gx_objzbuf = &machine.priority_bitmap.pix8(0);
 	gx_shdzbuf = auto_alloc_array(machine, UINT8, GX_ZBUFSIZE);
 	gx_objpool = auto_alloc_array(machine, struct GX_OBJ, GX_MAX_OBJECTS);
 
@@ -1163,10 +1155,10 @@ void konamigx_objdma(void)
 	if (gx_objdma && gx_spriteram && K053247_ram) memcpy(gx_spriteram, K053247_ram, 0x1000);
 }
 
-void konamigx_mixer(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect,
+void konamigx_mixer(running_machine &machine, bitmap_rgb32 &bitmap, const rectangle &cliprect,
 					tilemap_t *sub1, int sub1flags,
 					tilemap_t *sub2, int sub2flags,
-					int mixerflags, bitmap_t *extra_bitmap, int rushingheroes_hack)
+					int mixerflags, bitmap_ind16 *extra_bitmap, int rushingheroes_hack)
 {
 	static const int xoffset[8] = { 0, 1, 4, 5, 16, 17, 20, 21 };
 	static const int yoffset[8] = { 0, 2, 8, 10, 32, 34, 40, 42 };
@@ -1182,6 +1174,8 @@ void konamigx_mixer(running_machine &machine, bitmap_t *bitmap, const rectangle
 	int nobj, i, j, k, l, temp, temp1, temp2, temp3, temp4, count;
 	int order, offs, code, color, zcode, pri = 0, spri, spri_min, shdprisel, shadow, alpha, drawmode;
 
+    // buffer can move when it's resized, so refresh the pointer
+	gx_objzbuf = &machine.priority_bitmap.pix8(0);
 
 	// abort if object database failed to initialize
 	objpool = gx_objpool;
@@ -1580,7 +1574,7 @@ void konamigx_mixer(running_machine &machine, bitmap_t *bitmap, const rectangle
 					{
 						int pixeldouble_output = 0;
 						const rectangle &visarea = machine.primary_screen->visible_area();
-						int width = visarea.max_x - visarea.min_x + 1;
+						int width = visarea.width();
 
 						if (width>512) // vsnetscr case
 							pixeldouble_output = 1;
@@ -1633,8 +1627,8 @@ void konamigx_mixer(running_machine &machine, bitmap_t *bitmap, const rectangle
 							// - todo, use the pixeldouble_output I just added for vsnet instead?
 							for (yy=0;yy<height;yy++)
 							{
-								UINT16* src = BITMAP_ADDR16(extra_bitmap,yy,0);
-								UINT32* dst = BITMAP_ADDR32(bitmap,yy,0);
+								UINT16* src = &extra_bitmap->pix16(yy);
+								UINT32* dst = &bitmap.pix32(yy);
 								int shiftpos = 0;
 								for (xx=0;xx<width;xx+=2)
 								{
@@ -1857,7 +1851,7 @@ WRITE32_HANDLER( konamigx_type3_psac2_bank_w )
 	/* handle this by creating 2 roz tilemaps instead, otherwise performance dies completely on dual screen mode
     if (konamigx_type3_psac2_actual_bank!=konamigx_type3_psac2_actual_last_bank)
     {
-        tilemap_mark_all_tiles_dirty (gx_psac_tilemap);
+        gx_psac_tilemap->mark_all_dirty();
         konamigx_type3_psac2_actual_last_bank = konamigx_type3_psac2_actual_bank;
     }
     */
@@ -2156,8 +2150,8 @@ VIDEO_START(konamigx_type3)
 	K056832_vh_start(machine, "gfx1", K056832_BPP_6, 0, NULL, konamigx_type2_tile_callback, 1);
 	K055673_vh_start(machine, "gfx2", K055673_LAYOUT_GX6, -132, -23, konamigx_type2_sprite_callback);
 
-	dualscreen_left_tempbitmap = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_RGB32);
-	dualscreen_right_tempbitmap = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_RGB32);
+	dualscreen_left_tempbitmap = auto_bitmap_rgb32_alloc(machine, width, height);
+	dualscreen_right_tempbitmap = auto_bitmap_rgb32_alloc(machine, width, height);
 
 	_gxcommoninitnosprites(machine);
 
@@ -2169,10 +2163,10 @@ VIDEO_START(konamigx_type3)
 
 
 	/* set up tile layers */
-	type3_roz_temp_bitmap = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_INDEXED16);
+	type3_roz_temp_bitmap = auto_bitmap_ind16_alloc(machine, width, height);
 
 
-	//tilemap_set_flip(gx_psac_tilemap, TILEMAP_FLIPX| TILEMAP_FLIPY);
+	//gx_psac_tilemap->set_flip(TILEMAP_FLIPX| TILEMAP_FLIPY);
 
 	K053936_wraparound_enable(0, 1);
 //  K053936GP_set_offset(0, -30, -1);
@@ -2195,8 +2189,8 @@ VIDEO_START(konamigx_type4)
 	K056832_vh_start(machine, "gfx1", K056832_BPP_8, 0, NULL, konamigx_type2_tile_callback, 0);
 	K055673_vh_start(machine, "gfx2", K055673_LAYOUT_GX6, -79, -24, konamigx_type2_sprite_callback); // -23 looks better in intro
 
-	dualscreen_left_tempbitmap = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_RGB32);
-	dualscreen_right_tempbitmap = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_RGB32);
+	dualscreen_left_tempbitmap = auto_bitmap_rgb32_alloc(machine, width, height);
+	dualscreen_right_tempbitmap = auto_bitmap_rgb32_alloc(machine, width, height);
 
 	_gxcommoninitnosprites(machine);
 
@@ -2226,8 +2220,8 @@ VIDEO_START(konamigx_type4_vsn)
 	K056832_vh_start(machine, "gfx1", K056832_BPP_8, 0, NULL, konamigx_type2_tile_callback, 2);   // set djmain_hack to 2 to kill layer association or half the tilemaps vanish on screen 0
 	K055673_vh_start(machine, "gfx2", K055673_LAYOUT_GX6, -132, -23, konamigx_type2_sprite_callback);
 
-	dualscreen_left_tempbitmap = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_RGB32);
-	dualscreen_right_tempbitmap = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_RGB32);
+	dualscreen_left_tempbitmap = auto_bitmap_rgb32_alloc(machine, width, height);
+	dualscreen_right_tempbitmap = auto_bitmap_rgb32_alloc(machine, width, height);
 
 	_gxcommoninitnosprites(machine);
 
@@ -2256,8 +2250,8 @@ VIDEO_START(konamigx_type4_sd2)
 	K056832_vh_start(machine, "gfx1", K056832_BPP_8, 0, NULL, konamigx_type2_tile_callback, 0);
 	K055673_vh_start(machine, "gfx2", K055673_LAYOUT_GX6, -81, -23, konamigx_type2_sprite_callback);
 
-	dualscreen_left_tempbitmap = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_RGB32);
-	dualscreen_right_tempbitmap = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_RGB32);
+	dualscreen_left_tempbitmap = auto_bitmap_rgb32_alloc(machine, width, height);
+	dualscreen_right_tempbitmap = auto_bitmap_rgb32_alloc(machine, width, height);
 
 	_gxcommoninitnosprites(machine);
 
@@ -2314,20 +2308,17 @@ VIDEO_START(opengolf)
 	gx_psac_tilemap2 = tilemap_create(machine, get_gx_psac1b_tile_info, tilemap_scan_cols,  16, 16, 128, 128);
 
 	// transparency will be handled manually in post-processing
-	//tilemap_set_transparent_pen(gx_psac_tilemap, 0);
-	//tilemap_set_transparent_pen(gx_psac_tilemap2, 0);
+	//gx_psac_tilemap->set_transparent_pen(0);
+	//gx_psac_tilemap2->set_transparent_pen(0);
 
 	gx_rozenable = 0;
 	gx_specialrozenable = 1;
 
-	gxtype1_roz_dstbitmap =  auto_bitmap_alloc(machine,512,512,BITMAP_FORMAT_INDEXED16); // BITMAP_FORMAT_INDEXED16 because we NEED the raw pen data for post-processing
-	gxtype1_roz_dstbitmap2 = auto_bitmap_alloc(machine,512,512,BITMAP_FORMAT_INDEXED16); // BITMAP_FORMAT_INDEXED16 because we NEED the raw pen data for post-processing
+	gxtype1_roz_dstbitmap =  auto_bitmap_ind16_alloc(machine,512,512); // BITMAP_FORMAT_IND16 because we NEED the raw pen data for post-processing
+	gxtype1_roz_dstbitmap2 = auto_bitmap_ind16_alloc(machine,512,512); // BITMAP_FORMAT_IND16 because we NEED the raw pen data for post-processing
 
 
-	gxtype1_roz_dstbitmapclip.min_x = 0;
-	gxtype1_roz_dstbitmapclip.max_x = 512-1;
-	gxtype1_roz_dstbitmapclip.min_y = 0;
-	gxtype1_roz_dstbitmapclip.max_y = 512-1;
+	gxtype1_roz_dstbitmapclip.set(0, 512-1, 0, 512-1);
 
 
 	K053936_wraparound_enable(0, 1);
@@ -2335,7 +2326,7 @@ VIDEO_START(opengolf)
 
 	// urgh.. the priority bitmap is global, and because our temp bitmaps are bigger than the screen, this causes issues.. so just allocate something huge
 	// until there is a better solution, or priority bitmap can be specified manually.
-	machine.priority_bitmap = auto_bitmap_alloc(machine,2048,2048,BITMAP_FORMAT_INDEXED16);
+	machine.priority_bitmap.allocate(2048,2048);
 
 }
 
@@ -2355,20 +2346,17 @@ VIDEO_START(racinfrc)
 	gx_psac_tilemap2 = tilemap_create(machine, get_gx_psac1b_tile_info, tilemap_scan_cols,  16, 16, 128, 128);
 
 	// transparency will be handled manually in post-processing
-	//tilemap_set_transparent_pen(gx_psac_tilemap, 0);
-	//tilemap_set_transparent_pen(gx_psac_tilemap2, 0);
+	//gx_psac_tilemap->set_transparent_pen(0);
+	//gx_psac_tilemap2->set_transparent_pen(0);
 
 	gx_rozenable = 0;
 	gx_specialrozenable = 1;
 
-	gxtype1_roz_dstbitmap =  auto_bitmap_alloc(machine,512,512,BITMAP_FORMAT_INDEXED16); // BITMAP_FORMAT_INDEXED16 because we NEED the raw pen data for post-processing
-	gxtype1_roz_dstbitmap2 = auto_bitmap_alloc(machine,512,512,BITMAP_FORMAT_INDEXED16); // BITMAP_FORMAT_INDEXED16 because we NEED the raw pen data for post-processing
+	gxtype1_roz_dstbitmap =  auto_bitmap_ind16_alloc(machine,512,512); // BITMAP_FORMAT_IND16 because we NEED the raw pen data for post-processing
+	gxtype1_roz_dstbitmap2 = auto_bitmap_ind16_alloc(machine,512,512); // BITMAP_FORMAT_IND16 because we NEED the raw pen data for post-processing
 
 
-	gxtype1_roz_dstbitmapclip.min_x = 0;
-	gxtype1_roz_dstbitmapclip.max_x = 512-1;
-	gxtype1_roz_dstbitmapclip.min_y = 0;
-	gxtype1_roz_dstbitmapclip.max_y = 512-1;
+	gxtype1_roz_dstbitmapclip.set(0, 512-1, 0, 512-1);
 
 
 	K053936_wraparound_enable(0, 1);
@@ -2376,106 +2364,14 @@ VIDEO_START(racinfrc)
 
 	// urgh.. the priority bitmap is global, and because our temp bitmaps are bigger than the screen, this causes issues.. so just allocate something huge
 	// until there is a better solution, or priority bitmap can be specified manually.
-	machine.priority_bitmap = auto_bitmap_alloc(machine,2048,2048,BITMAP_FORMAT_INDEXED16);
+	machine.priority_bitmap.allocate(2048,2048);
 
 
 }
 
-SCREEN_UPDATE(konamigx)
+SCREEN_UPDATE_RGB32(konamigx)
 {
 	int i, newbank, newbase, dirty, unchained;
-	bitmap_t* realbitmap = bitmap;
-
-	if (konamigx_has_dual_screen)
-	{
-		device_t *left_screen  = screen->machine().device("screen");
-		device_t *right_screen = screen->machine().device("screen2");
-
-		/* the video gets demuxed by a board which plugs into the jamma connector */
-		if (screen==left_screen)
-		{
-			konamigx_current_frame^=1;
-
-			if (konamigx_current_frame==1)
-			{
-				int offset=0;
-
-				if (konamigx_palformat==1)
-				{
-					for (offset=0;offset<0x4000/4;offset++)
-					{
-						UINT32 coldat = screen->machine().generic.paletteram.u32[offset];
-
-						set_color_555(screen->machine(), offset*2, 0, 5, 10,coldat >> 16);
-						set_color_555(screen->machine(), offset*2+1, 0, 5, 10,coldat & 0xffff);
-					}
-				}
-				else
-				{
-					for (offset=0;offset<0x8000/4;offset++)
-					{
-						int r,g,b;
-
-						r = (screen->machine().generic.paletteram.u32[offset] >>16) & 0xff;
-						g = (screen->machine().generic.paletteram.u32[offset] >> 8) & 0xff;
-						b = (screen->machine().generic.paletteram.u32[offset] >> 0) & 0xff;
-
-						palette_set_color(screen->machine(),offset,MAKE_RGB(r,g,b));
-					}
-				}
-
-				bitmap = dualscreen_left_tempbitmap;
-				// draw
-			}
-			else
-			{
-				copybitmap(bitmap, dualscreen_left_tempbitmap, 0, 0, 0, 0, cliprect);
-				return 0;
-			}
-
-		}
-		else if (screen==right_screen)
-		{
-
-			if (konamigx_current_frame==1)
-			{
-				copybitmap(bitmap, dualscreen_right_tempbitmap, 0, 0, 0, 0, cliprect);
-				return 0;
-			}
-			else
-			{
-
-				int offset=0;
-
-				if (konamigx_palformat==1)
-				{
-					for (offset=0;offset<0x4000/4;offset++)
-					{
-						UINT32 coldat = gx_subpaletteram32[offset];
-
-						set_color_555(screen->machine(), offset*2, 0, 5, 10,coldat >> 16);
-						set_color_555(screen->machine(), offset*2+1, 0, 5, 10,coldat & 0xffff);
-					}
-				}
-				else
-				{
-					for (offset=0;offset<0x8000/4;offset++)
-					{
-						int r,g,b;
-
-						r = (gx_subpaletteram32[offset] >>16) & 0xff;
-						g = (gx_subpaletteram32[offset] >> 8) & 0xff;
-						b = (gx_subpaletteram32[offset] >> 0) & 0xff;
-
-						palette_set_color(screen->machine(),offset,MAKE_RGB(r,g,b));
-					}
-				}
-				bitmap = dualscreen_right_tempbitmap;
-				// draw
-			}
-		}
-	}
-
 
 	/* if any banks are different from last render, we need to flush the planes */
 	for (dirty = 0, i = 0; i < 8; i++)
@@ -2515,10 +2411,10 @@ SCREEN_UPDATE(konamigx)
 
 		if (psac_colorbase != last_psac_colorbase)
 		{
-			tilemap_mark_all_tiles_dirty(gx_psac_tilemap);
+			gx_psac_tilemap->mark_all_dirty();
 			if (gx_rozenable == 3)
 			{
-				tilemap_mark_all_tiles_dirty(gx_psac_tilemap2);
+				gx_psac_tilemap2->mark_all_dirty();
 			}
 		}
 	}
@@ -2528,15 +2424,15 @@ SCREEN_UPDATE(konamigx)
 	// Type-1
 	if (gx_specialrozenable == 1)
 	{
-		K053936_0_zoom_draw(gxtype1_roz_dstbitmap, &gxtype1_roz_dstbitmapclip,gx_psac_tilemap, 0,0,0); // height data
-		K053936_0_zoom_draw(gxtype1_roz_dstbitmap2,&gxtype1_roz_dstbitmapclip,gx_psac_tilemap2,0,0,0); // colour data (+ some voxel height data?)
+		K053936_0_zoom_draw(*gxtype1_roz_dstbitmap, gxtype1_roz_dstbitmapclip,gx_psac_tilemap, 0,0,0); // height data
+		K053936_0_zoom_draw(*gxtype1_roz_dstbitmap2,gxtype1_roz_dstbitmapclip,gx_psac_tilemap2,0,0,0); // colour data (+ some voxel height data?)
 	}
 
 
 
 	if (gx_specialrozenable==3)
 	{
-		konamigx_mixer(screen->machine(), bitmap, cliprect, gx_psac_tilemap, GXSUB_8BPP,0,0,  0, 0, gx_rushingheroes_hack);
+		konamigx_mixer(screen.machine(), bitmap, cliprect, gx_psac_tilemap, GXSUB_8BPP,0,0,  0, 0, gx_rushingheroes_hack);
 	}
 	// hack, draw the roz tilemap if W is held
 	// todo: fix so that it works with the mixer without crashing(!)
@@ -2544,20 +2440,18 @@ SCREEN_UPDATE(konamigx)
 	{
 		// we're going to throw half of this away anyway in post-process, so only render what's needed
 		rectangle temprect;
-		temprect.min_x = cliprect->min_x;
-		temprect.max_x = cliprect->min_x+320;
-		temprect.min_y = cliprect->min_y;
-		temprect.max_y = cliprect->max_y;
+		temprect = cliprect;
+		temprect.max_x = cliprect.min_x+320;
 
-		if (konamigx_type3_psac2_actual_bank == 1) K053936_0_zoom_draw(type3_roz_temp_bitmap, &temprect,gx_psac_tilemap_alt, 0,0,0); // soccerss playfield
-		else K053936_0_zoom_draw(type3_roz_temp_bitmap, &temprect,gx_psac_tilemap, 0,0,0); // soccerss playfield
+		if (konamigx_type3_psac2_actual_bank == 1) K053936_0_zoom_draw(*type3_roz_temp_bitmap, temprect,gx_psac_tilemap_alt, 0,0,0); // soccerss playfield
+		else K053936_0_zoom_draw(*type3_roz_temp_bitmap, temprect,gx_psac_tilemap, 0,0,0); // soccerss playfield
 
 
-		konamigx_mixer(screen->machine(), bitmap, cliprect, 0, 0, 0, 0, 0, type3_roz_temp_bitmap, gx_rushingheroes_hack);
+		konamigx_mixer(screen.machine(), bitmap, cliprect, 0, 0, 0, 0, 0, type3_roz_temp_bitmap, gx_rushingheroes_hack);
 	}
 	else
 	{
-		konamigx_mixer(screen->machine(), bitmap, cliprect, 0, 0, 0, 0, 0, 0, gx_rushingheroes_hack);
+		konamigx_mixer(screen.machine(), bitmap, cliprect, 0, 0, 0, 0, 0, 0, gx_rushingheroes_hack);
 	}
 
 
@@ -2565,25 +2459,25 @@ SCREEN_UPDATE(konamigx)
 	/* Hack! draw type-1 roz layer here for testing purposes only */
 	if (gx_specialrozenable == 1)
 	{
-		const pen_t *paldata = screen->machine().pens;
+		const pen_t *paldata = screen.machine().pens;
 
-		if ( screen->machine().input().code_pressed(KEYCODE_W) )
+		if ( screen.machine().input().code_pressed(KEYCODE_W) )
 		{
 			int y,x;
 
 			// make it flicker, to compare positioning
-			//if (screen->frame_number() & 1)
+			//if (screen.frame_number() & 1)
 			{
 
 				for (y=0;y<256;y++)
 				{
-					//UINT16* src = BITMAP_ADDR16( gxtype1_roz_dstbitmap, y, 0);
+					//UINT16* src = &gxtype1_roz_dstbitmap->pix16(y);
 
-					//UINT32* dst = BITMAP_ADDR32( bitmap, y, 0);
+					//UINT32* dst = &bitmap.pix32(y);
 					// ths K053936 rendering should probably just be flipped
 					// this is just kludged to align the racing force 2d logo
-					UINT16* src = BITMAP_ADDR16( gxtype1_roz_dstbitmap2, y+30, 0);
-					UINT32* dst = BITMAP_ADDR32( bitmap, 256-y, 0);
+					UINT16* src = &gxtype1_roz_dstbitmap2->pix16(y+30);
+					UINT32* dst = &bitmap.pix32(256-y);
 
 					for (x=0;x<512;x++)
 					{
@@ -2597,19 +2491,90 @@ SCREEN_UPDATE(konamigx)
 
 	}
 
-	if (konamigx_has_dual_screen)
-	{
-		device_t *left_screen  = screen->machine().device("screen");
-		device_t *right_screen = screen->machine().device("screen2");
+	return 0;
+}
 
-		if (screen==left_screen)
+SCREEN_UPDATE_RGB32(konamigx_left)
+{
+	/* the video gets demuxed by a board which plugs into the jamma connector */
+	konamigx_current_frame^=1;
+
+	if (konamigx_current_frame==1)
+	{
+		int offset=0;
+
+		if (konamigx_palformat==1)
 		{
-			copybitmap(realbitmap, dualscreen_left_tempbitmap, 0, 0, 0, 0, cliprect);
+			for (offset=0;offset<0x4000/4;offset++)
+			{
+				UINT32 coldat = screen.machine().generic.paletteram.u32[offset];
+
+				set_color_555(screen.machine(), offset*2, 0, 5, 10,coldat >> 16);
+				set_color_555(screen.machine(), offset*2+1, 0, 5, 10,coldat & 0xffff);
+			}
 		}
-		else if (screen==right_screen)
+		else
 		{
-			copybitmap(realbitmap, dualscreen_right_tempbitmap, 0, 0, 0, 0, cliprect);
+			for (offset=0;offset<0x8000/4;offset++)
+			{
+				int r,g,b;
+
+				r = (screen.machine().generic.paletteram.u32[offset] >>16) & 0xff;
+				g = (screen.machine().generic.paletteram.u32[offset] >> 8) & 0xff;
+				b = (screen.machine().generic.paletteram.u32[offset] >> 0) & 0xff;
+
+				palette_set_color(screen.machine(),offset,MAKE_RGB(r,g,b));
+			}
 		}
+
+		SCREEN_UPDATE_NAME(konamigx)(NULL, screen, downcast<bitmap_rgb32 &>(*dualscreen_left_tempbitmap), cliprect);
+		copybitmap(bitmap, *dualscreen_left_tempbitmap, 0, 0, 0, 0, cliprect);
+	}
+	else
+	{
+		copybitmap(bitmap, *dualscreen_left_tempbitmap, 0, 0, 0, 0, cliprect);
+	}
+
+	return 0;
+}
+
+SCREEN_UPDATE_RGB32(konamigx_right)
+{
+	if (konamigx_current_frame==1)
+	{
+		copybitmap(bitmap, *dualscreen_right_tempbitmap, 0, 0, 0, 0, cliprect);
+	}
+	else
+	{
+
+		int offset=0;
+
+		if (konamigx_palformat==1)
+		{
+			for (offset=0;offset<0x4000/4;offset++)
+			{
+				UINT32 coldat = gx_subpaletteram32[offset];
+
+				set_color_555(screen.machine(), offset*2, 0, 5, 10,coldat >> 16);
+				set_color_555(screen.machine(), offset*2+1, 0, 5, 10,coldat & 0xffff);
+			}
+		}
+		else
+		{
+			for (offset=0;offset<0x8000/4;offset++)
+			{
+				int r,g,b;
+
+				r = (gx_subpaletteram32[offset] >>16) & 0xff;
+				g = (gx_subpaletteram32[offset] >> 8) & 0xff;
+				b = (gx_subpaletteram32[offset] >> 0) & 0xff;
+
+				palette_set_color(screen.machine(),offset,MAKE_RGB(r,g,b));
+			}
+		}
+
+		SCREEN_UPDATE_NAME(konamigx)(NULL, screen, downcast<bitmap_rgb32 &>(*dualscreen_right_tempbitmap), cliprect);
+		copybitmap(bitmap, *dualscreen_right_tempbitmap, 0, 0, 0, 0, cliprect);
 	}
 
 	return 0;
@@ -2695,8 +2660,8 @@ WRITE32_HANDLER( konamigx_tilebank_w )
 WRITE32_HANDLER(konamigx_t1_psacmap_w)
 {
 	COMBINE_DATA(&gx_psacram[offset]);
-	tilemap_mark_tile_dirty(gx_psac_tilemap, offset/2);
-	tilemap_mark_tile_dirty(gx_psac_tilemap2, offset/2);
+	gx_psac_tilemap->mark_tile_dirty(offset/2);
+	gx_psac_tilemap2->mark_tile_dirty(offset/2);
 }
 
 // type 4 RAM-based PSAC tilemap
@@ -2704,7 +2669,7 @@ WRITE32_HANDLER( konamigx_t4_psacmap_w )
 {
 	COMBINE_DATA(&gx_psacram[offset]);
 
-	tilemap_mark_tile_dirty(gx_psac_tilemap, offset*2);
-	tilemap_mark_tile_dirty(gx_psac_tilemap, (offset*2)+1);
+	gx_psac_tilemap->mark_tile_dirty(offset*2);
+	gx_psac_tilemap->mark_tile_dirty((offset*2)+1);
 }
 
