@@ -25,7 +25,7 @@ TODO:
 #include "includes/cdi.h"
 
 #if ENABLE_VERBOSE_LOG
-INLINE void verboselog(running_machine *machine, int n_level, const char *s_fmt, ...)
+INLINE void verboselog(running_machine &machine, int n_level, const char *s_fmt, ...)
 {
     if( VERBOSE_LEVEL >= n_level )
     {
@@ -34,23 +34,23 @@ INLINE void verboselog(running_machine *machine, int n_level, const char *s_fmt,
         va_start( v, s_fmt );
         vsprintf( buf, s_fmt, v );
         va_end( v );
-        logerror( "%08x: %s", cpu_get_pc(machine->device("maincpu")), buf );
+        logerror( "%08x: %s", cpu_get_pc(machine.device("maincpu")), buf );
     }
 }
 #else
 #define verboselog(x,y,z,...)
 #endif
 
-static void cdi220_draw_lcd(running_machine *machine, int y);
+static void cdi220_draw_lcd(running_machine &machine, int y);
 static void mcd212_update_region_arrays(mcd212_regs_t *mcd212);
 static void mcd212_set_display_parameters(mcd212_regs_t *mcd212, int channel, UINT8 value);
-static void mcd212_update_visible_area(running_machine *machine);
+static void mcd212_update_visible_area(running_machine &machine);
 static void mcd212_set_vsr(mcd212_regs_t *mcd212, int channel, UINT32 value);
 static void mcd212_set_dcp(mcd212_regs_t *mcd212, int channel, UINT32 value);
 static UINT32 mcd212_get_vsr(mcd212_regs_t *mcd212, int channel);
 static UINT32 mcd212_get_dcp(mcd212_regs_t *mcd212, int channel);
 static UINT32 mcd212_get_screen_width(mcd212_regs_t *mcd212);
-static void mcd212_set_register(running_machine *machine, int channel, UINT8 reg, UINT32 value);
+static void mcd212_set_register(running_machine &machine, int channel, UINT8 reg, UINT32 value);
 static void mcd212_process_ica(mcd212_regs_t *mcd212, int channel);
 static void mcd212_process_dca(mcd212_regs_t *mcd212, int channel);
 static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels_r, UINT8 *pixels_g, UINT8 *pixels_b);
@@ -84,17 +84,17 @@ static const UINT16 cdi220_lcd_char[20*22] =
     0x1000, 0x1000, 0x1000, 0x1000, 0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x0400, 0x0400, 0x0400, 0x0400
 };
 
-static void cdi220_draw_lcd(running_machine *machine, int y)
+static void cdi220_draw_lcd(running_machine &machine, int y)
 {
-    cdi_state *state = machine->driver_data<cdi_state>();
-    bitmap_t *bitmap = state->lcdbitmap;
-    UINT32 *scanline = BITMAP_ADDR32(bitmap, y, 0);
+    cdi_state *state = machine.driver_data<cdi_state>();
+    bitmap_rgb32 &bitmap = state->m_lcdbitmap;
+    UINT32 *scanline = &bitmap.pix32(y);
     int x = 0;
     int lcd = 0;
 
     for(lcd = 0; lcd < 8; lcd++)
     {
-        cdislave_device *slave = downcast<cdislave_device *>(machine->device("slave"));
+        cdislave_device *slave = downcast<cdislave_device *>(machine.device("slave"));
         UINT16 data = (slave->get_lcd_state()[lcd*2] << 8) |
                        slave->get_lcd_state()[lcd*2 + 1];
         for(x = 0; x < 20; x++)
@@ -349,10 +349,10 @@ static void mcd212_set_vsr(mcd212_regs_t *mcd212, int channel, UINT32 value)
     mcd212->channel[channel].dcr |= (value >> 16) & 0x003f;
 }
 
-static void mcd212_set_register(running_machine *machine, int channel, UINT8 reg, UINT32 value)
+static void mcd212_set_register(running_machine &machine, int channel, UINT8 reg, UINT32 value)
 {
-    cdi_state *state = machine->driver_data<cdi_state>();
-    mcd212_regs_t *mcd212 = &state->mcd212_regs;
+    cdi_state *state = machine.driver_data<cdi_state>();
+    mcd212_regs_t *mcd212 = &state->m_mcd212_regs;
 
     switch(reg)
     {
@@ -534,13 +534,13 @@ static void mcd212_set_display_parameters(mcd212_regs_t *mcd212, int channel, UI
     mcd212->channel[channel].dcr |= (value & 0x10) << 7;
 }
 
-static void mcd212_update_visible_area(running_machine *machine)
+static void mcd212_update_visible_area(running_machine &machine)
 {
-    cdi_state *state = machine->driver_data<cdi_state>();
-    mcd212_regs_t *mcd212 = &state->mcd212_regs;
-    const rectangle &visarea = machine->primary_screen->visible_area();
+    cdi_state *state = machine.driver_data<cdi_state>();
+    mcd212_regs_t *mcd212 = &state->m_mcd212_regs;
+    const rectangle &visarea = machine.primary_screen->visible_area();
     rectangle visarea1;
-    attoseconds_t period = machine->primary_screen->frame_period().attoseconds;
+    attoseconds_t period = machine.primary_screen->frame_period().attoseconds;
     int width = 0;
 
     if((mcd212->channel[0].dcr & (MCD212_DCR_CF | MCD212_DCR_FD)) && (mcd212->channel[0].csrw & MCD212_CSR1W_ST))
@@ -557,7 +557,7 @@ static void mcd212_update_visible_area(running_machine *machine)
     visarea1.min_y = visarea.min_y;
     visarea1.max_y = visarea.max_y;
 
-    machine->primary_screen->configure(width, 302, visarea1, period);
+    machine.primary_screen->configure(width, 302, visarea1, period);
 }
 
 static UINT32 mcd212_get_screen_width(mcd212_regs_t *mcd212)
@@ -571,9 +571,9 @@ static UINT32 mcd212_get_screen_width(mcd212_regs_t *mcd212)
 
 static void mcd212_process_ica(mcd212_regs_t *mcd212, int channel)
 {
-    running_machine *machine = mcd212->machine;
-    cdi_state *state = machine->driver_data<cdi_state>();
-    UINT16 *ica = channel ? state->planeb : state->planea;
+    running_machine &machine = mcd212->machine();
+    cdi_state *state = machine.driver_data<cdi_state>();
+    UINT16 *ica = channel ? state->m_planeb : state->m_planea;
     UINT32 addr = 0x000400/2;
     UINT32 cmd = 0;
     while(1)
@@ -620,20 +620,20 @@ static void mcd212_process_ica(mcd212_regs_t *mcd212, int channel)
                 mcd212->channel[1].csrr |= 1 << (2 - channel);
                 if(mcd212->channel[1].csrr & (MCD212_CSR2R_IT1 | MCD212_CSR2R_IT2))
                 {
-                    UINT8 interrupt = (state->scc68070_regs.lir >> 4) & 7;
+                    UINT8 interrupt = (state->m_scc68070_regs.lir >> 4) & 7;
                     if(interrupt)
                     {
-                        cpu_set_input_line_vector(machine->device("maincpu"), M68K_IRQ_1 + (interrupt - 1), 56 + interrupt);
+                        device_set_input_line_vector(machine.device("maincpu"), M68K_IRQ_1 + (interrupt - 1), 56 + interrupt);
                         cputag_set_input_line(machine, "maincpu", M68K_IRQ_1 + (interrupt - 1), ASSERT_LINE);
                     }
                 }
 #if 0
                 if(mcd212->channel[1].csrr & MCD212_CSR2R_IT2)
                 {
-                    UINT8 interrupt = state->scc68070_regs.lir & 7;
+                    UINT8 interrupt = state->m_scc68070_regs.lir & 7;
                     if(interrupt)
                     {
-                        cpu_set_input_line_vector(machine->device("maincpu"), M68K_IRQ_1 + (interrupt - 1), 24 + interrupt);
+                        device_set_input_line_vector(machine.device("maincpu"), M68K_IRQ_1 + (interrupt - 1), 24 + interrupt);
                         cputag_set_input_line(machine, "maincpu", M68K_IRQ_1 + (interrupt - 1), ASSERT_LINE);
                     }
                 }
@@ -656,9 +656,9 @@ static void mcd212_process_ica(mcd212_regs_t *mcd212, int channel)
 
 static void mcd212_process_dca(mcd212_regs_t *mcd212, int channel)
 {
-    running_machine *machine = mcd212->machine;
-    cdi_state *state = machine->driver_data<cdi_state>();
-    UINT16 *dca = channel ? state->planeb : state->planea;
+    running_machine &machine = mcd212->machine();
+    cdi_state *state = machine.driver_data<cdi_state>();
+    UINT16 *dca = channel ? state->m_planeb : state->m_planea;
     UINT32 addr = (mcd212->channel[channel].dca & 0x0007ffff) / 2; //(mcd212_get_dcp(mcd212, channel) & 0x0007ffff) / 2; // mcd212->channel[channel].dca / 2;
     UINT32 cmd = 0;
     UINT32 count = 0;
@@ -689,7 +689,7 @@ static void mcd212_process_dca(mcd212_regs_t *mcd212, int channel)
             case 0x30: case 0x31: case 0x32: case 0x33: case 0x34: case 0x35: case 0x36: case 0x37: // RELOAD DCP and STOP
             case 0x38: case 0x39: case 0x3a: case 0x3b: case 0x3c: case 0x3d: case 0x3e: case 0x3f:
                 verboselog(machine, 11, "%08x: %08x: DCA %d: RELOAD DCP and STOP\n", addr * 2 + channel * 0x200000, cmd, channel );
-                mcd212_set_dcp(&state->mcd212_regs, channel, cmd & 0x001fffff);
+                mcd212_set_dcp(&state->m_mcd212_regs, channel, cmd & 0x001fffff);
                 addr = (cmd & 0x0007ffff) / 2;
                 addr_changed = 1;
                 stop = 1;
@@ -697,12 +697,12 @@ static void mcd212_process_dca(mcd212_regs_t *mcd212, int channel)
             case 0x40: case 0x41: case 0x42: case 0x43: case 0x44: case 0x45: case 0x46: case 0x47: // RELOAD VSR
             case 0x48: case 0x49: case 0x4a: case 0x4b: case 0x4c: case 0x4d: case 0x4e: case 0x4f:
                 verboselog(machine, 11, "%08x: %08x: DCA %d: RELOAD VSR\n", addr * 2 + channel * 0x200000, cmd, channel );
-                mcd212_set_vsr(&state->mcd212_regs, channel, cmd & 0x001fffff);
+                mcd212_set_vsr(&state->m_mcd212_regs, channel, cmd & 0x001fffff);
                 break;
             case 0x50: case 0x51: case 0x52: case 0x53: case 0x54: case 0x55: case 0x56: case 0x57: // RELOAD VSR and STOP
             case 0x58: case 0x59: case 0x5a: case 0x5b: case 0x5c: case 0x5d: case 0x5e: case 0x5f:
                 verboselog(machine, 11, "%08x: %08x: DCA %d: RELOAD VSR and STOP\n", addr * 2 + channel * 0x200000, cmd, channel );
-                mcd212_set_vsr(&state->mcd212_regs, channel, cmd & 0x001fffff);
+                mcd212_set_vsr(&state->m_mcd212_regs, channel, cmd & 0x001fffff);
                 stop = 1;
                 break;
             case 0x60: case 0x61: case 0x62: case 0x63: case 0x64: case 0x65: case 0x66: case 0x67: // INTERRUPT
@@ -711,20 +711,20 @@ static void mcd212_process_dca(mcd212_regs_t *mcd212, int channel)
                 mcd212->channel[1].csrr |= 1 << (2 - channel);
                 if(mcd212->channel[1].csrr & (MCD212_CSR2R_IT1 | MCD212_CSR2R_IT2))
                 {
-                    UINT8 interrupt = (state->scc68070_regs.lir >> 4) & 7;
+                    UINT8 interrupt = (state->m_scc68070_regs.lir >> 4) & 7;
                     if(interrupt)
                     {
-                        cpu_set_input_line_vector(machine->device("maincpu"), M68K_IRQ_1 + (interrupt - 1), 56 + interrupt);
+                        device_set_input_line_vector(machine.device("maincpu"), M68K_IRQ_1 + (interrupt - 1), 56 + interrupt);
                         cputag_set_input_line(machine, "maincpu", M68K_IRQ_1 + (interrupt - 1), ASSERT_LINE);
                     }
                 }
 #if 0
                 if(mcd212->channel[1].csrr & MCD212_CSR2R_IT2)
                 {
-                    UINT8 interrupt = state->scc68070_regs.lir & 7;
+                    UINT8 interrupt = state->m_scc68070_regs.lir & 7;
                     if(interrupt)
                     {
-                        cpu_set_input_line_vector(machine->device("maincpu"), M68K_IRQ_1 + (interrupt - 1), 24 + interrupt);
+                        device_set_input_line_vector(machine.device("maincpu"), M68K_IRQ_1 + (interrupt - 1), 24 + interrupt);
                         cputag_set_input_line(machine, "maincpu", M68K_IRQ_1 + (interrupt - 1), ASSERT_LINE);
                     }
                 }
@@ -732,7 +732,7 @@ static void mcd212_process_dca(mcd212_regs_t *mcd212, int channel)
                 break;
             case 0x78: case 0x79: case 0x7a: case 0x7b: case 0x7c: case 0x7d: case 0x7e: case 0x7f: // RELOAD DISPLAY PARAMETERS
                 verboselog(machine, 6, "%08x: %08x: DCA %d: RELOAD DISPLAY PARAMETERS\n", addr * 2 + channel * 0x200000, cmd, channel );
-                mcd212_set_display_parameters(&state->mcd212_regs, channel, cmd & 0x1f);
+                mcd212_set_display_parameters(&state->m_mcd212_regs, channel, cmd & 0x1f);
                 break;
             default:
                 mcd212_set_register(machine, channel, cmd >> 24, cmd & 0x00ffffff);
@@ -804,9 +804,9 @@ INLINE UINT8 BYTE_TO_CLUT(int channel, int icm, UINT8 byte)
 
 static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels_r, UINT8 *pixels_g, UINT8 *pixels_b)
 {
-    running_machine *machine = mcd212->machine;
-    cdi_state *state = machine->driver_data<cdi_state>();
-    UINT8 *data = channel ? (UINT8*)state->planeb : (UINT8*)state->planea;
+    running_machine &machine = mcd212->machine();
+    cdi_state *state = machine.driver_data<cdi_state>();
+    UINT8 *data = channel ? (UINT8*)state->m_planeb : (UINT8*)state->m_planea;
     UINT32 vsr = mcd212_get_vsr(mcd212, channel) & 0x0007ffff;
     UINT8 done = 0;
     UINT32 x = 0;
@@ -873,12 +873,12 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
                         for(; x < width; x += 2)
                         {
                             BYTE68K b0 = byte;
-                            BYTE68K bU1 = bU + state->mcd212_ab.deltaUV[b0];
-                            BYTE68K bY0 = bY + state->mcd212_ab.deltaY[b0];
+                            BYTE68K bU1 = bU + state->m_mcd212_ab.deltaUV[b0];
+                            BYTE68K bY0 = bY + state->m_mcd212_ab.deltaY[b0];
 
                             BYTE68K b1 = data[(vsr & 0x0007ffff) ^ 1];
-                            BYTE68K bV1 = bV + state->mcd212_ab.deltaUV[b1];
-                            BYTE68K bY1 = bY0 + state->mcd212_ab.deltaY[b1];
+                            BYTE68K bV1 = bV + state->m_mcd212_ab.deltaUV[b1];
+                            BYTE68K bY1 = bY0 + state->m_mcd212_ab.deltaY[b1];
 
                             BYTE68K bU0 = (bU + bU1) >> 1;
                             BYTE68K bV0 = (bV + bV1) >> 1;
@@ -891,11 +891,11 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
                             bU = bU0;
                             bV = bV0;
 
-                            pbLimit = state->mcd212_ab.limit + bY + BYTE68K_MAX;
+                            pbLimit = state->m_mcd212_ab.limit + bY + BYTE68K_MAX;
 
-                            pixels_r[x + 0] = pixels_r[x + 1] = pbLimit[state->mcd212_ab.matrixVR[bV]];
-                            pixels_g[x + 0] = pixels_g[x + 1] = pbLimit[state->mcd212_ab.matrixUG[bU] + state->mcd212_ab.matrixVG[bV]];
-                            pixels_b[x + 0] = pixels_b[x + 1] = pbLimit[state->mcd212_ab.matrixUB[bU]];
+                            pixels_r[x + 0] = pixels_r[x + 1] = pbLimit[state->m_mcd212_ab.matrixVR[bV]];
+                            pixels_g[x + 0] = pixels_g[x + 1] = pbLimit[state->m_mcd212_ab.matrixUG[bU] + state->m_mcd212_ab.matrixVG[bV]];
+                            pixels_b[x + 0] = pixels_b[x + 1] = pbLimit[state->m_mcd212_ab.matrixUB[bU]];
 
                             if(mosaic_enable)
                             {
@@ -919,11 +919,11 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
                             bU = bU1;
                             bV = bV1;
 
-                            pbLimit = state->mcd212_ab.limit + bY + BYTE68K_MAX;
+                            pbLimit = state->m_mcd212_ab.limit + bY + BYTE68K_MAX;
 
-                            pixels_r[x + 0] = pixels_r[x + 1] = pbLimit[state->mcd212_ab.matrixVR[bV]];
-                            pixels_g[x + 0] = pixels_g[x + 1] = pbLimit[state->mcd212_ab.matrixUG[bU] + state->mcd212_ab.matrixVG[bV]];
-                            pixels_b[x + 0] = pixels_b[x + 1] = pbLimit[state->mcd212_ab.matrixUB[bU]];
+                            pixels_r[x + 0] = pixels_r[x + 1] = pbLimit[state->m_mcd212_ab.matrixVR[bV]];
+                            pixels_g[x + 0] = pixels_g[x + 1] = pbLimit[state->m_mcd212_ab.matrixUG[bU] + state->m_mcd212_ab.matrixVG[bV]];
+                            pixels_b[x + 0] = pixels_b[x + 1] = pbLimit[state->m_mcd212_ab.matrixUB[bU]];
 
                             if(mosaic_enable)
                             {
@@ -943,7 +943,7 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
 
                             vsr++;
                         }
-                        mcd212_set_vsr(&state->mcd212_regs, channel, (vsr - 1) & 0x0007ffff);
+                        mcd212_set_vsr(&state->m_mcd212_regs, channel, (vsr - 1) & 0x0007ffff);
                     }
                     else if(icm == 1 || icm == 3 || icm == 4)
                     {
@@ -972,7 +972,7 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
                             byte = data[(vsr & 0x0007ffff) ^ 1];
                             vsr++;
                         }
-                        mcd212_set_vsr(&state->mcd212_regs, channel, (vsr - 1) & 0x0007ffff);
+                        mcd212_set_vsr(&state->m_mcd212_regs, channel, (vsr - 1) & 0x0007ffff);
                     }
                     else if(icm == 11)
                     {
@@ -1008,7 +1008,7 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
                             byte = data[(vsr & 0x0007ffff) ^ 1];
                             vsr++;
                         }
-                        mcd212_set_vsr(&state->mcd212_regs, channel, (vsr - 1) & 0x0007ffff);
+                        mcd212_set_vsr(&state->m_mcd212_regs, channel, (vsr - 1) & 0x0007ffff);
                     }
                     else
                     {
@@ -1052,7 +1052,7 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
                                 pixels_b[x] = b;
                             }
                             done = 1;
-                            mcd212_set_vsr(&state->mcd212_regs, channel, vsr);
+                            mcd212_set_vsr(&state->m_mcd212_regs, channel, vsr);
                         }
                         else
                         {
@@ -1074,7 +1074,7 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
                             if(x >= width)
                             {
                                 done = 1;
-                                mcd212_set_vsr(&state->mcd212_regs, channel, vsr);
+                                mcd212_set_vsr(&state->m_mcd212_regs, channel, vsr);
                             }
                         }
                     }
@@ -1093,7 +1093,7 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
                         if(x >= width)
                         {
                             done = 1;
-                            mcd212_set_vsr(&state->mcd212_regs, channel, vsr);
+                            mcd212_set_vsr(&state->m_mcd212_regs, channel, vsr);
                         }
                     }
                 }
@@ -1102,7 +1102,7 @@ static void mcd212_process_vsr(mcd212_regs_t *mcd212, int channel, UINT8 *pixels
     }
 
     //printf( ": vsr after: %08x\n", vsr);
-    //mcd212_set_vsr(&state->mcd212_regs, channel, vsr);
+    //mcd212_set_vsr(&state->m_mcd212_regs, channel, vsr);
 }
 
 static const UINT32 mcd212_4bpp_color[16] =
@@ -1113,7 +1113,7 @@ static const UINT32 mcd212_4bpp_color[16] =
 
 static void mcd212_mix_lines(mcd212_regs_t *mcd212, UINT8 *plane_a_r, UINT8 *plane_a_g, UINT8 *plane_a_b, UINT8 *plane_b_r, UINT8 *plane_b_g, UINT8 *plane_b_b, UINT32 *out)
 {
-    running_machine *machine = mcd212->machine;
+    running_machine &machine = mcd212->machine();
     int x = 0;
     UINT8 debug_mode = input_port_read(machine, "DEBUG");
     UINT8 global_plane_a_disable = debug_mode & 1;
@@ -1331,12 +1331,11 @@ static void mcd212_draw_cursor(mcd212_regs_t *mcd212, UINT32 *scanline, int y)
 
 static void mcd212_draw_scanline(mcd212_regs_t *mcd212, int y)
 {
-    running_machine *machine = mcd212->machine;
-    bitmap_t *bitmap = machine->generic.tmpbitmap;
+    bitmap_rgb32 &bitmap = mcd212->m_bitmap;
     UINT8 plane_a_r[768], plane_a_g[768], plane_a_b[768];
     UINT8 plane_b_r[768], plane_b_g[768], plane_b_b[768];
     UINT32 out[768];
-    UINT32 *scanline = BITMAP_ADDR32(bitmap, y, 0);
+    UINT32 *scanline = &bitmap.pix32(y);
     int x;
 
     mcd212_process_vsr(mcd212, 0, plane_a_r, plane_a_g, plane_a_b);
@@ -1354,8 +1353,8 @@ static void mcd212_draw_scanline(mcd212_regs_t *mcd212, int y)
 
 READ16_HANDLER( mcd212_r )
 {
-    cdi_state *state = space->machine->driver_data<cdi_state>();
-    mcd212_regs_t *mcd212 = &state->mcd212_regs;
+    cdi_state *state = space->machine().driver_data<cdi_state>();
+    mcd212_regs_t *mcd212 = &state->m_mcd212_regs;
     UINT8 channel = 1 - (offset / 8);
 
     switch(offset)
@@ -1364,7 +1363,7 @@ READ16_HANDLER( mcd212_r )
         case 0x10/2:
             if(ACCESSING_BITS_0_7)
             {
-                verboselog(space->machine, 12, "mcd212_r: Status Register %d: %02x & %04x\n", channel + 1, mcd212->channel[1 - (offset / 8)].csrr, mem_mask);
+                verboselog(space->machine(), 12, "mcd212_r: Status Register %d: %02x & %04x\n", channel + 1, mcd212->channel[1 - (offset / 8)].csrr, mem_mask);
                 if(channel == 0)
                 {
                     return mcd212->channel[0].csrr;
@@ -1372,43 +1371,43 @@ READ16_HANDLER( mcd212_r )
                 else
                 {
                     UINT8 old_csr = mcd212->channel[1].csrr;
-                    UINT8 interrupt1 = (state->scc68070_regs.lir >> 4) & 7;
-                    //UINT8 interrupt2 = state->scc68070_regs.lir & 7;
+                    UINT8 interrupt1 = (state->m_scc68070_regs.lir >> 4) & 7;
+                    //UINT8 interrupt2 = state->m_scc68070_regs.lir & 7;
                     mcd212->channel[1].csrr &= ~(MCD212_CSR2R_IT1 | MCD212_CSR2R_IT2);
                     if(interrupt1)
                     {
-                        cputag_set_input_line(space->machine, "maincpu", M68K_IRQ_1 + (interrupt1 - 1), CLEAR_LINE);
+                        cputag_set_input_line(space->machine(), "maincpu", M68K_IRQ_1 + (interrupt1 - 1), CLEAR_LINE);
                     }
                     //if(interrupt2)
                     //{
-                    //  cputag_set_input_line(space->machine, "maincpu", M68K_IRQ_1 + (interrupt2 - 1), CLEAR_LINE);
+                    //  cputag_set_input_line(space->machine(), "maincpu", M68K_IRQ_1 + (interrupt2 - 1), CLEAR_LINE);
                     //}
                     return old_csr;
                 }
             }
             else
             {
-                verboselog(space->machine, 2, "mcd212_r: Unknown Register %d: %04x\n", channel + 1, mem_mask);
+                verboselog(space->machine(), 2, "mcd212_r: Unknown Register %d: %04x\n", channel + 1, mem_mask);
             }
             break;
         case 0x02/2:
         case 0x12/2:
-            verboselog(space->machine, 2, "mcd212_r: Display Command Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, mcd212->channel[1 - (offset / 8)].dcr, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_r: Display Command Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, mcd212->channel[1 - (offset / 8)].dcr, mem_mask);
             return mcd212->channel[1 - (offset / 8)].dcr;
         case 0x04/2:
         case 0x14/2:
-            verboselog(space->machine, 2, "mcd212_r: Video Start Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, mcd212->channel[1 - (offset / 8)].vsr, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_r: Video Start Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, mcd212->channel[1 - (offset / 8)].vsr, mem_mask);
             return mcd212->channel[1 - (offset / 8)].vsr;
         case 0x08/2:
         case 0x18/2:
-            verboselog(space->machine, 2, "mcd212_r: Display Decoder Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, mcd212->channel[1 - (offset / 8)].ddr, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_r: Display Decoder Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, mcd212->channel[1 - (offset / 8)].ddr, mem_mask);
             return mcd212->channel[1 - (offset / 8)].ddr;
         case 0x0a/2:
         case 0x1a/2:
-            verboselog(space->machine, 2, "mcd212_r: DCA Pointer Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, mcd212->channel[1 - (offset / 8)].dcp, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_r: DCA Pointer Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, mcd212->channel[1 - (offset / 8)].dcp, mem_mask);
             return mcd212->channel[1 - (offset / 8)].dcp;
         default:
-            verboselog(space->machine, 2, "mcd212_r: Unknown Register %d & %04x\n", (1 - (offset / 8)) + 1, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_r: Unknown Register %d & %04x\n", (1 - (offset / 8)) + 1, mem_mask);
             break;
     }
 
@@ -1417,49 +1416,49 @@ READ16_HANDLER( mcd212_r )
 
 WRITE16_HANDLER( mcd212_w )
 {
-    cdi_state *state = space->machine->driver_data<cdi_state>();
-    mcd212_regs_t *mcd212 = &state->mcd212_regs;
+    cdi_state *state = space->machine().driver_data<cdi_state>();
+    mcd212_regs_t *mcd212 = &state->m_mcd212_regs;
 
     switch(offset)
     {
         case 0x00/2:
         case 0x10/2:
-            verboselog(space->machine, 2, "mcd212_w: Status Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_w: Status Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
             COMBINE_DATA(&mcd212->channel[1 - (offset / 8)].csrw);
-            mcd212_update_visible_area(space->machine);
+            mcd212_update_visible_area(space->machine());
             break;
         case 0x02/2:
         case 0x12/2:
-            verboselog(space->machine, 2, "mcd212_w: Display Command Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_w: Display Command Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
             COMBINE_DATA(&mcd212->channel[1 - (offset / 8)].dcr);
-            mcd212_update_visible_area(space->machine);
+            mcd212_update_visible_area(space->machine());
             break;
         case 0x04/2:
         case 0x14/2:
-            verboselog(space->machine, 2, "mcd212_w: Video Start Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_w: Video Start Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
             COMBINE_DATA(&mcd212->channel[1 - (offset / 8)].vsr);
             break;
         case 0x08/2:
         case 0x18/2:
-            verboselog(space->machine, 2, "mcd212_w: Display Decoder Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_w: Display Decoder Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
             COMBINE_DATA(&mcd212->channel[1 - (offset / 8)].ddr);
             break;
         case 0x0a/2:
         case 0x1a/2:
-            verboselog(space->machine, 2, "mcd212_w: DCA Pointer Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_w: DCA Pointer Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
             COMBINE_DATA(&mcd212->channel[1 - (offset / 8)].dcp);
             break;
         default:
-            verboselog(space->machine, 2, "mcd212_w: Unknown Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
+            verboselog(space->machine(), 2, "mcd212_w: Unknown Register %d: %04x & %04x\n", (1 - (offset / 8)) + 1, data, mem_mask);
             break;
     }
 }
 
 TIMER_CALLBACK( mcd212_perform_scan )
 {
-    cdi_state *state = machine->driver_data<cdi_state>();
-    mcd212_regs_t *mcd212 = &state->mcd212_regs;
-    int scanline = machine->primary_screen->vpos();
+    cdi_state *state = machine.driver_data<cdi_state>();
+    mcd212_regs_t *mcd212 = &state->m_mcd212_regs;
+    int scanline = machine.primary_screen->vpos();
 
     if(/*mcd212->channel[0].dcr & MCD212_DCR_DE*/1)
     {
@@ -1506,12 +1505,13 @@ TIMER_CALLBACK( mcd212_perform_scan )
             }
         }
     }
-    timer_adjust_oneshot(mcd212->scan_timer, machine->primary_screen->time_until_pos(( scanline + 1 ) % 302, 0), 0);
+    mcd212->scan_timer->adjust(machine.primary_screen->time_until_pos(( scanline + 1 ) % 302, 0));
 }
 
-void mcd212_init(running_machine *machine, mcd212_regs_t *mcd212)
+void mcd212_init(running_machine &machine, mcd212_regs_t *mcd212)
 {
-    mcd212->machine = machine;
+    mcd212->m_machine = &machine;
+    machine.primary_screen->register_screen_bitmap(mcd212->m_bitmap);
 
     int index = 0;
     for(index = 0; index < 2; index++)
@@ -1523,9 +1523,9 @@ void mcd212_init(running_machine *machine, mcd212_regs_t *mcd212)
         mcd212->channel[index].ddr = 0;
         mcd212->channel[index].dcp = 0;
         mcd212->channel[index].dca = 0;
-        memset(mcd212->channel[index].clut_r, 0, 768);
-        memset(mcd212->channel[index].clut_g, 0, 768);
-        memset(mcd212->channel[index].clut_b, 0, 768);
+        memset(mcd212->channel[index].clut_r, 0, 256);
+        memset(mcd212->channel[index].clut_g, 0, 256);
+        memset(mcd212->channel[index].clut_b, 0, 256);
         mcd212->channel[index].image_coding_method = 0;
         mcd212->channel[index].transparency_control = 0;
         mcd212->channel[index].plane_order = 0;
@@ -1650,31 +1650,27 @@ void mcd212_ab_init(mcd212_ab_t *mcd212_ab)
 
 VIDEO_START( cdimono1 )
 {
-    cdi_state *state = machine->driver_data<cdi_state>();
+    cdi_state *state = machine.driver_data<cdi_state>();
 
-    VIDEO_START_CALL(generic_bitmapped);
-    mcd212_ab_init(&state->mcd212_ab);
-    mcd212_init(machine, &state->mcd212_regs);
-    state->mcd212_regs.scan_timer = timer_alloc(machine, mcd212_perform_scan, 0);
-    timer_adjust_oneshot(state->mcd212_regs.scan_timer, machine->primary_screen->time_until_pos(0, 0), 0);
+    mcd212_ab_init(&state->m_mcd212_ab);
+    mcd212_init(machine, &state->m_mcd212_regs);
+    state->m_mcd212_regs.scan_timer = machine.scheduler().timer_alloc(FUNC(mcd212_perform_scan));
+    state->m_mcd212_regs.scan_timer->adjust(machine.primary_screen->time_until_pos(0, 0));
 
-    state->lcdbitmap = downcast<screen_device *>(machine->device("lcd"))->alloc_compatible_bitmap();
+	screen_device *screen = downcast<screen_device *>(machine.device("lcd"));
+    screen->register_screen_bitmap(state->m_lcdbitmap);
 }
 
-VIDEO_UPDATE( cdimono1 )
+SCREEN_UPDATE_RGB32( cdimono1 )
 {
-    cdi_state *state = screen->machine->driver_data<cdi_state>();
-    device_t *main_screen = screen->machine->device("screen");
-    device_t *lcd_screen = screen->machine->device("lcd");
+    cdi_state *state = screen.machine().driver_data<cdi_state>();
+    copybitmap(bitmap, state->m_mcd212_regs.m_bitmap, 0, 0, 0, 0, cliprect);
+    return 0;
+}
 
-    if (screen == main_screen)
-    {
-        copybitmap(bitmap, screen->machine->generic.tmpbitmap, 0, 0, 0, 0, cliprect);
-    }
-    else if (screen == lcd_screen)
-    {
-        copybitmap(bitmap, state->lcdbitmap, 0, 0, 0, 0, cliprect);
-    }
-
+SCREEN_UPDATE_RGB32( cdimono1_lcd )
+{
+    cdi_state *state = screen.machine().driver_data<cdi_state>();
+    copybitmap(bitmap, state->m_lcdbitmap, 0, 0, 0, 0, cliprect);
     return 0;
 }
