@@ -20,7 +20,7 @@ PALETTE_INIT( mouser )
 {
 	int i;
 
-	for (i = 0; i < machine->total_colors(); i++)
+	for (i = 0; i < machine.total_colors(); i++)
 	{
 		int bit0, bit1, bit2, r, g, b;
 
@@ -46,18 +46,18 @@ PALETTE_INIT( mouser )
 
 WRITE8_HANDLER( mouser_flip_screen_x_w )
 {
-	flip_screen_x_set(space->machine, ~data & 1);
+	flip_screen_x_set(space->machine(), ~data & 1);
 }
 
 WRITE8_HANDLER( mouser_flip_screen_y_w )
 {
-	flip_screen_y_set(space->machine, ~data & 1);
+	flip_screen_y_set(space->machine(), ~data & 1);
 }
 
-VIDEO_UPDATE( mouser )
+SCREEN_UPDATE_IND16( mouser )
 {
-	mouser_state *state = screen->machine->driver_data<mouser_state>();
-	UINT8 *spriteram = state->spriteram;
+	mouser_state *state = screen.machine().driver_data<mouser_state>();
+	UINT8 *spriteram = state->m_spriteram;
 	int offs;
 	int sx, sy;
 	int flipx, flipy;
@@ -71,12 +71,12 @@ VIDEO_UPDATE( mouser )
 		sx = offs % 32;
 		sy = offs / 32;
 
-		if (flip_screen_x_get(screen->machine))
+		if (flip_screen_x_get(screen.machine()))
 		{
 			sx = 31 - sx;
 		}
 
-		if (flip_screen_y_get(screen->machine))
+		if (flip_screen_y_get(screen.machine()))
 		{
 			sy = 31 - sy;
 		}
@@ -90,10 +90,10 @@ VIDEO_UPDATE( mouser )
 		/* Note: this is _not_ dependant on flipping */
 		color_offs = offs % 32 + ((256 + 8 * (offs / 32) - spriteram[offs % 32] )% 256) / 8 * 32;
 
-		drawgfx_opaque(bitmap,cliprect,screen->machine->gfx[0],
-				state->videoram[offs] | (state->colorram[color_offs] >> 5) * 256 | ((state->colorram[color_offs] >> 4) & 1) * 512,
-				state->colorram[color_offs]%16,
-				flip_screen_x_get(screen->machine),flip_screen_y_get(screen->machine),
+		drawgfx_opaque(bitmap,cliprect,screen.machine().gfx[0],
+				state->m_videoram[offs] | (state->m_colorram[color_offs] >> 5) * 256 | ((state->m_colorram[color_offs] >> 4) & 1) * 512,
+				state->m_colorram[color_offs]%16,
+				flip_screen_x_get(screen.machine()),flip_screen_y_get(screen.machine()),
 				8*sx,scrolled_y_position);
 	}
 
@@ -108,20 +108,20 @@ VIDEO_UPDATE( mouser )
 		flipx = BIT(spriteram[offs], 6);
 		flipy = BIT(spriteram[offs], 7);
 
-		if (flip_screen_x_get(screen->machine))
+		if (flip_screen_x_get(screen.machine()))
 		{
 			flipx = !flipx;
 			sx = 240 - sx;
 		}
 
-		if (flip_screen_y_get(screen->machine))
+		if (flip_screen_y_get(screen.machine()))
 		{
 			flipy = !flipy;
 			sy = 238 - sy;
 		}
 
 		if (BIT(spriteram[offs + 1], 4))
-			drawgfx_transpen(bitmap,cliprect,screen->machine->gfx[1+((spriteram[offs+1]&0x20)>>5)],
+			drawgfx_transpen(bitmap,cliprect,screen.machine().gfx[1+((spriteram[offs+1]&0x20)>>5)],
 					spriteram[offs]&0x3f,
 					spriteram[offs+1]%16,
 					flipx,flipy,
@@ -137,20 +137,20 @@ VIDEO_UPDATE( mouser )
 		flipx = BIT(spriteram[offs], 6);
 		flipy = BIT(spriteram[offs], 7);
 
-		if (flip_screen_x_get(screen->machine))
+		if (flip_screen_x_get(screen.machine()))
 		{
 			flipx = !flipx;
 			sx = 240 - sx;
 		}
 
-		if (flip_screen_y_get(screen->machine))
+		if (flip_screen_y_get(screen.machine()))
 		{
 			flipy = !flipy;
 			sy = 238 - sy;
 		}
 
 		if (BIT(spriteram[offs + 1], 4))
-			drawgfx_transpen(bitmap,cliprect,screen->machine->gfx[1+((spriteram[offs+1]&0x20)>>5)],
+			drawgfx_transpen(bitmap,cliprect,screen.machine().gfx[1+((spriteram[offs+1]&0x20)>>5)],
 					spriteram[offs]&0x3f,
 					spriteram[offs+1]%16,
 					flipx,flipy,
