@@ -69,8 +69,6 @@ static TILE_GET_INFO( get_ms32_extra_tile_info )
 VIDEO_START( ms32 )
 {
 	ms32_state *state = machine.driver_data<ms32_state>();
-	int width = machine.primary_screen->width();
-	int height = machine.primary_screen->height();
 
 	state->m_priram_8   = auto_alloc_array_clear(machine, UINT8, 0x2000);
 	state->m_palram_16  = auto_alloc_array_clear(machine, UINT16, 0x20000);
@@ -87,18 +85,18 @@ VIDEO_START( ms32 )
 
 
 	/* set up tile layers */
-	state->m_temp_bitmap_tilemaps = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_INDEXED16);
-	state->m_temp_bitmap_sprites  = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_INDEXED16);
-	state->m_temp_bitmap_sprites_pri = auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_INDEXED16); // not actually being used for rendering, we embed pri info in the raw colour bitmap
+	machine.primary_screen->register_screen_bitmap(state->m_temp_bitmap_tilemaps);
+	machine.primary_screen->register_screen_bitmap(state->m_temp_bitmap_sprites);
+	machine.primary_screen->register_screen_bitmap(state->m_temp_bitmap_sprites_pri); // not actually being used for rendering, we embed pri info in the raw colour bitmap
 
-	bitmap_fill(state->m_temp_bitmap_tilemaps,0,0);
-	bitmap_fill(state->m_temp_bitmap_sprites,0,0);
-	bitmap_fill(state->m_temp_bitmap_sprites_pri,0,0);
+	state->m_temp_bitmap_tilemaps.fill(0);
+	state->m_temp_bitmap_sprites.fill(0);
+	state->m_temp_bitmap_sprites_pri.fill(0);
 
-	tilemap_set_transparent_pen(state->m_tx_tilemap,0);
-	tilemap_set_transparent_pen(state->m_bg_tilemap,0);
-	tilemap_set_transparent_pen(state->m_bg_tilemap_alt,0);
-	tilemap_set_transparent_pen(state->m_roz_tilemap,0);
+	state->m_tx_tilemap->set_transparent_pen(0);
+	state->m_bg_tilemap->set_transparent_pen(0);
+	state->m_bg_tilemap_alt->set_transparent_pen(0);
+	state->m_roz_tilemap->set_transparent_pen(0);
 
 	state->m_reverse_sprite_order = 1;
 
@@ -190,9 +188,9 @@ WRITE32_HANDLER( ms32_gfxctrl_w )
 	{
 		/* bit 1 = flip screen */
 		state->m_flipscreen = data & 0x02;
-		tilemap_set_flip(state->m_tx_tilemap,state->m_flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
-		tilemap_set_flip(state->m_bg_tilemap,state->m_flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
-		tilemap_set_flip(state->m_bg_tilemap_alt,state->m_flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
+		state->m_tx_tilemap->set_flip(state->m_flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
+		state->m_bg_tilemap->set_flip(state->m_flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
+		state->m_bg_tilemap_alt->set_flip(state->m_flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
 
 		/* bit 2 used by f1superb, unknown */
 
@@ -205,7 +203,7 @@ WRITE32_HANDLER( ms32_gfxctrl_w )
 
 
 /* SPRITES based on tetrisp2 for now, readd priority bits later */
-static void draw_sprites(running_machine &machine, bitmap_t *bitmap, bitmap_t *bitmap_pri, const rectangle *cliprect, UINT16 *sprram_top, size_t sprram_size, int gfxnum, int reverseorder)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, bitmap_ind8 &bitmap_pri, const rectangle &cliprect, UINT16 *sprram_top, size_t sprram_size, int gfxnum, int reverseorder)
 {
 	int tx, ty, sx, sy, flipx, flipy;
 	int xsize, ysize;
@@ -275,7 +273,7 @@ static void draw_sprites(running_machine &machine, bitmap_t *bitmap, bitmap_t *b
 }
 
 
-static void draw_roz(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect,int priority)
+static void draw_roz(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect,int priority)
 {
 	ms32_state *state = machine.driver_data<ms32_state>();
 	/* TODO: registers 0x40/4 / 0x44/4 and 0x50/4 / 0x54/4 are used, meaning unknown */
@@ -285,11 +283,11 @@ static void draw_roz(running_machine &machine, bitmap_t *bitmap, const rectangle
 		rectangle my_clip;
 		int y,maxy;
 
-		my_clip.min_x = cliprect->min_x;
-		my_clip.max_x = cliprect->max_x;
+		my_clip.min_x = cliprect.min_x;
+		my_clip.max_x = cliprect.max_x;
 
-		y = cliprect->min_y;
-		maxy = cliprect->max_y;
+		y = cliprect.min_y;
+		maxy = cliprect.max_y;
 
 		while (y <= maxy)
 		{
@@ -317,7 +315,7 @@ static void draw_roz(running_machine &machine, bitmap_t *bitmap, const rectangle
 			if (incxx & 0x10000) incxx |= ~0x1ffff;
 			if (incxy & 0x10000) incxy |= ~0x1ffff;
 
-			tilemap_draw_roz(bitmap, &my_clip, state->m_roz_tilemap,
+			state->m_roz_tilemap->draw_roz(bitmap, my_clip,
 					(start2x+startx+offsx)<<16, (start2y+starty+offsy)<<16,
 					incxx<<8, incxy<<8, 0, 0,
 					1, // Wrap
@@ -348,7 +346,7 @@ static void draw_roz(running_machine &machine, bitmap_t *bitmap, const rectangle
 		if (incyy & 0x10000) incyy |= ~0x1ffff;
 		if (incyx & 0x10000) incyx |= ~0x1ffff;
 
-		tilemap_draw_roz(bitmap, cliprect, state->m_roz_tilemap,
+		state->m_roz_tilemap->draw_roz(bitmap, cliprect,
 				(startx+offsx)<<16, (starty+offsy)<<16,
 				incxx<<8, incxy<<8, incyx<<8, incyy<<8,
 				1, // Wrap
@@ -358,9 +356,9 @@ static void draw_roz(running_machine &machine, bitmap_t *bitmap, const rectangle
 
 
 
-SCREEN_UPDATE( ms32 )
+SCREEN_UPDATE_RGB32( ms32 )
 {
-	ms32_state *state = screen->machine().driver_data<ms32_state>();
+	ms32_state *state = screen.machine().driver_data<ms32_state>();
 	int scrollx,scrolly;
 	int asc_pri;
 	int scr_pri;
@@ -377,34 +375,34 @@ SCREEN_UPDATE( ms32 )
 	int i;
 
 	for (i = 0;i < 0x10000;i++)	// colors 0x3000-0x3fff are not used
-		update_color(screen->machine(), i);
+		update_color(screen.machine(), i);
 
 	scrollx = state->m_tx_scroll[0x00/4] + state->m_tx_scroll[0x08/4] + 0x18;
 	scrolly = state->m_tx_scroll[0x0c/4] + state->m_tx_scroll[0x14/4];
-	tilemap_set_scrollx(state->m_tx_tilemap, 0, scrollx);
-	tilemap_set_scrolly(state->m_tx_tilemap, 0, scrolly);
+	state->m_tx_tilemap->set_scrollx(0, scrollx);
+	state->m_tx_tilemap->set_scrolly(0, scrolly);
 
 	scrollx = state->m_bg_scroll[0x00/4] + state->m_bg_scroll[0x08/4] + 0x10;
 	scrolly = state->m_bg_scroll[0x0c/4] + state->m_bg_scroll[0x14/4];
-	tilemap_set_scrollx(state->m_bg_tilemap, 0, scrollx);
-	tilemap_set_scrolly(state->m_bg_tilemap, 0, scrolly);
-	tilemap_set_scrollx(state->m_bg_tilemap_alt, 0, scrollx);
-	tilemap_set_scrolly(state->m_bg_tilemap_alt, 0, scrolly);
+	state->m_bg_tilemap->set_scrollx(0, scrollx);
+	state->m_bg_tilemap->set_scrolly(0, scrolly);
+	state->m_bg_tilemap_alt->set_scrollx(0, scrollx);
+	state->m_bg_tilemap_alt->set_scrolly(0, scrolly);
 
 
-	bitmap_fill(screen->machine().priority_bitmap,cliprect,0);
+	screen.machine().priority_bitmap.fill(0, cliprect);
 
 
 
 	/* TODO: 0 is correct for gametngk, but break f1superb scrolling grid (text at
        top and bottom of the screen becomes black on black) */
-	bitmap_fill(state->m_temp_bitmap_tilemaps,cliprect,0);	/* bg color */
+	state->m_temp_bitmap_tilemaps.fill(0, cliprect);	/* bg color */
 
 	/* clear our sprite bitmaps */
-	bitmap_fill(state->m_temp_bitmap_sprites,cliprect,0);
-	bitmap_fill(state->m_temp_bitmap_sprites_pri,cliprect,0);
+	state->m_temp_bitmap_sprites.fill(0, cliprect);
+	state->m_temp_bitmap_sprites_pri.fill(0, cliprect);
 
-	draw_sprites(screen->machine(), state->m_temp_bitmap_sprites, state->m_temp_bitmap_sprites_pri, cliprect, state->m_sprram_16, 0x20000, 0, state->m_reverse_sprite_order);
+	draw_sprites(screen.machine(), state->m_temp_bitmap_sprites, state->m_temp_bitmap_sprites_pri, cliprect, state->m_sprram_16, 0x20000, 0, state->m_reverse_sprite_order);
 
 
 
@@ -427,46 +425,46 @@ SCREEN_UPDATE( ms32 )
 		rot_pri++;
 
 	if (rot_pri == 0)
-		draw_roz(screen->machine(), state->m_temp_bitmap_tilemaps, cliprect, 1 << 1);
+		draw_roz(screen.machine(), state->m_temp_bitmap_tilemaps, cliprect, 1 << 1);
 	else if (scr_pri == 0)
 		if (state->m_tilemaplayoutcontrol&1)
 		{
-			tilemap_draw(state->m_temp_bitmap_tilemaps,cliprect, state->m_bg_tilemap_alt,  0, 1 << 0);
+			state->m_bg_tilemap_alt->draw(state->m_temp_bitmap_tilemaps, cliprect, 0, 1 << 0);
 		}
 		else
 		{
-			tilemap_draw(state->m_temp_bitmap_tilemaps,cliprect, state->m_bg_tilemap,  0, 1 << 0);
+			state->m_bg_tilemap->draw(state->m_temp_bitmap_tilemaps, cliprect, 0, 1 << 0);
 		}
 	else if (asc_pri == 0)
-		tilemap_draw(state->m_temp_bitmap_tilemaps,cliprect, state->m_tx_tilemap,  0, 1 << 2);
+		state->m_tx_tilemap->draw(state->m_temp_bitmap_tilemaps, cliprect, 0, 1 << 2);
 
 	if (rot_pri == 1)
-		draw_roz(screen->machine(), state->m_temp_bitmap_tilemaps, cliprect, 1 << 1);
+		draw_roz(screen.machine(), state->m_temp_bitmap_tilemaps, cliprect, 1 << 1);
 	else if (scr_pri == 1)
 		if (state->m_tilemaplayoutcontrol&1)
 		{
-			tilemap_draw(state->m_temp_bitmap_tilemaps,cliprect, state->m_bg_tilemap_alt,  0, 1 << 0);
+			state->m_bg_tilemap_alt->draw(state->m_temp_bitmap_tilemaps, cliprect, 0, 1 << 0);
 		}
 		else
 		{
-			tilemap_draw(state->m_temp_bitmap_tilemaps,cliprect, state->m_bg_tilemap,  0, 1 << 0);
+			state->m_bg_tilemap->draw(state->m_temp_bitmap_tilemaps, cliprect, 0, 1 << 0);
 		}
 	else if (asc_pri == 1)
-		tilemap_draw(state->m_temp_bitmap_tilemaps,cliprect, state->m_tx_tilemap,  0, 1 << 2);
+		state->m_tx_tilemap->draw(state->m_temp_bitmap_tilemaps, cliprect, 0, 1 << 2);
 
 	if (rot_pri == 2)
-		draw_roz(screen->machine(), state->m_temp_bitmap_tilemaps, cliprect, 1 << 1);
+		draw_roz(screen.machine(), state->m_temp_bitmap_tilemaps, cliprect, 1 << 1);
 	else if (scr_pri == 2)
 		if (state->m_tilemaplayoutcontrol&1)
 		{
-			tilemap_draw(state->m_temp_bitmap_tilemaps,cliprect, state->m_bg_tilemap_alt,  0, 1 << 0);
+			state->m_bg_tilemap_alt->draw(state->m_temp_bitmap_tilemaps, cliprect, 0, 1 << 0);
 		}
 		else
 		{
-			tilemap_draw(state->m_temp_bitmap_tilemaps,cliprect, state->m_bg_tilemap,  0, 1 << 0);
+			state->m_bg_tilemap->draw(state->m_temp_bitmap_tilemaps, cliprect, 0, 1 << 0);
 		}
 	else if (asc_pri == 2)
-		tilemap_draw(state->m_temp_bitmap_tilemaps,cliprect, state->m_tx_tilemap,  0, 1 << 2);
+		state->m_tx_tilemap->draw(state->m_temp_bitmap_tilemaps, cliprect, 0, 1 << 2);
 
 	/* MIX it! */
 	/* this mixing isn't 100% accurate, it should be using ALL the data in
@@ -474,9 +472,9 @@ SCREEN_UPDATE( ms32 )
        than are supported here..  I don't know, it will need hw tests I think */
 	{
 		int xx, yy;
-		int width = screen->width();
-		int height = screen->height();
-		const pen_t *paldata = screen->machine().pens;
+		int width = screen.width();
+		int height = screen.height();
+		const pen_t *paldata = screen.machine().pens;
 
 		UINT16* srcptr_tile;
 		UINT8* srcptr_tilepri;
@@ -485,15 +483,15 @@ SCREEN_UPDATE( ms32 )
 
 		UINT32* dstptr_bitmap;
 
-		bitmap_fill(bitmap,cliprect,0);
+		bitmap.fill(0, cliprect);
 
 		for (yy=0;yy<height;yy++)
 		{
-			srcptr_tile =     BITMAP_ADDR16(state->m_temp_bitmap_tilemaps, yy, 0);
-			srcptr_tilepri =  BITMAP_ADDR8(screen->machine().priority_bitmap, yy, 0);
-			srcptr_spri =     BITMAP_ADDR16(state->m_temp_bitmap_sprites, yy, 0);
-			//srcptr_spripri =  BITMAP_ADDR8(state->m_temp_bitmap_sprites_pri, yy, 0);
-			dstptr_bitmap  =  BITMAP_ADDR32(bitmap, yy, 0);
+			srcptr_tile =     &state->m_temp_bitmap_tilemaps.pix16(yy);
+			srcptr_tilepri =  &screen.machine().priority_bitmap.pix8(yy);
+			srcptr_spri =     &state->m_temp_bitmap_sprites.pix16(yy);
+			//srcptr_spripri =  &state->m_temp_bitmap_sprites_pri.pix8(yy);
+			dstptr_bitmap  =  &bitmap.pix32(yy);
 			for (xx=0;xx<width;xx++)
 			{
 				UINT16 src_tile  = srcptr_tile[xx];
@@ -579,7 +577,7 @@ SCREEN_UPDATE( ms32 )
 				}
 				else if (primask == 0xc0)
 				{
-					dstptr_bitmap[xx] = paldata[screen->machine().rand()&0xfff];
+					dstptr_bitmap[xx] = paldata[screen.machine().rand()&0xfff];
 				}
 				else if (primask == 0xf0)
 				{
@@ -663,12 +661,12 @@ SCREEN_UPDATE( ms32 )
 					}
 					else if (src_tilepri==0x06)
 					{
-						//dstptr_bitmap[xx] = paldata[screen->machine().rand()&0xfff];
+						//dstptr_bitmap[xx] = paldata[screen.machine().rand()&0xfff];
 						dstptr_bitmap[xx] = paldata[src_tile]; // assumed
 					}
 					else if (src_tilepri==0x07)
 					{
-						//dstptr_bitmap[xx] = paldata[screen->machine().rand()&0xfff];
+						//dstptr_bitmap[xx] = paldata[screen.machine().rand()&0xfff];
 						dstptr_bitmap[xx] = paldata[src_tile]; // assumed
 					}
 				}
