@@ -102,7 +102,7 @@ static void namconb1_install_palette(running_machine &machine)
 } /* namconb1_install_palette */
 
 static void
-video_update_common(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, int bROZ )
+video_update_common(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int bROZ )
 {
 	int pri;
 	namconb1_install_palette(machine);
@@ -131,26 +131,23 @@ video_update_common(running_machine &machine, bitmap_t *bitmap, const rectangle
 
 /************************************************************************************************/
 
-SCREEN_UPDATE( namconb1 )
+SCREEN_UPDATE_IND16( namconb1 )
 {
 	/* compute window for custom screen blanking */
 	rectangle clip;
 	//004a 016a 0021 0101 0144 0020 (nebulas ray)
-	UINT32 xclip = screen->machine().generic.paletteram.u32[0x1800/4];
-	UINT32 yclip = screen->machine().generic.paletteram.u32[0x1804/4];
+	UINT32 xclip = screen.machine().generic.paletteram.u32[0x1800/4];
+	UINT32 yclip = screen.machine().generic.paletteram.u32[0x1804/4];
 	clip.min_x = (xclip>>16)    - 0x4a;
 	clip.max_x = (xclip&0xffff) - 0x4a - 1;
 	clip.min_y = (yclip>>16)    - 0x21;
 	clip.max_y = (yclip&0xffff) - 0x21 - 1;
 	/* intersect with master clip rectangle */
-	if( clip.min_x < cliprect->min_x ){ clip.min_x = cliprect->min_x; }
-	if( clip.min_y < cliprect->min_y ){ clip.min_y = cliprect->min_y; }
-	if( clip.max_x > cliprect->max_x ){ clip.max_x = cliprect->max_x; }
-	if( clip.max_y > cliprect->max_y ){ clip.max_y = cliprect->max_y; }
+	clip &= cliprect;
 
-	bitmap_fill( bitmap, cliprect , get_black_pen(screen->machine()));
+	bitmap.fill(get_black_pen(screen.machine()), cliprect );
 
-	video_update_common( screen->machine(), bitmap, &clip, 0 );
+	video_update_common( screen.machine(), bitmap, clip, 0 );
 
 	return 0;
 }
@@ -171,32 +168,29 @@ VIDEO_START( namconb1 )
 
 /****************************************************************************************************/
 
-SCREEN_UPDATE( namconb2 )
+SCREEN_UPDATE_IND16( namconb2 )
 {
-	namconb1_state *state = screen->machine().driver_data<namconb1_state>();
+	namconb1_state *state = screen.machine().driver_data<namconb1_state>();
 	/* compute window for custom screen blanking */
 	rectangle clip;
 	//004a016a 00210101 01440020
-	UINT32 xclip = screen->machine().generic.paletteram.u32[0x1800/4];
-	UINT32 yclip = screen->machine().generic.paletteram.u32[0x1804/4];
+	UINT32 xclip = screen.machine().generic.paletteram.u32[0x1800/4];
+	UINT32 yclip = screen.machine().generic.paletteram.u32[0x1804/4];
 	clip.min_x = (xclip>>16)    - 0x4b;
 	clip.max_x = (xclip&0xffff) - 0x4b - 1;
 	clip.min_y = (yclip>>16)    - 0x21;
 	clip.max_y = (yclip&0xffff) - 0x21 - 1;
 	/* intersect with master clip rectangle */
-	if( clip.min_x < cliprect->min_x ){ clip.min_x = cliprect->min_x; }
-	if( clip.min_y < cliprect->min_y ){ clip.min_y = cliprect->min_y; }
-	if( clip.max_x > cliprect->max_x ){ clip.max_x = cliprect->max_x; }
-	if( clip.max_y > cliprect->max_y ){ clip.max_y = cliprect->max_y; }
+	clip &= cliprect;
 
-	bitmap_fill( bitmap, cliprect , get_black_pen(screen->machine()));
+	bitmap.fill(get_black_pen(screen.machine()), cliprect );
 
 	if( memcmp(state->m_tilemap_tile_bank,state->m_tilebank32,sizeof(state->m_tilemap_tile_bank))!=0 )
 	{
 		namco_tilemap_invalidate();
 		memcpy(state->m_tilemap_tile_bank,state->m_tilebank32,sizeof(state->m_tilemap_tile_bank));
 	}
-	video_update_common( screen->machine(), bitmap, &clip, 1 );
+	video_update_common( screen.machine(), bitmap, clip, 1 );
 	return 0;
 }
 
