@@ -74,16 +74,16 @@ struct RozParam
 INLINE void
 DrawRozHelperBlock(const struct RozParam *rozInfo, int destx, int desty,
 	int srcx, int srcy, int width, int height,
-	bitmap_t *destbitmap, bitmap_t *flagsbitmap,
-	bitmap_t *srcbitmap, UINT32 size_mask)
+	bitmap_ind16 &destbitmap, bitmap_ind8 &flagsbitmap,
+	bitmap_ind16 &srcbitmap, UINT32 size_mask)
 {
 	int desty_end = desty + height;
 
 	int end_incrx = rozInfo->incyx - (width * rozInfo->incxx);
 	int end_incry = rozInfo->incyy - (width * rozInfo->incxy);
 
-	UINT16 *dest = BITMAP_ADDR16(destbitmap, desty, destx);
-	int dest_rowinc = destbitmap->rowpixels - width;
+	UINT16 *dest = &destbitmap.pix16(desty, destx);
+	int dest_rowinc = destbitmap.rowpixels() - width;
 
 	while (desty < desty_end)
 	{
@@ -103,9 +103,9 @@ DrawRozHelperBlock(const struct RozParam *rozInfo, int destx, int desty,
 				goto L_SkipPixel;
 			}
 
-			if (*BITMAP_ADDR8(flagsbitmap, ypos, xpos) & TILEMAP_PIXEL_LAYER0)
+			if (flagsbitmap.pix8(ypos, xpos) & TILEMAP_PIXEL_LAYER0)
 			{
-				*dest = *BITMAP_ADDR16(srcbitmap, ypos, xpos) + rozInfo->color;
+				*dest = srcbitmap.pix16(ypos, xpos) + rozInfo->color;
 			}
 
 		L_SkipPixel:
@@ -123,14 +123,14 @@ DrawRozHelperBlock(const struct RozParam *rozInfo, int destx, int desty,
 
 static void
 DrawRozHelper(
-	bitmap_t *bitmap,
+	bitmap_ind16 &bitmap,
 	tilemap_t *tmap,
-	const rectangle *clip,
+	const rectangle &clip,
 	const struct RozParam *rozInfo )
 {
-	tilemap_set_palette_offset( tmap, rozInfo->color );
+	tmap->set_palette_offset(rozInfo->color );
 
-	if( bitmap->bpp == 16 )
+	if( bitmap.bpp() == 16 )
 	{
 		/* On many processors, the simple approach of an outer loop over the
             rows of the destination bitmap with an inner loop over the columns
@@ -162,20 +162,20 @@ DrawRozHelper(
 #define ROZ_BLOCK_SIZE 8
 
 		UINT32 size_mask = rozInfo->size - 1;
-		bitmap_t *srcbitmap = tilemap_get_pixmap(tmap);
-		bitmap_t *flagsbitmap = tilemap_get_flagsmap(tmap);
-		UINT32 srcx = (rozInfo->startx + (clip->min_x * rozInfo->incxx) +
-			(clip->min_y * rozInfo->incyx));
-		UINT32 srcy = (rozInfo->starty + (clip->min_x * rozInfo->incxy) +
-			(clip->min_y * rozInfo->incyy));
-		int destx = clip->min_x;
-		int desty = clip->min_y;
+		bitmap_ind16 &srcbitmap = tmap->pixmap();
+		bitmap_ind8 &flagsbitmap = tmap->flagsmap();
+		UINT32 srcx = (rozInfo->startx + (clip.min_x * rozInfo->incxx) +
+			(clip.min_y * rozInfo->incyx));
+		UINT32 srcy = (rozInfo->starty + (clip.min_x * rozInfo->incxy) +
+			(clip.min_y * rozInfo->incyy));
+		int destx = clip.min_x;
+		int desty = clip.min_y;
 
-		int row_count = (clip->max_y - desty) + 1;
+		int row_count = (clip.max_y - desty) + 1;
 		int row_block_count = row_count / ROZ_BLOCK_SIZE;
 		int row_extra_count = row_count % ROZ_BLOCK_SIZE;
 
-		int column_count = (clip->max_x - destx) + 1;
+		int column_count = (clip.max_x - destx) + 1;
 		int column_block_count = column_count / ROZ_BLOCK_SIZE;
 		int column_extra_count = column_count % ROZ_BLOCK_SIZE;
 
@@ -235,8 +235,8 @@ DrawRozHelper(
 	}
 	else
 	{
-		tilemap_draw_roz(
-			bitmap, clip, tmap,
+		tmap->draw_roz(
+			bitmap, clip,
 			rozInfo->startx, rozInfo->starty,
 			rozInfo->incxx, rozInfo->incxy,
 			rozInfo->incyx, rozInfo->incyy,
@@ -245,7 +245,7 @@ DrawRozHelper(
 } /* DrawRozHelper */
 
 static void
-DrawROZ(bitmap_t *bitmap,const rectangle *cliprect)
+DrawROZ(bitmap_ind16 &bitmap,const rectangle &cliprect)
 {
 	const int xoffset = 38,yoffset = 0;
 	struct RozParam rozParam;
@@ -313,7 +313,7 @@ READ16_HANDLER( namcos2_68k_roz_ram_r )
 WRITE16_HANDLER( namcos2_68k_roz_ram_w )
 {
 	COMBINE_DATA(&namcos2_68k_roz_ram[offset]);
-	tilemap_mark_tile_dirty(tilemap_roz,offset);
+	tilemap_roz->mark_tile_dirty(offset);
 //      if( space->machine().input().code_pressed(KEYCODE_Q) )
 //      {
 //          debugger_break(space->machine());
@@ -445,44 +445,44 @@ VIDEO_START( namcos2 )
 {
 	namco_tilemap_init(machine,2,machine.region("gfx4")->base(),TilemapCB);
 	tilemap_roz = tilemap_create(machine, get_tile_info_roz,tilemap_scan_rows,8,8,256,256);
-	tilemap_set_transparent_pen(tilemap_roz,0xff);
+	tilemap_roz->set_transparent_pen(0xff);
 	DrawSpriteInit(machine);
 }
 
 static void
-ApplyClip( rectangle *clip, const rectangle *cliprect )
+ApplyClip( rectangle &clip, const rectangle &cliprect )
 {
-	clip->min_x = GetPaletteRegister(0) - 0x4a;
-	clip->max_x = GetPaletteRegister(1) - 0x4a - 1;
-	clip->min_y = GetPaletteRegister(2) - 0x21;
-	clip->max_y = GetPaletteRegister(3) - 0x21 - 1;
+	clip.min_x = GetPaletteRegister(0) - 0x4a;
+	clip.max_x = GetPaletteRegister(1) - 0x4a - 1;
+	clip.min_y = GetPaletteRegister(2) - 0x21;
+	clip.max_y = GetPaletteRegister(3) - 0x21 - 1;
 	/* intersect with master clip rectangle */
-	sect_rect(clip, cliprect);
+	clip &= cliprect;
 } /* ApplyClip */
 
-SCREEN_UPDATE( namcos2_default )
+SCREEN_UPDATE_IND16( namcos2_default )
 {
 	rectangle clip;
 	int pri;
 
-	UpdatePalette(screen->machine());
-	bitmap_fill( bitmap, cliprect , get_black_pen(screen->machine()));
-	ApplyClip( &clip, cliprect );
+	UpdatePalette(screen.machine());
+	bitmap.fill(get_black_pen(screen.machine()), cliprect );
+	ApplyClip( clip, cliprect );
 
 	/* HACK: enable ROZ layer only if it has priority > 0 */
-	tilemap_set_enable(tilemap_roz,(namcos2_gfx_ctrl & 0x7000) ? 1 : 0);
+	tilemap_roz->enable((namcos2_gfx_ctrl & 0x7000) ? 1 : 0);
 
 	for( pri=0; pri<16; pri++ )
 	{
 		if( (pri&1)==0 )
 		{
-			namco_tilemap_draw( bitmap, &clip, pri/2 );
+			namco_tilemap_draw( bitmap, clip, pri/2 );
 
 			if( ((namcos2_gfx_ctrl & 0x7000) >> 12)==pri/2 )
 			{
-				DrawROZ(bitmap,&clip);
+				DrawROZ(bitmap,clip);
 			}
-			namcos2_draw_sprites(screen->machine(), bitmap, &clip, pri/2, namcos2_gfx_ctrl );
+			namcos2_draw_sprites(screen.machine(), bitmap, clip, pri/2, namcos2_gfx_ctrl );
 		}
 	}
 	return 0;
@@ -497,23 +497,23 @@ VIDEO_START( finallap )
 	namco_road_init(machine, 3);
 }
 
-SCREEN_UPDATE( finallap )
+SCREEN_UPDATE_IND16( finallap )
 {
 	rectangle clip;
 	int pri;
 
-	UpdatePalette(screen->machine());
-	bitmap_fill( bitmap, cliprect , get_black_pen(screen->machine()));
-	ApplyClip( &clip, cliprect );
+	UpdatePalette(screen.machine());
+	bitmap.fill(get_black_pen(screen.machine()), cliprect );
+	ApplyClip( clip, cliprect );
 
 	for( pri=0; pri<16; pri++ )
 	{
 		if( (pri&1)==0 )
 		{
-			namco_tilemap_draw( bitmap, &clip, pri/2 );
+			namco_tilemap_draw( bitmap, clip, pri/2 );
 		}
-		namco_road_draw(screen->machine(), bitmap,&clip,pri );
-		namcos2_draw_sprites(screen->machine(), bitmap,&clip,pri,namcos2_gfx_ctrl );
+		namco_road_draw(screen.machine(), bitmap,clip,pri );
+		namcos2_draw_sprites(screen.machine(), bitmap,clip,pri,namcos2_gfx_ctrl );
 	}
 	return 0;
 }
@@ -534,27 +534,27 @@ VIDEO_START( luckywld )
 	}
 } /* luckywld */
 
-SCREEN_UPDATE( luckywld )
+SCREEN_UPDATE_IND16( luckywld )
 {
 	rectangle clip;
 	int pri;
 
-	UpdatePalette(screen->machine());
-	bitmap_fill( bitmap, cliprect , get_black_pen(screen->machine()));
-	ApplyClip( &clip, cliprect );
+	UpdatePalette(screen.machine());
+	bitmap.fill(get_black_pen(screen.machine()), cliprect );
+	ApplyClip( clip, cliprect );
 
 	for( pri=0; pri<16; pri++ )
 	{
 		if( (pri&1)==0 )
 		{
-			namco_tilemap_draw( bitmap, &clip, pri/2 );
+			namco_tilemap_draw( bitmap, clip, pri/2 );
 		}
-		namco_road_draw(screen->machine(), bitmap,&clip,pri );
+		namco_road_draw(screen.machine(), bitmap,clip,pri );
 		if( namcos2_gametype==NAMCOS2_LUCKY_AND_WILD )
 		{
-			namco_roz_draw( bitmap, &clip, pri );
+			namco_roz_draw( bitmap, clip, pri );
 		}
-		namco_obj_draw(screen->machine(), bitmap, &clip, pri );
+		namco_obj_draw(screen.machine(), bitmap, clip, pri );
 	}
 	return 0;
 }
@@ -567,19 +567,19 @@ VIDEO_START( sgunner )
 	namco_obj_init( machine, 0, 0x0, NULL );
 }
 
-SCREEN_UPDATE( sgunner )
+SCREEN_UPDATE_IND16( sgunner )
 {
 	rectangle clip;
 	int pri;
 
-	UpdatePalette(screen->machine());
-	bitmap_fill( bitmap, cliprect , get_black_pen(screen->machine()));
-	ApplyClip( &clip, cliprect );
+	UpdatePalette(screen.machine());
+	bitmap.fill(get_black_pen(screen.machine()), cliprect );
+	ApplyClip( clip, cliprect );
 
 	for( pri=0; pri<8; pri++ )
 	{
-		namco_tilemap_draw( bitmap, &clip, pri );
-		namco_obj_draw(screen->machine(), bitmap, &clip, pri );
+		namco_tilemap_draw( bitmap, clip, pri );
+		namco_obj_draw(screen.machine(), bitmap, clip, pri );
 	}
 	return 0;
 }
@@ -593,23 +593,23 @@ VIDEO_START( metlhawk )
 	namco_roz_init( machine, 1, "gfx5" );
 }
 
-SCREEN_UPDATE( metlhawk )
+SCREEN_UPDATE_IND16( metlhawk )
 {
 	rectangle clip;
 	int pri;
 
-	UpdatePalette(screen->machine());
-	bitmap_fill( bitmap, cliprect , get_black_pen(screen->machine()));
-	ApplyClip( &clip, cliprect );
+	UpdatePalette(screen.machine());
+	bitmap.fill(get_black_pen(screen.machine()), cliprect );
+	ApplyClip( clip, cliprect );
 
 	for( pri=0; pri<16; pri++ )
 	{
 		if( (pri&1)==0 )
 		{
-			namco_tilemap_draw( bitmap, &clip, pri/2 );
+			namco_tilemap_draw( bitmap, clip, pri/2 );
 		}
-		namco_roz_draw( bitmap, &clip, pri );
-		namcos2_draw_sprites_metalhawk(screen->machine(), bitmap,&clip,pri );
+		namco_roz_draw( bitmap, clip, pri );
+		namcos2_draw_sprites_metalhawk(screen.machine(), bitmap,clip,pri );
 	}
 	return 0;
 }
