@@ -8,23 +8,22 @@
 #include "emu.h"
 #include "includes/portrait.h"
 
-int portrait_scroll;
-UINT8 *portrait_bgvideoram, *portrait_fgvideoram;
-static tilemap_t *foreground, *background;
 
 WRITE8_HANDLER( portrait_bgvideo_write )
 {
-	tilemap_mark_tile_dirty(background,offset/2);
-	portrait_bgvideoram[offset] = data;
+	portrait_state *state = space->machine().driver_data<portrait_state>();
+	state->m_background->mark_tile_dirty(offset/2);
+	state->m_bgvideoram[offset] = data;
 }
 
 WRITE8_HANDLER( portrait_fgvideo_write )
 {
-	tilemap_mark_tile_dirty(foreground,offset/2);
-	portrait_fgvideoram[offset] = data;
+	portrait_state *state = space->machine().driver_data<portrait_state>();
+	state->m_foreground->mark_tile_dirty(offset/2);
+	state->m_fgvideoram[offset] = data;
 }
 
-INLINE void get_tile_info( running_machine *machine, tile_data *tileinfo, int tile_index, const UINT8 *source )
+INLINE void get_tile_info( running_machine &machine, tile_data &tileinfo, int tile_index, const UINT8 *source )
 {
 	int attr    = source[tile_index*2+0];
 	int tilenum = source[tile_index*2+1];
@@ -57,20 +56,23 @@ INLINE void get_tile_info( running_machine *machine, tile_data *tileinfo, int ti
 
 static TILE_GET_INFO( get_bg_tile_info )
 {
-	get_tile_info( machine, tileinfo, tile_index, portrait_bgvideoram );
+	portrait_state *state = machine.driver_data<portrait_state>();
+	get_tile_info( machine, tileinfo, tile_index, state->m_bgvideoram );
 }
 
 static TILE_GET_INFO( get_fg_tile_info )
 {
-	get_tile_info( machine, tileinfo, tile_index, portrait_fgvideoram );
+	portrait_state *state = machine.driver_data<portrait_state>();
+	get_tile_info( machine, tileinfo, tile_index, state->m_fgvideoram );
 }
 
 VIDEO_START( portrait )
 {
-	background = tilemap_create( machine, get_bg_tile_info, tilemap_scan_rows,       16, 16, 32, 32 );
-	foreground = tilemap_create( machine, get_fg_tile_info, tilemap_scan_rows,  16, 16, 32, 32 );
+	portrait_state *state = machine.driver_data<portrait_state>();
+	state->m_background = tilemap_create( machine, get_bg_tile_info, tilemap_scan_rows,       16, 16, 32, 32 );
+	state->m_foreground = tilemap_create( machine, get_fg_tile_info, tilemap_scan_rows,  16, 16, 32, 32 );
 
-	tilemap_set_transparent_pen( foreground, 7 );
+	state->m_foreground->set_transparent_pen(7 );
 }
 
 
@@ -78,10 +80,10 @@ VIDEO_START( portrait )
 PALETTE_INIT( portrait )
 {
 	int i;
-	UINT8* lookup = machine->region("tileattr")->base();
+	UINT8* lookup = machine.region("tileattr")->base();
 
 	/* allocate the colortable */
-	machine->colortable = colortable_alloc(machine, 0x40);
+	machine.colortable = colortable_alloc(machine, 0x40);
 
 /*
     for (i = 0;i < 0x40;i++)
@@ -94,7 +96,7 @@ PALETTE_INIT( portrait )
         g = (data >> 3) & 0x3;
         b = (data >> 5) & 0x7;
 
-        colortable_palette_set_color(machine->colortable, i, MAKE_RGB(pal3bit(r), pal2bit(g), pal3bit(b)));
+        colortable_palette_set_color(machine.colortable, i, MAKE_RGB(pal3bit(r), pal2bit(g), pal3bit(b)));
 
         color_prom++;
     }
@@ -109,10 +111,10 @@ PALETTE_INIT( portrait )
 		g = (data >> 5) & 0x1f;
 		b = (data >> 10) & 0x1f;
 
-		colortable_palette_set_color(machine->colortable, i, MAKE_RGB(pal5bit(r), pal5bit(g), pal5bit(b)));
+		colortable_palette_set_color(machine.colortable, i, MAKE_RGB(pal5bit(r), pal5bit(g), pal5bit(b)));
 
 		// ?? the lookup seems to reference 0x3f colours, unless 1 bit is priority or similar?
-		colortable_palette_set_color(machine->colortable, i+0x20, MAKE_RGB(pal5bit(r>>1), pal5bit(g>>1), pal5bit(b>>1)));
+		colortable_palette_set_color(machine.colortable, i+0x20, MAKE_RGB(pal5bit(r>>1), pal5bit(g>>1), pal5bit(b>>1)));
 
 		color_prom++;
 	}
@@ -122,14 +124,15 @@ PALETTE_INIT( portrait )
 	for (i = 0;i < 0x800;i++)
 	{
 		UINT8 ctabentry = lookup[i]&0x3f;
-		colortable_entry_set_value(machine->colortable, i, ctabentry);
+		colortable_entry_set_value(machine.colortable, i, ctabentry);
 	}
 }
 
 
-static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
-	UINT8 *source = machine->generic.spriteram.u8;
+	portrait_state *state = machine.driver_data<portrait_state>();
+	UINT8 *source = state->m_spriteram;
 	UINT8 *finish = source + 0x200;
 
 	while( source < finish )
@@ -152,7 +155,7 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 
 		if(attr & 0x08) sy |= 0x100;
 
-		sx += (source - machine->generic.spriteram.u8) - 8;
+		sx += (source - state->m_spriteram) - 8;
 		sx &= 0x1ff;
 
 		sy = (512 - 64) - sy;
@@ -164,11 +167,11 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 			break;
 
 		case 0x40:
-			sy -= portrait_scroll;
+			sy -= state->m_scroll;
 			break;
 
 		case 0x80:
-			sy -= portrait_scroll;
+			sy -= state->m_scroll;
 			break;
 
 		case 0xc0:
@@ -176,7 +179,7 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 
 		}
 
-		drawgfx_transpen(bitmap,cliprect,machine->gfx[0],
+		drawgfx_transpen(bitmap,cliprect,machine.gfx[0],
 				tilenum,color,
 				0,fy,
 				sx,sy,7);
@@ -185,25 +188,26 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 	}
 }
 
-VIDEO_UPDATE( portrait )
+SCREEN_UPDATE_IND16( portrait )
 {
+	portrait_state *state = screen.machine().driver_data<portrait_state>();
 	rectangle cliprect_scroll, cliprect_no_scroll;
 
-	cliprect_scroll = cliprect_no_scroll = *cliprect;
+	cliprect_scroll = cliprect_no_scroll = cliprect;
 
 	cliprect_no_scroll.min_x = cliprect_no_scroll.max_x - 111;
 	cliprect_scroll.max_x    = cliprect_scroll.min_x    + 319;
 
-	tilemap_set_scrolly(background, 0, 0);
-	tilemap_set_scrolly(foreground, 0, 0);
-	tilemap_draw(bitmap, &cliprect_no_scroll, background, 0, 0);
-	tilemap_draw(bitmap, &cliprect_no_scroll, foreground, 0, 0);
+	state->m_background->set_scrolly(0, 0);
+	state->m_foreground->set_scrolly(0, 0);
+	state->m_background->draw(bitmap, cliprect_no_scroll, 0, 0);
+	state->m_foreground->draw(bitmap, cliprect_no_scroll, 0, 0);
 
-	tilemap_set_scrolly(background, 0, portrait_scroll);
-	tilemap_set_scrolly(foreground, 0, portrait_scroll);
-	tilemap_draw(bitmap, &cliprect_scroll, background, 0, 0);
-	tilemap_draw(bitmap, &cliprect_scroll, foreground, 0, 0);
+	state->m_background->set_scrolly(0, state->m_scroll);
+	state->m_foreground->set_scrolly(0, state->m_scroll);
+	state->m_background->draw(bitmap, cliprect_scroll, 0, 0);
+	state->m_foreground->draw(bitmap, cliprect_scroll, 0, 0);
 
-	draw_sprites(screen->machine, bitmap,cliprect);
+	draw_sprites(screen.machine(), bitmap,cliprect);
 	return 0;
 }
