@@ -14,9 +14,9 @@ Vid Regs:
 0x3003fe8 -- c0c0???? flipscreen for screen 1 and 2 resp.
              ????8080 Screen size select
 0x3003fec -- a0000xxx always? is in two working games. 0x00000fff is bank select for gfx test
-0x3003ff0 -- 000000ff brightness for screen 1, ffffff00 are probably seperate rgb brightness (not used)
+0x3003ff0 -- 000000ff brightness for screen 1, ffffff00 are probably separate rgb brightness (not used)
 0x3003ff4 -- ffffff00 screen 1 clear colour
-0x3003ff8 -- 000000ff brightness for screen 2, ffffff00 are probably seperate rgb brightness (not used)
+0x3003ff8 -- 000000ff brightness for screen 2, ffffff00 are probably separate rgb brightness (not used)
 0x3003ffc -- ffffff00 screen 2 clear colour
 
 HotDebut: 86010000 00009998 80000000 Small Screen
@@ -31,7 +31,7 @@ HgKairak: 86010000 1f201918 a0000000 Large Screen
 
 
 /* --- SPRITES --- */
-static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, UINT32 scr )
+static void draw_sprites( running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, UINT32 scr )
 {
 	/*- Sprite Format 0x0000 - 0x2bff -**
 
@@ -127,21 +127,17 @@ static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rect
 	}
 }
 
-SCREEN_UPDATE( psikyo4 )
+SCREEN_UPDATE_IND16( psikyo4_left )
 {
-	device_t *left_screen  = screen->machine().device("lscreen");
-	device_t *right_screen = screen->machine().device("rscreen");
+	bitmap.fill(0x1000, cliprect);
+	draw_sprites(screen.machine(), bitmap, cliprect, 0x0000);
+	return 0;
+}
 
-	if (screen == left_screen)
-	{
-		bitmap_fill(bitmap, cliprect, 0x1000);
-		draw_sprites(screen->machine(), bitmap, cliprect, 0x0000);
-	}
-	if (screen == right_screen)
-	{
-		bitmap_fill(bitmap, cliprect, 0x1001);
-		draw_sprites(screen->machine(), bitmap, cliprect, 0x2000);
-	}
+SCREEN_UPDATE_IND16( psikyo4_right )
+{
+	bitmap.fill(0x1001, cliprect);
+	draw_sprites(screen.machine(), bitmap, cliprect, 0x2000);
 	return 0;
 }
 
