@@ -186,13 +186,13 @@ static VIDEO_START( ww3 )
  *
  *************************************/
 
-static SCREEN_UPDATE( redalert )
+static SCREEN_UPDATE_RGB32( redalert )
 {
-	redalert_state *state = screen->machine().driver_data<redalert_state>();
+	redalert_state *state = screen.machine().driver_data<redalert_state>();
 	pen_t pens[NUM_CHARMAP_PENS + NUM_BITMAP_PENS + 1];
 	offs_t offs;
 
-	get_pens(screen->machine(), pens);
+	get_pens(screen.machine(), pens);
 
 	for (offs = 0; offs < 0x2000; offs++)
 	{
@@ -235,9 +235,9 @@ static SCREEN_UPDATE( redalert )
 				pen = pens[((charmap_code & 0xfe) << 1) | color_prom_a0_a1];
 
 			if ((*state->m_video_control ^ state->m_control_xor) & 0x04)
-				*BITMAP_ADDR32(bitmap, y, x) = pen;
+				bitmap.pix32(y, x) = pen;
 			else
-				*BITMAP_ADDR32(bitmap, y ^ 0xff, x ^ 0xff) = pen;
+				bitmap.pix32(y ^ 0xff, x ^ 0xff) = pen;
 
 			/* next pixel */
 			x = x + 1;
@@ -259,13 +259,13 @@ static SCREEN_UPDATE( redalert )
  *
  *************************************/
 
-static SCREEN_UPDATE( demoneye )
+static SCREEN_UPDATE_RGB32( demoneye )
 {
-	redalert_state *state = screen->machine().driver_data<redalert_state>();
+	redalert_state *state = screen.machine().driver_data<redalert_state>();
 	pen_t pens[NUM_CHARMAP_PENS + NUM_BITMAP_PENS + 1];
 	offs_t offs;
 
-	get_pens(screen->machine(), pens);
+	get_pens(screen.machine(), pens);
 
 	for (offs = 0; offs < 0x2000; offs++)
 	{
@@ -312,9 +312,9 @@ static SCREEN_UPDATE( demoneye )
 				pen = pens[((charmap_code & 0xfe) << 1) | color_prom_a0_a1];
 
 			if (*state->m_video_control & 0x04)
-				*BITMAP_ADDR32(bitmap, y ^ 0xff, x ^ 0xff) = pen;
+				bitmap.pix32(y ^ 0xff, x ^ 0xff) = pen;
 			else
-				*BITMAP_ADDR32(bitmap, y, x) = pen;
+				bitmap.pix32(y, x) = pen;
 
 			/* next pixel */
 			x = x + 1;
@@ -334,13 +334,13 @@ static SCREEN_UPDATE( demoneye )
  *
  *************************************/
 
-static SCREEN_UPDATE( panther )
+static SCREEN_UPDATE_RGB32( panther )
 {
-	redalert_state *state = screen->machine().driver_data<redalert_state>();
+	redalert_state *state = screen.machine().driver_data<redalert_state>();
 	pen_t pens[NUM_CHARMAP_PENS + NUM_BITMAP_PENS + 1];
 	offs_t offs;
 
-	get_panther_pens(screen->machine(), pens);
+	get_panther_pens(screen.machine(), pens);
 
 	for (offs = 0; offs < 0x2000; offs++)
 	{
@@ -383,9 +383,9 @@ static SCREEN_UPDATE( panther )
 				pen = pens[((charmap_code & 0xfe) << 1) | color_prom_a0_a1];
 
 			if ((*state->m_video_control ^ state->m_control_xor) & 0x04)
-				*BITMAP_ADDR32(bitmap, y, x) = pen;
+				bitmap.pix32(y, x) = pen;
 			else
-				*BITMAP_ADDR32(bitmap, y ^ 0xff, x ^ 0xff) = pen;
+				bitmap.pix32(y ^ 0xff, x ^ 0xff) = pen;
 
 			/* next pixel */
 			x = x + 1;
@@ -408,12 +408,11 @@ static SCREEN_UPDATE( panther )
 
 static MACHINE_CONFIG_FRAGMENT( redalert_video_common )
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
-	MCFG_SCREEN_UPDATE(redalert)
+	MCFG_SCREEN_UPDATE_STATIC(redalert)
 MACHINE_CONFIG_END
 
 MACHINE_CONFIG_FRAGMENT( redalert_video )
@@ -441,12 +440,11 @@ MACHINE_CONFIG_FRAGMENT( demoneye_video )
 	MCFG_VIDEO_START(redalert)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
-	MCFG_SCREEN_UPDATE(demoneye)
+	MCFG_SCREEN_UPDATE_STATIC(demoneye)
 MACHINE_CONFIG_END
 
 
@@ -455,11 +453,10 @@ MACHINE_CONFIG_FRAGMENT( panther_video )
 	MCFG_VIDEO_START(ww3)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
-	MCFG_SCREEN_UPDATE(panther)
+	MCFG_SCREEN_UPDATE_STATIC(panther)
 MACHINE_CONFIG_END
 
