@@ -9,15 +9,9 @@
 #include "sound/discrete.h"
 
 
-UINT8 *skydiver_videoram;
-
-static tilemap_t *bg_tilemap;
-static int width = 0;
-
-
 MACHINE_RESET( skydiver )
 {
-	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = machine.device("maincpu")->memory().space(AS_PROGRAM);
 
 	/* reset all latches */
 	skydiver_start_lamp_1_w(space, 0, 0);
@@ -43,7 +37,8 @@ MACHINE_RESET( skydiver )
 
 static TILE_GET_INFO( get_tile_info )
 {
-	UINT8 code = skydiver_videoram[tile_index];
+	skydiver_state *state = machine.driver_data<skydiver_state>();
+	UINT8 code = state->m_videoram[tile_index];
 	SET_TILE_INFO(0, code & 0x3f, code >> 6, 0);
 }
 
@@ -57,7 +52,8 @@ static TILE_GET_INFO( get_tile_info )
 
 VIDEO_START( skydiver )
 {
-	bg_tilemap = tilemap_create(machine, get_tile_info,tilemap_scan_rows,8,8,32,32);
+	skydiver_state *state = machine.driver_data<skydiver_state>();
+	state->m_bg_tilemap = tilemap_create(machine, get_tile_info,tilemap_scan_rows,8,8,32,32);
 }
 
 
@@ -69,42 +65,46 @@ VIDEO_START( skydiver )
 
 WRITE8_HANDLER( skydiver_videoram_w )
 {
-	skydiver_videoram[offset] = data;
-	tilemap_mark_tile_dirty(bg_tilemap, offset);
+	skydiver_state *state = space->machine().driver_data<skydiver_state>();
+	state->m_videoram[offset] = data;
+	state->m_bg_tilemap->mark_tile_dirty(offset);
 }
 
 
 READ8_HANDLER( skydiver_wram_r )
 {
-	return skydiver_videoram[offset | 0x380];
+	skydiver_state *state = space->machine().driver_data<skydiver_state>();
+	return state->m_videoram[offset | 0x380];
 }
 
 WRITE8_HANDLER( skydiver_wram_w )
 {
-	skydiver_videoram[offset | 0x0380] = data;
+	skydiver_state *state = space->machine().driver_data<skydiver_state>();
+	state->m_videoram[offset | 0x0380] = data;
 }
 
 
 WRITE8_HANDLER( skydiver_width_w )
 {
-	width = offset;
+	skydiver_state *state = space->machine().driver_data<skydiver_state>();
+	state->m_width = offset;
 }
 
 
 WRITE8_HANDLER( skydiver_coin_lockout_w )
 {
-	coin_lockout_global_w(space->machine, !offset);
+	coin_lockout_global_w(space->machine(), !offset);
 }
 
 
 WRITE8_HANDLER( skydiver_start_lamp_1_w )
 {
-	set_led_status(space->machine, 0, offset);
+	set_led_status(space->machine(), 0, offset);
 }
 
 WRITE8_HANDLER( skydiver_start_lamp_2_w )
 {
-	set_led_status(space->machine, 1, offset);
+	set_led_status(space->machine(), 1, offset);
 }
 
 
@@ -130,7 +130,7 @@ WRITE8_HANDLER( skydiver_lamp_d_w )
 
 WRITE8_HANDLER( skydiver_2000_201F_w )
 {
-	device_t *discrete = space->machine->device("discrete");
+	device_t *discrete = space->machine().device("discrete");
 	int bit = offset & 0x01;
 
 	watchdog_reset_w(space,0,0);
@@ -168,8 +168,9 @@ WRITE8_HANDLER( skydiver_2000_201F_w )
  *
  *************************************/
 
-static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
+	skydiver_state *state = machine.driver_data<skydiver_state>();
 	int pic;
 
 
@@ -183,12 +184,12 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 		int color;
 		int wide;
 
-		sx = 29*8 - skydiver_videoram[pic + 0x0390];
-		sy = 30*8 - skydiver_videoram[pic*2 + 0x0398];
-		charcode = skydiver_videoram[pic*2 + 0x0399];
+		sx = 29*8 - state->m_videoram[pic + 0x0390];
+		sy = 30*8 - state->m_videoram[pic*2 + 0x0398];
+		charcode = state->m_videoram[pic*2 + 0x0399];
 		xflip = charcode & 0x10;
 		yflip = charcode & 0x08;
-		wide = (~pic & 0x02) && width;
+		wide = (~pic & 0x02) && state->m_width;
 		charcode = (charcode & 0x07) | ((charcode & 0x60) >> 2);
 		color = pic & 0x01;
 
@@ -197,7 +198,7 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 			sx -= 8;
 		}
 
-		drawgfxzoom_transpen(bitmap,cliprect,machine->gfx[1],
+		drawgfxzoom_transpen(bitmap,cliprect,machine.gfx[1],
 			charcode, color,
 			xflip,yflip,sx,sy,
 			wide ? 0x20000 : 0x10000, 0x10000,0);
@@ -205,10 +206,11 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 }
 
 
-VIDEO_UPDATE( skydiver )
+SCREEN_UPDATE_IND16( skydiver )
 {
-	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
+	skydiver_state *state = screen.machine().driver_data<skydiver_state>();
+	state->m_bg_tilemap->draw(bitmap, cliprect, 0,0);
 
-	draw_sprites(screen->machine, bitmap, cliprect);
+	draw_sprites(screen.machine(), bitmap, cliprect);
 	return 0;
 }
