@@ -45,7 +45,7 @@ WRITE8_HANDLER( ssozumo_videoram_w )
 	ssozumo_state *state = space->machine().driver_data<ssozumo_state>();
 
 	state->m_videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
+	state->m_bg_tilemap->mark_tile_dirty(offset);
 }
 
 WRITE8_HANDLER( ssozumo_colorram_w )
@@ -53,7 +53,7 @@ WRITE8_HANDLER( ssozumo_colorram_w )
 	ssozumo_state *state = space->machine().driver_data<ssozumo_state>();
 
 	state->m_colorram[offset] = data;
-	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
+	state->m_bg_tilemap->mark_tile_dirty(offset);
 }
 
 WRITE8_HANDLER( ssozumo_videoram2_w )
@@ -61,7 +61,7 @@ WRITE8_HANDLER( ssozumo_videoram2_w )
 	ssozumo_state *state = space->machine().driver_data<ssozumo_state>();
 
 	state->m_videoram2[offset] = data;
-	tilemap_mark_tile_dirty(state->m_fg_tilemap, offset);
+	state->m_fg_tilemap->mark_tile_dirty(offset);
 }
 
 WRITE8_HANDLER( ssozumo_colorram2_w )
@@ -69,7 +69,7 @@ WRITE8_HANDLER( ssozumo_colorram2_w )
 	ssozumo_state *state = space->machine().driver_data<ssozumo_state>();
 
 	state->m_colorram2[offset] = data;
-	tilemap_mark_tile_dirty(state->m_fg_tilemap, offset);
+	state->m_fg_tilemap->mark_tile_dirty(offset);
 }
 
 WRITE8_HANDLER( ssozumo_paletteram_w )
@@ -110,7 +110,7 @@ WRITE8_HANDLER( ssozumo_scroll_w )
 {
 	ssozumo_state *state = space->machine().driver_data<ssozumo_state>();
 
-	tilemap_set_scrolly(state->m_bg_tilemap, 0, data);
+	state->m_bg_tilemap->set_scrolly(0, data);
 }
 
 WRITE8_HANDLER( ssozumo_flipscreen_w )
@@ -147,10 +147,10 @@ VIDEO_START( ssozumo )
 	state->m_fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_cols_flip_x,
 		 8, 8, 32, 32);
 
-	tilemap_set_transparent_pen(state->m_fg_tilemap, 0);
+	state->m_fg_tilemap->set_transparent_pen(0);
 }
 
-static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	ssozumo_state *state = machine.driver_data<ssozumo_state>();
 	UINT8 *spriteram = state->m_spriteram;
@@ -184,12 +184,12 @@ static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const recta
 	}
 }
 
-SCREEN_UPDATE( ssozumo )
+SCREEN_UPDATE_IND16( ssozumo )
 {
-	ssozumo_state *state = screen->machine().driver_data<ssozumo_state>();
+	ssozumo_state *state = screen.machine().driver_data<ssozumo_state>();
 
-	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
-	tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
-	draw_sprites(screen->machine(), bitmap, cliprect);
+	state->m_bg_tilemap->draw(bitmap, cliprect, 0, 0);
+	state->m_fg_tilemap->draw(bitmap, cliprect, 0, 0);
+	draw_sprites(screen.machine(), bitmap, cliprect);
 	return 0;
 }
