@@ -141,11 +141,11 @@ Note: press Z to show some info on each sprite (debug builds only)
 #endif
 
 
-static void ssv_drawgfx(	bitmap_t *bitmap, const rectangle *cliprect, const gfx_element *gfx,
+static void ssv_drawgfx(	bitmap_ind16 &bitmap, const rectangle &cliprect, const gfx_element *gfx,
 					UINT32 code,UINT32 color,int flipx,int flipy,int x0,int y0,
 					int shadow )
 {
-	ssv_state *state = gfx->machine->driver_data<ssv_state>();
+	ssv_state *state = gfx->machine().driver_data<ssv_state>();
 	const UINT8 *addr, *source;
 	UINT8 pen;
 	UINT16 *dest;
@@ -164,16 +164,16 @@ static void ssv_drawgfx(	bitmap_t *bitmap, const rectangle *cliprect, const gfx_
 #define SSV_DRAWGFX(SETPIXELCOLOR)												\
 	for ( sy = y0; sy != y1; sy += dy )											\
 	{																			\
-		if ( sy >= cliprect->min_y && sy <= cliprect->max_y )					\
+		if ( sy >= cliprect.min_y && sy <= cliprect.max_y )					\
 		{																		\
 			source	=	addr;													\
-			dest	=	BITMAP_ADDR16(bitmap, sy, 0);							\
+			dest	=	&bitmap.pix16(sy);							\
 																				\
 			for ( sx = x0; sx != x1; sx += dx )									\
 			{																	\
 				pen = *source++;												\
 																				\
-				if ( pen && sx >= cliprect->min_x && sx <= cliprect->max_x )	\
+				if ( pen && sx >= cliprect.min_x && sx <= cliprect.max_x )	\
 					SETPIXELCOLOR												\
 			}																	\
 		}																		\
@@ -183,7 +183,7 @@ static void ssv_drawgfx(	bitmap_t *bitmap, const rectangle *cliprect, const gfx_
 
 	if (shadow)
 	{
-		SSV_DRAWGFX( { dest[sx] = ((dest[sx] & state->shadow_pen_mask) | (pen << state->shadow_pen_shift)) & 0x7fff; } )
+		SSV_DRAWGFX( { dest[sx] = ((dest[sx] & state->m_shadow_pen_mask) | (pen << state->m_shadow_pen_shift)) & 0x7fff; } )
 	}
 	else
 	{
@@ -194,51 +194,51 @@ static void ssv_drawgfx(	bitmap_t *bitmap, const rectangle *cliprect, const gfx_
 
 VIDEO_START( ssv )
 {
-	machine->gfx[0]->color_granularity = 64; /* 256 colour sprites with palette selectable on 64 colour boundaries */
+	machine.gfx[0]->color_granularity = 64; /* 256 colour sprites with palette selectable on 64 colour boundaries */
 }
 
 VIDEO_START( eaglshot )
 {
-	ssv_state *state = machine->driver_data<ssv_state>();
+	ssv_state *state = machine.driver_data<ssv_state>();
 	VIDEO_START_CALL(ssv);
 
-	state->eaglshot_gfxram		=	auto_alloc_array(machine, UINT16, 16 * 0x40000 / 2);
+	state->m_eaglshot_gfxram		=	auto_alloc_array(machine, UINT16, 16 * 0x40000 / 2);
 
-	gfx_element_set_source(machine->gfx[0], (UINT8 *)state->eaglshot_gfxram);
-	gfx_element_set_source(machine->gfx[1], (UINT8 *)state->eaglshot_gfxram);
+	gfx_element_set_source(machine.gfx[0], (UINT8 *)state->m_eaglshot_gfxram);
+	gfx_element_set_source(machine.gfx[1], (UINT8 *)state->m_eaglshot_gfxram);
 }
 
 static TILE_GET_INFO( get_tile_info_0 )
 {
-	ssv_state *state = machine->driver_data<ssv_state>();
-	UINT16 tile = state->gdfs_tmapram[tile_index];
+	ssv_state *state = machine.driver_data<ssv_state>();
+	UINT16 tile = state->m_gdfs_tmapram[tile_index];
 
 	SET_TILE_INFO(3, tile, 0, TILE_FLIPXY( tile >> 14 ));
 }
 
 WRITE16_HANDLER( gdfs_tmapram_w )
 {
-	ssv_state *state = space->machine->driver_data<ssv_state>();
+	ssv_state *state = space->machine().driver_data<ssv_state>();
 
-	COMBINE_DATA(&state->gdfs_tmapram[offset]);
-	tilemap_mark_tile_dirty(state->gdfs_tmap, offset);
+	COMBINE_DATA(&state->m_gdfs_tmapram[offset]);
+	state->m_gdfs_tmap->mark_tile_dirty(offset);
 }
 
 VIDEO_START( gdfs )
 {
-	ssv_state *state = machine->driver_data<ssv_state>();
+	ssv_state *state = machine.driver_data<ssv_state>();
 
 	VIDEO_START_CALL(ssv);
 
-	state->eaglshot_gfxram		=	auto_alloc_array(machine, UINT16, 4 * 0x100000 / 2);
+	state->m_eaglshot_gfxram		=	auto_alloc_array(machine, UINT16, 4 * 0x100000 / 2);
 
-	machine->gfx[2]->color_granularity = 64; /* 256 colour sprites with palette selectable on 64 colour boundaries */
-	gfx_element_set_source(machine->gfx[2], (UINT8 *)state->eaglshot_gfxram);
+	machine.gfx[2]->color_granularity = 64; /* 256 colour sprites with palette selectable on 64 colour boundaries */
+	gfx_element_set_source(machine.gfx[2], (UINT8 *)state->m_eaglshot_gfxram);
 
-	state->gdfs_tmap			=	tilemap_create(	machine, get_tile_info_0, tilemap_scan_rows,
+	state->m_gdfs_tmap			=	tilemap_create(	machine, get_tile_info_0, tilemap_scan_rows,
 											 16,16, 0x100,0x100	);
 
-	tilemap_set_transparent_pen(state->gdfs_tmap, 0);
+	state->m_gdfs_tmap->set_transparent_pen(0);
 }
 
 /***************************************************************************
@@ -275,27 +275,25 @@ VIDEO_START( gdfs )
     (resolution, visible area, flipping etc.)
 
     1c0060-61   ---- ---- ---- ---- ?                           21 or 2b    for all games
-    1c0062-63   fedc ba98 7654 3210     x start visible area
-    1c0064-65   fedc ba98 7654 3210     x end visible area
-    1c0066-67   ---- ---- ---- ----     ?                           1c6     for all games
-    1c0068-69   ---- ---- ---- ----     ?                           1       for all games
-    1c006a-6b   fedc ba98 7654 3210     y start visible area
-    1c006c-6d   fedc ba98 7654 3210     y end visible area
-    1c006e-6f   ---- ---- ---- ----     ?                           106     for all games
-    1c0070-71   ---- ---- ---- ---- ?
-            ---- --98 7654 3210     y global tilemap offset
-    1c0072-73   ---- ---- ---- ----     ?
-    1c0074-75   ---- ---- ---- ----     ?
-            -e-- ---- ---- ---- y sprite inversion
-            ---c ---- ---- ---- x sprite inversion?
-            ---- ba98 ---- ---- ?                           0101 for all games
-            ---- ---- -6-- ---- y tilemap inversion?
-            ---- ---- ---4 ---- x tilemap inversion?
-    1c0076-77   -e-- ---- ---- ----     global/local sprites coordinates
-            ---- ---- -6-- ----     shadow (2bits - 4bits)
-    1c0078-79   ---- ---- ---- ----     ?
-    1c007a-7b   ---- ---- ---- ----     ?
-            ---- -a-- ---- ----     left-right up-down inversion
+    1c0062-63   fedc ba98 7654 3210 x start visible area
+    1c0064-65   fedc ba98 7654 3210 x end visible area
+    1c0066-67   ---- ---- ---- ---- ?                           1c6     for all games
+    1c0068-69   ---- ---- ---- ---- ?                           1       for all games
+    1c006a-6b   fedc ba98 7654 3210 y start visible area
+    1c006c-6d   fedc ba98 7654 3210 y end visible area
+    1c006e-6f   ---- ---- ---- ---- ?                           106     for all games
+    1c0070-71   fedc ba98 7654 3210 signed y global tilemap x offset
+    1c0072-73   ---- ---- ---- ---- ?
+    1c0074-75   ---- ---- ---- ---- ?
+                -e-- ---- ---- ---- y flipscreen
+                ---c ---- ---- ---- x flipscreen
+                ---- ba98 ---- ---- ?                           0101 for all games
+                ---- ---- 7654 3210 signed global tilemap x offset
+    1c0076-77   -e-- ---- ---- ---- global/local sprites coordinates
+                ---- ---- 7--- ---- shadow (0 = 2 bits, 1 = 4 bits)
+    1c0078-79   ---- ---- ---- ---- ?
+    1c007a-7b   ---- ---- ---- ---- ?
+                ---- b--- ---- ---- sprite coordinate mode
 
             1c0060-7f:
 
@@ -305,11 +303,11 @@ VIDEO_START( gdfs )
 
     dynagear:   002b 002c 00d4 01c6 - 0001 0012 0102 0106
             02fd 0000 0500 0000 - 0015 5940
-            ????      ????  (flip)
+            03ed      5558  (flip)
 
     eaglshot:   0021 002a 00ca 01c6 - 0001 0016 00f6 0106
             0301 0000 0500 d000 - 0015 5940
-            ????      ????  (flip)
+            03f1      5560 d00f  (flip)
 
     gdfs:       002b 002c 00d5 01c6 - 0001 0012 0102 0106
             03ec 0711 0500 0000 - 00d5 5950
@@ -325,7 +323,7 @@ VIDEO_START( gdfs )
 
     janjans1:   0021 0023 00cb 01c6 - 0001 000f 00fe 0106
             0300 0000 0500 c000 - 0015 5140
-            0300            (flip)
+            0300      0500  (flip)
 
     keithlcy:   002b 0025 00cd 01c6 - 0001 0013 0101 0106
             0300 0711 0500 0000 - 0015 5940
@@ -384,7 +382,7 @@ VIDEO_START( gdfs )
 
 READ16_HANDLER( ssv_vblank_r )
 {
-	if (space->machine->primary_screen->vblank())
+	if (space->machine().primary_screen->vblank())
 		return 0x2000 | 0x1000;
 	else
 		return 0x0000;
@@ -392,9 +390,9 @@ READ16_HANDLER( ssv_vblank_r )
 
 WRITE16_HANDLER( ssv_scroll_w )
 {
-	ssv_state *state = space->machine->driver_data<ssv_state>();
+	ssv_state *state = space->machine().driver_data<ssv_state>();
 
-	COMBINE_DATA(state->scroll + offset);
+	COMBINE_DATA(state->m_scroll + offset);
 
 /*  offsets 60-7f: CRT Controller   */
 
@@ -402,22 +400,22 @@ WRITE16_HANDLER( ssv_scroll_w )
 
 WRITE16_HANDLER( paletteram16_xrgb_swap_word_w )
 {
-	ssv_state *state = space->machine->driver_data<ssv_state>();
+	ssv_state *state = space->machine().driver_data<ssv_state>();
 	int r, g, b;
 	UINT16 data0, data1;
 
-	COMBINE_DATA(state->paletteram + offset);
+	COMBINE_DATA(state->m_paletteram + offset);
 
 	offset &= ~1;
 
-	data0 = state->paletteram[offset + 1];
-	data1 = state->paletteram[offset];
+	data0 = state->m_paletteram[offset + 1];
+	data1 = state->m_paletteram[offset];
 
 	r = data0 & 0xff;
 	g = data1 >> 8;
 	b = data1 & 0xff;
 
-	palette_set_color(space->machine, offset>>1, MAKE_RGB(r, g, b));
+	palette_set_color(space->machine(), offset>>1, MAKE_RGB(r, g, b));
 }
 
 /***************************************************************************
@@ -608,11 +606,11 @@ From the above some noteworthy cases are:
 
 /* Draw a tilemap sprite */
 
-static void draw_row(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int sx, int sy, int scroll)
+static void draw_row(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int sx, int sy, int scroll)
 {
-	ssv_state *state = machine->driver_data<ssv_state>();
-	UINT16 *spriteram16 = state->spriteram;
-	UINT16 *ssv_scroll = state->scroll;
+	ssv_state *state = machine.driver_data<ssv_state>();
+	UINT16 *spriteram16 = state->m_spriteram;
+	UINT16 *ssv_scroll = state->m_scroll;
 	rectangle clip;
 	int attr, code, color, mode, size, page, shadow;
 	int x, x1, sx1, flipx, xnum, xstart, xend, xinc;
@@ -630,24 +628,21 @@ static void draw_row(running_machine *machine, bitmap_t *bitmap, const rectangle
 
 	/* Set up a clipping region for the tilemap slice .. */
 
-	clip.min_x = sx;
-	clip.max_x = sx + xnum * 0x10 - 1;
-	clip.min_y = sy;
-	clip.max_y = sy + ynum * 0x8  - 1;
+	clip.set(sx, sx + xnum * 0x10 - 1, sy, sy + ynum * 0x8  - 1);
 
 	/* .. and clip it against the visible screen */
 
-	if (clip.min_x > cliprect->max_x)	return;
-	if (clip.min_y > cliprect->max_y)	return;
+	if (clip.min_x > cliprect.max_x)	return;
+	if (clip.min_y > cliprect.max_y)	return;
 
-	if (clip.max_x < cliprect->min_x)	return;
-	if (clip.max_y < cliprect->min_y)	return;
+	if (clip.max_x < cliprect.min_x)	return;
+	if (clip.max_y < cliprect.min_y)	return;
 
-	if (clip.min_x < cliprect->min_x)	clip.min_x = cliprect->min_x;
-	if (clip.max_x > cliprect->max_x)	clip.max_x = cliprect->max_x;
+	if (clip.min_x < cliprect.min_x)	clip.min_x = cliprect.min_x;
+	if (clip.max_x > cliprect.max_x)	clip.max_x = cliprect.max_x;
 
-	if (clip.min_y < cliprect->min_y)	clip.min_y = cliprect->min_y;
-	if (clip.max_y > cliprect->max_y)	clip.max_y = cliprect->max_y;
+	if (clip.min_y < cliprect.min_y)	clip.min_y = cliprect.min_y;
+	if (clip.max_y > cliprect.max_y)	clip.max_y = cliprect.max_y;
 
 	/* Get the scroll data */
 	x    = ssv_scroll[ scroll * 4 + 0 ];	// x scroll
@@ -697,9 +692,19 @@ static void draw_row(running_machine *machine, bitmap_t *bitmap, const rectangle
 			attr	=	s3[1];	// code low  bits + color
 
 			/* Code's high bits are scrambled */
-			code	+=	state->tile_code[(attr & 0x3c00)>>10];
+			code	+=	state->m_tile_code[(attr & 0x3c00)>>10];
 			flipy	=	(attr & 0x4000);
 			flipx	=	(attr & 0x8000);
+
+			if ((ssv_scroll[0x74/2] & 0x1000) && ((ssv_scroll[0x74/2] & 0x2000) == 0))
+			{
+				if (flipx == 0) flipx = 1; else flipx = 0;
+			}
+			if ((ssv_scroll[0x74/2] & 0x4000) && ((ssv_scroll[0x74/2] & 0x2000) == 0))
+			{
+				if (flipy == 0) flipy = 1; else flipy = 0;
+			}
+
 			color	=	attr;
 
 			/* Select 256 or 64 color tiles */
@@ -717,7 +722,7 @@ static void draw_row(running_machine *machine, bitmap_t *bitmap, const rectangle
 			{
 				for (ty = ystart; ty != yend; ty += yinc)
 				{
-					ssv_drawgfx( bitmap, &clip, machine->gfx[gfx],
+					ssv_drawgfx( bitmap, clip, machine.gfx[gfx],
 											code++,
 											color,
 											flipx, flipy,
@@ -733,21 +738,21 @@ static void draw_row(running_machine *machine, bitmap_t *bitmap, const rectangle
 
 /* Draw the "background layer" using multiple tilemap sprites */
 
-static void draw_layer(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int  nr)
+static void draw_layer(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int  nr)
 {
 	int sy;
-	for ( sy = 0; sy <= machine->primary_screen->visible_area().max_y; sy += 0x40 )
+	for ( sy = 0; sy <= machine.primary_screen->visible_area().max_y; sy += 0x40 )
 		draw_row(machine, bitmap, cliprect, 0, sy, nr);
 }
 
 /* Draw sprites in the sprites list */
 
-static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	/* Sprites list */
-	ssv_state *state = machine->driver_data<ssv_state>();
-	UINT16 *ssv_scroll = state->scroll;
-	UINT16 *spriteram16 = state->spriteram;
+	ssv_state *state = machine.driver_data<ssv_state>();
+	UINT16 *ssv_scroll = state->m_scroll;
+	UINT16 *spriteram16 = state->m_spriteram;
 
 	UINT16 *s1	=	spriteram16;
 	UINT16 *end1	=	spriteram16 + 0x02000/2;
@@ -819,7 +824,7 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 				scroll	=	s2[ 0 ];	// scroll index
 
 				if (ssv_scroll[0x76/2] & 0x1000)
-					sy -= 0x20;						// kludge for eaglshot
+					sy -= 0x20;						// eaglshot
 				else
 				{
 					if (ssv_scroll[0x7a/2] & 0x0800)
@@ -853,9 +858,19 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 				attr	=	s2[1];	// code low  bits + color
 
 				/* Code's high bits are scrambled */
-				code	+=	state->tile_code[(attr & 0x3c00)>>10];
+				code	+=	state->m_tile_code[(attr & 0x3c00)>>10];
 				flipy	=	(attr & 0x4000);
 				flipx	=	(attr & 0x8000);
+
+				if ((ssv_scroll[0x74/2] & 0x1000) && ((ssv_scroll[0x74/2] & 0x2000) == 0))
+				{
+					if (flipx == 0) flipx = 1; else flipx = 0;
+				}
+				if ((ssv_scroll[0x74/2] & 0x4000) && ((ssv_scroll[0x74/2] & 0x2000) == 0))
+				{
+					if (flipy == 0) flipy = 1; else flipy = 0;
+				}
+
 				color	=	attr;
 
 				/* Select 256 or 64 color tiles */
@@ -880,49 +895,47 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 				sx	=	(sx & 0x1ff) - (sx & 0x200);
 				sy	=	(sy & 0x1ff) - (sy & 0x200);
 
-				sprites_offsx = -((ssv_scroll[0x7a/2] & 0x0800) >> 8);
+				sprites_offsx =  ((ssv_scroll[0x74/2] & 0x7f) - (ssv_scroll[0x74/2] & 0x80));
 
-				sprites_offsy = (-1)*((ssv_scroll[0x70/2] & 0x1ff) - (ssv_scroll[0x70/2] & 0x200)
-								 + ssv_scroll[0x6a/2] + 1) - (((ssv_scroll[0x7a/2] ^ 0x0800) & 0x0800) >> 8);
+				sprites_offsy = -((ssv_scroll[0x70/2] & 0x1ff) - (ssv_scroll[0x70/2] & 0x200) + ssv_scroll[0x6a/2] + 1);
 
-				if (ssv_scroll[0x74/2] & 0x4000)	// srmp7, twineag2, ultrax, vasara
+				if (ssv_scroll[0x74/2] & 0x4000) // flipscreen y
 				{
 					sy = -sy;
 					if (ssv_scroll[0x74/2] & 0x8000)
-						sy += 0x00;			// srmp7, twineag2, ultrax
+						sy += 0x00;			//
 					else
-						sy -= 0x10;			// vasara
+						sy -= 0x10;			// vasara (hack)
 				}
 
-				// sprites can use x and y coordinates relative to a side, the other side or the center
-				// for now we use a kludge
+				if (ssv_scroll[0x74/2] & 0x1000) // flipscreen x
+				{
+					sx = -sx + 0x100;
+				}
 
-				if (ssv_scroll[0x74/2] & 0x8000)
+				// sprites can be relative to a side, the other side or the center
+
+				if (ssv_scroll[0x7a/2] == 0x7140)
 				{
-					if (ssv_scroll[0x76/2] & 0x4000) {					// twineag2, ultrax
-						sx	=	sprites_offsx + sx - (xnum - 1) * 8;
-						sy	=	sprites_offsy - sy - (ynum * 8) / 2;
-					} else {									// srmp7
-						sx	=	sprites_offsx + sx;
-						sy	=	sprites_offsy - sy;
-					}
+					// srmp7
+					sx	=	sprites_offsx + sx;
+					sy	=	sprites_offsy - sy;
 				}
-				else if (ssv_scroll[0x76/2] & 0x1000)					// eaglshot
+				else if (ssv_scroll[0x7a/2] & 0x0800)
 				{
-					sx	=	sprites_offsx + sx - (xnum - 1) * 8;
+					// dynagear, drifto94, eaglshot, keithlcy, mslider, srmp4, stmblade, twineag2, ultrax
+					sx	=	sprites_offsx + sx - (xnum * 8)    ;
 					sy	=	sprites_offsy - sy - (ynum * 8) / 2;
 				}
-				else if (ssv_scroll[0x70/2] == 0x02fd)					// dynagear
+				else
 				{
+					// hypreact, hypreac2, janjans1, meosism, ryorioh, survarts, sxyreact, sxyreac2, vasara, vasara2
 					sx	=	sprites_offsx + sx;
-					sy	=	sprites_offsy - sy - (ynum * 8) / 2;
-				}
-				else											// other games
-				{
-					sx	=	sprites_offsx + sx;
-					sy	=	sprites_offsy - sy - (ynum - 1) * 8;
+					sy	=	sprites_offsy - sy - (ynum * 8);
 				}
 
+
+
 				/* Sprite code masking */
 				if (xnum == 2 && ynum == 4) // needed by hypreact
 				{
@@ -935,7 +948,7 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 				{
 					for (y = ystart; y != yend; y += yinc)
 					{
-						ssv_drawgfx( bitmap, cliprect, machine->gfx[gfx],
+						ssv_drawgfx( bitmap, cliprect, machine.gfx[gfx],
 												code++,
 												color,
 												flipx, flipy,
@@ -945,10 +958,10 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 				}
 
 				#ifdef MAME_DEBUG
-				if (input_code_pressed(machine, KEYCODE_Z))	/* Display some info on each sprite */
+				if (machine.input().code_pressed(KEYCODE_Z))	/* Display some info on each sprite */
 				{	char buf[30];
 					sprintf(buf, "%02X",/*(s2[2] & ~0x3ff)>>8*/mode>>8);
-					ui_draw_text(&machine->render().ui_container(), buf, sx, sy);
+					ui_draw_text(&machine.render().ui_container(), buf, sx, sy);
 				}
 				#endif
 
@@ -968,9 +981,9 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 
 ***************************************************************************/
 
-VIDEO_UPDATE( eaglshot )
+SCREEN_UPDATE_IND16( eaglshot )
 {
-	return VIDEO_UPDATE_CALL(ssv);
+	return SCREEN_UPDATE16_CALL(ssv);
 }
 
 /*
@@ -1026,12 +1039,12 @@ VIDEO_UPDATE( eaglshot )
         E.h                             Unused
 
 */
-static void gdfs_draw_zooming_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority)
+static void gdfs_draw_zooming_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, int priority)
 {
 	/* Sprites list */
 
-	ssv_state *state = machine->driver_data<ssv_state>();
-	UINT16 *spriteram16_2 = state->spriteram2;
+	ssv_state *state = machine.driver_data<ssv_state>();
+	UINT16 *spriteram16_2 = state->m_spriteram2;
 	UINT16 *s1	=	spriteram16_2;
 	UINT16 *end1	=	spriteram16_2 + 0x02000/2;
 	UINT16 *s2;
@@ -1069,6 +1082,18 @@ static void gdfs_draw_zooming_sprites(running_machine *machine, bitmap_t *bitmap
 
 			flipx	=	(attr & 0x8000);
 			flipy	=	(attr & 0x4000);
+
+/*
+            if ((ssv_scroll[0x74/2] & 0x1000) && ((ssv_scroll[0x74/2] & 0x2000) == 0))
+            {
+                if (flipx == 0) flipx = 1; else flipx = 0;
+            }
+            if ((ssv_scroll[0x74/2] & 0x4000) && ((ssv_scroll[0x74/2] & 0x2000) == 0))
+            {
+                if (flipy == 0) flipy = 1; else flipy = 0;
+            }
+*/
+
 			color	=	(attr & 0x0400) ? attr : attr * 4;
 
 			/* Single-sprite tile size */
@@ -1114,7 +1139,7 @@ static void gdfs_draw_zooming_sprites(running_machine *machine, bitmap_t *bitmap
 			{
 				for (y = ystart; y != yend; y += yinc)
 				{
-					drawgfxzoom_transpen( bitmap, cliprect, machine->gfx[2],
+					drawgfxzoom_transpen( bitmap, cliprect, machine.gfx[2],
 									code++,
 									color,
 									flipx, flipy,
@@ -1125,11 +1150,11 @@ static void gdfs_draw_zooming_sprites(running_machine *machine, bitmap_t *bitmap
 			}
 
 			#ifdef MAME_DEBUG
-			if (input_code_pressed(machine, KEYCODE_Z))	/* Display some info on each sprite */
+			if (machine.input().code_pressed(KEYCODE_Z))	/* Display some info on each sprite */
 			{
 				char buf[10];
 				sprintf(buf, "%X",size);
-				ui_draw_text(&machine->render().ui_container(), buf, sx / 0x10000, sy / 0x10000);
+				ui_draw_text(&machine.render().ui_container(), buf, sx / 0x10000, sy / 0x10000);
 			}
 			#endif
 		}	/* single-sprites */
@@ -1137,76 +1162,76 @@ static void gdfs_draw_zooming_sprites(running_machine *machine, bitmap_t *bitmap
 	}	/* sprites list */
 }
 
-VIDEO_UPDATE( gdfs )
+SCREEN_UPDATE_IND16( gdfs )
 {
-	ssv_state *state = screen->machine->driver_data<ssv_state>();
+	ssv_state *state = screen.machine().driver_data<ssv_state>();
 	int pri;
 
-	VIDEO_UPDATE_CALL(ssv);
+	SCREEN_UPDATE16_CALL(ssv);
 
 	for (pri = 0; pri <= 0xf; pri++)
-		gdfs_draw_zooming_sprites(screen->machine, bitmap, cliprect, pri);
+		gdfs_draw_zooming_sprites(screen.machine(), bitmap, cliprect, pri);
 
-	tilemap_set_scrollx(state->gdfs_tmap, 0, state->gdfs_tmapscroll[0x0c/2]);
-	tilemap_set_scrolly(state->gdfs_tmap, 0, state->gdfs_tmapscroll[0x10/2]);
-	tilemap_draw(bitmap,cliprect, state->gdfs_tmap, 0, 0);
+	state->m_gdfs_tmap->set_scrollx(0, state->m_gdfs_tmapscroll[0x0c/2]);
+	state->m_gdfs_tmap->set_scrolly(0, state->m_gdfs_tmapscroll[0x10/2]);
+	state->m_gdfs_tmap->draw(bitmap, cliprect, 0, 0);
 
 	return 0;
 }
 
-void ssv_enable_video(running_machine *machine, int enable)
+void ssv_enable_video(running_machine &machine, int enable)
 {
-	ssv_state *state = machine->driver_data<ssv_state>();
+	ssv_state *state = machine.driver_data<ssv_state>();
 
-	state->enable_video = enable;
+	state->m_enable_video = enable;
 }
 
-VIDEO_UPDATE( ssv )
+SCREEN_UPDATE_IND16( ssv )
 {
-	rectangle clip = { 0, 0, 0, 0 };
+	rectangle clip;
 
-	ssv_state *state = screen->machine->driver_data<ssv_state>();
+	ssv_state *state = screen.machine().driver_data<ssv_state>();
 
-	if (state->scroll[0x76/2] & 0x0080)
+	// Shadow
+	if (state->m_scroll[0x76/2] & 0x0080)
 	{
 		// 4 bit shadows (mslider, stmblade)
-		state->shadow_pen_mask		=	0x1fff;
-		state->shadow_pen_shift	=	11;
+		state->m_shadow_pen_shift = 15-4;
 	}
 	else
 	{
 		// 2 bit shadows
-		state->shadow_pen_mask		=	0x3fff;
-		state->shadow_pen_shift	=	13;
+		state->m_shadow_pen_shift = 15-2;
 	}
+	state->m_shadow_pen_mask = (1 << state->m_shadow_pen_shift) - 1;
 
 	/* The background color is the first one in the palette */
-	bitmap_fill(bitmap,cliprect, 0);
+	bitmap.fill(0, cliprect);
 
 	// used by twineag2 and ultrax
-	clip.min_x = (cliprect->max_x / 2 + state->scroll[0x62/2]) * 2 - state->scroll[0x64/2] * 2 + 2;
-	clip.max_x = (cliprect->max_x / 2 + state->scroll[0x62/2]) * 2 - state->scroll[0x62/2] * 2 + 1;
-	clip.min_y = (cliprect->max_y     + state->scroll[0x6a/2])     - state->scroll[0x6c/2]     + 1;
-	clip.max_y = (cliprect->max_y     + state->scroll[0x6a/2])     - state->scroll[0x6a/2]        ;
+	clip.min_x = (cliprect.max_x / 2 + state->m_scroll[0x62/2]) * 2 - state->m_scroll[0x64/2] * 2 + 2;
+	clip.max_x = (cliprect.max_x / 2 + state->m_scroll[0x62/2]) * 2 - state->m_scroll[0x62/2] * 2 + 1;
+	clip.min_y = (cliprect.max_y     + state->m_scroll[0x6a/2])     - state->m_scroll[0x6c/2]     + 1;
+	clip.max_y = (cliprect.max_y     + state->m_scroll[0x6a/2])     - state->m_scroll[0x6a/2]        ;
 
 //  printf("%04x %04x %04x %04x\n",clip.min_x, clip.max_x, clip.min_y, clip.max_y);
 
 	if (clip.min_x < 0) clip.min_x = 0;
 	if (clip.min_y < 0) clip.min_y = 0;
-	if (clip.max_x > cliprect->max_x) clip.max_x = cliprect->max_x;
-	if (clip.max_y > cliprect->max_y) clip.max_y = cliprect->max_y;
+	if (clip.max_x > cliprect.max_x) clip.max_x = cliprect.max_x;
+	if (clip.max_y > cliprect.max_y) clip.max_y = cliprect.max_y;
 
 	if (clip.min_x > clip.max_x)
 		clip.min_x = clip.max_x;
 	if (clip.min_y > clip.max_y)
 		clip.min_y = clip.max_y;
 
-	if (!state->enable_video)
+	if (!state->m_enable_video)
 		return 0;
 
-	draw_layer(screen->machine, bitmap, &clip, 0);	// "background layer"
+	draw_layer(screen.machine(), bitmap, clip, 0);	// "background layer"
 
-	draw_sprites(screen->machine, bitmap, &clip);	// sprites list
+	draw_sprites(screen.machine(), bitmap, clip);	// sprites list
 
 
 	return 0;
