@@ -122,7 +122,7 @@ WRITE16_HANDLER( suna16_paletteram16_w )
 
 ***************************************************************************/
 
-static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, UINT16 *sprites, int gfx)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, UINT16 *sprites, int gfx)
 {
 	suna16_state *state = machine.driver_data<suna16_state>();
 	int offs;
@@ -221,33 +221,33 @@ static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const recta
 
 ***************************************************************************/
 
-SCREEN_UPDATE( suna16 )
+SCREEN_UPDATE_IND16( suna16 )
 {
-	suna16_state *state = screen->machine().driver_data<suna16_state>();
+	suna16_state *state = screen.machine().driver_data<suna16_state>();
 
 	/* Suna Quiz indicates the background is the last pen */
-	bitmap_fill(bitmap,cliprect,0xff);
-	draw_sprites(screen->machine(), bitmap, cliprect, state->m_spriteram, 0);
+	bitmap.fill(0xff, cliprect);
+	draw_sprites(screen.machine(), bitmap, cliprect, state->m_spriteram, 0);
 	return 0;
 }
 
-SCREEN_UPDATE( bestbest )
+SCREEN_UPDATE_IND16( bestbest )
 {
-	suna16_state *state = screen->machine().driver_data<suna16_state>();
+	suna16_state *state = screen.machine().driver_data<suna16_state>();
 	int layers_ctrl = -1;
 
 #ifdef MAME_DEBUG
-if (screen->machine().input().code_pressed(KEYCODE_Z))
+if (screen.machine().input().code_pressed(KEYCODE_Z))
 {	int msk = 0;
-	if (screen->machine().input().code_pressed(KEYCODE_Q))	msk |= 1;
-	if (screen->machine().input().code_pressed(KEYCODE_W))	msk |= 2;
+	if (screen.machine().input().code_pressed(KEYCODE_Q))	msk |= 1;
+	if (screen.machine().input().code_pressed(KEYCODE_W))	msk |= 2;
 	if (msk != 0) layers_ctrl &= msk;
 }
 #endif
 
 	/* Suna Quiz indicates the background is the last pen */
-	bitmap_fill(bitmap,cliprect,0xff);
-	if (layers_ctrl & 1)	draw_sprites(screen->machine(), bitmap, cliprect, state->m_spriteram,  0);
-	if (layers_ctrl & 2)	draw_sprites(screen->machine(), bitmap, cliprect, state->m_spriteram2, 1);
+	bitmap.fill(0xff, cliprect);
+	if (layers_ctrl & 1)	draw_sprites(screen.machine(), bitmap, cliprect, state->m_spriteram,  0);
+	if (layers_ctrl & 2)	draw_sprites(screen.machine(), bitmap, cliprect, state->m_spriteram2, 1);
 	return 0;
 }
