@@ -25,7 +25,7 @@ WRITE16_HANDLER( taotaido_sprite_character_bank_select_w )
 /* sprites are like the other video system / psikyo games, we can merge this with aerofgt and plenty of other
    things eventually */
 
-static void draw_sprite(running_machine &machine, UINT16 spriteno, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_sprite(running_machine &machine, UINT16 spriteno, bitmap_ind16 &bitmap, const rectangle &cliprect )
 {
 	taotaido_state *state = machine.driver_data<taotaido_state>();
 	/*- SPR RAM Format -**
@@ -109,7 +109,7 @@ static void draw_sprite(running_machine &machine, UINT16 spriteno, bitmap_t *bit
 	}
 }
 
-static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect )
 {
 	taotaido_state *state = machine.driver_data<taotaido_state>();
 	/* first part of sprite ram is the list of sprites to draw, terminated with 0x4000 */
@@ -150,7 +150,7 @@ WRITE16_HANDLER( taotaido_tileregs_w )
 				state->m_video_bank_select[(offset-4)*2] = data >> 8;
 			if(ACCESSING_BITS_0_7)
 				state->m_video_bank_select[(offset-4)*2+1] = data &0xff;
-				tilemap_mark_all_tiles_dirty(state->m_bg_tilemap);
+				state->m_bg_tilemap->mark_all_dirty();
 			break;
 	}
 }
@@ -159,7 +159,7 @@ WRITE16_HANDLER( taotaido_bgvideoram_w )
 {
 	taotaido_state *state = space->machine().driver_data<taotaido_state>();
 	COMBINE_DATA(&state->m_bgram[offset]);
-	tilemap_mark_tile_dirty(state->m_bg_tilemap,offset);
+	state->m_bg_tilemap->mark_tile_dirty(offset);
 }
 
 static TILE_GET_INFO( taotaido_bg_tile_info )
@@ -197,44 +197,45 @@ VIDEO_START(taotaido)
 }
 
 
-SCREEN_UPDATE(taotaido)
+SCREEN_UPDATE_IND16(taotaido)
 {
-	taotaido_state *state = screen->machine().driver_data<taotaido_state>();
-//  tilemap_set_scrollx(state->m_bg_tilemap,0,(state->m_scrollram[0x380/2]>>4)); // the values put here end up being wrong every other frame
-//  tilemap_set_scrolly(state->m_bg_tilemap,0,(state->m_scrollram[0x382/2]>>4)); // the values put here end up being wrong every other frame
+	taotaido_state *state = screen.machine().driver_data<taotaido_state>();
+//  state->m_bg_tilemap->set_scrollx(0,(state->m_scrollram[0x380/2]>>4)); // the values put here end up being wrong every other frame
+//  state->m_bg_tilemap->set_scrolly(0,(state->m_scrollram[0x382/2]>>4)); // the values put here end up being wrong every other frame
 
 	/* not amazingly efficient however it should be functional for row select and linescroll */
 	int line;
 	rectangle clip;
 
-	const rectangle &visarea = screen->visible_area();
-	clip.min_x = visarea.min_x;
-	clip.max_x = visarea.max_x;
-	clip.min_y = visarea.min_y;
-	clip.max_y = visarea.max_y;
+	const rectangle &visarea = screen.visible_area();
+	clip = visarea;
 
 	for (line = 0; line < 224;line++)
 	{
 		clip.min_y = clip.max_y = line;
 
-		tilemap_set_scrollx(state->m_bg_tilemap,0,((state->m_scrollram[(0x00+4*line)/2])>>4)+30);
-		tilemap_set_scrolly(state->m_bg_tilemap,0,((state->m_scrollram[(0x02+4*line)/2])>>4)-line);
+		state->m_bg_tilemap->set_scrollx(0,((state->m_scrollram[(0x00+4*line)/2])>>4)+30);
+		state->m_bg_tilemap->set_scrolly(0,((state->m_scrollram[(0x02+4*line)/2])>>4)-line);
 
-		tilemap_draw(bitmap,&clip,state->m_bg_tilemap,0,0);
+		state->m_bg_tilemap->draw(bitmap, clip, 0,0);
 	}
 
-	draw_sprites(screen->machine(), bitmap,cliprect);
+	draw_sprites(screen.machine(), bitmap,cliprect);
 	return 0;
 }
 
-SCREEN_EOF( taotaido )
+SCREEN_VBLANK( taotaido )
 {
-	taotaido_state *state = machine.driver_data<taotaido_state>();
-	/* sprites need to be delayed by 2 frames? */
+	// rising edge
+	if (vblank_on)
+	{
+		taotaido_state *state = screen.machine().driver_data<taotaido_state>();
+		/* sprites need to be delayed by 2 frames? */
 
-	memcpy(state->m_spriteram2_older,state->m_spriteram2_old,0x10000);
-	memcpy(state->m_spriteram2_old,state->m_spriteram2,0x10000);
+		memcpy(state->m_spriteram2_older,state->m_spriteram2_old,0x10000);
+		memcpy(state->m_spriteram2_old,state->m_spriteram2,0x10000);
 
-	memcpy(state->m_spriteram_older,state->m_spriteram_old,0x2000);
-	memcpy(state->m_spriteram_old,state->m_spriteram,0x2000);
+		memcpy(state->m_spriteram_older,state->m_spriteram_old,0x2000);
+		memcpy(state->m_spriteram_old,state->m_spriteram,0x2000);
+	}
 }
