@@ -119,7 +119,7 @@ WRITE16_HANDLER( roundup5_text_w )
 	tatsumi_state *state = space->machine().driver_data<tatsumi_state>();
 	UINT16 *videoram = state->m_videoram;
 	COMBINE_DATA(&videoram[offset]);
-	tilemap_mark_tile_dirty( state->m_tx_layer,offset);
+	state->m_tx_layer->mark_tile_dirty(offset);
 }
 
 READ16_HANDLER( cyclwarr_videoram0_r )
@@ -140,8 +140,8 @@ WRITE16_HANDLER( cyclwarr_videoram0_w )
 	COMBINE_DATA(&state->m_cyclwarr_videoram0[offset]);
 	if (offset>=0x400)
 	{
-		tilemap_mark_tile_dirty( state->m_layer0, offset-0x400);
-		tilemap_mark_tile_dirty( state->m_layer1, offset-0x400);
+		state->m_layer0->mark_tile_dirty(offset-0x400);
+		state->m_layer1->mark_tile_dirty(offset-0x400);
 	}
 }
 
@@ -151,8 +151,8 @@ WRITE16_HANDLER( cyclwarr_videoram1_w )
 	COMBINE_DATA(&state->m_cyclwarr_videoram1[offset]);
 	if (offset>=0x400)
 	{
-		tilemap_mark_tile_dirty( state->m_layer2, offset-0x400);
-		tilemap_mark_tile_dirty( state->m_layer3, offset-0x400);
+		state->m_layer2->mark_tile_dirty(offset-0x400);
+		state->m_layer3->mark_tile_dirty(offset-0x400);
 	}
 }
 
@@ -205,10 +205,10 @@ VIDEO_START( apache3 )
 	tatsumi_state *state = machine.driver_data<tatsumi_state>();
 	state->m_tx_layer = tilemap_create(machine, get_text_tile_info,tilemap_scan_rows,8,8,64,64);
 	state->m_shadow_pen_array = auto_alloc_array_clear(machine, UINT8, 8192);
-	state->m_temp_bitmap = auto_bitmap_alloc(machine, 512, 512, BITMAP_FORMAT_RGB32);
+	state->m_temp_bitmap.allocate(512, 512);
 	state->m_apache3_road_x_ram = auto_alloc_array(machine, UINT8, 512);
 
-	tilemap_set_transparent_pen(state->m_tx_layer,0);
+	state->m_tx_layer->set_transparent_pen(0);
 }
 
 VIDEO_START( roundup5 )
@@ -218,7 +218,7 @@ VIDEO_START( roundup5 )
 	state->m_shadow_pen_array = auto_alloc_array_clear(machine, UINT8, 8192);
 	state->m_roundup5_vram = auto_alloc_array(machine, UINT16, (0x48000 * 4)/2);
 
-	tilemap_set_transparent_pen(state->m_tx_layer,0);
+	state->m_tx_layer->set_transparent_pen(0);
 
 	gfx_element_set_source(machine.gfx[1], (UINT8 *)state->m_roundup5_vram);
 }
@@ -248,12 +248,12 @@ VIDEO_START( bigfight )
 
 /********************************************************************/
 
-INLINE void roundupt_drawgfxzoomrotate(
-		bitmap_t *dest_bmp, const rectangle *clip, const gfx_element *gfx,
+template<class _BitmapClass>
+INLINE void roundupt_drawgfxzoomrotate(tatsumi_state *state,
+		_BitmapClass &dest_bmp, const rectangle &clip, const gfx_element *gfx,
 		UINT32 code,UINT32 color,int flipx,int flipy,UINT32 ssx,UINT32 ssy,
 		int scalex, int scaley, int rotate, int write_priority_only )
 {
-	tatsumi_state *state = gfx->machine().driver_data<tatsumi_state>();
 	rectangle myclip;
 
 	if (!scalex || !scaley) return;
@@ -266,20 +266,8 @@ INLINE void roundupt_drawgfxzoomrotate(
     */
 
 	/* KW 991012 -- Added code to force clip to bitmap boundary */
-	if(clip)
-	{
-		myclip.min_x = clip->min_x;
-		myclip.max_x = clip->max_x;
-		myclip.min_y = clip->min_y;
-		myclip.max_y = clip->max_y;
-
-		if (myclip.min_x < 0) myclip.min_x = 0;
-		if (myclip.max_x >= dest_bmp->width) myclip.max_x = dest_bmp->width-1;
-		if (myclip.min_y < 0) myclip.min_y = 0;
-		if (myclip.max_y >= dest_bmp->height) myclip.max_y = dest_bmp->height-1;
-
-		clip=&myclip;
-	}
+	myclip = clip;
+	myclip &= dest_bmp.cliprect();
 
 	{
 		if( gfx )
@@ -346,31 +334,28 @@ INLINE void roundupt_drawgfxzoomrotate(
 					y_index = 0;
 				}
 
-				if( clip )
-				{
-					if( sx < clip->min_x)
-					{ /* clip left */
-						int pixels = clip->min_x-sx;
-						sx += pixels;
-						x_index_base += pixels*dx;
-					}
-					if( sy < clip->min_y )
-					{ /* clip top */
-						int pixels = clip->min_y-sy;
-						sy += pixels;
-						y_index += pixels*dy;
-					}
-					/* NS 980211 - fixed incorrect clipping */
-					if( ex > clip->max_x+1 )
-					{ /* clip right */
-						int pixels = ex-clip->max_x-1;
-						ex -= pixels;
-					}
-					if( ey > clip->max_y+1 )
-					{ /* clip bottom */
-						int pixels = ey-clip->max_y-1;
-						ey -= pixels;
-					}
+				if( sx < myclip.min_x)
+				{ /* clip left */
+					int pixels = myclip.min_x-sx;
+					sx += pixels;
+					x_index_base += pixels*dx;
+				}
+				if( sy < myclip.min_y )
+				{ /* clip top */
+					int pixels = myclip.min_y-sy;
+					sy += pixels;
+					y_index += pixels*dy;
+				}
+				/* NS 980211 - fixed incorrect clipping */
+				if( ex > myclip.max_x+1 )
+				{ /* clip right */
+					int pixels = ex-myclip.max_x-1;
+					ex -= pixels;
+				}
+				if( ey > myclip.max_y+1 )
+				{ /* clip bottom */
+					int pixels = ey-myclip.max_y-1;
+					ey -= pixels;
 				}
 
 				if( ex>sx )
@@ -403,7 +388,7 @@ INLINE void roundupt_drawgfxzoomrotate(
 
 							for( y=sy; y<ey; y++ )
 							{
-								UINT32 *dest = BITMAP_ADDR32(dest_bmp, y, 0);
+								UINT32 *dest = &dest_bmp.pix32(y);
 								int cx = startx;
 								int cy = starty;
 
@@ -434,8 +419,7 @@ INLINE void roundupt_drawgfxzoomrotate(
 							for( y=sy; y<ey; y++ )
 							{
 								const UINT8 *source = code_base + (y_index>>16) * gfx->line_modulo;
-								UINT32 *dest = BITMAP_ADDR32(dest_bmp, y, 0);
-								UINT8 *priority_dest = BITMAP_ADDR8(dest_bmp, y, 0);
+								typename _BitmapClass::pixel_t *dest = &dest_bmp.pix(y);
 
 								int x, x_index = x_index_base;
 								for( x=sx; x<ex; x++ )
@@ -445,7 +429,7 @@ INLINE void roundupt_drawgfxzoomrotate(
 									{
 										// Only draw shadow pens if writing priority buffer
 										if (write_priority_only)
-											priority_dest[x]=shadow_pens[c];
+											dest[x]=shadow_pens[c];
 										else if (!shadow_pens[c])
 											dest[x]=pal[c];
 									}
@@ -463,9 +447,14 @@ INLINE void roundupt_drawgfxzoomrotate(
 	}
 }
 
-static void mycopyrozbitmap_core(bitmap_t *bitmap,bitmap_t *srcbitmap,
+static void mycopyrozbitmap_core(bitmap_ind8 &bitmap,bitmap_rgb32 &srcbitmap,
 		int dstx,int dsty, int srcwidth, int srcheight,int incxx,int incxy,int incyx,int incyy,
-		const rectangle *clip,int transparent_color)
+		const rectangle &clip,int transparent_color)
+{ }
+
+static void mycopyrozbitmap_core(bitmap_rgb32 &bitmap,bitmap_rgb32 &srcbitmap,
+		int dstx,int dsty, int srcwidth, int srcheight,int incxx,int incxy,int incyx,int incyy,
+		const rectangle &clip,int transparent_color)
 {
 	UINT32 cx;
 	UINT32 cy;
@@ -474,8 +463,8 @@ static void mycopyrozbitmap_core(bitmap_t *bitmap,bitmap_t *srcbitmap,
 	int sy;
 	int ex;
 	int ey;
-//  const int xmask = srcbitmap->width-1;
-//  const int ymask = srcbitmap->height-1;
+//  const int xmask = srcbitmap.width()-1;
+//  const int ymask = srcbitmap.height()-1;
 	const int widthshifted = srcwidth << 16;
 	const int heightshifted = srcheight << 16;
 	UINT32 *dest;
@@ -488,10 +477,10 @@ static void mycopyrozbitmap_core(bitmap_t *bitmap,bitmap_t *srcbitmap,
 	ex = dstx + srcwidth;
 	ey = dsty + srcheight;
 
-	if (sx<clip->min_x) sx=clip->min_x;
-	if (ex>clip->max_x) ex=clip->max_x;
-	if (sy<clip->min_y) sy=clip->min_y;
-	if (ey>clip->max_y) ey=clip->max_y;
+	if (sx<clip.min_x) sx=clip.min_x;
+	if (ex>clip.max_x) ex=clip.max_x;
+	if (sy<clip.min_y) sy=clip.min_y;
+	if (ey>clip.max_y) ey=clip.max_y;
 
 	if (sx <= ex)
 	{
@@ -501,13 +490,13 @@ static void mycopyrozbitmap_core(bitmap_t *bitmap,bitmap_t *srcbitmap,
 			x = sx;
 			cx = startx;
 			cy = starty;
-			dest = BITMAP_ADDR32(bitmap, sy, sx);
+			dest = &bitmap.pix32(sy, sx);
 
 			while (x <= ex)
 			{
 				if (cx < widthshifted && cy < heightshifted)
 				{
-					int c = *BITMAP_ADDR32(srcbitmap, cy >> 16, cx >> 16);
+					int c = srcbitmap.pix32(cy >> 16, cx >> 16);
 
 					if (c != transparent_color)
 						*dest = c;
@@ -525,7 +514,8 @@ static void mycopyrozbitmap_core(bitmap_t *bitmap,bitmap_t *srcbitmap,
 	}
 }
 
-static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect, int write_priority_only, int rambank)
+template<class _BitmapClass>
+static void draw_sprites(running_machine &machine, _BitmapClass &bitmap, const rectangle &cliprect, int write_priority_only, int rambank)
 {
 	tatsumi_state *state = machine.driver_data<tatsumi_state>();
 	UINT16 *spriteram16 = state->m_spriteram;
@@ -612,7 +602,7 @@ static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const recta
 		if (rotate)
 		{
 			render_y = 0;
-			bitmap_fill(state->m_temp_bitmap, 0, 0);
+			state->m_temp_bitmap.fill(0);
 		}
 
 		extent_x = extent_y = 0;
@@ -651,13 +641,13 @@ static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const recta
 
 				for (w = 0; w < x_width; w++) {
 					if (rotate)
-						roundupt_drawgfxzoomrotate(
+						roundupt_drawgfxzoomrotate(state,
 								state->m_temp_bitmap,cliprect,machine.gfx[0],
 								base,
 								color,flip_x,flip_y,x_pos,render_y,
 								scale,scale,0,write_priority_only);
 					else
-						roundupt_drawgfxzoomrotate(
+						roundupt_drawgfxzoomrotate(state,
 								bitmap,cliprect,machine.gfx[0],
 								base,
 								color,flip_x,flip_y,x_pos,render_y,
@@ -712,7 +702,7 @@ static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const recta
 	}
 }
 
-static void draw_sky(running_machine &machine, bitmap_t *bitmap,const rectangle *cliprect, int palette_base, int start_offset)
+static void draw_sky(running_machine &machine, bitmap_rgb32 &bitmap,const rectangle &cliprect, int palette_base, int start_offset)
 {
 	// all todo
 	int x,y;
@@ -729,12 +719,12 @@ start_offset-=48;
 			if (col<palette_base) col=palette_base;
 			if (col>palette_base+127) col=palette_base+127;
 
-			*BITMAP_ADDR32(bitmap, y, x) = machine.pens[col];
+			bitmap.pix32(y, x) = machine.pens[col];
 		}
 	}
 }
 
-static void draw_road(running_machine &machine, bitmap_t *bitmap,const rectangle *cliprect,bitmap_t *shadow_bitmap)
+static void draw_road(running_machine &machine, bitmap_rgb32 &bitmap,const rectangle &cliprect,bitmap_ind8 &shadow_bitmap)
 {
 	tatsumi_state *state = machine.driver_data<tatsumi_state>();
 /*
@@ -860,11 +850,11 @@ offset is from last pixel of first road segment?
 		/* Fill in left of road segment */
 		for (x=0; x<startPos && x<320; x++) {
 			int col = linedata[0]&0xf;
-			UINT8 shadow=*BITMAP_ADDR8(shadow_bitmap, y, x);
+			UINT8 shadow=shadow_bitmap.pix8(y, x);
 			if (shadow)
-				*BITMAP_ADDR32(bitmap, y, x) = machine.pens[768 + pal*16 + col];
+				bitmap.pix32(y, x) = machine.pens[768 + pal*16 + col];
 			else
-				*BITMAP_ADDR32(bitmap, y, x) = machine.pens[256 + pal*16 + col];
+				bitmap.pix32(y, x) = machine.pens[256 + pal*16 + col];
 		}
 
 		/* If startpos is negative, clip it and adjust the sampling position accordingly */
@@ -879,16 +869,16 @@ offset is from last pixel of first road segment?
 		for (x=startPos; x<320 && (samplePos>>11)<0x80; x++) {
 			// look up colour
 			int col = linedata[(samplePos>>11)&0x7f]&0xf;
-			UINT8 shadow=*BITMAP_ADDR8(shadow_bitmap, y, x);
+			UINT8 shadow=shadow_bitmap.pix8(y, x);
 
 			/* Clamp if we have reached the end of the pixel data */
 			//if ((samplePos>>11) > 0x7f)
 			//  col=linedata[0x7f]&0xf;
 
 			if (shadow)
-				*BITMAP_ADDR32(bitmap, y, x) = machine.pens[768 + pal*16 + col];
+				bitmap.pix32(y, x) = machine.pens[768 + pal*16 + col];
 			else
-				*BITMAP_ADDR32(bitmap, y, x) = machine.pens[256 + pal*16 + col];
+				bitmap.pix32(y, x) = machine.pens[256 + pal*16 + col];
 
 			samplePos+=step;
 		}
@@ -910,16 +900,16 @@ offset is from last pixel of first road segment?
 		/* Fill pixels */
 		for (x=startPos; x<320 && x<endPos; x++) {
 			int col = linedata[0x80]&0xf;
-			UINT8 shadow=*BITMAP_ADDR8(shadow_bitmap, y, x);
+			UINT8 shadow=shadow_bitmap.pix8(y, x);
 
 			/* Clamp if we have reached the end of the pixel data */
 			//if ((samplePos>>11) > 0x7f)
 			//  col=linedata[0x7f]&0xf;
 
 			if (shadow)
-				*BITMAP_ADDR32(bitmap, y, x) = machine.pens[768 + pal*16 + col + 32];
+				bitmap.pix32(y, x) = machine.pens[768 + pal*16 + col + 32];
 			else
-				*BITMAP_ADDR32(bitmap, y, x) = machine.pens[256 + pal*16 + col + 32];
+				bitmap.pix32(y, x) = machine.pens[256 + pal*16 + col + 32];
 		}
 
 		if (endPos<0) {
@@ -934,16 +924,16 @@ offset is from last pixel of first road segment?
 		for (/*x=endPos*/; x<320; x++) {
 			// look up colour
 			int col = linedata[((samplePos>>11)&0x7f) + 0x200]&0xf;
-			UINT8 shadow=*BITMAP_ADDR8(shadow_bitmap, y, x);
+			UINT8 shadow=shadow_bitmap.pix8(y, x);
 
 			/* Clamp if we have reached the end of the pixel data */
 			if ((samplePos>>11) > 0x7f)
 				col=linedata[0x7f + 0x200]&0xf;
 
 			if (shadow)
-				*BITMAP_ADDR32(bitmap, y, x) = machine.pens[768 + pal*16 + col + 32];
+				bitmap.pix32(y, x) = machine.pens[768 + pal*16 + col + 32];
 			else
-				*BITMAP_ADDR32(bitmap, y, x) = machine.pens[256 + pal*16 + col + 32];
+				bitmap.pix32(y, x) = machine.pens[256 + pal*16 + col + 32];
 
 			samplePos+=step;
 		}
@@ -988,14 +978,14 @@ static void update_cluts(running_machine &machine, int fake_palette_offset, int
 
 /**********************************************************************/
 
-static void draw_bg(running_machine &machine, bitmap_t *dst, tilemap_t *src, const UINT16* scrollx, const UINT16* scrolly, const UINT16* tilemap_ram, int tile_bank, int xscroll_offset, int yscroll_offset, int xsize, int ysize)
+static void draw_bg(running_machine &machine, bitmap_rgb32 &dst, tilemap_t *src, const UINT16* scrollx, const UINT16* scrolly, const UINT16* tilemap_ram, int tile_bank, int xscroll_offset, int yscroll_offset, int xsize, int ysize)
 {
 	/*
         Each tile (0x4000 of them) has a lookup table in ROM to build an individual 3-bit palette
         from sets of 8 bit palettes!
     */
 	const UINT8* tile_cluts = machine.region("gfx4")->base();
-	const bitmap_t *src_bitmap = tilemap_get_pixmap(src);
+	const bitmap_ind16 &src_bitmap = src->pixmap();
 	int src_y_mask=ysize-1;
 	int src_x_mask=xsize-1;
 	int tile_y_mask=(ysize/8)-1;
@@ -1013,19 +1003,19 @@ static void draw_bg(running_machine &machine, bitmap_t *dst, tilemap_t *src, con
 			int bank = (tile_bank >> (((tilemap_ram[(tile_index+0x400)&0x7fff]&0xc00)>>10)*4))&0xf;
 			int tile = (tilemap_ram[(tile_index+0x400)&0x7fff]&0x3ff) | (bank<<10);
 
-			p=*BITMAP_ADDR16(src_bitmap, src_y&src_y_mask, src_x&src_x_mask);
+			p=src_bitmap.pix16(src_y&src_y_mask, src_x&src_x_mask);
 			pp=tile_cluts[tile*8 + (p&0x7)];
 			ppp=pp + ((p&0x78)<<5);
 
 			if ((p&0x7)!=0 || ((p&0x7)==0 && (pp&0x7)!=0)) // Transparent pixels are set by both the tile pixel data==0 AND colour palette==0
-				*BITMAP_ADDR32(dst, y, x) = machine.pens[ppp];
+				dst.pix32(y, x) = machine.pens[ppp];
 		}
 	}
 }
 
 /* Draw the sky and ground, applying rotation (eventually). Experimental! */
 #if 0
-static void draw_ground(running_machine &machine, bitmap_t *dst, const rectangle *cliprect)
+static void draw_ground(running_machine &machine, bitmap_rgb32 &dst, const rectangle &cliprect)
 {
 	tatsumi_state *state = machine.driver_data<tatsumi_state>();
 	int x, y;
@@ -1034,7 +1024,7 @@ static void draw_ground(running_machine &machine, bitmap_t *dst, const rectangle
 	UINT16 gva = 0x180; // TODO
 	UINT8 sky_val = state->m_apache3_rotate_ctrl[1] & 0xff;
 
-	for (y = cliprect->min_y; y <= cliprect->max_y; ++y)
+	for (y = cliprect.min_y; y <= cliprect.max_y; ++y)
 	{
 		UINT16 rgdb = 0;//state->m_apache3_road_x_ram[gva & 0xff];
 		UINT16 gha = 0xf60; // test
@@ -1043,9 +1033,9 @@ static void draw_ground(running_machine &machine, bitmap_t *dst, const rectangle
 		if (gva & 0x100)
 		{
 			/* Sky */
-			for (x = cliprect->min_x; x <= cliprect->max_x; ++x)
+			for (x = cliprect.min_x; x <= cliprect.max_x; ++x)
 			{
-				*BITMAP_ADDR32(dst, y, x) = machine.pens[0x100 + (sky_val & 0x7f)];
+				dst.pix32(y, x) = machine.pens[0x100 + (sky_val & 0x7f)];
 
 				/* Update horizontal counter? */
 				gha = (gha + 1) & 0xfff;
@@ -1054,7 +1044,7 @@ static void draw_ground(running_machine &machine, bitmap_t *dst, const rectangle
 		else
 		{
 			/* Ground */
-			for (x = cliprect->min_x; x <= cliprect->max_x; ++x)
+			for (x = cliprect.min_x; x <= cliprect.max_x; ++x)
 			{
 				UINT8 colour;
 				UINT16 hval;
@@ -1075,7 +1065,7 @@ static void draw_ground(running_machine &machine, bitmap_t *dst, const rectangle
 				colour = (BIT(hval, 11) << 4) | (colour << 2) | ln;
 
 				/* Draw the pixel */
-				*BITMAP_ADDR32(dst, y, x) = machine.pens[0x200 + colour];
+				dst.pix32(y, x) = machine.pens[0x200 + colour];
 
 				/* Update horizontal counter */
 				gha = (gha + 1) & 0xfff;
@@ -1090,87 +1080,87 @@ static void draw_ground(running_machine &machine, bitmap_t *dst, const rectangle
 #endif
 /**********************************************************************/
 
-SCREEN_UPDATE( apache3 )
+SCREEN_UPDATE_RGB32( apache3 )
 {
-	tatsumi_state *state = screen->machine().driver_data<tatsumi_state>();
-	update_cluts(screen->machine(), 1024, 0, 2048);
+	tatsumi_state *state = screen.machine().driver_data<tatsumi_state>();
+	update_cluts(screen.machine(), 1024, 0, 2048);
 
-	tilemap_set_scrollx(state->m_tx_layer,0,24);
+	state->m_tx_layer->set_scrollx(0,24);
 
-	bitmap_fill(bitmap,cliprect,screen->machine().pens[0]);
-	draw_sky(screen->machine(), bitmap, cliprect, 256, state->m_apache3_rotate_ctrl[1]);
-//  draw_ground(screen->machine(), bitmap, cliprect);
-	draw_sprites(screen->machine(), bitmap,cliprect,0, (state->m_sprite_control_ram[0x20]&0x1000) ? 0x1000 : 0);
-	tilemap_draw(bitmap,cliprect,state->m_tx_layer,0,0);
+	bitmap.fill(screen.machine().pens[0], cliprect);
+	draw_sky(screen.machine(), bitmap, cliprect, 256, state->m_apache3_rotate_ctrl[1]);
+//  draw_ground(screen.machine(), bitmap, cliprect);
+	draw_sprites(screen.machine(), bitmap,cliprect,0, (state->m_sprite_control_ram[0x20]&0x1000) ? 0x1000 : 0);
+	state->m_tx_layer->draw(bitmap, cliprect, 0,0);
 	return 0;
 }
 
-SCREEN_UPDATE( roundup5 )
+SCREEN_UPDATE_RGB32( roundup5 )
 {
-	tatsumi_state *state = screen->machine().driver_data<tatsumi_state>();
+	tatsumi_state *state = screen.machine().driver_data<tatsumi_state>();
 //  UINT16 bg_x_scroll=state->m_roundup5_unknown1[0];
 //  UINT16 bg_y_scroll=state->m_roundup5_unknown2[0];
 
-	update_cluts(screen->machine(), 1024, 512, 4096);
+	update_cluts(screen.machine(), 1024, 512, 4096);
 
-	tilemap_set_scrollx(state->m_tx_layer,0,24);
-	tilemap_set_scrolly(state->m_tx_layer,0,0); //(((state->m_roundupt_crt_reg[0xe]<<8)|state->m_roundupt_crt_reg[0xf])>>5) + 96);
+	state->m_tx_layer->set_scrollx(0,24);
+	state->m_tx_layer->set_scrolly(0,0); //(((state->m_roundupt_crt_reg[0xe]<<8)|state->m_roundupt_crt_reg[0xf])>>5) + 96);
 
-	bitmap_fill(bitmap,cliprect,screen->machine().pens[384]); // todo
-	bitmap_fill(screen->machine().priority_bitmap,cliprect,0);
+	bitmap.fill(screen.machine().pens[384], cliprect); // todo
+	screen.machine().priority_bitmap.fill(0, cliprect);
 
-	draw_sprites(screen->machine(), screen->machine().priority_bitmap,cliprect,1,(state->m_sprite_control_ram[0xe0]&0x1000) ? 0x1000 : 0); // Alpha pass only
-	draw_road(screen->machine(), bitmap,cliprect,screen->machine().priority_bitmap);
-	draw_sprites(screen->machine(), bitmap,cliprect,0,(state->m_sprite_control_ram[0xe0]&0x1000) ? 0x1000 : 0); // Full pass
-	tilemap_draw(bitmap,cliprect,state->m_tx_layer,0,0);
+	draw_sprites(screen.machine(), screen.machine().priority_bitmap,cliprect,1,(state->m_sprite_control_ram[0xe0]&0x1000) ? 0x1000 : 0); // Alpha pass only
+	draw_road(screen.machine(), bitmap,cliprect,screen.machine().priority_bitmap);
+	draw_sprites(screen.machine(), bitmap,cliprect,0,(state->m_sprite_control_ram[0xe0]&0x1000) ? 0x1000 : 0); // Full pass
+	state->m_tx_layer->draw(bitmap, cliprect, 0,0);
 	return 0;
 }
 
-SCREEN_UPDATE( cyclwarr )
+SCREEN_UPDATE_RGB32( cyclwarr )
 {
-	tatsumi_state *state = screen->machine().driver_data<tatsumi_state>();
+	tatsumi_state *state = screen.machine().driver_data<tatsumi_state>();
 	state->m_bigfight_bank=state->m_bigfight_a40000[0];
 	if (state->m_bigfight_bank!=state->m_bigfight_last_bank)
 	{
-		tilemap_mark_all_tiles_dirty(state->m_layer0);
-		tilemap_mark_all_tiles_dirty(state->m_layer1);
-		tilemap_mark_all_tiles_dirty(state->m_layer2);
-		tilemap_mark_all_tiles_dirty(state->m_layer3);
+		state->m_layer0->mark_all_dirty();
+		state->m_layer1->mark_all_dirty();
+		state->m_layer2->mark_all_dirty();
+		state->m_layer3->mark_all_dirty();
 		state->m_bigfight_last_bank=state->m_bigfight_bank;
 	}
 
-	bitmap_fill(bitmap,cliprect,screen->machine().pens[0]);
+	bitmap.fill(screen.machine().pens[0], cliprect);
 
-	draw_bg(screen->machine(), bitmap, state->m_layer3, &state->m_cyclwarr_videoram1[0x000], &state->m_cyclwarr_videoram1[0x100], state->m_cyclwarr_videoram1, state->m_bigfight_a40000[0], 8, -0x80, 512, 4096);
-	draw_bg(screen->machine(), bitmap, state->m_layer2, &state->m_cyclwarr_videoram1[0x200], &state->m_cyclwarr_videoram1[0x300], state->m_cyclwarr_videoram1, state->m_bigfight_a40000[0], 8, -0x80, 512, 4096);
-	draw_bg(screen->machine(), bitmap, state->m_layer1, &state->m_cyclwarr_videoram0[0x000], &state->m_cyclwarr_videoram0[0x100], state->m_cyclwarr_videoram0, state->m_bigfight_a40000[0], 8, -0x40, 1024, 2048);
-	update_cluts(screen->machine(), 8192, 4096, 8192);
-	draw_sprites(screen->machine(), bitmap,cliprect,0,(state->m_sprite_control_ram[0xe0]&0x1000) ? 0x1000 : 0);
-	draw_bg(screen->machine(), bitmap, state->m_layer0, &state->m_cyclwarr_videoram0[0x200], &state->m_cyclwarr_videoram0[0x300], state->m_cyclwarr_videoram0, state->m_bigfight_a40000[0], 0x10, -0x80, 512, 4096);
+	draw_bg(screen.machine(), bitmap, state->m_layer3, &state->m_cyclwarr_videoram1[0x000], &state->m_cyclwarr_videoram1[0x100], state->m_cyclwarr_videoram1, state->m_bigfight_a40000[0], 8, -0x80, 512, 4096);
+	draw_bg(screen.machine(), bitmap, state->m_layer2, &state->m_cyclwarr_videoram1[0x200], &state->m_cyclwarr_videoram1[0x300], state->m_cyclwarr_videoram1, state->m_bigfight_a40000[0], 8, -0x80, 512, 4096);
+	draw_bg(screen.machine(), bitmap, state->m_layer1, &state->m_cyclwarr_videoram0[0x000], &state->m_cyclwarr_videoram0[0x100], state->m_cyclwarr_videoram0, state->m_bigfight_a40000[0], 8, -0x40, 1024, 2048);
+	update_cluts(screen.machine(), 8192, 4096, 8192);
+	draw_sprites(screen.machine(), bitmap,cliprect,0,(state->m_sprite_control_ram[0xe0]&0x1000) ? 0x1000 : 0);
+	draw_bg(screen.machine(), bitmap, state->m_layer0, &state->m_cyclwarr_videoram0[0x200], &state->m_cyclwarr_videoram0[0x300], state->m_cyclwarr_videoram0, state->m_bigfight_a40000[0], 0x10, -0x80, 512, 4096);
 
 	return 0;
 }
 
-SCREEN_UPDATE( bigfight )
+SCREEN_UPDATE_RGB32( bigfight )
 {
-	tatsumi_state *state = screen->machine().driver_data<tatsumi_state>();
+	tatsumi_state *state = screen.machine().driver_data<tatsumi_state>();
 	state->m_bigfight_bank=state->m_bigfight_a40000[0];
 	if (state->m_bigfight_bank!=state->m_bigfight_last_bank)
 	{
-		tilemap_mark_all_tiles_dirty(state->m_layer0);
-		tilemap_mark_all_tiles_dirty(state->m_layer1);
-		tilemap_mark_all_tiles_dirty(state->m_layer2);
-		tilemap_mark_all_tiles_dirty(state->m_layer3);
+		state->m_layer0->mark_all_dirty();
+		state->m_layer1->mark_all_dirty();
+		state->m_layer2->mark_all_dirty();
+		state->m_layer3->mark_all_dirty();
 		state->m_bigfight_last_bank=state->m_bigfight_bank;
 	}
 
-	bitmap_fill(bitmap,cliprect,screen->machine().pens[0]);
-	draw_bg(screen->machine(), bitmap, state->m_layer3, &state->m_cyclwarr_videoram1[0x000], &state->m_cyclwarr_videoram1[0x100], state->m_cyclwarr_videoram1, state->m_bigfight_a40000[0], 8, -0x40, 1024, 2048);
-	draw_bg(screen->machine(), bitmap, state->m_layer2, &state->m_cyclwarr_videoram1[0x200], &state->m_cyclwarr_videoram1[0x300], state->m_cyclwarr_videoram1, state->m_bigfight_a40000[0], 8, -0x40, 1024, 2048);
-	draw_bg(screen->machine(), bitmap, state->m_layer1, &state->m_cyclwarr_videoram0[0x000], &state->m_cyclwarr_videoram0[0x100], state->m_cyclwarr_videoram0, state->m_bigfight_a40000[0], 8, -0x40, 1024, 2048);
-	update_cluts(screen->machine(), 8192, 4096, 8192);
-	draw_sprites(screen->machine(), bitmap,cliprect,0,(state->m_sprite_control_ram[0xe0]&0x1000) ? 0x1000 : 0);
-	draw_bg(screen->machine(), bitmap, state->m_layer0, &state->m_cyclwarr_videoram0[0x200], &state->m_cyclwarr_videoram0[0x300], state->m_cyclwarr_videoram0, state->m_bigfight_a40000[0], 0x10, -0x40, 1024, 2048);
+	bitmap.fill(screen.machine().pens[0], cliprect);
+	draw_bg(screen.machine(), bitmap, state->m_layer3, &state->m_cyclwarr_videoram1[0x000], &state->m_cyclwarr_videoram1[0x100], state->m_cyclwarr_videoram1, state->m_bigfight_a40000[0], 8, -0x40, 1024, 2048);
+	draw_bg(screen.machine(), bitmap, state->m_layer2, &state->m_cyclwarr_videoram1[0x200], &state->m_cyclwarr_videoram1[0x300], state->m_cyclwarr_videoram1, state->m_bigfight_a40000[0], 8, -0x40, 1024, 2048);
+	draw_bg(screen.machine(), bitmap, state->m_layer1, &state->m_cyclwarr_videoram0[0x000], &state->m_cyclwarr_videoram0[0x100], state->m_cyclwarr_videoram0, state->m_bigfight_a40000[0], 8, -0x40, 1024, 2048);
+	update_cluts(screen.machine(), 8192, 4096, 8192);
+	draw_sprites(screen.machine(), bitmap,cliprect,0,(state->m_sprite_control_ram[0xe0]&0x1000) ? 0x1000 : 0);
+	draw_bg(screen.machine(), bitmap, state->m_layer0, &state->m_cyclwarr_videoram0[0x200], &state->m_cyclwarr_videoram0[0x300], state->m_cyclwarr_videoram0, state->m_bigfight_a40000[0], 0x10, -0x40, 1024, 2048);
 
 	return 0;
 }
