@@ -71,14 +71,14 @@ WRITE8_HANDLER( thedeep_vram_0_w )
 {
 	thedeep_state *state = space->machine().driver_data<thedeep_state>();
 	state->m_vram_0[offset] = data;
-	tilemap_mark_tile_dirty(state->m_tilemap_0, offset / 2);
+	state->m_tilemap_0->mark_tile_dirty(offset / 2);
 }
 
 WRITE8_HANDLER( thedeep_vram_1_w )
 {
 	thedeep_state *state = space->machine().driver_data<thedeep_state>();
 	state->m_vram_1[offset] = data;
-	tilemap_mark_tile_dirty(state->m_tilemap_1, offset / 2);
+	state->m_tilemap_1->mark_tile_dirty(offset / 2);
 }
 
 
@@ -107,10 +107,10 @@ VIDEO_START( thedeep )
 	state->m_tilemap_0  = tilemap_create(machine, get_tile_info_0,tilemap_scan_rows_back,16,16,0x20,0x20);
 	state->m_tilemap_1  = tilemap_create(machine, get_tile_info_1,tilemap_scan_rows,8,8,0x20,0x20);
 
-	tilemap_set_transparent_pen( state->m_tilemap_0,  0 );
-	tilemap_set_transparent_pen( state->m_tilemap_1,  0 );
+	state->m_tilemap_0->set_transparent_pen(0 );
+	state->m_tilemap_1->set_transparent_pen(0 );
 
-	tilemap_set_scroll_cols(state->m_tilemap_0, 0x20);	// column scroll for the background
+	state->m_tilemap_0->set_scroll_cols(0x20);	// column scroll for the background
 }
 
 /***************************************************************************
@@ -147,7 +147,7 @@ Offset:     Bits:       Value:
 
 ***************************************************************************/
 
-static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	thedeep_state *state = machine.driver_data<thedeep_state>();
 	UINT8 *s = state->m_spriteram, *end = s + state->m_spriteram_size;
@@ -209,25 +209,25 @@ static void draw_sprites(running_machine &machine, bitmap_t *bitmap, const recta
 
 ***************************************************************************/
 
-SCREEN_UPDATE( thedeep )
+SCREEN_UPDATE_IND16( thedeep )
 {
-	thedeep_state *state = screen->machine().driver_data<thedeep_state>();
+	thedeep_state *state = screen.machine().driver_data<thedeep_state>();
 	int scrollx = state->m_scroll[0] + (state->m_scroll[1]<<8);
 	int scrolly = state->m_scroll[2] + (state->m_scroll[3]<<8);
 	int x;
 
-	tilemap_set_scrollx(state->m_tilemap_0, 0, scrollx);
+	state->m_tilemap_0->set_scrollx(0, scrollx);
 
 	for (x = 0; x < 0x20; x++)
 	{
 		int y = state->m_scroll2[x*2+0] + (state->m_scroll2[x*2+1]<<8);
-		tilemap_set_scrolly(state->m_tilemap_0, x, y + scrolly);
+		state->m_tilemap_0->set_scrolly(x, y + scrolly);
 	}
 
-	bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine()));
+	bitmap.fill(get_black_pen(screen.machine()), cliprect);
 
-	tilemap_draw(bitmap,cliprect,state->m_tilemap_0,0,0);
-	draw_sprites(screen->machine(), bitmap,cliprect);
-	tilemap_draw(bitmap,cliprect,state->m_tilemap_1,0,0);
+	state->m_tilemap_0->draw(bitmap, cliprect, 0,0);
+	draw_sprites(screen.machine(), bitmap,cliprect);
+	state->m_tilemap_1->draw(bitmap, cliprect, 0,0);
 	return 0;
 }
