@@ -16,7 +16,7 @@ PALETTE_INIT( tia_NTSC );
 PALETTE_INIT( tia_PAL );
 
 VIDEO_START( tia );
-SCREEN_UPDATE( tia );
+SCREEN_UPDATE_IND16( tia );
 
 READ8_HANDLER( tia_r );
 WRITE8_HANDLER( tia_w );
