@@ -20,7 +20,7 @@ static TILE_GET_INFO( get_tile_info )
 VIDEO_START( triplhnt )
 {
 	triplhnt_state *state = machine.driver_data<triplhnt_state>();
-	state->m_helper = machine.primary_screen->alloc_compatible_bitmap();
+	machine.primary_screen->register_screen_bitmap(state->m_helper);
 
 	state->m_bg_tilemap = tilemap_create(machine, get_tile_info, tilemap_scan_rows, 16, 16, 16, 16);
 }
@@ -32,7 +32,7 @@ static TIMER_CALLBACK( triplhnt_hit_callback )
 }
 
 
-static void draw_sprites(running_machine &machine, bitmap_t* bitmap, const rectangle* cliprect)
+static void draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	triplhnt_state *state = machine.driver_data<triplhnt_state>();
 	int i;
@@ -59,17 +59,11 @@ static void draw_sprites(running_machine &machine, bitmap_t* bitmap, const recta
 
 		if (state->m_sprite_zoom)
 		{
-			rect.min_x = hpos - 16;
-			rect.min_y = 196 - vpos;
-			rect.max_x = rect.min_x + 63;
-			rect.max_y = rect.min_y + 63;
+			rect.set(hpos - 16, hpos - 16 + 63, 196 - vpos, 196 - vpos + 63);
 		}
 		else
 		{
-			rect.min_x = hpos - 16;
-			rect.min_y = 224 - vpos;
-			rect.max_x = rect.min_x + 31;
-			rect.max_y = rect.min_y + 31;
+			rect.set(hpos - 16, hpos - 16 + 31, 224 - vpos, 224 - vpos + 31);
 		}
 
 		/* render sprite to auxiliary bitmap */
@@ -78,14 +72,7 @@ static void draw_sprites(running_machine &machine, bitmap_t* bitmap, const recta
 			2 * code + state->m_sprite_bank, 0, code & 8, 0,
 			rect.min_x, rect.min_y);
 
-		if (rect.min_x < cliprect->min_x)
-			rect.min_x = cliprect->min_x;
-		if (rect.min_y < cliprect->min_y)
-			rect.min_y = cliprect->min_y;
-		if (rect.max_x > cliprect->max_x)
-			rect.max_x = cliprect->max_x;
-		if (rect.max_y > cliprect->max_y)
-			rect.max_y = cliprect->max_y;
+		rect &= cliprect;
 
 		/* check for collisions and copy sprite */
 
@@ -97,8 +84,8 @@ static void draw_sprites(running_machine &machine, bitmap_t* bitmap, const recta
 			{
 				for (y = rect.min_y; y <= rect.max_y; y++)
 				{
-					pen_t a = *BITMAP_ADDR16(state->m_helper, y, x);
-					pen_t b = *BITMAP_ADDR16(bitmap, y, x);
+					pen_t a = state->m_helper.pix16(y, x);
+					pen_t b = bitmap.pix16(y, x);
 
 					if (a == 2 && b == 7)
 					{
@@ -107,7 +94,7 @@ static void draw_sprites(running_machine &machine, bitmap_t* bitmap, const recta
 					}
 
 					if (a != 1)
-						*BITMAP_ADDR16(bitmap, y, x) = a;
+						bitmap.pix16(y, x) = a;
 				}
 			}
 		}
@@ -118,16 +105,16 @@ static void draw_sprites(running_machine &machine, bitmap_t* bitmap, const recta
 }
 
 
-SCREEN_UPDATE( triplhnt )
+SCREEN_UPDATE_IND16( triplhnt )
 {
-	triplhnt_state *state = screen->machine().driver_data<triplhnt_state>();
-	device_t *discrete = screen->machine().device("discrete");
+	triplhnt_state *state = screen.machine().driver_data<triplhnt_state>();
+	device_t *discrete = screen.machine().device("discrete");
 
-	tilemap_mark_all_tiles_dirty(state->m_bg_tilemap);
+	state->m_bg_tilemap->mark_all_dirty();
 
-	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
+	state->m_bg_tilemap->draw(bitmap, cliprect, 0, 0);
 
-	draw_sprites(screen->machine(), bitmap, cliprect);
+	draw_sprites(screen.machine(), bitmap, cliprect);
 
 	discrete_sound_w(discrete, TRIPLHNT_BEAR_ROAR_DATA, state->m_playfield_ram[0xfa] & 15);
 	discrete_sound_w(discrete, TRIPLHNT_SHOT_DATA, state->m_playfield_ram[0xfc] & 15);
