@@ -19,19 +19,19 @@ to switch between 8*8 tiles and 16*16 tiles.
 #include "video/decospr.h"
 
 
-SCREEN_UPDATE( tumblep )
+SCREEN_UPDATE_IND16( tumblep )
 {
-	tumblep_state *state = screen->machine().driver_data<tumblep_state>();
+	tumblep_state *state = screen.machine().driver_data<tumblep_state>();
 	UINT16 flip = deco16ic_pf_control_r(state->m_deco_tilegen1, 0, 0xffff);
 
-	flip_screen_set(screen->machine(), BIT(flip, 7));
+	flip_screen_set(screen.machine(), BIT(flip, 7));
 	deco16ic_pf_update(state->m_deco_tilegen1, state->m_pf1_rowscroll, state->m_pf2_rowscroll);
 
-	bitmap_fill(bitmap, cliprect, 256); /* not verified */
+	bitmap.fill(256, cliprect); /* not verified */
 
 	deco16ic_tilemap_2_draw(state->m_deco_tilegen1, bitmap, cliprect, TILEMAP_DRAW_OPAQUE, 0);
 	deco16ic_tilemap_1_draw(state->m_deco_tilegen1, bitmap, cliprect, 0, 0);
 
-	screen->machine().device<decospr_device>("spritegen")->draw_sprites(screen->machine(), bitmap, cliprect, state->m_spriteram, 0x400);
+	screen.machine().device<decospr_device>("spritegen")->draw_sprites(bitmap, cliprect, state->m_spriteram, 0x400);
 	return 0;
 }
